# 数据库的规范化

> 原文：<https://www.studytonight.com/dbms/database-normalization.php>

数据库规范化是一种组织数据库中数据的技术。规范化是一种分解表的系统方法，以消除数据冗余(重复)和不良特征，如插入、更新和删除异常。这是一个多步骤的过程，将数据放入表格形式，从关系表中删除重复的数据。

标准化主要用于两个目的，

*   消除冗余(无用)数据。
*   确保数据相关性有意义，即数据是逻辑存储的。

下面的**视频**会给你一个很好的数据库规范化的概述。如果你愿意，你可以跳过视频，因为这个概念在视频下面有详细的介绍。

* * *

## 没有规范化的问题

如果一个表没有适当地规范化，并且有数据冗余，那么它不仅会消耗额外的内存空间，而且会使处理和更新数据库变得困难，而不会面临数据丢失。如果数据库没有规范化，插入、更新和删除异常会非常频繁。为了理解这些异常，让我们举一个**学生**表的例子。

| 滚装船 | 名字 | 树枝 | 煤斗 | office_tel |
| Four hundred and one | 阿康 | 中学生毕业考试 | 薛汀哲 | Fifty-three thousand three hundred and thirty-seven |
| Four hundred and two | Bkon | 中学生毕业考试 | 薛汀哲 | Fifty-three thousand three hundred and thirty-seven |
| Four hundred and three | Ckon 先生 | 中学生毕业考试 | 薛汀哲 | Fifty-three thousand three hundred and thirty-seven |
| Four hundred and four | Dkon | 中学生毕业考试 | 薛汀哲 | Fifty-three thousand three hundred and thirty-seven |

在上表中，我们有 4 个计算机科学的数据。学生。我们可以看到，对于学院内同一个分支的学生重复`branch`、`hod`(系主任)和`office_tel`字段的数据，这就是**数据冗余**。

* * *

#### 插入异常

假设对于新的录取，除非学生选择了分支，否则不能插入该学生的数据，否则我们将不得不将分支信息设置为**空**。

此外，如果我们必须插入同一分支的 100 名学生的数据，则分支信息将对所有这 100 名学生重复。

这些场景只不过是**插入异常**。

* * *

#### 上升异常

如果 X 先生离开学院怎么办？还是不再是计算机科学系的 HOD？在这种情况下，所有的学生记录都必须更新，如果我们误错过了任何记录，这将导致数据不一致。这是上升异常。

* * *

#### 删除异常

在我们的**学生**表中，两个不同的信息保存在一起，学生信息和分支信息。因此，在学年结束时，如果学生记录被删除，我们也会丢失分支信息。这是删除异常。

* * *

## 规范化规则

规范化规则分为以下几种正常形式:

1.  第一范式
2.  第二范式
3.  第三范式
4.  BCNF(中央银行)
5.  第四范式

* * *

### 第一范式(1NF)

对于第一范式的表格，应遵循以下 4 条规则:

1.  它应该只有单(原子)值属性/列。
2.  存储在列中的值应该属于同一域
3.  表中的所有列都应该有唯一的名称。
4.  数据存储的顺序也无关紧要。

在下一个教程中，我们将详细讨论 [**第一范式**](first-normal-form.php) 。

* * *

### 第二范式(2NF)

对于处于第二范式的表，

1.  应该是第一范式。
2.  而且，它不应该有部分依赖。

要了解什么是部分依赖，以及如何将表规范化为第二范式，请跳转到 [**第二范式**](second-normal-form.php) 教程。

* * *

### 第三范式(3NF)

当一个表处于第三范式时，

1.  它是第二范式。
2.  而且，它没有传递依赖。

这里是 [**第三范式**](third-normal-form.php) 教程。但是我们建议你先学习第二范式，然后转向第三范式。

* * *

### 博伊斯和柯德范式(BCNF)

**Boyce 和 Codd 范式**是第三范式的更高版本。此表单处理 3NF 无法处理的特定类型的异常。没有多个重叠候选关键字的 3NF 表被称为在 BCNF。一张桌子要放在 BCNF，必须满足以下条件:

*   r 必须是第三范式
*   并且，对于每个函数依赖(X → Y)，X 应该是一个超级键。

要通过一个非常容易理解的例子详细了解 BCNF，请前往 [**博耶-科德范式**](boyce-codd-normal-form.php) 教程。

* * *

### 第四范式(4NF)

当一个表处于第四范式时，

1.  这是在博伊斯-科德范式。
2.  而且，它没有多值依赖。

这里是 [**第四范式**](fourth-normal-form.php) 教程。但是我们建议你在进入第四范式之前先了解其他范式。

* * *

* * *