# 什么是第一范式（1NF）？

> 原文：<https://www.studytonight.com/dbms/first-normal-form.php>

在本教程中，我们将学习第一(第一)范式，它更像规范化过程的第一步。第一范式期望您以这样一种方式设计您的表，即它可以很容易地扩展，并且在需要时更容易从中检索数据。

在上一个教程中，我们学习并理解了数据冗余或重复如何导致插入、删除和更新异常等几个问题，以及**归一化**如何减少数据冗余并使数据更有意义。

> 如果数据库中的表甚至不是第一范式，则认为**数据库设计不良**。

* * *

## 第一范式规则

第一种范式要求您在设计数据库时遵循一些简单的规则，它们是:

#### 规则 1:单值属性

表中的每一列都应该是单值的，这意味着它们不应该包含多个值。稍后我们将通过一个例子来解释这一点，现在让我们看看其他规则。

* * *

#### 规则 2:属性域不应该改变

这更像是一个“常识”规则。在每一列中，存储的值必须是相同的类型。

**例如:**如果你有一栏`dob`来保存一组人的出生日期，那么你不能或者不可以将其中一些人的“姓名”和其他人的“出生日期”一起保存在该栏中。它应该只保存所有记录/行的“出生日期”。

* * *

#### 规则 3:属性/列的唯一名称

此规则要求表中的每一列都应有唯一的名称。这是为了避免在检索数据或对存储的数据执行任何其他操作时出现混乱。

如果一个或多个列有相同的名称，那么 DBMS 将会混乱。

* * *

#### 规则 4:秩序不重要

这条规则说，您在表中存储数据的顺序并不重要。

* * *

## 举个例子

虽然所有的规则都是不言自明的，但让我们举一个例子，我们将创建一个表来存储学生数据，其中将有学生的学号、他们的姓名和他们选择的科目名称。

这是我们的表格，其中添加了一些示例数据。

| 滚动 _ 否 | 名字 | 科目 |
| One hundred and one | 阿康 | 操作系统，CN |
| One hundred and three | Ckon 先生 | 爪哇 |
| One hundred and two | Bkon | C，C++ |

我们的表已经满足了 4 个规则中的 3 个，因为我们所有的列名都是唯一的，我们已经按照我们想要的顺序存储了数据，并且没有在列中混合不同类型的数据。

但是在我们表中的 3 个不同的学生中，有 2 个选择了不止一个科目。我们将主题名称存储在一个单独的列中。但是根据第一范式，每一列必须包含原子值。

### 如何解决这个问题？

这很简单，因为我们所要做的就是将这些值分解成原子值。

这是我们更新的表格，它现在满足第一范式。

| 滚动 _ 否 | 名字 | 科目 |
| One hundred and one | 阿康 | 旧历法 |
| One hundred and one | 阿康 | 通信网络（Communicating Net 的缩写） |
| One hundred and three | Ckon 先生 | 爪哇 |
| One hundred and two | Bkon | C |
| One hundred and two | Bkon | C++ |

通过这样做，虽然一些值被重复，但是`subject`列的值现在对于每个记录/行都是原子的。

使用第一范式，数据冗余增加，因为多行中将有许多列具有相同的数据，但每行作为一个整体将是唯一的。

* * *

* * *