# 什么是第二范式？

> 原文：<https://www.studytonight.com/dbms/second-normal-form.php>

对于处于第二范式的表，它必须满足两个条件:

1.  表格应该是第一范式。
2.  不应该有部分依赖。

如果你愿意，你可以跳过视频，因为这个概念将在视频下面详细介绍。

什么是**部分依赖**？别担心。首先让我们了解一下什么是表中的**依赖关系**？

* * *

## 什么是依赖？

我们举一个**学生**表的例子，表中有`student_id`、`name`、`reg_no`(注册号)、`branch`和`address`(学生家庭住址)。

| 学生 id | 名字 | reg_no | 树枝 | 地址 |
|  |  |  |  |  |
|  |  |  |  |  |
|  |  |  |  |  |

在这个表中，`student_id`是主键，对于每一行都是唯一的，因此我们可以使用`student_id`从这个表中获取任何一行数据

即使对于学生姓名相同的情况，如果我们知道`student_id`，我们也可以很容易地获取正确的记录。

| 学生 id | 名字 | reg_no | 树枝 | 地址 |
| Ten | 阿康 | 07-WY | 中学生毕业考试 | 喀拉拉邦 |
| Eleven | 阿康 | 08-WY | 信息技术 | 古吉拉特邦 |

因此，我们可以说一个表的**主键**是一列或一组列(复合键)，它可以唯一地标识表中的每条记录。

我可以用`student_id` **10** 从学生的分支机构名称中询问，我就能得到。同样，如果我用`student_id` **10** 或 **11** 询问学生姓名，我也会得到。所以我所需要的就是`student_id`并且每隔一列**都依赖于它，或者可以用它来获取。**

这就是**依赖**，我们也称之为**功能依赖**。

* * *

## 什么是部分依赖？

既然我们知道了什么是依赖，我们就能更好地理解什么是部分依赖。

对于像 Student 这样的简单表，像`student_id`这样的单个列可以唯一识别表中的所有记录。

但这并不总是正确的。现在，让我们扩展我们的示例，看看是否有超过 1 列可以一起充当主键。

让我们为**主题**创建另一个表，它将有`subject_id`和`subject_name`字段，`subject_id`将是主键。

| 主题 id | 主题名称 |
| one | 爪哇 |
| Two | C++ |
| three | 服务器端编程语言（Professional Hypertext Preprocessor 的缩写） |

现在我们有一个包含学生信息的**学生**表和另一个存储科目信息的**科目**表。

让我们创建另一个表格**分数**，以存储学生在各自科目中获得的**分数**。我们还将保留教授该科目的老师的名字**以及分数。**

| 分数 _id | 学生 id | 主题 id | 记号 | 教师 |
| one | Ten | one | Seventy | Java 老师 |
| Two | Ten | Two | Seventy-five | C++老师 |
| three | Eleven | one | Eighty | Java 老师 |

在评分表中，我们保存**学生证**以了解这些是哪个学生的分数，**学科学生证**以了解这些分数是哪个学科的。

`student_id + subject_id`共同构成此表的**候选键**(了解[数据库键](database-key.php)，可以是**主键**。

困惑，这个组合怎么可能是主键？

看，如果我让你给我拿`student_id` 10 的学生分数，你能从这张表中得到吗？不，因为你不知道哪个科目。如果我给你`subject_id`，你就不知道是哪个学生了。因此我们需要`student_id + subject_id`来唯一识别任何一行。

### 但是部分依赖在哪里？

现在如果你看一下**分数**表，我们有一个列名`teacher`，它只依赖于主题，对于 Java 是 Java 老师，对于 C++是 C++老师&等等。

正如我们刚才讨论的，这个表的主键是由两列组成的`student_id` & `subject_id`，但是老师的名字只取决于科目，因此有了`subject_id`，与`student_id`无关。

这就是**部分依赖**，表中的属性只依赖于主键的一部分，而不依赖于整个键。

* * *

## 如何删除部分依赖？

对此可以有许多不同的解决方案，但我们的目标是从分数表中删除教师的姓名。

最简单的解决方法是从 Score 表中删除列`teacher`，并将其添加到 Subject 表中。因此，主题表将变成:

| 主题 id | 主题名称 | 教师 |
| one | 爪哇 | Java 老师 |
| Two | C++ | C++老师 |
| three | 服务器端编程语言（Professional Hypertext Preprocessor 的缩写） | Php 老师 |

我们的分数表现在是第二范式，没有部分依赖。

| 分数 _id | 学生 id | 主题 id | 记号 |
| one | Ten | one | Seventy |
| Two | Ten | Two | Seventy-five |
| three | Eleven | one | Eighty |

* * *

## 快速回顾

1.  对于处于第二范式的表，它应该处于第一范式，并且不应该具有部分依赖关系。
2.  当对于复合主键，表中的任何属性只依赖于主键的一部分，而不依赖于完整的主键时，就存在部分依赖关系。
3.  为了移除部分依赖，我们可以划分表，移除导致部分依赖的属性，并将其移动到其他表中，在那里它很适合。

* * *

* * *