# `COMMIT`、`ROLLBACK`和`SAVEPOINT`命令

> 原文：<https://www.studytonight.com/dbms/tcl-command.php>

事务控制语言(TCL)命令用于管理[数据库](overview-of-dbms.php)中的事务。

在继续使用 TCL 命令之前，请先检查以下主题:

*   [DML 命令](dml-command.php)
*   [驾驶员侧车门开关指令](create-query.php)

这些用于管理 DML 语句对表中数据所做的更改。它还允许将语句组合成逻辑事务。

* * *

## `COMMIT`命令

`COMMIT`命令用于将任何事务永久保存到数据库中。

当我们使用像`INSERT`、`UPDATE`或`DELETE`这样的任何 DML 命令时，这些命令所做的更改不是永久的，直到当前会话关闭，这些命令所做的更改才能回滚。

为了避免这种情况，我们使用`COMMIT`命令将更改标记为永久。

下面是 commit 命令语法，

```sql
COMMIT;
```

* * *

## `ROLLBACK`命令

此命令将数据库恢复到上次提交的状态。它还与`SAVEPOINT`命令一起使用，以跳转到正在进行的事务中的保存点。

如果我们已经使用`UPDATE`命令对数据库进行了一些更改，并且意识到这些更改不是必需的，那么我们可以使用`ROLLBACK`命令回滚这些更改，如果它们不是使用`COMMIT`命令提交的话。

以下是回滚命令语法，

```sql
ROLLBACK TO savepoint_name;
```

* * *

## `SAVEPOINT`命令

`SAVEPOINT`命令用于临时保存事务，以便您可以在需要时回滚到该点。

以下是保存点命令语法，

```sql
SAVEPOINT savepoint_name;
```

简而言之，使用此命令，我们可以在任何表中命名数据的不同状态，然后在需要时使用`ROLLBACK`命令回滚到该状态。

* * *

### 使用保存点和回滚

下表为**类**，

| 编号 | 名字 |
| one | 全面 |
| Two | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| four | 亚历克斯 |

让我们在上表中使用一些 SQL 查询并查看结果。

```sql
INSERT INTO class VALUES(5, 'Rahul');

COMMIT;

UPDATE class SET name = 'Abhijit' WHERE id = '5';

SAVEPOINT A;

INSERT INTO class VALUES(6, 'Chris');

SAVEPOINT B;

INSERT INTO class VALUES(7, 'Bravo');

SAVEPOINT C;

SELECT * FROM class;
```

> **注:** `SELECT`语句用于显示表中存储的数据。

生成的表看起来像，

| 编号 | 名字 |
| one | 全面 |
| Two | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| four | 亚历克斯 |
| five | 牛宿 |
| six | 克莉丝 |
| seven | 好极了 |

现在让我们使用`ROLLBACK`命令将数据状态回滚到**保存点 B** 。

```sql
ROLLBACK TO B;

SELECT * FROM class;
```

现在我们的**类**表会是这样的，

| 编号 | 名字 |
| one | 全面 |
| Two | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| four | 亚历克斯 |
| five | 牛宿 |
| six | 克莉丝 |

现在让我们再次使用`ROLLBACK`命令将数据状态回滚到**保存点 A**

```sql
ROLLBACK TO A;

SELECT * FROM class;
```

现在桌子看起来像，

| 编号 | 名字 |
| one | 全面 |
| Two | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| four | 亚历克斯 |
| five | 牛宿 |

现在你知道命令`COMMIT`、`ROLLBACK`和`SAVEPOINT`是如何工作的了。

* * *

* * *