# SQL 中的除法运算符

> 原文：<https://www.studytonight.com/dbms/division-operator.php>

当我们必须评估包含关键字`ALL`的查询时，使用除法运算符。

使用除法运算符的一些情况是:

1.  哪个人在某个城市的所有银行都有账户？
2.  哪些学生修完了毕业所需的所有课程？

在上述指定的问题陈述中，关键字`'all'`后的描述定义了一个包含一些元素的集合，最终结果包含那些满足这些要求的单元。

另一种识别除法运算符用法的方法是使用`if...then`的逻辑蕴涵。在上面两个例子的上下文中，我们可以看到查询意味着，

1.  如果在那个特定的城市有一家银行，那个人必须在那个银行有一个账户。
2.  如果在要求毕业的课程列表中有一门课程，那么这个人一定上过这门课程。

不要担心，如果你不清楚所有这些新的东西，我们会试着在继续学习本教程的时候解释清楚。

我们将详细看到上面提到的第二个例子。

**表 1:课程 _ 选修** →由学生姓名和所选课程组成。

| 学生名 | 课程 |
| 罗伯特 | 数据库 |
| 罗伯特 | 编程语言 |
| 大卫 | 数据库 |
| 大卫 | 操作系统 |
| 汉纳 | 编程语言 |
| 汉纳 | 机器学习 |
| 汤姆(男子名) | 操作系统 |

**表 2:课程 _ 必修** →由一个人为了毕业需要修的课程组成。

| 课程 |
| 数据库 |
| 编程语言 |

* * *

## 使用除法运算符

现在，让我们尝试找出正确的 SQL 查询来获取第一个需求的结果，即:

> **查询:**找到所有能毕业的同学。(即修完一个人毕业所需的所有科目。)

不幸的是，我们没有直接的方法来表达除法运算符。让我们一步步来，为除法运算符编写查询。

### 1.找到所有的学生

创建一组所有已学习课程的学生。这可以使用以下命令轻松完成。

```sql
CREATE TABLE AllStudents AS SELECT DISTINCT Student_Name FROM Course_Taken
```

该命令将返回表**所有学生**，作为结果集:

| 学生名称 |
| 罗伯特 |
| 大卫 |
| 汉纳 |
| 汤姆(男子名) |

* * *

### 2.找到所有的学生和毕业所需的课程

接下来，我们将创建一组学生和他们毕业所需的课程。我们可以用**所有学生**和**课程 _ 必修**的笛卡尔乘积的形式来表达，使用以下命令。

```sql
CREATE table StudentsAndRequired AS 
SELECT AllStudents.Student_Name, Course_Required.Course
FROM AllStudents, Course_Required
```

现在新的结果集表**学生和要求的**将是:

| 学生名 | 课程 |
| 罗伯特 | 数据库 |
| 罗伯特 | 编程语言 |
| 大卫 | 数据库 |
| 大卫 | 编程语言 |
| 汉纳 | 数据库 |
| 汉纳 | 编程语言 |
| 汤姆(男子名) | 数据库 |
| 汤姆(男子名) | 编程语言 |

* * *

### 3.找到所有学生和他们没有上过的必修课

在这里，我们为找到不能毕业的学生迈出了第一步。这个想法就是简单地找到那些没有修过毕业所需课程的学生，这样他们就不能毕业了。这只是存在于**学生和必需的**中而不存在于**课程中的所有元组/行。**

```sql
CREATE  table StudentsAndNotTaken AS 
SELECT * FROM StudentsAndRequired WHERE NOT EXISTS 
(Select * FROM Course_Taken WHERE StudentsAndRequired.Student_Name = Course_Taken.Student_Name 
AND StudentsAndRequired.Course = Course_Taken.Course)
```

表**学生和非学生**出来是:

| 学生名 | 课程 |
| 大卫 | 编程语言 |
| 汉纳 | 数据库 |
| 汤姆(男子名) | 数据库 |
| 汤姆(男子名) | 编程语言 |

* * *

### 4.查找所有无法毕业的学生

所有在桌子上的学生都是不能毕业的。因此，我们可以找到不能毕业的学生，

```sql
CREATE table CannotGraduate AS SELECT DISTINCT Student_Name FROM StudentsAndNotTaken
```

| 学生名称 |
| 大卫 |
| 汉纳 |
| 汤姆(男子名) |

* * *

### 5.找到所有能毕业的学生

能够毕业的学生仅仅是那些出现在**全体学生**但不在**不能毕业**的学生。这可以通过以下查询来完成:

```sql
CREATE Table CanGraduate AS SELECT * FROM AllStudents 
WHERE NOT EXISTS 
(SELECT * FROM CannotGraduate WHERE 
    CannotGraduate.Student_name = AllStudents.Student_name)
```

结果如下:

| 学生名称 |
| 罗伯特 |

因此，我们刚刚了解到，不同的步骤如何引导我们找到最终答案。现在让我们看看如何在一个查询中编写所有这 5 个步骤，这样我们就不必创建这么多表。

```sql
SELECT DISTINCT  x.Student_Name FROM Course_Taken AS x WHERE NOT 
EXISTS(SELECT * FROM Course_Required AS y WHERE NOT 
EXISTS(SELECT * FROM Course_Taken AS z 
    WHERE z.Student_name = x.Student_name 
    AND z.Course = y.Course ))
```

| 学生名称 |
| 罗伯特 |

这给了我们和上面 5 步一样的结果。

* * *

* * *