# SQL `JOIN`

> 原文：<https://www.studytonight.com/dbms/joining-in-sql.php>

SQL Join 用于从两个或多个表中获取数据，这些表被连接起来以显示为一组数据。它用于通过使用两个或多个表共有的值来组合这两个表中的列。

`JOIN`关键字用于连接两个或多个表的 SQL 查询。加入表的最低要求条件是 **(n-1)** ，其中 **n** 是表的数量。一个表也可以自己连接，这就是所谓的**自连接**。

* * *

## JOIN 的类型

以下是我们可以在 SQL 中使用的连接类型:

*   内部的
*   外面的
*   左边的
*   对吧

* * *

## 交叉连接或笛卡尔乘积

这种类型的 Join 返回来自 JOIN 中的表的行的笛卡尔乘积。它将返回一个由记录组成的表，这些记录将第一个表中的每一行与第二个表中的每一行组合在一起。

交叉连接语法是，

```sql
SELECT column-name-list
FROM 
table-name1 CROSS JOIN table-name2;
```

* * *

#### 交叉连接的例子

以下是**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| four | 亚历克斯 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |

`Cross` JOIN 查询将、

```sql
SELECT * FROM 
class CROSS JOIN class_info;
```

结果集表如下所示，

| 身份 | 名字 | 身份 | 地址 |
| one | 全面 | one | 德里 |
| Two | 亚当 | one | 德里 |
| four | 亚历克斯 | one | 德里 |
| one | 全面 | Two | 孟买 |
| Two | 亚当 | Two | 孟买 |
| four | 亚历克斯 | Two | 孟买 |
| one | 全面 | three | chennai |
| Two | 亚当 | three | chennai |
| four | 亚历克斯 | three | chennai |

如您所见，这个连接返回两个表中所有记录的叉积。

* * *

## 内部连接或等价连接

这是一个简单的连接，根据 SQL 查询中指定的相等条件，结果基于匹配的数据。

内部连接语法是，

```sql
SELECT column-name-list FROM 
table-name1 INNER JOIN table-name2 
WHERE table-name1.column-name = table-name2.column-name;
```

* * *

#### INNER JOIN 示例

考虑一个**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| three | 亚历克斯 |
| four | 国立大学 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |

**内部** JOIN 查询将、

```sql
SELECT * from class INNER JOIN class_info where class.id = class_info.id;
```

结果集表如下所示，

| 身份 | 名字 | 身份 | 地址 |
| one | 全面 | one | 德里 |
| Two | 亚当 | Two | 孟买 |
| three | 亚历克斯 | three | chennai |

* * *

### Natural JOIN

自然联接是一种内部联接，它基于要联接的两个表中具有相同名称和相同数据类型的列。

自然连接的语法是，

```sql
SELECT * FROM 
table-name1 NATURAL JOIN table-name2;
```

* * *

#### 自然连接的例子

这里是**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| three | 亚历克斯 |
| four | 国立大学 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |

**自然联接查询将，**

```sql
SELECT * from class NATURAL JOIN class_info; 
```

结果集表如下所示，

| 身份 | 名字 | 地址 |
| one | 全面 | 德里 |
| Two | 亚当 | 孟买 |
| three | 亚历克斯 | chennai |

在上面的例子中，两个被连接的表都有**标识**列(相同的名称和相同的数据类型)，因此两个表中**标识**的值匹配的记录将是这两个表自然连接的结果。

* * *

## 外部连接

外部联接基于匹配和不匹配的数据。外部连接进一步细分为，

1.  左外连接
2.  右外连接
3.  完全外部连接

* * *

### 左外连接

左外部连接返回一个结果集表，其中有来自两个表的**匹配数据**，然后是**左**表的剩余行，以及来自**右**表的列的空值。

左外连接的语法是，

```sql
SELECT column-name-list FROM 
table-name1 LEFT OUTER JOIN table-name2
ON table-name1.column-name = table-name2.column-name;
```

要指定一个条件，我们使用`ON`关键字和外部连接。

**甲骨文**的左外连接语法是，

```sql
SELECT column-name-list FROM 
table-name1, table-name2 on table-name1.column-name = table-name2.column-name(**+**);
```

* * *

#### 左外连接示例

这里是**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| three | 亚历克斯 |
| four | 国立大学 |
| five | 阿施施 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |
| seven | 无聊死了 |
| eight | 帕尼帕特 |

**左外连接**查询将是，

```sql
SELECT * FROM class LEFT OUTER JOIN class_info ON (class.id = class_info.id); 
```

结果集表如下所示，

| 身份 | 名字 | 身份 | 地址 |
| one | 全面 | one | 德里 |
| Two | 亚当 | Two | 孟买 |
| three | 亚历克斯 | three | chennai |
| four | 国立大学 | 空 | 空 |
| five | 阿施施 | 空 | 空 |

* * *

### 右外连接

右外连接返回一个结果集表，其中来自两个被连接的表的**匹配数据**，然后是**右**表的剩余行，剩余的**左**表的列为空。

右外连接的语法是，

```sql
SELECT column-name-list FROM 
table-name1 RIGHT OUTER JOIN table-name2 
ON table-name1.column-name = table-name2.column-name;
```

**甲骨文**的右外连接语法是，

```sql
SELECT column-name-list FROM 
table-name1, table-name2 
ON table-name1.column-name(**+**) = table-name2.column-name;
```

* * *

#### 右外连接示例

再次**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| three | 亚历克斯 |
| four | 国立大学 |
| five | 阿施施 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |
| seven | 无聊死了 |
| eight | 帕尼帕特 |

**右外连接**查询将是，

```sql
SELECT * FROM class RIGHT OUTER JOIN class_info ON (class.id = class_info.id); 
```

生成的表看起来像，

| 身份 | 名字 | 身份 | 地址 |
| one | 全面 | one | 德里 |
| Two | 亚当 | Two | 孟买 |
| three | 亚历克斯 | three | chennai |
| 空 | 空 | seven | 无聊死了 |
| 空 | 空 | eight | 帕尼帕特 |

* * *

### 完全外部连接

完全外部连接返回一个结果集表，其中有两个表的**匹配数据**，然后是左**表和右**表的剩余行。****

完全外部联接的语法是，

```sql
SELECT column-name-list FROM 
table-name1 FULL OUTER JOIN table-name2
ON table-name1.column-name = table-name2.column-name;
```

#### 全外连接的例子是，

**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| three | 亚历克斯 |
| four | 国立大学 |
| five | 阿施施 |

和**类信息**表，

| 身份 | 地址 |
| one | 德里 |
| Two | 孟买 |
| three | chennai |
| seven | 无聊死了 |
| eight | 帕尼帕特 |

**全外连接**查询会是这样的，

```sql
SELECT * FROM class FULL OUTER JOIN class_info ON (class.id = class_info.id);
```

结果集表如下所示，

| 身份 | 名字 | 身份 | 地址 |
| one | 全面 | one | 德里 |
| Two | 亚当 | Two | 孟买 |
| three | 亚历克斯 | three | chennai |
| four | 国立大学 | 空 | 空 |
| five | 阿施施 | 空 | 空 |
| 空 | 空 | seven | 无聊死了 |
| 空 | 空 | eight | 帕尼帕特 |

现在我们已经学习了 SQL JOIN，您也可以查看这些 SQL 主题及其用法:

*   [SQL 函数](sql-function.php)
*   [SQL 别名](sql-alias.php)
*   [SQL SET 操作](set-operation-in-sql.php)
*   [SQL 视图](sql-views.php)

* * *

* * *