# 什么是 SQL 序列？

> 原文：<https://www.studytonight.com/dbms/sql-sequences.php>

**序列**是一些数据库系统支持的一个特性，可以按需产生唯一的值。一些 DBMS 如 **MySQL** 支持`AUTO_INCREMENT`代替顺序。

`AUTO_INCREMENT`应用于列，每次向表中插入新记录时，它会自动将列值增加`1`。

序列也有些类似于`AUTO_INCREMENT`但是它也有一些额外的特性。

* * *

## 创建序列

创建序列的语法是，

```sql
CREATE SEQUENCE sequence-name
    START WITH initial-value
    INCREMENT BY increment-value
    MAXVALUE maximum-value
    CYCLE | NOCYCLE;
```

*   **初始值**指定序列的起始值。
*   **增量值**是序列增加的值。
*   **最大值**指定了序列自身递增的上限或最大值。
*   关键字`CYCLE`指定如果最大值超过设定的限制，序列将从开始重新开始它的循环。
*   并且，`NO CYCLE`指定如果序列超过`MAXVALUE`值，将抛出一个错误。

* * *

### 在 SQL 查询中使用序列

让我们从创建一个序列开始，从`1`开始，递增`1`，最大值为`999`。

```sql
CREATE SEQUENCE seq_1
START WITH 1
INCREMENT BY 1
MAXVALUE 999
CYCLE;
```

现在让我们使用上面刚刚创建的序列。

下面我们有一个**类**表，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| four | 亚历克斯 |

该查询将是，

```sql
INSERT INTO class VALUE(seq_1.nextval, 'anu');
```

结果集表看起来像，

| 身份 | 名字 |
| one | 全面 |
| Two | 亚当 |
| four | 亚历克斯 |
| one | 国立大学 |

一旦使用`nextval`，即使没有在表中插入任何记录，序列也会递增。

* * *

* * *