# SQL 视图

> 原文：<https://www.studytonight.com/dbms/sql-views.php>

SQL 中的视图是一个或多个表中数据的逻辑子集。视图用于限制数据访问。

创建视图的语法，

```sql
CREATE or REPLACE VIEW view_name 
    AS
    SELECT column_name(s)
    FROM table_name
    WHERE condition
```

通过查看上面的 SQL 查询，您可能已经理解了，视图是使用从其他表中获取的数据创建的。它更像是用数据创建的临时表。

* * *

## 创建视图

考虑遵循**销售**表，

| 似…的 | 订单名称 | 上一余额 | 顾客 |
| Eleven | ord1 | Two thousand | 亚历克斯 |
| Twelve | 订单 2 | One thousand | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| Thirteen | ord3 | Two thousand | 全面 |
| Fourteen | ord4 | One thousand | 圣经》和《古兰经》传统中）亚当（人类第一人的名字 |
| Fifteen | ord5 | Two thousand | 亚历克斯 |

从上表创建视图的 SQL 查询将是，

```sql
CREATE or REPLACE VIEW sale_view 
AS 
SELECT * FROM Sale WHERE customer = 'Alex';
```

从`SELECT`语句提取的数据将存储在另一个名为 **sale_view** 的对象中。我们也可以分别使用`CREATE`和`REPLACE`，但是两者一起使用效果更好，就好像任何具有指定名称的视图都存在一样，这个查询会用新的数据替换它。

* * *

## 显示视图

在视图中显示数据的语法类似于使用`SELECT`语句从表中获取数据。

```sql
SELECT * FROM sale_view;
```

* * *

## 强制视图创建

`FORCE`关键字在创建视图时使用，非常有力。即使表不存在，该关键字也用于创建视图。创建强制视图后，如果我们创建基表并在其中输入值，视图将自动更新。

强制视图的语法是，

```sql
CREATE or REPLACE FORCE VIEW view_name AS
    SELECT column_name(s)
    FROM table_name
    WHERE condition;
```

* * *

## 更新视图

`UPDATE`视图命令与表格命令相同。

更新视图的语法是，

```sql
UPDATE view-name SET VALUE
WHERE condition;
```

**注意:**如果我们更新一个视图，它也会自动更新基表数据。

* * *

## 只读视图

我们可以创建一个带有只读选项的视图来限制对该视图的访问。

创建只读视图的语法

```sql
CREATE or REPLACE FORCE VIEW view_name AS
    SELECT column_name(s)
    FROM table_name
    WHERE condition WITH read-only; 
```

以上语法将为**只读**目的创建视图，我们不能将数据更新或插入只读视图。它会抛出一个**错误**。

* * *

## 视图类型

有两种类型的视图，

*   简单视图
*   复杂视图

| 简单视图 | 复杂视图 |
| 从一个表创建 | 从一个或多个表创建 |
| 不包含函数 | 包含函数 |
| 不包含数据组 | 包含多组数据 |

* * *

* * *