# MongoDB 概述

> 原文：<https://www.studytonight.com/mongodb/overview-of-mongodb>

MongoDB 由一组数据库组成。每个数据库也由集合组成。MongoDB 中的数据存储在集合中。下图描述了 MongoDB 中的典型数据库结构。

![Overview of MongoDB](img/cecdba71f92655b05f99aa193837cf7c.png)

* * *

## MongoDB 中的数据库

MongoDB 中的数据库只不过是集合的容器。在接下来的课程中，我们将学习如何创建新的数据库、删除数据库以及如何使用现有的数据库。

* * *

## MongoDB 中的集合

*   集合只不过是一组 MongoDB 文档。这些文档相当于关系 DBMS 中表格中的一行数据。但是，与 RDBMS 相比，MongoDB 中的集合与任何集合模式都不相关。集合是存储相关数据的一种方式。由于没有模式，任何类型的文档都可以保存在一个集合中，尽管为了索引效率，建议使用相似性。文档的最大大小可以是 4MB。
*   我们可以使用**命名空间**对集合进行逻辑分组和嵌套。**例如:**可以有一个名为`db.studytonight.users`的集合保存用户信息，那么就可以有像`db.studytonight.forum.questions`、`db.studytonight.forum.answers`这样的其他集合分别存储论坛问答。
*   如果我们在命名空间集合上创建**索引**，它将只应用于该命名空间。我们将在本教程的后面学习如何创建索引。
*   一旦在集合中创建了第一个文档，就在物理上创建了集合。
*   当我们可以将任何表单或数据保存在单个集合中时，您一定想知道为什么要创建具有不同命名空间的多个集合。这是因为，MongoDB 不会为完全不相关的文档索引属性。因此，建议将相关数据保存在集合中。

* * *

## MongoDB 中的文档

MongoDB 中的文档只不过是键值对的集合。这些文档将具有动态模式，这意味着同一集合中的文档不需要拥有相同的字段集。

因为 MongoDB 被认为是一个无模式数据库，所以每个集合可以保存不同类型的对象。集合中的每个对象都被称为文档，它以类似 JSON(JavaScript 对象符号)的结构(除了键值对列表什么都没有)来表示。数据在 **BSON** 中存储和查询，它的二进制表示类似 JSON 的数据。您可以从本网页→ [BSON 规格](http://bsonspec.org/)和 [BSON 型号](from https://docs.mongodb.com/manual/reference/bson-types/)了解更多关于 BSON 格式的信息

* * *

### MongoDB 中的样本数据

![Sample Data in MongoDB](img/f0cc69a2e1b8ee6b91063dc8f396499d.png)

**注意:**在上图中，字段`_id`代表给定文档的主键标识符。MongoDB 也以值数组的形式存储这些值。事实上，任何类型的数据都可以存储为值，不需要预先定义任何东西。换句话说，你不必预先定义要存储的数据类型，你可以存储任何你想要的东西。请记住，MongoDB 是无模式的。

文档不是由简单的标识来标识的，而是由对象标识符类型来标识的。默认的 id 是机器标识符、时间戳和进程 Id 的组合，以保持其唯一性，但用户可以将其更改为任何内容。

* * *

### 数组作为值的示例

```sql
{ _id : 112233,
  name : "Viraj",
  education : [
           {
              year : 2029,
              course : "BTECH",
              college : "IIT, Delhi"
            },
           {
              year : 2031,
              course : "MS",
              college : "Harvard College"
           }
  ]
}
```

### 一个文档中不同数据类型的示例

文档中字段的值可以是任何东西，包括其他文档、数组、文档数组、日期对象、字符串等。

```sql
var mydoc = {
    _id : ObjectId("5099803df3f4948bd2f98391"),
    name : { first: "Alan", last: "Turing" },
    birth : new Date('Jun 23, 1912'),
    death : new Date('Jun 07, 1954'),
    contribs : [ "Turing machine", "Turing test", "Turingery" ],
    view : NumberLong(1250000)
} 
```

* * *

* * *