# 什么时候切换到 MongoDB

> 原文：<https://www.studytonight.com/mongodb/why-switch-to-mongodb>

首先，MongoDB 不能替代任何传统的 RDMS 数据库。但是，考虑到 MongoDB 以 BSON(JSON 的二进制表示)的形式构建/存储数据，这是一种自我解释和人类可读的数据格式，以及它为要开发的应用程序提供缩放功能的方式，下面是一些重要的因素，这些因素清楚地表明开发人员应该使用 MongoDB 来开发他们的应用程序。

* * *

## 数据插入一致性

基本上，与在事务中进行插入的安全问题相比，MongoDB 喜欢更高的数据插入率。因此，写入一致性较低。如果需要写入大量数据，而又不用担心会丢失一些数据，那么 MongoDB 应该是首选，而且确实是最适合的。

## 数据损坏恢复

当数据恢复过程需要更快、更安全、更自动化时，首选 MongoDB。在 MySQL 中，如果数据库(一些表)损坏，您可以通过删除/更新数据来单独修复它们。在 MongoDB 中，您必须在数据库级别进行修复。但是有一个命令可以自动做到这一点，但是它会读取所有数据并将其重新写入一组新的文件。因此，如果您的数据库很大，可能需要一些时间，在这段时间内，您的数据库将被锁定。但是，这也比丢失完整的数据集要好。

## 负载平衡

当数据无限增长并且需要适当的负载平衡时，MongoDB 是最好的解决方案。因为它支持更快的副本设置选项及其内置的分片功能。

## 避免 JOINS

当开发人员不想规范化他们的数据并坚持不使用任何 JOINS 时，那么他们应该真正使用 MongoDB。例如:如果有 2 个集合学生和地址(其中一个学生可以有多个地址)。在典型的关系 DBMS 中，为了从**地址**表中获取与学生相关的地址，使用了 JOIN。但是，在 MongoDB 中，地址数据可以作为文档嵌入到**学生**集合中。因此，无需使用任何 JOIN，只需一个简单的查询就可以获取学生和地址的所有必要详细信息。

```sql
db.address.insert([
    {
        _id: 'addr1',
        name: 'Bangalore'
    },
    {
        _id: 'addr2',
        name: 'Delhi'
    }
]);

db.student.insert([
    {
        _id: 's1',
        name: 'Student1',
        address: ['addr1']
    },
    {
        **_id**: '*s2*',
        **name**: '*Student2*',
        **address**: ['*addr1*','*addr2*']
    },
]);
```

## 最适合更改模式

众所周知，每当任何关系 DBMS 中的一个表被更改时(比如添加一个新列)，整个数据库很有可能被锁定，这反过来又会导致性能大幅下降。因为 MongoDB 是无模式的，所以添加新字段不会导致任何问题。

## 不是关系数据

当要存储的数据不需要是关系数据时，应该选择 MongoDB。

## 更多的原因...

1.  尽管 SQL 数据库具有非常好的一致性，但它们在数据分区方面却很糟糕。像 MongoDB 这样的 NoSQL 数据库可以用在这个场景中。
2.  将应用程序数据对象直接映射到基于文档的存储中非常容易。因为类似 JSON 的格式非常类似于任何编程语言中的对象表示。文档比关系 DBMS 的一组关系表更接近对象。
3.  如果您计划创建一个数据库集群，该集群可能在地理上分布以提供加速的数据查询，那么 MongoDB 应该是您的选择。

* * *

* * *