# PL/SQL 块

> 原文：<https://www.studytonight.com/plsql/plsql-block>

在 PL/SQL 程序中，代码是分块编写的。每个 PL/SQL 块有 3 个部分，分别是:

1.  声明部分
2.  开始部分
3.  例外部分

随后是结尾的 **END** 语句。

* * *

## PL/SQL 块

PL/SQL 块创建描述要执行的进程的结构化逻辑代码块。这样的块由 SQL 语句和 PL/SQL 指令组成，然后传递给 oracle 引擎执行。PL/SQL 块由以下四个部分组成:

*   **DECLARE Section:**

    PL/SQL 代码从一个声明部分开始，在该部分中可以声明内存变量和其他 oracle 对象，如游标、触发器等，如果需要也可以初始化。一旦声明/初始化，我们就可以在 SQL 语句中使用它们来进行数据操作。因为我们不需要在每个 PL/SQL 代码中要求变量等，所以这个部分是可选的。

*   **BEGIN Section:**

    本节包含需要执行的 SQL 和 PL/SQL 语句，并包含主要逻辑。这个部分负责处理数据检索和操作，可能是处理分支，可以使用循环和条件语句等。

*   **EXCEPTION Section:**

    此部分是可选的。主要用于处理 **BEGIN** 和 **EXCEPTION** 区间可能出现的错误。

*   **END Section:**

    这部分是 PL/SQL 块结束的指示。

* * *

### 是时候举个例子了！

让我们从编写一个基本的 PL/SQL 块开始，它什么都不会做，或者只是在控制台中打印一些东西。这将帮助我们理解语法。

```sql
BEGIN
   NULL;
END;
```

上面的 PL/SQL 块没有 **DECLARE** 部分，只有 **BEGIN** 和 **END** 部分。它不会做任何事情，因为`NULL`语句不会做任何事情。

我们能

* * *

### 使用 PL/SQL 块显示输出

如果您想要显示您的 PL/SQL 块的执行输出，您可以通过使用`DBMS_OUTPUT.PUT_LINE`语句来实现。

让我们举一个简单的例子:

```sql
BEGIN
   DBMS_OUTPUT.PUT_LINE('Hello World!');
END;
/
```

你好世界！

如果你仔细看上面的 PL/SQL 块，我们已经在`END;`语句后面多放了一个`/`，使用它将自动执行脚本。

* * *

## 匿名 PL/SQL 块

一般来说，PL/SQL 块是大程序的一部分，或者是子程序，或者是函数，或者是过程，或者是触发器等，但是它们可以独立定义，也可以执行。

当我们定义一个没有头的 PL/SQL 块时，它被称为**匿名块**。

让我们举一个 PL/SQL 块的例子，它将添加两个数字，并在输出中显示结果:

```sql
DECLARE 
    -- declare variable a and b  
    -- and these variables have integer datatype  
   a number;  
   b number;   
BEGIN 
   a:= 7;  
   b:= 77;  
   dbms_output.put_line('Sum of the number is: ' || a + b);  
END;  
/
```

Eighty-four

如果你不明白我们是怎么做到的，别担心。本教程只是一个介绍，在接下来的几个教程中我们会学习到 PL/SQL 运算符、数据类型、变量等，所以点击 **Next →** 进入下一个教程。

* * *

* * *