# 变量、常量和字面值

> 原文：<https://www.studytonight.com/plsql/plsql-variables>

在我们之前的教程中，我们介绍了 [**PL/SQL 数据类型**](datatype-in-plsql) ，在本教程中，我们将学习 PL/SQL 变量、常量和文本。我们还将编写一些简单的 PL/SQL 块，看看我们如何定义变量并使用它们。

### 什么是标识符？

在继续之前，让我们了解什么是标识符。你被你的名字所识别，因此你的名字就是你的标识符。同样，在编程中，我们使用标识符来命名数据，数据可以是任何形式的数据。

* * *

## PL/SQL 变量

变量是用于存储特定数据类型数据的保留内存区域。这是一个**标识符**，用于标识存储数据的存储位置。在任何 PL/SQL 块的`DECLARE`部分完成变量声明时，该内存被保留。

**变量声明语法:**

```sql
Variable_name  datatype(size);
```

让我们举一个简单的例子来说明如何在 PL/SQL 中定义一个变量，

```sql
roll_no NUMBER(2);

a int;
```

如果我们想在声明时给变量赋值，语法应该是，

```sql
Variable_name datatype(size) NOT NULL:=value;
```

让我们也举一个简单的例子，

```sql
eid NUMBER(2) NOT NULL := 5;
```

在上面的 PL/SQL 代码中，我们定义了一个名为`eid`的变量，该变量的数据类型为`NUMBER`，可以容纳多个长度为 **2** 的字节，这意味着它可以容纳一个高达 **99** 的数字(因为从 100 开始我们有 3 个数字)，该变量的默认值为 **5** 。

关键字**不为空**表示`eid`不能为空。

这里，`:=`是一个**赋值运算符**，用于给变量赋值。(我们将在下一个教程中了解各种运算符)

* * *

### 在 PL/SQL 中声明变量的规则

以下是在定义和使用 PL/SQL 中的变量时需要记住的一些重要规则:

1.  变量名是用户定义的。它应该以一个字符开头，后面最多可以有 29 个字符。
2.  PL/SQL 的关键字(即保留字)不能作为变量名。
3.  Multiple variables can be declared in a single line provided they must be separated from each other by at least one space and comma.

    例如:`a,b,c int;`

4.  Variable names containing two words should not contain space between them. It must be covered by underscore instead.

    例如:`Roll_no`

5.  变量名区分大小写，表示`a_var`和`A_var`不一样

* * *

### 是时候举个例子了！

让我们举一个简单的例子来看看如何声明一个变量并使用它，

```sql
set serveroutput on;
DECLARE
	a NUMBER(2);
	b NUMBER(2) := 5;
BEGIN
	a := b;
	dbms_output.put_line(a);
END; 
```

five

在上面的例子中，我们已经声明了两个变量`a`和`b`，并为变量`b`赋值，然后在 **BEGIN** 块中，我们将变量`b`的值赋给变量`a`，然后在控制台上打印它的值。

* * *

## PL/SQL 常量

常量是那些在声明时在整个 PL/SQL 块中保持固定的值。对于声明常数，使用`constant`关键字。

**声明常量的语法**:

```sql
Constant_Name  constant  Datatype(size) := value;
```

让我们举一个简单的代码例子，

```sql
school_name constant VARCHAR2(20) := "DPS";
```

在上面的代码示例中，常量名称是用户定义的，后跟一个关键字`constant`，然后我们已经声明了它的值，一旦声明就不能更改。

* * *

### 是时候举个例子了！

下面我们有一个简单的程序来演示常量在 PL/SQL 中的使用，

```sql
set serveroutput on;
DECLARE
	school_name constant varchar2(20) := "DPS";
BEGIN
	dbms_output.put_line('I study in '|| school_name);
END; 
```

我在 DPS PL/SQL 程序的学习顺利完成。

* * *

## PL/SQL 通用

字面值是一个由自身表达的值，通常是常量。例如，如果你的名字是亚历克斯，那么对你来说**亚历克斯**是一个字面值(常量的值)。换句话说，在程序中声明为常数的值称为字面值值。字面值可以是数字、字符串或日期。

| 字面值的类型 | 说明 | 例子 |
| 数字的 | 它可以是正数，也可以是负数。 | 2,-5,10,-50 |
| 线 | 它是字符的集合，使用时用单引号括起来。 | 《你好，世界》 |
| 日期 | 它是 **DD-MON-YYYY **格式的日期，在任何程序中使用时总是用单引号括起来。**T3】** | ' 1995 年 11 月 25 日' |

* * *

### 是时候举个例子了！

这里我们有一个简单的程序来演示字面值在 PL/SQL 中的使用，

```sql
set serveroutput on;
DECLARE
	str varchar2(20):= 'Welcome to Studytonight.com';
BEGIN
	dbms_output.put_line(str);
END; 
```

欢迎来到 Studytonight.com

在下一个教程中，我们将学习 PL/SQL 中的运算符。

* * *

* * *