# PL/SQL 中的运算符

> 原文：<https://www.studytonight.com/plsql/plsql-operators>

运算符是一种符号，它告诉编译器对与符号一起指定的一个或多个操作数执行运算。必须对其执行操作的[变量](plsql-variables)称为**操作数**，要执行的操作由**运算符符号**表示。

在 PL/SQL 中，运算符可以大致分为以下几类:

*   算术运算符
*   关系运算符
*   比较运算符
*   逻辑运算符

* * *

## 算术运算符

算术运算符用于对操作数执行不同的数学运算。以下是 PL/SQL 中可用的算术运算符:

**注**:为了给每个操作者提供例子，我们考虑两个变量，`a`和`b`分别取值 6 和 3。

| 操作员 | 使用 | 例子 |
| `+` | 将两个操作数相加 | `a+b`将给出 9 |
| `-` | 执行减法，从第一个操作数中减去第二个操作数。这个运算符也可以返回负值。 | `a-b`将给出 3 |
| `/` | 执行除法运算。 | `a/b`将给出 2 |
| `*` | 执行乘法 | `a*b`将给出 18 |
| `**` | 执行求幂运算，即第一个操作数的幂等于第二个操作数的幂 | `a**b`将给出 216 |

* * *

## 关系运算符

关系运算符用于比较两个值，并以布尔值的形式返回结果(要么是**真**要么是**假**)。它们主要用于需要某种比较的情况。以下是 PL/SQL 中可用的关系运算符:

**注**:为了给每个操作者提供示例，我们考虑两个变量，`a`和`b`，分别取值 7 和 14。

| 操作员 | 使用 | 例子 |
| `=` | 检查给定的两个操作数的值是否相等。如果它相等，那么条件将返回真或假。 | `(a = b)`为假 |
| `!=``<>``~=` | 这些运算符用于检查两个操作数是否不相等，或者它们的值是否不同。如果操作数不相等，则条件将返回 true 或 false。 | `a != b`是真的吗 |
| `<` | 检查 LHS 值是否小于 RHS 值。如果是，条件返回真。 | `a < b`是真的吗 |
| `>` | 检查 LHS 值是否大于 RHS 值。如果是，条件返回真。 | `a > b`为假(不为真) |
| `<=` | 检查 LHS 值是否小于或等于 RHS 值。 | `a <= b`是真的吗 |
| `>=` | 检查 LHS 值是否大于或等于 RHS 值 | `a >= b`为假(不为真) |

* * *

## 逻辑运算符

逻辑运算符用于组合多个表达式或定义具有两个操作数的表达式，并根据逻辑运算符周围的操作数或表达式返回`True`或`False`。

**注**:为了给每个操作符提供例子，我们考虑两个变量(或表达式)`a`和`b`，分别取值为真和假。

| 操作员 | 使用 | 例子 |
| `AND` | 当 LHS 和 RHS 操作数都为真时，返回**真**。当 LHS 和 RHS 操作数都为假或其中之一为假时，
返回**假**。 | `a AND b`将返回假 |
| `OR` | 当 LHS 和 RHS 操作数都为真或其中之一为真时，返回**真**。当 LHS 和 RHS 操作数为假时，
返回**假**。 | `a OR b`将返回真 |
| `NOT` | 应用于单个操作数。当操作数为假时，返回**真**。当操作数为真时，
返回**假**。 | `NOT a`将返回假 |

在上表中，当我们说操作数时，它也可以是表达式。在编写 SQL 查询时，我们倾向于将这些运算符与 [WHERE 子句](/dbms/where-clause.php)一起使用。

* * *

## 比较运算符

比较运算符用于将一个值与另一个值进行比较，并将结果返回为**真**或**假**或**空**。以下是不同类型的比较运算符:

### 1.`LIKE`操作员

该运算符用于匹配单个字符或一组字符(字符串)。有两个通配符用于匹配。

`%`用于匹配任意字符的字符串。

而`_`用于匹配单个字符。

这里可以看到:[SQL 中 LIKE 运算符示例](/dbms/like-clause.php)

如果字符串或字符匹配，该运算符返回**真**，否则返回**假**。

```sql
SELECT * from student WHERE sname LIKE 'J%';
```

当我们执行上面的 SQL 查询时，它将显示名称以 J 开头的学生记录，其中`%`用于匹配第一个字符 J 之后的任何字符的字符串。如果学生表中有乔恩、吉亚、约翰、詹姆斯等名字，我们将得到他们。

我们再举一个例子，

```sql
SELECT * from student WHERE sname LIKE '_ _ _ a';
```

当我们执行上面的 SQL 查询时，它将显示学生记录，该记录的名称由 4 个字母组成，以字符 a 结尾。

### 2.`BETWEEN`操作员

该运算符用于检查值是否在某个给定范围内。如果值在给定范围内，则返回**真**，否则返回**假**。

让我们举个例子:

```sql
SELECT * from student WHERE age BETWEEN 12 AND 18;
```

上面的 SQL 查询将显示年龄在 12 到 18 岁之间的学生记录。

### 3.`IN`操作员

当需要将任何值与给定的值列表进行比较时，使用该运算符。如果给定列表中存在该值，则返回**真**，否则返回**假**。当我们必须进行多个比较而不是使用多个`OR`条件时，这个运算符就派上了用场。

让我们举个例子:

```sql
SELECT * from student WHERE city IN ('Delhi','Goa','Kerela');
```

上面的 SQL 查询，将显示属于城市德里或果阿或凯拉的学生记录。

### 4.`IS NULL`操作员

如果操作数值为空，该运算符返回**真**，否则返回**假**

让我们举个例子:

```sql
SELECT * from student WHERE age IS NULL;
```

上面的 SQL 查询，将显示表中年龄字段为空的学生记录

* * *

* * *