# PL/SQL 循环

> 原文：<https://www.studytonight.com/plsql/plsql-loops>

PL/SQL 中的循环提供了一种方法，可以根据需要多次重复任何程序或任何代码语句的特定部分。

在 PL/SQL 中，当我们想要在代码块中重复执行一条语句时，我们有三个不同的循环选项可供选择。它们是:

1.  基本循环
2.  当循环
3.  用于循环

在本教程中，我们将了解所有这三种循环，同时涵盖 nexted loops 的概念，这意味着循环中的循环。让我们开始吧。

* * *

## 基本循环

当不确定代码块要重复多少次时，在 PL/SQL 代码中首选基本循环或简单循环。当我们使用基本循环时，代码块将至少执行一次。

使用时，必须考虑以下两点:

*   简单循环总是以关键字`LOOP`开始，以关键字`END LOOP`结束。
*   通过使用`exit`语句或通过使用语句`exit when`指定特定条件，可以在任何给定点终止基本/简单循环。

**语法:**

```sql
LOOP
	sequence of statements
END LOOP; 

```

让我们看看下面代码示例中的简单循环。

### 是时候举个例子了！

在下面的代码中，我们使用循环在控制台上打印从 1 到 10 的计数，并使用`exit`语句来打破循环。

```sql
set serveroutput on;

DECLARE
	i int;
BEGIN
	i := 1;
	LOOP
		if i>10 then
			exit;
		end if;
		dbms_output.put_line(i);
		i := i+1;
	END LOOP;
END;

```

1 2 3 4 5 6 7 8 9 10 PL/SQL 程序已成功完成

让我们再举一个例子，我们将使用`exit when`语句来打破循环。

```sql
set serveroutput on;

DECLARE
	i int;
BEGIN
	i := 0;
	LOOP
		i := i+2
		dbms_output.put_line(i);
		exit WHEN x > 10
	END LOOP;
END;

```

2 4 6 8 10 PL/SQL 程序成功完成

* * *

## 当循环时

这是一个入口控制循环，这意味着在进入 while 循环之前，首先测试条件，如果条件为**真**，则执行该语句或一组语句，如果条件为**假**，则控制将移出 while 循环。

**语法:**

```sql
WHILE <test_condition> LOOP
	<action>
END LOOP;
```

让我们在下面的代码示例中看看 while 循环是如何工作的。

### 是时候举个例子了！

下面我们有一个简单的程序，使用 while 循环打印 1 到 10 之间的奇数。

```sql
set serveroutput on;

DECLARE
	num int:=1;
BEGIN
	while(num <= 10) LOOP
		dbms_output.put_line(''|| no);
		num := num+2;
	END LOOP;
END;

```

1 3 5 7 9 PL/SQL 程序成功完成。

**注意:**您必须编写代码来增加您放入条件中的变量值，否则变量值将保持不变，条件将始终为真。

* * *

## 用于循环

当 PL/SQL 代码块中的某些语句要重复固定次数时，使用此循环。

当我们使用 for 循环时，我们应该定义一个计数器变量，它根据循环开始时提供的开始和结束值来决定循环将执行多少次。

for 循环在每个循环周期结束时自动将计数器变量的值递增 1。

程序员不需要编写任何递增或递减值的指令。

**语法:**

```sql
FOR counter_variable IN start_value..end_value LOOP
	statement to be executed
END LOOP; 
```

让我们看看下面例子中的 for 循环。

### 是时候举个例子了！

在下面的例子中，我们使用了 for 循环来打印从 1 到 10 的数字。

```sql
set serveroutput on;
DECLARE
	i number(2);
BEGIN
	FOR i IN 1..10 LOOP
		dbms_output.put_line(i);
	END LOOP;
END;

```

1 2 3 4 5 6 7 8 9 10 PL/SQL 程序成功完成。

现在。让我们举另一个例子，我们将以相反的顺序打印数字。

```sql
set serveroutput on;
DECLARE
	i number(2);
BEGIN
	FOR i IN REVERSE 1..10 LOOP
		dbms_output.put_line(i);
	END LOOP;
END; 
```

10 9 8 7 6 5 4 3 2 1 PL/SQL 程序成功完成。

在上面的程序中， **REVERSE** 关键字用于以相反的顺序打印数字。

* * *

* * *