# PL/SQL 字符串

> 原文：<https://www.studytonight.com/plsql/plsql-strings>

在本教程中，我们将学习 PL/SQL 中的字符串，包括各种类型的字符串，声明字符串变量的语法，然后在 PL/SQL 代码块中使用它。

就像在任何其他编程语言中一样，PL/SQL 中的字符串是字符的组合，可以是数字、特殊字符、字母或全部。

PL/SQL 为我们提供了创建可变长度字符串的自由，可以选择提供字符串的大小。

在 PL/SQL 中，基本上有三种不同类型的字符串，它们是:

1.  **固定长度的字符串**:当我们定义一个固定长度的字符串时，我们必须在声明它的同时指定字符串的大小。一旦我们声明了一个固定长度的字符串，变量占用的内存空间就等于用空格填充内存空间的字符串长度。
2.  **可变长度字符串**:如果是可变长度字符串，该字符串的长度最多可达 32，767 个字符。当一个可变长度字符串最初被声明时，没有为它提供空格。
3.  **CLOB(字符大对象)**:这是一种可变长度的字符串，其大小可达 128 太字节。

* * *

## PL/SQL:字符串声明的语法

当用引号括起来时，基本字面值也是字符串，例如:

```sql
'This is a string literal'
```

> 要在字符串中包含单引号，必须使用两个单引号。例如，‘你认为这是你的选择’。

为了声明一个字符串变量，我们必须指定[数据类型](datatype-in-plsql)和定义字符串最大长度的长度值。

我们可以使用像 CHAR、VARCHAR2、CLOB 等数据类型，其中每一个都用来定义不同类型的字符串。

首先我们来看看**如何声明一个变长字符串变量**。我们使用 VARCHAR2 数据类型。

```sql
name VARCHAR2(10)
```

这里，`name`是变量的名称，VARCHAR2 是数据类型，10 是字符串可以采用的最大长度。

现在，让我们看看如何才能**声明一个固定长度的字符串变量**。我们对此使用 CHAR 数据类型。声明这种类型的字符串时，可以提供也可以不提供字符串的大小/长度，因为如果不提供，Oracle 数据库会自动使用所需的最大长度。例如，

```sql
approved CHAR(1) := 'Y'
approved CHAR := 1
```

让我们以 PL/SQL 代码为例，我们将使用多个字符串来更好地理解这个概念。

* * *

## 字符串用法示例

在下面的代码示例中，我们将使用所有 3 种类型的字符串。

```sql
DECLARE 
   	s_name VARCHAR2(20); 
   	s_age NUMBER(2); 
   	s_address CLOB; 
   	s_gender CHAR(1); 
BEGIN 
   	s_name := 'Sherlock Holmes'; 
   	s_age := 21; 
   	s_address := '221B, Baker Street, London'; 
   	s_gender := 'M';
   	IF s_gender = 'M' THEN 
      	dbms_output.put_line(s_name || ' is a student at Studytonight'); 
      	dbms_output.put_line('He is ' || s_age || ' years old.'); 
      	dbms_output.put_line('He lives at ' || s_address); 
    ELSE
    	dbms_output.put_line(s_name || ' is a student at Studytonight'); 
      	dbms_output.put_line('She is ' || s_age || ' years old.'); 
      	dbms_output.put_line('She lives at ' || s_address);
   END IF; 
END; 
/
```

夏洛克·福尔摩斯是今晚学习的学生，他今年 21 岁。他住在伦敦贝克街 221B 号

* * *

### 有用的字符串函数

您可以在甲骨文网站的官方文档中找到所有字符串函数的列表和用法示例:[字符串函数](https://docs.oracle.com/cd/E17952_01/mysql-5.1-en/string-functions.html)

* * *

* * *