# PL/SQL 中的存储过程和函数

> 原文：<https://www.studytonight.com/plsql/plsql-procedure-and-function>

在本教程中，我们将通过示例介绍 PL/SQL 中存储过程和函数的概念。

存储过程和函数都可以定义为一组逻辑编写的语句，存储在数据库中，并在调用时执行，以执行特定的任务。

函数和存储过程都有一个**唯一命名的代码块**，该代码块被编译并存储在数据库中。

创建的任何存储过程或函数，除非被调用，否则仍然没有用。因此，在创建存储过程或函数之后，有必要从另一个 PL/SQL 块调用该存储过程或函数，以便达到创建它的目的。

* * *

## 创建存储过程或函数

每当存储过程或函数的代码块被写入时，它们就会被 oracle 引擎自动编译。在编译**过程中，如果出现任何错误**，我们会在屏幕上看到一条消息，说创建的过程或函数有编译错误，但实际错误不会显示。

为了找出编译错误，可以执行以下语句:

```sql
SELECT * from USER_ERRORS;
```

一旦被编译，它就被 oracle 引擎作为一个**数据库对象**存储在数据库中。

PL/SQL 中存储过程或函数的代码块由以下三部分组成:

*   **声明部分:**在该部分中，声明了将由过程或函数使用的变量、常数、[光标](plsql-cursor)或异常。
*   **可执行部分**:在这一部分中，编写了创建的过程或函数的定义。本节还包含赋值、控制执行和操作数据的 SQL 或 PL/SQL 语句。
*   **[异常处理部分](plsql-exception-handling) :** 在该部分中，编写了在执行以可执行部分编写的代码时可能出现的预期异常。此部分是可选的。

* * *

## 存储过程或函数的优势

以下是存储过程和函数在 PL/SQL 中的一些优点:

**1。提高数据库性能**

*   编译由 oracle 引擎自动完成。
*   每当过程或函数的调用完成时，oracle 引擎会将编译后的代码加载到一个名为系统全局区域(SGA)的内存区域，这样执行速度会更快。

**2。提供可重用性并避免冗余**

*   过程或函数的同一代码块可以被调用任意次来处理多个数据。
*   由于这种原因，代码的行数不能重复编写。

**3。保持完整性**

*   诚信意味着准确。过程或函数的使用确保了完整性，因为它们被 oracle 引擎存储为数据库对象。

**4。维护安全**

*   使用存储过程或函数有助于维护数据库的安全性，因为可以通过向用户授予访问/权限来控制对它们的访问和使用，而更改、编辑或操作数据库的权限可能不会授予用户。

**5。节省内存**

*   存储过程或函数具有共享内存。因此，它节省了内存，因为一个过程或一个函数的单个副本可以由任何数量的具有访问权限的用户加载执行。

* * *

## 存储过程和函数的区别

下面我们列出了 PL/SQL 中存储过程和函数之间的一些区别:

| 存储过程 | 功能 |
| 可能会也可能不会向程序的调用部分返回值。 | 向程序的调用部分返回一个值。 |
| 使用输入、输出、输入输出参数。 | 仅使用输入参数。 |
| 使用“输出”参数返回值。 | 使用“RETURN”返回一个值。 |
| 如果在调用该值后将返回该值，则不指定该值的数据类型。 | 必须指定对其进行调用后要返回的值的数据类型。 |
| 不能从代码的函数块中调用。 | 可以从程序代码块中调用。 |

* * *

### 创建存储过程的语法

下面是在 oracle 中创建存储过程的基本语法:

```sql
CREATE OR REPLACE PROCEDURE <procedure_name> 
(<variable_name>IN/OUT/IN OUT <datatype>,
   <variable_name>IN/OUT/IN OUT <datatype>,...) IS/AS
variable/constant declaration;
BEGIN
	-- PL/SQL subprogram body;
EXCEPTION
	-- Exception Handling block ;
END <procedure_name>; 
```

让我们理解上面的代码，

*   **过程名**是过程名，**变量名**是存储过程中使用的变量的变量名。
*   `CREATE or REPLACE PROCEDURE`是用于指定要创建的过程的名称的关键字。
*   `BEGIN`、`EXCEPTION`和`END`是用于指示正在创建的过程的不同部分的关键词。
*   输入/输出/输入输出是参数模式。
*   模式中的**指的是**只读模式**，该模式用于变量，通过该变量它将接受来自用户的值。这是默认的参数模式。**
*   **输出**模式是指**只写模式**，用于将值返回给用户的变量。
*   **输入输出**模式是指**读写模式**，该模式用于变量，该变量要么接受用户的值，要么将该值返回给用户。
*   最后，<procedure_name>是可选写的，可以简单使用`END`语句结束过程定义。</procedure_name>

* * *

### 是时候举个例子了！

在下面的代码示例中，我们创建了一个简单的程序来演示如何使用存储过程来添加两个数字:

```sql
set serveroutput on;

CREATE OR REPACE PROCEDURE Sum(a IN number, b IN number) IS
c number; 
BEGIN
	c := a+b;
	dbms_output.put_line('Sum of two nos= '|| c);
END Sum;

```

已创建过程。

为了调用创建的过程，将执行以下代码:

```sql
set serveroutput on;

DECLARE
	x number;
	y number;
BEGIN
	x := &x;
	y := &y;
	Sum(x,y);
END;
```

输入 x: 10 的值输入 y: 20 的值两个数之和= 30 PL/SQL 过程已成功创建。

* * *

## 在 PL/SQL 中创建函数的语法

既然我们知道了如何创建存储过程，以及如何在另一个 PL/SQL 代码块中使用它们，那么是时候了解如何在 PL/SQL 中创建函数了。

```sql
CREATE OR REPLACE FUNCTION <function_name>
(<variable_name> IN <datatype>,
<variable_name> IN <datatype>,...)
RETURN <datatype> IS/AS
variable/constant declaration;
BEGIN
	-- PL/SQL subprogram body;
EXCEPTION
	-- Exception Handling block ;
END <function_name>; 
```

让我们理解上面的代码，

*   **函数名**用于定义函数名，**变量名**是函数中使用的变量的变量名。
*   `CREATE or REPLACE FUNCTION`是用于指定要创建的函数的名称的关键字。
*   模式中的**指的是**只读模式**，该模式用于变量，通过该变量它将接受来自用户的值。这是默认的参数模式。**
*   `RETURN`是一个关键字，后跟一个数据类型，指定函数将返回的值的数据类型。

上述代码的大部分类似于用于定义存储过程的代码。

* * *

### 是时候举个例子了！

在下面的代码中，我们有一个程序来演示如何使用函数将两个数字相加。

```sql
set serveroutput on;

CREATE OR REPLACE FUNCTION Sum(a IN number, b IN number) RETURN Number IS
c number;
BEGIN
	c := a+b;
	RETURN c;
END; 
```

创建的函数

为了调用函数`Sum`，将执行以下代码:

```sql
set serveroutput on;

DECLARE
	no1 number;
	no2 number;
	result number;
BEGIN
	no1 := &no1;
	no2 := &no2;
	result := Sum(no1,no2);
dbms_output.put_line(‘Sum of two nos=’||result);
END;
```

输入 no1:5 的值输入 no2:5 的值两个 no 之和=10 PL/SQL 过程已成功创建。

有了这些，现在我们知道了如何在 PL/SQL 中定义和使用存储过程，以及如何在 PL/SQL 中定义和使用函数。

* * *

* * *