# PL/SQL 中的游标

> 原文：<https://www.studytonight.com/plsql/plsql-cursor>

在本教程中，我们将学习 PL/SQL 中的游标，它只不过是指向 oracle 引擎的工作区或上下文区的指针。

光标是指向**工作区**或上下文区的指针，由 oracle 引擎用于**执行 SQL 语句**。这样的工作区是 oracle 引擎专用于 SQL 操作的。

当 oracle 引擎执行一个 SQL 语句时，返回的数据行存储在游标中，称为**活动数据集**。并且游标占用了保存活动数据集中的行数所需的内存大小。

包含从表中检索的值的游标由 oracle engine 在主内存的预定义区域中打开。该数据然后通过网络传输到客户端机器。

* * *

## PL/SQL 中游标的类型

根据创建和使用光标的条件，光标可以分为两种类型:

NaN.  隐式光标
NaN.  显式光标

### 隐式光标

在执行任何类似`INSERT`、`UPDATE`或`DELETE`的 DML(数据操作语言)查询时，由 Oracle 引擎自动创建、维护和关闭的游标称为隐式游标。

隐式游标由 Oracle 控制，程序员不能访问它的信息。

当执行 DML 语句时，会创建一个隐式游标并附加到它上面。

### 显式光标

为了执行任何返回多行的`SELECT`查询，必须由程序通过 PL/SQL 代码创建、维护和关闭的游标称为显式游标。

它是一个在 PL/SQL 块的`Declare`部分声明的用户定义的光标，用于其可执行部分。

* * *

## 使用显式光标

要定义光标，需要遵循以下步骤:

*   **声明光标**

    这是在 PL/SQL 代码的声明部分通过编写检索数据进行处理的 SQL 语句来完成的。

    **Syntax:**

    ```sql
    CURSOR <cursor_name> IS <SELECT query>;
    ```

    例如，如果我们有**用户**表，该表具有列 **id** 、**名称**和**电子邮件**，那么为了执行`SELECT`查询，我们可以这样声明光标:

    ```sql
    CURSOR c_users IS 
    	SELECT id, name, email FROM users;
    ```

*   **打开光标**

    这是在 PL/SQL 代码的开始部分完成的。通过打开游标，为游标分配了获取记录的内存。

    **Syntax:**

    ```sql
    OPEN <cursor_name>;
    ```

    对于上面声明的`c_users`光标，它将是:

    ```sql
    OPEN c_users;
    ```

*   **获取光标**

    要一次一行地将光标中的数据提取到内存变量中，我们使用`FETCH`命令。

    **语法:**

    ```sql
     fetch <cursor_name> into <list_of_variables>;
    ```

*   要检查光标是否打开，我们使用光标的`%ISOPEN`属性。

    **语法:**

    ```sql
    if  <cursor_name> %ISOPEN
    ```

*   确定提取是否成功。这可以通过使用`FOUND`或`NOT FOUND`属性来实现，因为如果 fetch 命令未能从游标中检索到任何行，则它会将“发现”设置为 false，而不是“发现”为 true。
*   为了处理存储在内存变量中的数据，我们需要一个循环(我们稍后会谈到这一点)。
*   处理完成后，使用 Exit 语句退出循环。
*   然后，使用`CLOSE`命令关闭光标。
**Syntax:**

```sql
CLOSE cursorname;
```

* * *

### 光标属性

要使用隐式或显式游标，可以使用以下属性:

| 属性名 | 描述 |
| `%ISOPEN` | 如果光标打开，它返回一个布尔值**真**否则它返回布尔值**假** |
| `%FOUND` | 如果光标提取的记录成功，则返回布尔值**真**，否则返回布尔值**假** |
| `%NOTFOUND` | 如果光标提取的记录不成功，则返回布尔值**真**，否则返回布尔值**假** |
| `%ROWCOUNT` | 它返回受 PL/SQL 语句影响的行数 |

* * *

## 是时候举个例子了！

最后，让我们看看一个光标在行动。下面我们有一个 4 列的学生表，即**rollino**、 **SNAME** 、 **AGE** 、 **COURSE** 。

| 滚装船 | SNAME | 年龄 | 课程 |
| Eleven | 安奴 | Twenty | 平衡计分卡 |
| Twelve | 阿莎 | Twenty-one | 商学士 |
| Thirteen | 阿坡 | Eighteen | 喹啉甲酸 |
| Fourteen | 男性 | Twenty | 喹啉甲酸 |
| Fifteen | 波动 | Nineteen | BBA |

上表学生将在下面的程序中使用，我们将使用`SELECT`查询获取所有学生的姓名，将其存储在光标中，然后围绕光标循环打印姓名。

```sql
DECLARE
	CURSOR student_cursor IS SELECT sname FROM Student ;
	snm Student.sname %type;
BEGIN
	OPEN student_cursor;
	IF student_cursor%ISOPEN FALSE then
		dbms_output.put_line('Cannot open cursor');
	ELSE
		LOOP
			FETCH student_cursor INTO snm;
			IF student_cursor%NOTFOUND then
				Exit;
			END IF;
			dbms_ output.put_line('' ||snm);
		END LOOP;
		dbms_output.put_line('Total Records: ' ||student_cursor%rowcount);
	CLOSE student_cursor;
END;
```

Anu Asha Arpit Chetan Nihal 总记录:5 PL/SQL 程序成功完成。

在上面的程序中，

*   我们使用了一个名为`student_cursor`的光标。
*   输出显示学生的姓名以及找到的记录总数。

* * *

## 用于循环的光标

游标`FOR LOOP`是一个用于游标的循环，当存储在游标中的所有数据被迭代时，它会自动检查行数并退出循环。用于循环的光标会自动执行以下操作:

*   隐式声明其循环索引为`%rowtype`记录
*   打开光标
*   为每次迭代从游标中检索记录
*   处理完所有记录后关闭光标。
*   也可以使用`EXIT`或`GOTO`语句关闭光标。

**Syntax:**

```sql
FOR variable_name IN cursor_name LOOP
	-- Executable statements
END LOOP; 
```

* * *

### 显示光标用于循环的示例

下面我们有一个简单的 PL/SQL 代码块，展示了循环游标的使用:

```sql
DECLARE
	CURSOR student_cursor IS SELECT sname FROM Student;
BEGIN
	FOR snm IN student_cursor LOOP	
		dbms_output.put_line('' || snm);
	END LOOP;
END; 
```

Anu Asha Arpit Chetan Nihal PL/SQL 程序成功完成。

在上面的程序中，

*   使用名为`student_cursor`的光标。
*   输出显示学生的姓名。

* * *

## 什么是参数化光标？

参数化游标是一种带有参数的游标，它允许我们使用包含变量的条件创建动态 SQL 查询。

这里我们有参数化游标声明的语法:

```sql
CURSOR cursor_name (variable_name Datatype) IS <SELECT statement...>;
```

声明参数化游标后，当我们打开它时，我们必须提供参数化游标中要使用的值，如下所示:

```sql
OPEN cursor_name(value/variable/expression);
```

让我们举一个例子来演示参数化游标的使用:

```sql
set serveroutput on;

DECLARE
	CURSOR showRec(sno student.rollno%type) IS SELECT sname, course FROM student WHERE rollno=sno;
	a  student.sname%type;
	b  student.course%type;
	c  student.rollno%type;
BEGIN
    d := &rollno;
	OPEN showRec(d);
		IF showRec%Isopen = FALSE then
			dbms_output.put_line('Cannot open Cursor');
		ELSE
			LOOP
				FETCH showRec into a,b;
				EXIT WHEN showRec%NOTFOUND;
				dbms_output.put_line(a|| '' ||b);
			END LOOP;
		End IF;
	CLOSE showRec;
END;
```

输入 d:12-| SNAME | COURSE | = = = = = = = = = = = = = = = = = = = = = = = = = = = = = | Asha | BCOM |-PL/SQL 过程已成功完成。

在上面的程序中，

*   使用名为`student_cursor`的光标。
*   输出显示学生的**姓名**和**课程**，该学生的**号**是在程序执行期间由用户输入的。

* * *

* * *