# PL/SQL 中的触发器

> 原文：<https://www.studytonight.com/plsql/plsql-triggers>

oracle 中的触发器是 PL/SQL 代码块，oracle 引擎可以根据某些操作或事件自动执行这些代码块。

这些事件可以是:

*   语句(创建、更改、删除、截断)
*   DML 语句(插入、选择、更新、删除)
*   数据库操作，如连接或断开与 oracle 的连接(登录、注销、关机)

满足特定条件时，oracle 引擎会自动重复调用触发器。

触发器可以根据需要激活或停用。

如果触发器被激活，则由 oracle 引擎隐式执行；如果触发器被停用，则由 oracle 引擎显式执行。

* * *

## 触发器的使用

这里我们提到了一些使用触发器非常有用的用例:

*   维护复杂的约束，通过常规的约束(如主要的、外来的、独特的等)应用技术，这不是不可能就是非常困难。
*   记录在桌面上所做的更改。
*   自动生成主键值。
*   防止无效交易发生。
*   向数据库授予授权并提供安全性。
*   强制引用完整性。

* * *

## 触发器的一部分

每当创建触发器时，它都包含以下三个连续部分:

*   **触发事件或语句:**触发事件发生的语句称为触发事件或语句。这样的语句可以是 DDL 语句、DML 语句或任何数据库操作，执行这些语句会引发触发器。
*   **触发限制:**对触发器施加的条件或任何限制称为触发限制。因此，如果这样的条件是**真**，则触发发生，否则不发生。
*   **触发动作:**包含当触发发生时要执行的可执行语句的主体，该可执行语句与触发语句一起执行，并且在将触发限制评估为**真时**被称为触发动作。

* * *

## 触发器的类型

上图清楚地表明，触发器可以分为三类:

1.  电平触发器
2.  事件触发器
3.  定时触发器

**进一步分为不同的部分。**

### 电平触发器

有两种不同类型的级别触发器，它们是:

1.  **行级别触发**
    *   它会为执行 DML 语句(如插入、更新、删除等)而受到影响的每一条记录触发。
    *   它总是在触发语句中使用`FOR EACH` ROW 子句。
2.  **语句级别触发**
    *   它对执行的每个语句触发一次。

### 事件触发器

有 3 种不同类型的事件触发器，它们是:

1.  **驾驶员侧车门开启事件触发器**
    *   它会随着每个 DDL 语句的执行而触发(CREATE、ALTER、DROP、TRUNCATE)。
2.  **DML 事件触发器**
    *   它在执行每个 DML 语句(插入、更新、删除)时触发。
3.  **数据库事件触发器**
    *   它随着每个数据库操作的执行而触发，这些操作可以是登录、注销、关机、服务器错误等。

### 定时触发器

有两种不同类型的定时触发器，它们是:

1.  **触发前**
    *   它在执行 DML 语句之前激发。
    *   触发语句可以执行，也可以不执行，这取决于 before 条件块。
2.  **触发后**
    *   它在执行 DML 语句后激发。

* * *

### 创建触发器的语法

以下是创建触发器的语法:

```sql
CREATE OR REPLACE TRIGGER <trigger_name>
BEFORE/AFTER/INSTEAD OF
	INSERT/DELETE/UPDATE ON <table_name>
REFERENCING (OLD AS O, NEW AS N)
	FOR EACH ROW WHEN (test_condition)
DECLARE
	-- Variable declaration;
BEGIN
	-- Executable statements;
EXCEPTION
	-- Error handling statements;
END <trigger_name>;
END; 
```

哪里，

`CREATE OR REPLACE TRIGGER`是用于创建触发器的关键字， **< trigger_name >** 是用户定义的，其中触发器可以被赋予名称。

`BEFORE/AFTER/INSTEAD OF`指定触发发生的时间。创建视图时使用`INSTEAD OF`。

**插入/更新/删除**指定 DML 语句。

**<表名>** 指定要应用 DML 语句的表的名称。

`REFERENCING`是用于为 DML 语句提供新旧值引用的关键字。

`FOR EACH ROW`是用于指定行级跳跳虎的子句。

`WHEN`是用于指定要应用的条件的子句，仅适用于行级触发器。

`DECLARE`、`BEGIN`、`EXCEPTION`、`END`分别是 PL/SQL 代码块中包含变量声明、可执行语句、错误处理语句和标记 PL/SQL 块结束的不同部分，其中 DECLARE 和 EXCEPTION 部分是可选的。

* * *

### 是时候举个例子了！

下面我们有一个简单的程序来演示触发器在 PL/SQL 代码块中的使用。

```sql
CREATE OR REPLACE TRIGGER CheckAge
BEFORE
INSERT OR UPDATE ON student
FOR EACH ROW
BEGIN
	IF :new.Age>30 THEN
		raise_application_error(-20001, 'Age should not be greater than 30');
	END IF;
END; 
```

触发器已创建。

下面是学生表，

| 滚装船 | SNAME | 年龄 | 课程 |
| Eleven | 安奴 | Twenty | 平衡计分卡 |
| Twelve | 阿莎 | Twenty-one | 商学士 |
| Thirteen | 阿坡 | Eighteen | 喹啉甲酸 |
| Fourteen | 男性 | Twenty | 喹啉甲酸 |
| Fifteen | 波动 | Nineteen | BBA |

在初始化触发器`CheckAge`之后，每当我们在上面的表 STUDENT 中插入任何新值或更新现有值时，我们的触发器都会在执行`INSERT`或`UPDATE`语句之前检查**年龄**，并根据触发限制或条件的结果执行该语句。

让我们举几个例子来试着理解这一点，

**例 1:**

```sql
INSERT into STUDENT values(16, 'Saina', 32, 'BCOM');
```

年龄不应大于 30 岁

**例 2:**

```sql
INSERT into STUDENT values(17, 'Anna', 22, 'BCOM');
```

创建了 1 行

**例 3:**

```sql
UPDATE STUDENT set age=31 where ROLLNO=12; 
```

年龄不应大于 30 岁

**例 4:**

```sql
 UPDATE STUDENT set age=23 where ROLLNO=12; 
```

更新了 1 行。

* * *