# PL/SQL 中的包

> 原文：<https://www.studytonight.com/plsql/plsql-packages>

包是一种将子程序，如[程序](plsql-procedure-and-function)、[函数](plsql-procedure-and-function)、异常或光标逻辑存储到单个公共单元中的方式。

包可以定义为一个被编译并存储在数据库中的 oracle 对象。

一旦它被编译并存储在数据库中，它就可以被对 Oracle 数据库具有可执行权限的所有数据库用户使用。

### 包装的成分

包有两个基本组件:

*   **规格**:是包装的申报部分
*   **正文**:是一个包的定义部分。

* * *

### 使用软件包的好处

以下是 PL/SQL 中包的一些好处:

1.  **REUSABILITY**

    每当创建包时，它都会被编译并存储在数据库中。因此，您只需编写一次代码，它就可以被其他应用程序重用。

2.  **OVERLOADING**

    在一个同名的包中可以创建两个或多个 >过程或函数。

3.  **CREATING MODULES**

    一个大的应用程序可以通过简单地创建模块(或子程序)来创建，这些模块定义清晰且易于工作。

4.  **IMPROVES PERFORMANCE**

    包代码在第一次调用自身时被加载到 Oracle 的 SGA(系统全局区域)中，因此其他后续调用将非常快速地工作。

5.  **GLOBAL DECLARATION**

    如果对象(过程、函数、[变量](plsql-variables)、常量、[异常](plsql-exception-handling)、[光标](plsql-cursor)等)在一个包中全局声明，则在需要时可以很容易地使用它们。

* * *

## 如何创建一个 PL/SQL 包？

以下是在 PL/SQL 代码块中声明和使用包的步骤:

### 第一步:包装规范或声明

它主要包括以下内容:

*   包名。
*   变量/常量/游标/过程/函数/异常声明。
*   该声明对包是全局的。

以下是**语法:**

```sql
CREATE OR REPLACE PACKAGE <package_name> IS/AS
	FUNCTION <function_name> (<list of arguments>) 
	RETURN <datatype>;
	PROCEDURE <procedure_name> (<list of arguments>);
	-- code statements
END <package_name>; 
```

哪里，

`CREATE OR REPLACE PACKAGE`是用于创建包的关键字

`FUNCTION`和`PROCEDURE`是创建包时用于声明函数和过程的关键字。

**<包 _ 名称>** 、 **<功能 _ 名称>** 、 **<程序 _ 名称>** 均为自定义名称。

`IS/AS`是用于申报包的关键字。

`RETURN`是指定由声明的函数返回的值的关键字。

### 步骤 2:包装主体

它主要包括以下内容:

*   它包含在包规范中声明的过程、函数或游标的定义。
*   它包含子程序体，子程序体包含已为其创建包的可执行语句

以下是**语法:**

```sql
CREATE  OR REPLACE PACKAGE BODY <package_name> IS/AS
FUNCTION <function_name> (<list of arguments>) RETURN <datatype>IS/AS
	-- local variable declaration;
	BEGIN
		-- executable  statements;
	EXCEPTION
		-- error handling statements;
END <function_name>;

PROCEDURE <procedure_name> (<list of arguments>)IS/AS
	-- local variable declaration;
	BEGIN
		-- executable statements;
	EXCEPTION
		-- error handling statements;
	END <procedure_name>;
END <package_name>;
```

哪里，

`CREATE OR REPLACE PACKAGE BODY`是用于创建带有正文的包的关键字。

`FUNCTION`和`PROCEDURE`是创建包时用于定义功能和过程的关键字。

**<包 _ 名称>** 、 **<功能 _ 名称>** 、 **<程序 _ 名称>** 均为用户自定义。

`IS/AS`是用于定义包体、功能和过程的关键字。

`RETURN`是指定由定义的函数返回的值的关键字。

`DECLARE`、`BEGIN`、`EXCEPTION`、`END`分别是 PL/SQL 代码块中包含变量声明、可执行语句、错误处理语句和标记 PL/SQL 块结束的不同部分，其中 DECLARE 和 EXCEPTION 部分是可选的。

**注意:**创建包只是定义它，要使用它我们必须使用包对象引用它。

以下是**引用包对象**的语法:

```sql
Packagename.objectname;
```

对象可以是函数、过程、游标、异常，它们已在包规范中声明并在包主体中定义，要访问它们的可执行语句，请使用上述语法。

### 是时候举个例子了！

我们有如下指定的学生表:

| 滚装船 | SNAME | 年龄 | 课程 |
| Eleven | 安奴 | Twenty | 平衡计分卡 |
| Twelve | 阿莎 | Twenty-one | 商学士 |
| Thirteen | 阿坡 | Eighteen | 喹啉甲酸 |
| Fourteen | 男性 | Twenty | 喹啉甲酸 |
| Fifteen | 波动 | Nineteen | BBA |

让我们编写一个简单的程序来演示包在 PL/SQL 中的使用。

**包规格的 PL/SQL 代码:**

```sql
CREATE OR REPLACE PACKAGE pkg_student IS
	PROCEDURE  updateRecord(sno student.rollno%type);
	FUNCTION deleteRecord(snm student.sname%type)
		RETURN boolean;
END pkg_student; 
```

已创建包

**包体 PL/SQL 代码:**

```sql
 set serveroutput on;
CREATE OR REPLACE PACKAGE BODY pkg_student IS
	PROCEDURE updateRecord(sno student.rollno%type) IS
		BEGIN
			Update student set age=23 where rollno=sno;
			IF  SQL%FOUND THEN
				dbms_output.put_line('RECORD UPDATED');
			ELSE
				dbms_output.put_line('RECORD NOT FOUND');
			END IF;
		END updateRecord;

	FUNCTION deleteRecord(snm student.sname%type) RETURN boolean IS
		BEGIN
			Delete from student where sname=snm;
			RETURN SQL%FOUND;
		END deleteRecord;
END pkg_student;
```

已创建包主体

现在让我们编写 **PL/SQL 代码，用于调用包**中使用的过程和函数。

```sql
 set serveroutput on;
DECLARE
	sno student.rollno%type;
	s_age student.age%type;
	snm student.sname%type;
BEGIN
	sno := &sno;
	snm := &snm
	pkg_student.updateRecord(sno);
	IF pkg_student.deleteRecord(snm) THEN
		dbms_output.put_line('RECORD DELETED');
	ELSE
		dbms_output.put_line('RECORD NOT FOUND');
	END IF;
END;
```

输入 sno: 12 的值输入 snm: Neha 记录更新记录未找到 PL/SQL 过程成功完成的值。

**注意:**如果创建的包规范或包主体存在编译错误，则屏幕上会显示以下警告消息:

警告:创建的包体有编译错误。

在这种情况下，可以通过执行以下语句来查看错误:

```sql
 SHOW ERRORS;
```

在下一个教程中，我们将介绍 PL/SQL 中的事务。

* * *

* * *