# PL/SQL 事务

> 原文：<https://www.studytonight.com/plsql/plsql-transactions>

事务是通过在 PL/SQL 代码块中执行 SQL 语句而执行的一系列操作，其中适用以下规则:

1.  如果我们在一个事务中有一组语句，那么完整的语句集将作为一个块执行，其中如果一个语句失败了，所有先前成功的语句执行的影响也将恢复。
2.  在事务中，要么所有语句都成功执行，要么都不执行。
3.  事务的范围通过使用 COMMIT 和 ROLLBACK 命令来定义

* * *

## 使用 PL/SQL 事务

它有开始也有结束。

每当遇到第一条 SQL 语句(特别是 DML 命令`INSERT`、`UPDATE`、`DELETE`、`SELECT`)时，事务开始，当执行`COMMIT`或`ROLLBACK`命令时，事务结束。

### 使用 COMMIT

提交命令在每个 DML 命令之后执行，因为它们不像 DDL 命令那样自动保存或提交。这样，commit 命令会永久更改数据库中的数据。

以下是**语法:**

```sql
Commit;
```

**注意:**默认情况下，DML 命令的**自动提交关闭**。可以使用以下命令设置 DML 命令的自动提交:

```sql
set autocommit on;
-- and to turn it off
set autocommit off;

```

### 使用回滚

回滚意味着**撤销**。每当执行**回滚**命令时，它将结束事务并撤消事务期间所做的所有更改。回滚可以应用于那些未提交的事务。

如果回滚命令在提交命令之后执行，它将不会有任何影响，因为在这种情况下，提交命令将使事务中所做的更改永久化。

以下是**语法:**

```sql
Rollback [to savepoint <savepointname >];
```

哪里，

**保存点**是一个可选参数，用于将事务部分回滚到某个指定点。

**保存点名称**是事务期间创建的保存点的名称，由用户定义。

### 使用保存点

对于较长的事务，保存点非常有用，因为它将较长的事务分成较小的部分，并将事务的某些点标记为检查点。

当我们想要回滚事务的特定部分，而不是将回滚应用于事务的不需要的部分或整个事务时，这很有用。

例如，如果一个完整的事务有 8 条 DML 语句，并且我们在 4 条语句之后创建了一个保存点，那么如果在执行第 6 条语句之后，由于某种原因，我们想要回滚第 4 条语句，那么我们可以很容易地做到这一点，并且事务可以从第 4 条语句开始再次执行。

以下是**语法:**

```sql
Savepoint  <savepointname>;
```

* * *

## 是时候举个例子了！

下面我们有一个 PL/SQL 程序来演示事务的执行，

```sql
set serveroutput on;

DECLARE
	rollno student.sno%type;
	snm student.sname%type;
	s_age student.age%type;
	s_cr student.course%type;
BEGIN
	rollno := &sno;
	snm := '&sname';
 	s_age := &age;
	s_cr := '&course';
	INSERT into student values(rollno,snm,age,course);
	dbms_output.put_line('One record inserted');
	COMMIT;
END; 
```

在 PL/SQL 块的上述代码中，数据库中有一个名为 **STUDENT** 的表，列 **sno** 为数字， **sname** 为 varchar2， **age** 为数字，**课程**为 varchar2。

在代码中，我们执行了`INSERT`语句，然后使用`COMMIT`语句将更改提交或永久保存到数据库中。

代替`COMMIT`语句，如果我们在那里使用`ROLLBACK`语句，那么即使`INSERT`语句执行成功，但是，在执行 PL/SQL 块之后，如果您将检查数据库中的 student 表，您将不会找到新的 Student 条目，因为我们执行了`ROLLBACK`语句，并且它回滚了更改。

### 带保存点和回滚的 PL/SQL 代码示例

让我们在上面的代码中添加两个 insert 语句，并在它们之间放置一个保存点，然后使用`ROLLBACK`命令恢复一个 insert 语句的更改。

```sql
set serveroutput on;

DECLARE
	rollno student.sno%type;
	snm student.sname%type;
	s_age student.age%type;
	s_cr student.course%type;
BEGIN
	rollno := &sno;
	snm := '&sname';
 	s_age := &age;
	s_cr := '&course';
	INSERT into student values(rollno,snm,age,course);
	dbms_output.put_line('One record inserted');
	COMMIT;
	-- adding savepoint
	SAVEPOINT savehere;
	-- second time asking user for input
	rollno := &sno;
	snm := '&sname';
 	s_age := &age;
	s_cr := '&course';
	INSERT into student values(rollno,snm,age,course);
	dbms_output.put_line('One record inserted');
	ROLLBACK [TO SAVEPOINT savehere];
END; 
```

执行上述代码后，我们将在 Student 表中创建一个条目，而第二个条目将被回滚。

* * *

* * *