# PL/SQL 中的锁

> 原文：<https://www.studytonight.com/plsql/locks-in-plsql>

**PL/SQL 中的锁**是维护数据库数据完整性的一种方式。因为 oracle 是一个多用户平台，在这个平台上，数据库中使用的表充当多个用户同时共享的全局资源。

由于多个用户同时对数据进行并发处理，数据可能会变得不一致。因此，锁在维护并发控制方面起着重要的作用，确保数据库中存储数据的数据完整性。

* * *

## PL/SQL:锁的类型

以下是 Oracle 中两种不同类型的锁定:

1.  隐式锁定
2.  显式锁定

* * *

### 隐式锁定

这是 oracle 引擎根据以下两个因素自动锁定数据库:

1.  要应用的锁的类型。
2.  要应用的锁定级别。

让我们逐一看看这两个因素:

**1。要使用的锁的类型**

根据对数据库执行的操作类型(读或写)，有两种类型的锁。

| 锁的类型 | 描述 |
| 共享锁 | 

*   Apply to the table that is viewing data, that is, reading the stored data.
*   Multiple shared locks can be applied to a table at the same time.
*   Used in the case of `SELECT` statement.

 |
| 互锁 | 

*   Apply to tables that are changing data (that is, writing data).
*   Only one exclusive lock can be placed at a time.
*   Used in the case of `INSERT`, `UPDATE` and `DELETE` statements.

 |

**2。要应用的锁定级别:**

锁定可以在三个级别上完成:

1.  **行级**:当使用`WHERE`子句在单行(或记录)的查询中应用条件时使用。
2.  **页面级**:当使用`WHERE`子句对某组数据(某些记录)进行查询时，使用该条件。
3.  **表级**:在使用`WHERE`子句对整个数据表(某些记录)进行查询时应用该条件时使用。

* * *

### 显式锁定

这是用户根据其授予的表权限对数据库进行的用户定义的锁定。这种类型的锁定覆盖了隐式锁定。显式锁定可以通过使用以下方法之一来完成:

1.  挑选...对于更新语句

2.  锁表语句

**1。选择…更新声明:**

以下是该语句的语法:

**语法:**

```sql
SELECT * FROM tablename WHERE condition For Update Nowait;
```

让我们举几个例子来看看，

假设两个客户端，客户端 X 和客户端 Y 在同一个数据库表 **flight_detail** 上执行事务

以下是**客户端 X** 运行的查询:

```sql
SELECT * from flight_detail where city='DELHI' For Update;
```

当执行上述`SELECT`语句时，oracle 引擎会自动锁定城市为**德里**的记录，并且只有当客户端 X 将执行`COMMIT`或`ROLLBACK`命令时，才能释放该锁定。

现在让我们看看**客户端 Y** 运行的查询:

```sql
SELECT * from flight_detail where city='DELHI' For Update;
```

现在**客户端 Y** 对已经被**客户端 X** 的 oracle 引擎锁定的同一记录执行`SELECT`语句。因此在这种情况下，客户端 Y 必须等待直到客户端 X 通过执行`COMMIT`语句释放锁。

因此，为了克服不必要的等待时间`NOWAIT`选项可以用来通知 oracle 引擎记录已经被锁定，并且它可以终止语句。

所以如果**客户端 Y** 使用`NOWAIT`选项执行查询，

```sql
SELECT * from flight_detail where city='DELHI' For Update Nowait;
```

随着上述语句的执行，oracle 引擎在输出*资源繁忙*中显示消息。

**注:**

Select…For update 语句不能与**组功能**、**组运算符**、**组运算符**和**不同的**子句一起使用。

* * *

## 锁表语句

我们还可以通过执行 Lock table 语句来获取表上的锁。

以下是**语法:**

```sql
LOCK TABLE tablename in lock mode WAIT/NOWAIT;
```

哪里，

锁定模式可以是以下模式之一:

*   `EXCLUSIVE`:允许对锁定的表进行查询。
*   `SHARE`:允许查询，但限制对表的更新。
*   `ROW EXCLUSIVE`:允许多用户并发访问表，但限制以独占或共享模式锁定表。
*   `SHARE ROW EXCLUSIVE`:允许查看整个表记录，但限制在共享模式下锁定表，也限制对表的 UPDATE。

`WAIT`表示 oracle 引擎将等待，直到资源自由可用。

`NOWAIT`表示 oracle 引擎不会等待资源可用，而是向用户显示消息**资源正忙**。

* * *

* * *