# Java 中的数据类型

> 原文：<https://www.studytonight.com/java/datatypes-and-identifier.php>

Java 语言有丰富的数据类型实现。数据类型指定可以存储在标识符中的值的大小和类型。

在 java 中，数据类型分为两类:

1.  原始数据类型
2.  非原始数据类型

* * *

## 1)原始数据类型

原始数据类型可以有八种类型:

| 原始数据类型 |
| `char` | `boolean` | `byte` | `short` | `int` | `long` | `float` | `double` |

一旦一个原始数据类型被声明，它的类型就永远不会改变，尽管在大多数情况下它的值会改变。这八种原始类型可以分为四组

#### 整数

这组包括`byte`、`short`、`int`、`long`

**字节:**为 1 字节(8 位)整数数据类型。值的范围从-128 到 127。默认值为零。示例:`byte b=10;`

**短:**2 字节(16 位)整数数据类型。值的范围从-32768 到 32767。默认值为零。示例:`short s=11;`

**int :** 是 4 字节(32 位)整数数据类型。值范围从-2147483648 到 2147483647。默认值为零。示例:`int i=10;`

**长:**8 字节(64 位)整数数据类型。数值范围从-9，223，372，036，854，775，808 到 9，223，372，036，854，775，807。默认值为零。示例:`long l=100012;`

**示例:**

让我们创建一个使用**`Integer`类型**数据的例子，我们可以了解如何在 java 程序中使用数据类型。

```java
	 package corejava;

public class Demo{      

    public static void main(String[] args) {
    	// byte type
    	byte b = 20;
    	System.out.println("b= "+b);

    	// short type
    	short s = 20;
    	System.out.println("s= "+s);

    	// int type
    	int i = 20;
    	System.out.println("i= "+i);

    	// long type
    	long l = 20;
    	System.out.println("l= "+l);

    }  
} 

```

b= 20 s= 20 i= 20 l= 20

#### 浮点数

该组包括`float`、`double`

**浮点:**是 4 字节(32 位)浮点数据类型。默认值 0.0f .示例:`float ff=10.3f;`

**double :** 是 8 字节(64 位)浮点数据类型。默认值 0.0d .示例:`double db=11.123;`

**示例:**

在这个例子中，我们使用`Float`类型和声明的变量来保存浮点值。`Float`类型**对于存储小数点值很有用。**

```java
	 public class Demo{      

    public static void main(String[] args) {
    	// float type
    	float f = 20.25f;
    	System.out.println("f= "+f);

    	// double type
    	double d = 20.25;
    	System.out.println("d= "+d);

    }  
} 

```

f= 20.25 d= 20.25

#### 特性

该组代表`char`，表示字符集内的符号，如字母和数字。

**字符:**2 字节(16 位)无符号 unicode 字符。范围从 0 到 65，535。示例:`char c='a';`

#### `Character`类型示例

Java 中的`Character`类型使用 2 字节到 unicode 字符。因为它使用 unicode，所以我们可以存储字母表字符、货币字符或 unicode 集合下的其他字符。

```java
    public class Demo {

    public static void main(String[] args) {

        char ch = 'S';
        System.out.println(ch);

        char ch2 = '&';
        System.out.println(ch2);

        char ch3 = '$';
        System.out.println(ch3);

    }

} 

```

新元

#### 布尔代数学体系的

这组表示`boolean`，这是一种表示真/假值的特殊类型。它们被定义为语言的常量。示例:`boolean b=true;`

#### `Boolean`类型示例

Java 中的`Boolean`类型只能处理两个值，要么是真要么是假。它主要用于条件表达式中，以执行基于条件编程。

```java
    public class Demo {

    public static void main(String[] args) {

        boolean t = true;
        System.out.println(t);

        boolean f = false;
        System.out.println(f);

    }

} 

```

真假

## 2)非原始(引用)数据类型

引用数据类型用于引用对象。引用变量被声明为特定，且该类型永远不能更改。

例如: **String str** ，这里 str 是 String 类型的引用变量。字符串是 Java 中的一个类。我们将在后面的“类和对象”一课中详细讨论引用数据类型。

引用类型用于保存对象的引用。对象可以是任何类或实体的实例。

在面向对象系统中，我们处理存储属性的对象。为了引用这些对象，我们使用引用类型。

我们将在后面的“类和对象”一课中详细讨论引用数据类型。

* * *

### Java 中的标识符

所有 Java 组件都需要名称。用于类、方法、接口和变量的名称称为**标识符**。标识符必须遵循一些规则。以下是规则:

*   所有标识符必须以字母(A 到 Z 或 A 到 Z)或货币字符($)或下划线开头。
*   在第一个字符之后，标识符可以有任何字符组合。
*   Java **关键字**不能作为标识符。
*   Java 中的标识符区分大小写，foo 和 Foo 是两种不同的标识符。

一些有效的标识符是: **int a，class Car，float amount** 等。

* * *

* * *