# Java `LocalDate.range()`方法

> 原文：<https://www.studytonight.com/java-examples/java-localdate-range-method>

Java range()方法用于获取指定字段的有效值范围。范围值表示字段的最小和最大有效值。例如，如果我们想得到**10 月**的天数，那么我们得到这个月的**范围 1-31** 。

我们可以使用`ChronoField`枚举作为参数来获取指定字段的范围。`ChronoField`枚举有以下值:

| 田 | 描述 |
| 对齐 _ 周 _ 月 _ 日 | 一个月内一致的星期几。 |
| 年 _ 月 _ 日 _ 周 _ 对齐 | 一年中一致的星期几。 |
| 每月的第 _ 周 | 一个月内一致的一周。 |
| 对齐 _ 周 _ 年 | 一年内一致的一周。 |
| 当日 AMPM | 每天的上午-下午。 |
| AMPM 时间 | 上午 10 点至下午 1 点的时钟。 |
| 一天中的钟点 | 一天中的整点钟。 |
| 月日 | 每月的某一天。 |
| 星期几 | 一周中的某一天，如星期二。 |
| 一年中的第 _ 天 | 一年中的某一天。 |
| 纪元日 | 纪元日，基于 1970-01-01(国际标准化组织)的 Java 纪元。 |
| 时代 | 时代。 |
| AMPM 时间 | 上午-下午的时间。 |
| 一天中的小时 | 一天中的某个时刻。 |
| 即时 _ 秒 | 瞬间划时代-秒。 |
| 微观 _OF_DAY | 微观的一天。 |
| 微秒 | 几分之一秒。 |
| 百万分之日 | 日复一日。 |
| 毫欧秒 | 毫秒。 |
| 每天分钟 | 一天中的一分钟。 |
| 分钟/小时 | 分秒必争。 |
| 年月日 | 一年中的月份，如三月。 |
| 纳米日 | 纳米时代。 |
| 第二纳米 | 纳米秒。 |
| 偏移量 _ 秒 | 与世界协调时/格林威治时间的偏移量。 |
| prolective _ MONTH | 基于月份的预测，从第 0 年开始按顺序计算月份。 |
| 第二天 | 第二天。 |
| 第二分钟 | 一分一秒。 |
| 年 | 预测年，如 2012 年。 |
| 纪元年 | 时代内的一年。 |

## 句法

```java
public ValueRange range(TemporalField field)
```

## 参数:

**字段-** 要查询范围的字段。

## 返回:

它返回字段的有效值范围。

## 举例时间:

让我们举个例子来获取日期中月份的范围。我们正在使用`ChronoField`枚举通过使用`range()`方法来获取范围。

```java
import java.time.LocalDate;
import java.time.temporal.ChronoField;
import java.time.temporal.ValueRange; 
public class DateDemo {

	public static void main(String[] args){  

		LocalDate localDate = LocalDate.of(2012, 02, 29);
		System.out.println(localDate);
		ValueRange vr = localDate.range(ChronoField.DAY_OF_MONTH);
		System.out.println("Range : "+vr);
	}
}
```

2012-02-29
区间:1 - 29

## 另一个例子的时间:

我们再举一个例子来理解`range()`法。在这里，我们得到了日期中的年份范围，范围从 1 到 366。

```java
import java.time.LocalDate;
import java.time.temporal.ChronoField;
import java.time.temporal.ValueRange; 
public class DateDemo {

	public static void main(String[] args){  

		LocalDate localDate = LocalDate.of(2012, 02, 29);
		System.out.println(localDate);
		ValueRange vr = localDate.range(ChronoField.DAY_OF_YEAR);
		System.out.println("Range : "+vr);
	}
}
```

2012-02-29
区间:1 - 366

## 实时示例:

试着用一个真实的例子，用我们强大的在线 Java 编译器立即执行代码。

* * *

* * *