# Java `LocalDate.until(Temporal, TemporalUnit)`方法

> 原文：<https://www.studytonight.com/java-examples/java-localdate-untiltemporal-temporalunit-method>

Java 直到()方法用于获取到另一个日期为止的时间量，以指定的单位表示。它根据单个`TemporalUnit`计算两个`LocalDate`对象之间的时间量。如果结束日期早于开始日期，结果将为负。传递给此方法的`Temporal`使用`from(TemporalAccessor)`方法转换为`LocalDate`。

例如，如果我们想要获取两个本地日期之间的天数，然后使用`ChronoUnit`枚举值。`ChronoUnit`是提供单位`DAYS`、`WEEKS`、`MONTHS`、`YEARS`、`DECADES`、`CENTURIES`、`MILLENNIA`和`ERAS`的枚举。

这种方法类似于[直到(ChronalDate)](https://www.studytonight.com/java-examples/java-localdate-untilchronolocaldate-method)，它返回两个本地日期对象之间的周期。我们建议你也读读这个方法。

它需要两个参数，第一个是`Temporal`类型，第二个是`TemporalUnit`类型。给出了该方法的语法。

## 句法

```java
public long until(Temporal endExclusive, TemporalUnit unit) 
```

## 参数:

**endExclusive -** 结束日期，这是一个`LocalDate`

**单位-** 指定日期字段的单位。

## 返回:

它返回一个`Long`类型值。

## 举例时间:

让我们举个例子来说明两个日期之间的年份。这里，我们使用直到()方法来获取 2002-01-10 和 2005-10-12 日期之间的年份。

```java
import java.time.LocalDate;
import java.time.temporal.ChronoUnit;
public class DateDemo {

	public static void main(String[] args){  

		LocalDate localDate = LocalDate.of(2002, 01, 10);
		System.out.println(localDate);
		long period = localDate.until(LocalDate.of(2005,10,12), ChronoUnit.YEARS);
		System.out.println("Years : "+period);
	}
}
```

2002-01-10
年:3

## 另一个例子的时间:

我们再举一个例子来理解`until()`法。在这里，我们得到两个日期之间的天数，并使用计时单位。两次约会的天数。

```java
import java.time.LocalDate;
import java.time.temporal.ChronoUnit;
public class DateDemo {

	public static void main(String[] args){  

		LocalDate localDate = LocalDate.of(2002, 01, 10);
		System.out.println(localDate);
		long period = localDate.until(LocalDate.of(2005,10,12), ChronoUnit.DAYS);
		System.out.println("Days : "+period);
	}
}
```

2002-01-10
日数:1371

## 实时示例:

试着用一个真实的例子，用我们强大的在线 Java 编译器立即执行代码。

* * *

* * *