# 如何在 Java 中读取 CSV 文件

> 原文：<https://www.studytonight.com/java-examples/how-to-read-a-csv-file-in-java>

在这篇文章中，我们将使用 Java 代码读取一个 CSV 文件。CSV 是一个逗号分隔的文件，用于存储数据。

我们可以通过几种方式读取 CSV 文件，例如使用 Scanner 类或第三方提供的`OpenCSV`库。你可以在这里下载 [opencsv](https://mvnrepository.com/artifact/com.opencsv/opencsv/3.8) 的 JAR 文件。

在这里，我们有两个例子来理解 Java 中 CSV 文件的读取过程。

我们有一个示例 CSV 文件 **students.csv** ，用于从 Java 中读取数据。

**//学生. csv**

```java
101,'Rohan','India'
102,'Kumar','SriLanka'
103,'David','USA'
```

## 举例时间:

让我们创建一个读取 CSV 文件的示例。在这里，我们使用 OpenCSV 库和`CSVReader`类来读取文件。该库对于 CSV 文件处理非常有用。

```java
import com.opencsv.*;
import java.io.FileReader;
import java.io.IOException;
public class Main {
	public static void main(String[] args){  
		String csvFile = "students.csv";
        CSVReader csvReader = null;
        try {
        	csvReader = new CSVReader(new FileReader(csvFile));
            String[] value;
            while ((value = csvReader.readNext()) != null) {
                System.out.println(value[0] + " " + value[1] + " " + value[2]);
            }
        } catch (IOException e) {
            System.out.println(e);
        }
	}
}
```

101“罗汉”“印度”
102“库马尔”“斯里兰卡”
103“大卫”“美国”

## 另一个例子的时间:

但是，还有另一种读取 CSV 文件的方法，使用`Scanner`类，该类用于从文件或输入资源中读取输入。这里，我们使用 Scanner 类和`useDelimeter()`方法来指定值分隔符。

```java
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;

public class Main {
	public static void main(String[] args) throws FileNotFoundException{  
		//Reading file using scanner
        Scanner scanner = new Scanner(new File("students.csv"));

        //Comma as a delimiter
        scanner.useDelimiter(",");

        while (scanner.hasNext()) 
        {
            System.out.print(scanner.next() + " ");
        }

        // Closing the scanner  
        scanner.close();
	}
}
```

101“罗汉”“印度”
102“库马尔”“斯里兰卡”
103“大卫”“美国”

* * *

* * *