# 如何在 Java 中编写文件

> 原文：<https://www.studytonight.com/java-examples/how-to-write-a-file-in-java>

在这篇文章中，我们将学习如何将数据写入文件。数据可以是单个字符、字符序列或多行字符串。

要将数据写入文件，我们使用的是 Java 的`Files`类。`Files`类提供了几种将数据写入文件的方法，如写入字节、字符串或可迭代等。

在这里，我们将使用`write()`方法编写一个字符串以及字符串列表。出于书写的目的，我们使用一个文件 **outfile.txt** 来存储书写的数据。

我们建议您在编写之前创建一个文件，但是，如果文件不存在，Java 会自动创建该文件。

## 举例时间:

现在，让我们看一个将数据写入文件的例子。这里，我们有一个文件 **outfile.txt** 将用于存储数据，`Files`类的`write()`方法用于此目的。该方法以字节格式写入数据，因此我们使用`getBytes()`方法将字符串转换为字节。

```java
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths; 
public class Main {

	public static void main(String[] args) throws IOException{  
		String lines = "Welcome to Studytonight.com \n It is technical portal.";
		Path path = Paths.get("outfile.txt");
		Files.write(path, lines.getBytes());
	}
}
```

执行完上面的代码，就可以打开看到同一个目录下的文件 **outfile.txt** 。

## 另一个例子的时间:

让我们再举一个将数据写入文件的例子。这里，我们向文件中写入一个字符串列表，并且在`write()`方法中，我们还指定了标准字符集。该方法是`write()`方法的替代版本之一。

```java
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.List;
import java.nio.charset.*;

public class Main {

	public static void main(String[] args) throws IOException{  
		List<String> lines = Arrays.asList("Welcome to Studytonight.com", "It is technical portal.");
		Path path = Paths.get("outfile.txt");
		Files.write(path, lines, StandardCharsets.UTF_8);
	}
}
```

成功执行上述代码后，您可以看到 outfile.txt 文件，该文件必须包含如下所示的写入数据。

**//文件:outfile.txt**

欢迎来到 Studytonight.com
是技术门户。

* * *

* * *