# 如何将数据写入 CSV 文件

> 原文：<https://www.studytonight.com/java-examples/how-to-write-data-into-csv-file>

在这篇文章中，我们将学习如何使用 Java 代码将数据写入 CSV 文件。在前一篇文章中，我们学习了从 CSV 文件中读取数据。你可以在这里参考这个帖子[“用 JAVA 阅读 CSV”](https://www.studytonight.com/java-examples/how-to-read-a-csv-file-in-java)。

要将数据写入 CSV 文件，我们使用的是第三方库`OpenCSV`库。因此，您必须从这里下载 JARs。[下载 OpenCSV 罐子](https://mvnrepository.com/artifact/com.opencsv/opencsv/3.8)。

下载 JARs 后，将它们导入到您的项目中。这个库包含两个重要的类`CSVReader`和`CSVWriter`，用于在 CSV 文件中进行读写操作。

在这里，我们使用`CSVWriter`类将数据写入 CSV 文件**学生. csv** 。

## 举例时间:

让我们创建一个将数据写入 CSV 文件的示例。在这里，我们要给**学生. csv** 文件写四条记录。所以，我们用`CSVWriter`类的`writeNext()`方法写数据。

```java
import java.io.FileWriter;
import java.io.IOException;

import com.opencsv.CSVWriter;

public class Main {
	public static void main(String[] args) throws IOException{  
		String csvFile = "students.csv";
		CSVWriter cw = new CSVWriter(new FileWriter(csvFile));
		String line1[] = {"Id", "Name", "Country"};
		String line2[] = {"1", "Sohan", "India"};
		String line3[] = {"2", "Rohan", "USA"};
		String line4[] = {"3", "Abhishek", "UK"};
		//Writing data to the csv file
		cw.writeNext(line1);
		cw.writeNext(line2);
		cw.writeNext(line3);
		cw.writeNext(line4);
		//close the file
		cw.close();
	}
}
```

成功执行上述代码后， **students.csv** 文件会有以下数据。

**//学生. csv**

“身份证”、“姓名”、“国家”
“1”、“索汉”、“印度”
“2”、“罗汉”、“美国”
“3”、“阿布舍克”、“英国”

## 另一个例子的时间:追加 CSV

我们再举一个例子来写 CSV 文件。这里，我们以追加模式打开 CSV 文件来写入数据。追加模式的好处是，它不会替换文件的旧数据。要启用追加模式，请使用`FilWriter()`构造器中的`true`文字，就像我们在下面的示例中所做的那样。

```java
import java.io.FileWriter;
import java.io.IOException;

import com.opencsv.CSVWriter;

public class Main {
	public static void main(String[] args) throws IOException{  
		String csvFile = "students.csv";
		CSVWriter cw = new CSVWriter(new FileWriter(csvFile,true));
		String[] line = {"4", "David", "USA"};
		//Writing data to the csv file
		cw.writeNext(line);
		//close the file
		cw.close();
	}
}
```

看，我们在文件中写了一个条目，它写在文件的末尾，这意味着我们的代码可以正常工作。

**// student.csv**

“Id”、“姓名”、“国家”
“1”、“Sohan”、“印度”
“2”、“Rohan”、“美国”
“3”、“Abhishek”、“英国”
“4”、“大卫”、“美国”

* * *

* * *