# 如何在 Java 中读取多个文本文件

> 原文：<https://www.studytonight.com/java-examples/how-to-read-multiple-text-files-in-java>

在这篇文章中，我们将使用 Java 代码读取多个文本文件。当我们处理一个需要从多个资源中读取数据的大型项目时，这很有帮助。

在这里，我们使用了一个`File`类，用于处理 Java 中与文件相关的操作。

要读取多个文件，可能有几种情况，但在这里，我们从一个文件夹或两个单独的文件中读取文件。

出于示例的目的，我们有两个文件 **file1.txt** 和 **file2.txt** ，它们位于一个文件夹 **filefolder** 中。这两个文件包含下面给出的一些数据。

**// file1.txt**

```java
The default port for mysql is 3306 
```

**//file2.txt**

```java
Oracle db is running at port 8080
```

## 示例:

让我们举一个使用 Java 代码读取多个文件的例子。在这里，我们有一个文件夹包含我们将要阅读的两个文件。我们使用`File`类获取文件实例，`BufferReader`类读取文件数据。

```java
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;

public class Main {
	public static void main(String[] args) throws IOException{  
        File dir = new File("filefolder");
        File[] files = dir.listFiles();
        // Fetching all the files
        for (File file : files) {
            if(file.isFile()) {
                BufferedReader inputStream = null;
                String line;
                try {
                    inputStream = new BufferedReader(new FileReader(file));
                    while ((line = inputStream.readLine()) != null) {
                        System.out.println(line);
                    }
                }catch(IOException e) {
                	System.out.println(e);
                }
                finally {
                    if (inputStream != null) {
                        inputStream.close();
                    }
                }
            }
        }

	}
}
```

【mysql 的默认端口是 3306
Oracle db 运行在端口 8080

## 实时示例:

试试这个例子，我们在文件夹外有两个单独的文本文件，并读取它们。您可以编辑这些文本文件来检查代码是否产生了所需的结果。

* * *

* * *