# 如何检查文件是否可读和可写

> 原文：<https://www.studytonight.com/java-examples/how-to-check-if-a-file-is-readable-and-writable>

在这篇文章中，我们将检查一个文件是否可读和可写。计算机系统中的每个文件都有指定其是否可以读取、写入或执行的属性。

出于某些安全原因，所有文件都不是公开可读或可写的。所以 Java File 类提供了在程序执行期间检查文件这些属性的方法。

为了检查读取属性，我们使用`canRead()`方法，对于写入，我们使用`File`类的`canWrite()`方法。

canRead()和 canWrite()方法都返回真或假的布尔值。如果文件是可读或可写的，那么我们可以从这两种方法中得到真实的结果。

## 举例时间:

让我们创建一个例子来检查一个文件是否可读。这里，我们使用的是 File 类的`canRead()`方法。

```java
import java.io.File;
public class Main {

	public static void main(String[] args){
		try {
			File file = new File("abc.txt");
			boolean canRead = file.canRead();
			if(canRead) {
				System.out.println("File can be read");
			}else {
				System.out.println("File can't be read");
			}
		}catch(Exception e) {
			System.out.println(e);
		}
	}
}
```

文件可读取

## 示例:

让我们创建一个示例来检查文件是否可写。这里，我们使用的是返回布尔值的 File 类的`canWrite()`方法。

```java
import java.io.File;
public class Main {

	public static void main(String[] args){
		try {
			File file = new File("abc.txt");
			boolean canWrite = file.canWrite();
			if(canWrite) {
				System.out.println("File is writeable");
			}else {
				System.out.println("File is not writeable");
			}
		}catch(Exception e) {
			System.out.println(e);
		}
	}
}
```

文件可写

## 示例:

如果一个文件是可写的，并且我们想用 Java 代码使它不可写，那么我们可以使用使文件不可写的`File`类的`setWritable()`方法，见下面的例子。

```java
import java.io.File;
public class Main {

	public static void main(String[] args){
		try {
			File file = new File("abc.txt");
			boolean canWrite = file.canWrite();
			// Setting file not to writable
			file.setWritable(false);
			if(canWrite) {
				System.out.println("File is writeable");
			}else {
				System.out.println("File is not writeable");
			}
		}catch(Exception e) {
			System.out.println(e);
		}
	}
}
```

文件不可写

* * *

* * *