# 如何在 Java 中连接数组

> 原文：<https://www.studytonight.com/java-examples/how-to-join-arrays-in-java>

在这篇文章中，我们将学习使用 Java 代码将多个数组连接成一个数组。可能会有这样一种情况，我们需要将两个或多个数组的数据组合成一个数组，例如将两个源组合成一个，以单个源的形式传输数据。

在这里，我们使用 Java 8 流 API 来连接数组，并以数组或流的形式获得结果。请看这里给出的例子。

## 举例时间:

让我们举一个例子，将两个字符串数组连接成一个字符串数组。这里，我们使用`Stream`的`of()`方法，该方法返回一个流序列，该流序列通过使用`toArray()`方法进一步转换为数组。

```java
import java.util.stream.Stream;
public class Main {
	public static void main(String[] args){  
		String[] asia = new String[]{"India", "Russia", "Japan"};
        String[] europe = new String[]{"Poland", "Germany", "France"};

		//join arrays
        String[] countries = Stream.of(asia,europe).flatMap(Stream::of).toArray(String[]::new);
        for (String country : countries) {
			System.out.println(country);
		}
	}
}
```

印度
俄国
日本
波兰
德国
法国

## 另一个例子的时间:

我们可以通过使用 concat()方法组合两个流，该方法返回指定类型的流。该示例解释了如何将两个或多个流连接成一个流，就像我们在上面的示例中合并两个数组一样。

```java
import java.util.stream.Stream;
public class Main {
	public static void main(String[] args){  
		Stream<Integer> stream1 = Stream.of(1, 2, 3);
	    Stream<Integer> stream2 = Stream.of(4, 5, 6);
	    //concat arrays
	    Stream<Integer> result = Stream.concat(stream1, stream2);
	    result.forEach(System.out::println);
	}
}
```

1
3
5
2
4
6

* * *

* * *