# 如何在 Java 中将字符串转换为`ArrayList`

> 原文：<https://www.studytonight.com/java-examples/how-to-convert-string-to-arraylist-in-java>

在这篇文章中，我们将使用 Java 代码将一个字符串转换为`ArrayList`。字符串是一个字符序列，在 Java 中是一个类，而`ArrayList`是列表接口的实现类。

假设，我们有一个由服务器资源路径组成的 URL 字符串，并由一些单独的符号分隔，我们希望将其获取为`ArrayList`。所以，我们需要执行这个转换。

要将字符串转换为`ArrayList,`，我们使用`asList()`、`split()`和`add()`方法。`asList()`方法属于`Arrays`类，从数组中返回一个列表。

`split()`方法属于`String`类，根据指定的拆分分隔符返回一个数组。

这里，我们有几个例子来说明字符串到`ArrayList`的转换过程。请看下面的例子。

## 举例时间:

让我们举一个从字符串中获取`ArrayList`的例子。这里，我们使用 split()方法获取一个字符串数组，然后使用 asList()方法将该数组转换为一个列表。

```java
import java.util.ArrayList;
import java.util.Arrays;

public class Main {
	public static void main(String[] args){
		String msg = "StudyTonight.com/tutorial/java/string";
		System.out.println(msg);
		// string to ArrayList
		ArrayList<String> list = new ArrayList<>(Arrays.asList(msg.split("/")));
		list.forEach(System.out::println);	
	}
}
```

StudyTonight.com/tutorial/java/string
StudyTonight.com
教程
Java
弦

## 例 1

如果我们有一个字符串数组，那么我们不需要`split()`方法。我们可以直接将这个数组传入`asList()`法得到`ArrayList`。请看下面的例子。

```java
import java.util.ArrayList;
import java.util.Arrays;

public class Main {
	public static void main(String[] args){
		String[] msg = {"StudyTonight.com","tutorial","java","string"};
		System.out.println(msg.length);
		// string[] to ArrayList
		ArrayList<String> list = new ArrayList<>(Arrays.asList(msg));
		list.forEach(System.out::println);	
	}
}
```

4
StudyTonight.com
教程
Java
弦

## 例 2

我们再举一个例子来获取 ArrayList，这里我们使用`add()`方法通过遍历将字符串数组元素添加到`ArrayList`中。这对于初学者来说是最简单的。

```java
import java.util.ArrayList;

public class Main {
	public static void main(String[] args){
		String[] msg = {"StudyTonight.com","tutorial","java","string"};
		System.out.println(msg.length);
		// string[] to ArrayList
		ArrayList<String> list = new ArrayList<>();
		for (String string : msg) {
			list.add(string);
		}
		System.out.println(list);	
	}
}
```

4
【study south . com，教程，java，string】

* * *

* * *