# 如何在 Java 中将`ArrayList`转换为`LinkedList`

> 原文：<https://www.studytonight.com/java-examples/how-to-convert-arraylist-to-linkedlist-in-java>

在这篇文章中，我们将把 Java 中的`ArrayList`转换为`LinkedList`。`ArrayList`和`LinkedList`都是类，分别用于实现基于数组的列表和基于`LinkedList`的列表。

当`ArrayList`将数据存储在类似数组的列表中时，`LinkedList`使用`LinkedList`数据结构来存储数据。两个类都实现了 Java 集合框架层次中的`List`接口。

要转换`ArrayList`，有几种方法，这里我们使用的一些方法，比如将 ArraList 作为参数传递给`LinkedList`构造器，或者使用`add()`方法逐个添加 ArrayList 元素，或者使用 stream API 将 stream 元素获取到 LinkedList。

## 举例时间:

举个例子把`ArrayList`转换成`LinkedList`。在这里，我们将`ArrayList`元素传递给`LinkedList`构造器，并获得一个新的数据结构。

```java
import java.util.ArrayList;
import java.util.LinkedList;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		System.out.println(arrList);
		// ArrayList to LinkedList
		LinkedList<String> linkList = new LinkedList<>(arrList);
		System.out.println("Linked List:");
		System.out.println(linkList);
	}
}
```

【芒果、苹果、橙子】
`LinkedList`:
【芒果、苹果、橙子】

## 另一个例子:

让我们创建另一个示例来将`ArrayList`转换为`LinkedList`。这里，我们使用`add()`方法向 LinkedList 添加元素。

```java
import java.util.ArrayList;
import java.util.LinkedList;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		System.out.println(arrList);
		// ArrayList to LinkedList
		LinkedList<String> linkList = new LinkedList<>();
		for (String arr : arrList) {
			linkList.add(arr);
		}
		System.out.println("Linked List:");
		System.out.println(linkList);
	}
}
```

【芒果、苹果、橙子】
`LinkedList`:
【芒果、苹果、橙子】

## 示例:Java 8

如果您使用的是 Java 8 或更高版本，那么您可以利用`Java 流 API`将`ArrayList`转换为`LinkedList`。这里，我们使用 stream 将`ArrayList`元素收集到 LinkedList 中。

```java
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.stream.Collectors;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		System.out.println(arrList);
		// ArrayList to LinkedList
		LinkedList<String> linkList = arrList.stream().collect(Collectors.toCollection(LinkedList::new));
		System.out.println("Linked List:");
		System.out.println(linkList);
	}
}
```

【芒果、苹果、橙子】
`LinkedList`:
【芒果、苹果、橙子】

* * *

* * *