# Java `ArrayList`到`LinkedHashSet`的转换

> 原文：<https://www.studytonight.com/java-examples/java-arraylist-to-linkedhashset-conversion>

在这篇文章中，我们将把[`ArrayList`](https://www.studytonight.com/java/arraylist-in-collection-framework.php)转换为[链接`HashSet`](https://www.studytonight.com/java/linkedhashset-in-collection-framework.php)。LinkedHashSet 是一个使用 linkedlist 数据结构在 Java 中实现 Set 的类。

当我们想要将类似数组的列表转换为唯一的数据集合时，这是很有帮助的。LinkedHashSet 用于收集唯一数据。

为了将`ArrayList`转换为 LinkedHashSet，我们使用了各种方法，如[流 API](https://www.studytonight.com/java-8/java-8-stream-api) 或 add()方法或 LinkedHashSet 构造器。见下面的例子。

## 举例时间:

在本例中，我们使用流 API 将`ArrayList`元素收集到 LinkedHashSet 中，以获得唯一的元素。请看下面的例子。

```java
import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.stream.Collectors;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		arrList.add("Apple");
		System.out.println(arrList);
		// ArrayList to LinkedHashSet
		LinkedHashSet<String> linkList = arrList.stream().collect(Collectors.toCollection(LinkedHashSet::new));
		System.out.println("Linked HashSet:");
		System.out.println(linkList);
	}
}
```

【芒果、苹果、橙子、苹果】
链接 HashSet:
【芒果、苹果、橙子】

## 示例:

如果要将元素一个一个地添加到 LinkedHashSet 中，那么可以使用 add()方法，得到一个唯一元素的集合。请看下面的例子。

```java
import java.util.ArrayList;
import java.util.LinkedHashSet;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		arrList.add("Apple");
		System.out.println(arrList);
		// ArrayList to LinkedHashSet
		LinkedHashSet<String> linkSet = new LinkedHashSet<String>();
		for (String arr : arrList) {
			linkSet.add(arr);
		}
		System.out.println("Linked HashSet:");
		System.out.println(linkSet);
	}
}
```

【芒果、苹果、橙子、苹果】
链接 HashSet:
【芒果、苹果、橙子】

## 示例:

这是另一种从`ArrayList`中获取 LinkedHashSet 的方法。这里，我们将`ArrayList`作为参数传递给 LinkedHashSet 的构造器。

```java
import java.util.ArrayList;
import java.util.LinkedHashSet;

public class Main {
	public static void main(String[] args){
		ArrayList<String> arrList = new ArrayList<>();
		arrList.add("Mango");
		arrList.add("Apple");
		arrList.add("Orange");
		arrList.add("Apple");
		System.out.println(arrList);
		// ArrayList to LinkedHashSet
		LinkedHashSet<String> linkSet = new LinkedHashSet<String>(arrList);
		System.out.println("Linked HashSet:");
		System.out.println(linkSet);
	}
}
```

【芒果、苹果、橙子、苹果】
链接 HashSet:
【芒果、苹果、橙子】

* * *

* * *