# 如何将 Java 日期转换为字符串

> 原文：<https://www.studytonight.com/java-type-conversion/how-to-convert-java-date-to-string>

在 Java 中，[日期](https://www.studytonight.com/java-8/java-8-date-and-time-api)可以用`DateFormat`和`Instant`类等几个类转换成[字符串](https://www.studytonight.com/java/string-handling-in-java.php)。`DateFormat`类提供了一个返回字符串对象的方法`format()`。`DateFormat`级属于`java.text`套餐。

## 1.通过使用`format()`方法

`format()`方法是`DateFormat`类的一部分，它是一个抽象类，用于将`Date`转换为`String`。`SimpleDateFormat`班是`DateFormat`班的一个子班。

## 例 1:

这里`Date`使用`SimpleDateFormat`类的`format()`方法转换为`String`。

```java
import java.text.DateFormat;  
import java.text.SimpleDateFormat;  
import java.util.Date;  
import java.util.Calendar; 

public class StudyTonight
{    
   public static void main(String [] args)throws Exception
   {  
      Date d = Calendar.getInstance().getTime();  
      DateFormat df = new SimpleDateFormat("yyyy-mm-dd hh:mm:ss");  
      String sDate = df.format(d);  
      System.out.println("String in form of Date is : " + sDate);  

   }

}
```

转换字符串:2020-27-29 03:27:15

## 2.通过使用`toString()`方法

`String`类的`toString()`方法用于获取任意类型对象的字符串对象。这里，我们使用`toString()`将日期对象转换为`String`类型。请看下面的例子。

```java
package com.studytonight;

import java.util.Date;
public class CoreJava {

	public static void main(String[] args) {
		Date date = new Date();
		String fullDate = date.toString();
		System.out.println(fullDate);
		String dateString = fullDate.substring( 0 , 11 );
		System.out.println(dateString);
		String timeString = fullDate.substring( 11 , 19 );
		System.out.println(timeString);
	}
}
```

Thu Nov 26 11:54:45 是 2020
Thu Nov 26
11:54:45

## 在 Java 中 8 `java.time`包

如果您使用的是 Java 8 或更高版本，则使用`toInstant()`方法获取即时对象，该对象可用于将日期转换为字符串。Instant 类用于使日期对象与 java 8 或更高版本兼容。请看下面的例子。

```java
package com.studytonight;

import java.time.Instant;
import java.util.Date;
public class CoreJava {

	public static void main(String[] args) {
		Date date = new Date();
		Instant instant = date.toInstant();
		String fullDate = instant.toString();
		System.out.println(fullDate);
		String dateString = fullDate.substring( 0 , 10 );
		System.out.println(dateString);
		String timeString = fullDate.substring( 11 , 19 );
		System.out.println(timeString);
	}
}
```

2020-11-26t 06:31:20.445 z
2020-11-26
06:31:20

* * *

* * *