# Java `Long.parseLong(String, int)`方法

> 原文：<https://www.studytonight.com/java-wrapper-class/java-long-parselongstring-s-int-radix-method>

Java `parseLong(String s, int radix)`方法是`java.lang`包的`Long`类的一部分。此方法用于将字符串值解析为作为参数传递的指定整数基数值中的**带符号十进制长【】对象。**

必须注意的是，除了用于定义整数符号的第一个字符之外，字符串中传递的字符必须都是十进制的。可以是 **ASCII 减号“-”符号**表示负值，也可以是 **ASCII 加号“+”符号**表示正值。必须注意的是，字符`L` ( `'\u004C'`)和`l` ( `'\u006C'`)都不允许作为类型指示符出现在字符串的末尾，这在 Java 编程语言源代码中是允许的-除了`L`或`l`可以作为大于或等于 22 的基数的数字出现。

### 语法:

```java
public static long parseLong (String s, int radix) 
```

### 参数:

传递的参数是要返回其带符号十进制 Long 对象的字符串值和将根据其解析输入字符串的整数基数值。

### 例外:

`NumberFormatException` : 当输入字符串不可解析时，会出现此异常。

### 返回:

根据基数值，以字符串值的带符号十进制 Long 对象的形式返回作为参数传递的值。

## 例 1:

这里，根据传递的整数基数，返回字符串值的带符号十进制长对象表示。

```java
import java.lang.Long;

public class StudyTonight {
  public static void main(String[] args) throws NumberFormatException {
    String s1 = "603";
    String s2 = "-603";
    int radix = 16;
    System.out.print("\nEntered value and Base value is: " + s1 + " and " + radix);
    //returns the signed Long object of the entered string in accordance with the radix            
    System.out.println("\nEquivalent Long object is " + Long.parseLong(s1, radix));

    System.out.print("\nEntered value and Base value is: " + s2 + " and " + radix);
    //returns the signed Long object of the entered string in accordance with the radix            
    System.out.println("\nEquivalent Long object is " + Long.parseLong(s2, radix));
  }
}
```

输入值和基础值为:603 和 16
等效长对象为 1539

输入值和基础值为:-603 和 16
等效长对象为-1539

## 例 2:

这里有一个用户定义的例子，任何使用这段代码的人都可以输入自己选择的值，并获得等效的输出。

```java
import java.util.Scanner;

public class StudyTonight {
  public static void main(String[] args) {
    try {
      System.out.print("Enter the value: ");
      Scanner sc = new Scanner(System. in );
      String s = sc.nextLine();
      System.out.print("Enter the radix: ");
      int radix = sc.nextInt();
      System.out.println("Equivalent Long object : " + Long.parseLong(s, radix)); //parse the string value into signed value with respect to radix 
    }
    catch(NumberFormatException e) {
      System.out.println("Invalid Input!!");
    }
  }
}
```

输入数值:567454
输入基数:8
等效长对象:192300
***************输入数值:-5232
输入基数:16
等效长对象:-21042
* * * * * * * * * * * * * * * * * * * * * * * * * * *输入数值:0x454
输入基数:8
！

## 实时示例:

在这里，您可以测试实时代码示例。您可以为不同的值执行示例，甚至可以编辑和编写您的示例来测试 Java 代码。

* * *

* * *