# Java 8 `StringJoiner`类

> 原文：<https://www.studytonight.com/java-8/java-8-stringjoiner-class>

Java StringJoiner 类包含在 Java 8 版本中，它允许我们构造一个由分隔符分隔的字符序列。

它位于 **java.util** 包中，用于提供通过用户定义的分隔符创建字符串的实用程序。分隔符可以是逗号(，)，冒号(:)等。我们还可以将后缀和前缀传递给字符串连接对象。

假设，我们有一个多词字符串，并希望用分隔符(逗号、分号)分隔每个词，那么 StringJoiner 就适合这个目的。下面给出了该类的声明。

## 申报

```java
public final class StringJoiner extends Object
```

## StringJoiner 类构造器

StringJoiner 类包含以下两个构造器:

| 

构造器

 | 

描述

 |
| 公共字符串分隔符 | 它构造了一个 StringJoiner，其中没有字符，没有前缀或后缀，以及提供的分隔符的副本。如果分隔符为空，它将引发 NullPointerException。 |
| 公共字符串连接符(字符序列分隔符、字符序列前缀、字符序列后缀) | 它使用提供的前缀、分隔符和后缀的副本来构造一个字符串连接符，其中没有字符。如果前缀、分隔符或后缀为空，它将引发 NullPointerException。 |

## `StringJoiner`类方法

下表包含 StringJoiner 类的方法。

| 

方法

 | 

描述

 |
| 公共字符串连接器添加(字符序列新元素) | 它添加给定字符序列值的副本作为字符串连接值的下一个元素。如果 newElement 为空，则添加“空”。 |
| 公共字符串连接合并(其他字符串连接) | 如果给定的 StringJoiner 不为空，它会添加没有前缀和后缀的内容作为下一个元素。如果给定的 StringJoiner 为空，则调用无效。 |
| 公共 int 长度() | 它返回该字符串连接器的字符串表示形式的长度。 |
| public string join setemptyvalue(charsequence emptyvalue) | 它设置在确定这个 StringJoiner 的字符串表示形式时使用的字符序列，并且还没有添加任何元素，也就是说，当它为空时。 |
| 公共字符串 toString() | 它返回由前缀、后缀或空值字符组成的当前值。 |

## 举例时间:

让我们举一个使用 StringJoiner 类创建字符串的例子。这里我们使用逗号分隔符来分隔字符串。见下面的例子。

```java
import java.util.StringJoiner;
public class STDemo {
	public static void main(String[] args) {
		StringJoiner sj = new StringJoiner(",");
		sj.add("India");
		sj.add("China");
		sj.add("US");
		sj.add("UK");
		System.out.println(sj);

	}

}
```

印度、中国、美国、英国

## 另一个例子的时间:

StringJoiner 允许后缀和前缀可选地包含字符串对象。在本例中，我们通过将括号设置为后缀和前缀，将冒号设置为分隔符来创建字符串。

```java
import java.util.StringJoiner;
public class STDemo {
	public static void main(String[] args) {
		StringJoiner sj = new StringJoiner(":","(",")");
		sj.add("India");
		sj.add("China");
		sj.add("US");
		sj.add("UK");
		System.out.println(sj);
	}

}
```

(印度:中国:美国:英国)

## 示例:获取字符串长度

StringJoiner 类提供了一个 length()方法来获取字符串的长度。在这个例子中，我们得到了字符串的长度。

```java
import java.util.StringJoiner;
public class STDemo {
	public static void main(String[] args) {
		StringJoiner sj = new StringJoiner(":","(",")");
		sj.add("India");
		sj.add("China");
		sj.add("US");
		sj.add("UK");
		System.out.println(sj);
		System.out.println("String length : "+sj.length());

	}

}
```

(印度:中国:美国:英国)
弦长:19

## 示例:合并两个字符串

StringJoiner merge()方法用于将两个 StringJoiner 对象合并为一个。在这个例子中，我们合并两个字符串，得到一个字符串对象。

```java
import java.util.StringJoiner;
public class STDemo {
	public static void main(String[] args) {
		StringJoiner sj = new StringJoiner(":","(",")");
		sj.add("India");
		sj.add("China");
		sj.add("US");
		sj.add("UK");
		System.out.println(sj);
		StringJoiner sj2 = new StringJoiner(":","(",")");
		sj.add("Germany");
		sj.add("Russia");
		sj = sj.merge(sj2);
		System.out.println(sj);

	}

}
```

(印度:中国:美国:英国)
(印度:中国:美国:英国:德国:俄罗斯)

* * *

* * *