# Java `DataOutputStream`类

> 原文：<https://www.studytonight.com/java-file-io/java-dataoutputstream-class>

在本教程中，我们将学习 [Java](https://www.studytonight.com/java/) 中的`DataOutputStream` 类。这个类用于将原始数据写入文件。这个类很有帮助，因为后面我们用`DataInputStream` 类提取这个数据。这里的原始数据类型包括`short`、`char`、`int`、`float`、`double` 和`boolean`。`DataOutputStream` 类也称为过滤类，它将输出流包装成原始数据。

### 句法

这是数据输出流的语法声明。

```java
public class DataOutputStream extends FilterOutputStream implements DataOutput 
```

### 方法

| 方法 | 描述 |
| --- | --- |
| int 大小() | 它用于返回写入数据输出流的字节数。 |
| 无效写入(int b) | 它用于将指定的字节写入基础输出流。 |
| 无效写入(字节[] b，int off，int len) | 它用于将 len 字节的数据写入输出流。 |
| void 布尔值(布尔值 v) | 它用于将布尔值作为 1 字节值写入输出流。 |
| void writeChar(int v) | 它用于将 char 作为 2 字节值写入输出流。 |
| 无效的写字符 | 它用于将字符串作为字符序列写入输出流。 |
| void writeByte(int v) | 它用于将一个字节作为 1 字节值写入输出流。 |
| 无效写字节(字符串) | 它用于将字符串作为字节序列写入输出流。 |
| 参见 writeInt(int v) | 它用于向输出流写入一个 int |
| void writeShort(int v) | 它用于向输出流写入一个短消息。 |
| void writeShort(int v) | 它用于向输出流写入一个短消息。 |
| void writeLong(长 v) | 它用于向输出流中写入一个 long。 |
| 空写输出(字符串) | 它用于以可移植的方式使用 UTF-8 编码将字符串写入输出流。 |
| 空隙冲洗() | 

&#124; 用于刷新数据输出流。 &#124;

 |

### 使用`writeInt()`方法的数据输出流类示例

在下面的程序中，我们正在实现 `writeInt()` 方法将数据写入文件。

```java
import java.io.DataOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;

public class StudyTonight 
{
	public static void main(String[] args) throws IOException 
	{ 
		FileOutputStream file = new FileOutputStream("E:\\studytonight\\myfile.txt");  
        DataOutputStream data = new DataOutputStream(file);  
        data.writeInt(68);  
        data.flush();  
        data.close();  
        System.out.println("Data is written to the file successfully"); 
	}  
}
```

数据成功写入文件

我的文件.txt

```java
 A
```

### 数据输出流类方法示例

在下面的程序中，我们使用了各种方法，如`writeDouble()`、`writeInt()`、 `writeBoolean()`和`writeChar()`。这些方法将以原始数据类型存储给定的数据。现在我们可以看到，这些数据不是可读的格式，但是当我们使用`DataInputStream` 类访问它时，读取输入数据会更加方便。

```java
import java.io.DataOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
public class StudyTonight 
{
	public static void main(String[] args) throws IOException 
	{ 
		FileOutputStream file = new FileOutputStream("E:\\studytonight\\myfile.txt");  
        DataOutputStream data = new DataOutputStream(file);  
        data.writeDouble(2.1); 
        data.writeInt(45); 
        data.writeBoolean(true); 
        data.writeChar('S'); 
        data.flush();  
        data.close();  
        System.out.println("Data is written to the file successfully"); 
	}  
}
```

数据成功写入文件

我的文件.txt

```java
@ ÌÌÌÌÌÍ   - S
```

### 结论

在本教程中，我们学习了 Java 中的`DataOutputStream` 类。此类用于将数据以基本数据类型存储到文件中，以便以后可以同样检索。

* * *

* * *