# Java `Writer`类

> 原文：<https://www.studytonight.com/java-file-io/java-writer-class>

在本教程中，我们将学习 [Java](https://www.studytonight.com/java/) 中的`Writer`类。这个类是`java.io`包的抽象类，所以我们不直接使用。我们可以使用它的子类。

### 作家的子类

*   缓冲区输出
*   类
*   `FileWriter`
*   StringWriter

### 构造器

对于`Write` 类，我们可以实现下面给出的两种类型的构造器变量。

| 构造器 | 描述 |
| --- | --- |
| `protected Writer()` | 它创建了一个新的字符流编写器，其关键部分将与编写器本身同步。 |
| `protected Writer(Object lock)` | 它创建一个新的字符流编写器，其关键部分将在给定的对象上同步。 |

### 写作课的方法

`Writer` 类支持的所有方法如下。

| 方法 | 描述 |
| --- | --- |
| `Writer append(char c)` | 它将指定的字符追加到该编写器中。 |
| `Writer append(CharSequence csq)` | 它将指定的字符序列附加到这个编写器 |
| `Writer append(CharSequence csq, int start, int end)` | 它将指定字符序列的子序列附加到这个编写器。 |
| `abstract void close()` | 它关闭了溪流，先冲洗它。 |
| `abstract void flush()` | 它冲向溪流。 |
| `void write(char[] cbuf)` | 它写一个字符数组。 |
| `abstract void write(char[] cbuf, int off, int len)` | 它写入字符数组的一部分。 |
| `void write(int c)` | 它只写一个字符。 |
| `void write(String str)` | 它写一个字符串。 |
| `void write(String str, int off, int len)` | 它写入字符串的一部分。 |

### 例 1

在这个例子中，我们使用`FileWriter` 类创建了一个`Writer` 对象。该写操作将把数据写入`output.txt`文件。以验证我们检查了文件并匹配了内容。

```java
package studytonight;
import java.io.FileWriter;
import java.io.Writer;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{
			Writer writer = new FileWriter("E:\\studytonight\\output.txt");  
			writer.write("Hello Studytonight");  
			writer.close();  
			System.out.println("Content is written to the file successfully...");
		}
		catch(Exception e)
		{
			System.out.println("Error: "+e.toString());
		}
	}
}
```

内容成功写入文件...

输出. txt

```java
Hello Studytonight
```

### 例 2

在下面的示例中，我们实现了如何向编写器追加 CharSequence。在追加该字符序列后，我们可以发现在输出中也添加了一个额外的字符串。

```java
package studytonight;
import java.io.FileWriter;
import java.io.Writer;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{
			Writer writer = new FileWriter("E:\\studytonight\\output.txt");    			
			CharSequence char_seq = "Hello";
			//append method to append CharSequence
			writer.append(char_seq);
			writer.write("Hello Studytonight");
			writer.close();  
			System.out.println("Content is written to the file successfully...");
		}
		catch(Exception e)
		{
			System.out.println("Error: "+e.toString());
		}
	}
}
```

内容成功写入文件...

输出. txt

```java
HelloHello Studytonight
```

### 结论

在本教程中，我们学习了`Writer` 课。对于这个类，大多数子类将覆盖这里定义的一些方法，以提供更高的效率和/或功能。

* * *

* * *