# Java `FileWriter`类

> 原文：<https://www.studytonight.com/java-file-io/java-filewriter-class>

在本教程中，我们将学习 [Java](https://www.studytonight.com/java/) 中的`FileWriter` 类。这个类用于在文件中写入数据。这个类扩展了`OutputStreamWriter`。这个类提供了直接写字符串的方法，所以我们不需要将字符串转换成字节数组。

### `FileWriter`类的构造器

这个类有两种不同的构造器，如下所示。

| 构造器 | 描述 |
| --- | --- |
| `FileWriter(String file)` | 此构造器创建一个新文件。它获取字符串形式的文件名。 |
| `FileWriter(File file)` | 此构造器创建一个新文件。它获取文件对象中的文件名。 |

### `FileWriter`类的方法

下表中提到了文件写类支持的所有方法。

| 方法 | 描述 |
| --- | --- |
| `void write(String text)` | 此方法用于将字符串写入`FileWriter`。 |
| `void write(char c)` | 此方法用于将字符写入`FileWriter`。 |
| `void write(char[] c)` | 该方法用于将字符数组写入`FileWriter`。 |
| `void flush()` | 此方法用于刷新`FileWriter`的数据。 |
| `void close()` | 此方法用于关闭`FileWriter`。 |

### 例子

在下面给出的例子中，我们使用`FileWriter`将数据写入文件。首先我们创建一个`FileWriter` 类的对象，然后我们使用`read()`方法写数据。

```java
package studytonight;
import java.io.FileWriter;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try{   		
			FileWriter filewriter=new FileWriter("E:\\studytonight\\output.txt");    
			filewriter.write("Welcome to Studytonight");    
			filewriter.close(); 
			System.out.print("Data Written to the file successfully...");
		}
		catch(Exception e){
			System.out.println("Error: "+e.toString());
		}
	}
}
```

数据成功写入文件...

输出. txt

```java
Welcome to Studytonight
```

### FileWriter 类中的 getEncoding()方法示例

在下面的例子中，我们使用`getEncoding()`方法来检查字符编码。我们可以看到在这个例子的输出中，我们得到了`UTF8` 作为这个`FileWriter`的字符编码。如果我们不指定在这种情况下，它将显示默认编码。

```java
package studytonight;
import java.io.FileWriter;
import java.nio.charset.Charset;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{   		
			FileWriter filewriter=new FileWriter("E:\\studytonight\\output.txt",Charset.forName("UTF8"));        
			//getting encoding of filewriter
			System.out.println("Character Encoding of filewriter is: "+filewriter.getEncoding());
			filewriter.close(); 
		}
		catch(Exception e)
		{
			System.out.println("Error: "+e.toString());
		}
	}
}
```

file writer 的字符编码为:UTF8

### 结论:

在本教程中，我们学习了 Java 中的`FileWriter` 类。这个类属于 **java.io** 包，用于在文件中写入数据。我们还学会了获取用于写入数据的编码类型。

* * *

* * *