# Java `BufferedWriter`类

> 原文：<https://www.studytonight.com/java-file-io/java-bufferedwriter-class>

在本教程中，我们将学习 [Java](https://www.studytonight.com/java/) 中的`BufferedWriter` 类。该类用于为`Writer` 实例提供缓冲。通过使用这个类，我们可以提高性能。该类维护 **8192** 字符的内部缓冲区。如果我们正在执行写操作，那么它会将数据存储在缓冲区中，而不是硬盘中，一旦缓冲区完全填满，它会将完整的缓冲区写入硬盘。

### 句法

这是`BufferedWriter`类的语法声明，是对`Writer`类的扩展。

```java
public class BufferedWriter extends Writer 
```

### Java BufferedWriter 类构造器

这个类提供了构造器的两种变体，如下表所示。

| 构造器 | 描述 |
| --- | --- |
| `BufferedWriter(Writer wrt)` | 它用于创建使用输出缓冲区默认大小的缓冲字符输出流。 |
| `BufferedWriter(Writer wrt, int size)` | 它用于创建使用指定输出缓冲区大小的缓冲字符输出流。 |

### Java BufferedWriter 类方法

下表给出了该表的各种方法。

| 方法 | 描述 |
| --- | --- |
| `void newLine()` | 此方法用于通过编写行分隔符来添加新行。 |
| `void write(int c)` | 此方法用于编写单个字符。 |
| `void write(char[] cbuf, int off, int len)` | 此方法用于写入字符数组的一部分。 |
| `void write(String s, int off, int len)` | 此方法用于写入字符串的一部分。 |
| `void flush()` | 此方法用于刷新输入流。 |
| `void close()` | 此方法用于关闭输入流。 |

### Java BufferedWriter 示例

在下面的例子中，我们使用的是 Java 中`BufferedWriter` 类的 `write()` 方法。这里我们用`FileWriter`创建了`BufferedWriter` ，然后创建了 8192 个字符的默认缓冲区。这里的缓冲区将有助于更有效地向文件中写入字符。

```java
package studytonight;
import java.io.BufferedWriter;
import java.io.FileWriter;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{
			FileWriter writer = new FileWriter("E:\\studytonight\\output.txt");  
			BufferedWriter buffer = new BufferedWriter(writer);  
			buffer.write("Hello Studytonight");  
			buffer.close();  
			System.out.println("Data is written to the file successfully..."); 
		}
		catch(Exception e)
		{
			System.out.print(false);
		}
	}
}
```

数据成功写入文件...

输出. txt

```java
Hello Studytonight
```

### Java BufferedWriter 示例

在这个例子中，我们实现了一个`public void write(String arg, int offset, int length)`，这里第一个参数`arg` 是一个要写入文件内部的字符串，`offset` 是一个索引，从这里我们将开始写入文件，`length` 是要写入的字符串的字符数。这个方法不返回值。

```java
package studytonight;
import java.io.BufferedWriter;
import java.io.FileWriter;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{
			FileWriter writer = new FileWriter("E:\\studytonight\\output.txt");  
			BufferedWriter buffer = new BufferedWriter(writer);  
			String str = "Hello Studytonight"; 
            buffer.write(str,5,str.length()-5); 
			buffer.close();  
			System.out.println("Data is written to the file successfully..."); 
		}
		catch(Exception e)
		{
			System.out.print(false);
		}
	}
}
```

数据成功写入文件...

输出. txt

```java
 Studytonight
```

### 结论

在本教程中，我们学习了 Java 中的`BufferedWriter` 类。java.io 包的 BufferedWriter 类可以与其他编写器一起使用，以更高效地写入数据。

* * *

* * *