# Java `PrintWriter`类

> 原文：<https://www.studytonight.com/java-file-io/java-printwriter-class>

在本教程中，我们将学习 Java 中的`PrintWriter` 类。此类用于将对象的格式化表示写入文本输出流。这个类将原始数据转换成文本格式，然后将转换后的数据写入编写器。

### 句法

这是`PrintWriter`类的语法。该类扩展了`Writer`类。

```java
public class PrintWriter extends Writer 
```

### PrintWriter 类的方法

下表给出了 PrintWriter 类支持的所有方法。

| 方法 | 描述 |
| --- | --- |
| `void println(boolean x)` | 此方法用于打印布尔值。 |
| `void println(char[] x)` | 此方法用于打印字符数组。 |
| `void println(int x)` | 此方法用于打印整数。 |
| `PrintWriter append(char c)` | 此方法用于将指定的字符追加到编写器中。 |
| `PrintWriter append(CharSequence ch)` | 此方法用于将指定的字符序列附加到编写器。 |
| `PrintWriter append(CharSequence ch, int start, int end)` | 此方法用于向编写器追加指定字符的子序列。 |
| `boolean checkError()` | 此方法用于刷新流并检查其错误状态。 |
| `protected void setError()` | 此方法用于指示发生了错误。 |
| `protected void clearError()` | 此方法用于清除流的错误状态。 |
| `PrintWriter format(String format, Object... args)` | 此方法用于使用指定的参数和格式字符串向编写器写入格式化字符串。 |
| `void print(Object obj)` | 此方法用于打印对象。 |
| `void flush()` | 此方法用于刷新流。 |
| `void close()` | 此方法用于关闭流。 |

### PrintWriter 示例

在这个例子中，我们在控制台上写数据。首先我们创建了一个`PrintWriter` 类的对象，通过将`System.in`作为参数传递给 c，然后通过使用这个对象，我们调用这个类的`write()`方法，数据将被打印在控制台上。

```java
package studytonight;
import java.io.PrintWriter;
public class StudyTonight 
{
	public static void main(String args[])
	{
		PrintWriter writer = new PrintWriter(System.out);    
		writer.write("Welcome to Studytonight");        
		writer.flush();  
		writer.close();  
	}
}
```

欢迎今晚来学习

### PrintWriter 示例

在这个例子中，我们在 PrintWriter 类的帮助下向文件中写入数据。这个例子类似于上面的例子，但是在创建`PrintWriter` 类的对象时，我们在构造器中传递了一个文件。之后`write()`方法会将数据写入提供的文件中。

```java
package studytonight;
import java.io.File;
import java.io.PrintWriter;
public class StudyTonight 
{
	public static void main(String args[])
	{
		try
		{
			PrintWriter writer= new PrintWriter(new File("E:\\studytonight\\output.txt"));  
			writer.write("Hello World");                                                   
			writer.flush();  
			writer.close();  
			System.out.println("Data is written to the file successfully...");
		}
		catch(Exception e)
		{
			System.out.println("Error: "+e.toString());
		}
	}
}
```

数据成功写入文件...

输出. txt

```java
Hello World
```

### 结论

在本教程中，我们学习了 Java 中的，`PrintWriter` 类。此类用于将对象的格式化表示写入文本输出流。这个类将原始数据转换成文本格式，然后将转换后的数据写入编写器。

* * *

* * *