# Bash `if..else`语句

> 原文：<https://www.studytonight.com/linux-guide/bash-if-else-statement>

Bash if-else 语句或条件语句是任何提供有条件执行代码功能的编程语言中最基本的概念。当我们希望只在某些条件满足时执行一段代码，而在条件不满足时执行一些代码时，这种方法很有用。

if-else 语句用于此目的，并具有其他几种形式，如 if、if-else、if-elif-else、嵌套 if 等。

我们将在本文中学习所有这些条件流。那么，让我们开始吧。

## 如果语句

这是仅在指定条件为真时执行的条件语句的最简单用法。这个语句的一般语法是。

```sh
if CONDITIONAL-COMMAND
then
  STATEMENTS
fi
```

CONDITIONAL-COMMAND 是一个条件，并且`if`语句仅在该条件为真时执行。`then`关键字与 if 相关联，并包含当 if 为真时执行的语句。让我们通过一个例子来理解。

### 示例:if 语句

在本例中，首先，语句读取用户输入，然后在 if 条件语句中验证该输入。如果用户输入小于 20，则将执行 if 条件。

```sh
#!/bin/bash

echo -n "Enter a number: "
read VAL

if [[ $VAL -lt 20 ]]
then
  echo "The value is less than 20."
fi
```

将此代码保存到. sh 文件中，并使用以下命令执行。

```sh
$ bash filename.sh
```

它将要求用户输入，如果输入小于 20，则输出为:

该值小于 20。

## if-else 语句

此语句是 if 语句的附加版本，提供了当 if 语句为 false 时执行的 else 语句。所以，如果你想在 if 条件失败时执行一些语句。该语句的一般语法是:

```sh
if CONDITIONAL-COMMAND
then
  STATEMENTS
else
  STATEMENTS
fi
```

### 示例:if-else 语句

在本例中，首先，语句读取用户输入，然后在 if 条件语句中验证该输入。如果用户输入小于 20，则将执行 if 条件，如果不是，则执行 else 语句。

```sh
#!/bin/bash

echo -n "Enter a number: "
read VAL

if [[ $VAL -lt 20 ]]
then
  echo "The value is less than 20."
else
  echo "The value is equal or greater than 20."
fi
```

它将要求用户输入，如果输入大于或等于 20，则执行 else 块，输出为:

该值等于或大于 20。

## if-elif-else 语句

此语句用于测试一行中的多个条件，如果任何条件为真，则退出控件。在某些编程语言中，它也被称为 if-else 阶梯。该语句的一般语法是:

```sh
if CONDITIONAL-COMMAND1
then
  STATEMENTS1
elif CONDITIONAL-COMMAND2
then
  STATEMENTS2
else
  STATEMENTS3
fi
```

elif 语句仅在 if 条件为 false 时执行。

### 示例:if-elif-else 语句

这里，如果用户输入 20，则 if 条件失败，控制转到 elif 条件，其中条件为真，语句执行。

```sh
#!/bin/bash

echo -n "Enter a number: "
read VAL

if [[ $VAL -lt 20 ]]
then
  echo "The value is less than 20."
elif [[ $VAL -eq 20 ]]
then
  echo "The value is equal to 20."
else
  echo "The value is equal or greater than 20."
fi
```

它将要求用户输入，如果输入等于 20，则将执行 elif 块，输出为:

该值等于 20。

## 嵌套 if 语句

Bash 允许在 if 语句中使用任意数量的 if 语句，这意味着我们可以使用嵌套的 if 语句来测试多个条件。当我们必须检查 if 语句中的多个条件时，这很有帮助。该语句的一般语法是:

```sh
if CONDITIONAL-COMMAND1
then
  if CONDITIONAL-COMMAND2
  then
     STATEMENTS1
  else
     STATEMENTS2
  fi
else
  STATEMENTS3 
fi
```

嵌套 if 仅在第一个 if 条件失败时执行。

### 示例:嵌套 if 语句

在这个例子中，我们从用户那里获取三个输入值，并使用嵌套的 if 语句测试哪一个更小。

```sh
#!/bin/bash

echo -n "Enter first number: "
read VAL1
echo -n "Enter second number: "
read VAL2
echo -n "Enter third number: "
read VAL3

if [[ $VAL1 -lt $VAL2 ]]
then
  if [[ $VAL1 -lt $VAL3 ]]
  then
    echo "$VAL1 is smallest Number"
  else
    echo "$VAL3 is smallest Number"
  fi
fi
```

它将要求用户输入，如果输入是 20、50、40，那么输出将是:

20 是最小的数

## 结论

Bash 脚本使用条件语句(如 if、if-else、if-elif 和嵌套 if)来创建基于指定条件执行的条件程序。在本文中，我们通过适当的例子和用例来理解条件语句的使用。

* * *

* * *