# Bash `for`语句

> 原文：<https://www.studytonight.com/linux-guide/bash-for-loop>

Bash 脚本中的 For 循环用于重复执行指定的语句/命令。Bash For 循环类似于 [C 语言](https://www.studytonight.com/c/)中的循环。如果你熟悉 C 语言，那么理解这个概念是很容易的，但是如果不熟悉，那么不要担心，理解起来非常简单。

将循环视为一些代码语句的主体，这些语句执行到指定的条件。在 Bash 中，也可以使用循环来迭代，直到该项出现在**列表、数组、字符串**等中。for 循环的一般语法如下。

### 用于循环语法的 Bash

```sh
for item in [LIST]
do
  [COMMANDS]
done 
```

让我们通过创造一些例子来学习。

## 循环迭代字符串元素的 Bash

我们可以使用 for 循环遍历字符串元素。它将每个单词视为一个元素，并迭代直到元素出现。它不需要任何条件，因为当项目完成时，它会自动停止。

```sh
VAL="India is my country"
for word in $VAL
do
  echo "word: $word"
done
```

字:印
字:正
字:吾
字:国

## Bash For 循环迭代一个范围

我们可以使用 for 循环来横向取一个范围的值。在 Bash 中，可以通过使用大括号来创建范围，所以我们在循环中传递范围，循环迭代直到范围的最大值。

这里，范围包括 0 到 5 个值。

```sh
for i in {0..5}
do
  echo "i= $i"
done
```

I = 0
I = 1
I = 2
I = 3
I = 4
I = 5

## 打印偶数值的循环 Bash

在该范围中，第一个值表示起点，第二个值表示终点，第三个值表示每次迭代的跳过点。这里，循环将每隔一次迭代就跳过一次，并且只对偶数值执行。请看下面的例子。

```sh
for i in {0..10..2}
do
  echo "i= $i"
done
```

I = 0
I = 2
I = 4
I = 6
I = 8
I = 10

## 循环迭代数组的 Bash

For 循环也可以用来遍历数组元素。当我们想要打印一个数组的元素时，这是循环最常见的用法，对于同样的数组，这也是循环最常见的用法。

```sh
INTEGER=(1 2 3 4)
for i in "${INTEGER[@]}"; do
  echo "i: $i"
done
```

i: 1
i: 2
i: 3
i: 4

## Bash 中循环的 c 风格

我们可以像使用 C 语言一样使用 for 循环。该循环包含三个部分:**初始化、条件、**和**增量**。

在第一部分中，变量以初始值/起始值开始，然后在条件中，指定结束值，这意味着循环只能进行到指定的结束值。最后，指定增量值，基本上将初始化的变量增加 1。

```sh
for ((i = 0 ; i <= 5 ; i++)); do
  echo "i= $i"
done
```

I = 0
I = 1
I = 2
I = 3
I = 4
I = 5

## Bash For 循环中的 Break 语句

break 语句用于停止当前的代码执行流，并且控件超出了范围。

在 for 循环中，我们可以使用 break 语句来停止其执行，并将控制权交还给 for 循环。您可以看到循环只打印前 3 个值，当它达到 3 时，由于 break 语句，它停止执行。

```sh
for ((i = 0 ; i <= 5 ; i++)); do
   if [[ "$i" == 3 ]]; then
      break
   fi
   echo "i= $i"
done
```

i= 0
i= 1
i= 2

## Bash For 循环中的继续语句

continue 语句用于跳过当前的代码执行流程，控制转到循环的下一个迭代。

在 for 循环中，我们可以使用 continue 语句跳过它的执行。您可以看到循环打印除 3 之外的所有值，因为当它达到 3 时，由于 continue 语句，它跳过执行，并继续下一个迭代，即 4。

```sh
for ((i = 0 ; i <= 5 ; i++)); do
   if [[ "$i" == 3 ]]; then
      continue
   fi
   echo "i= $i"
done
```

I = 0
I = 1
I = 2
I = 4
I = 5

## 结论

在 Bash 中，for 循环通常用于遍历列表、数组、字符串、范围等元素。我们还可以使用它来迭代/重复执行，直到指定的条件。循环的主要目的基本上是重复执行任务。所以，我们可以用它来重复 Linux 中的任何语句/命令。

* * *

* * *