# Linux 中的`gzip`命令

> 原文：<https://www.studytonight.com/linux-guide/gzip-command-in-linux>

`gzip`命令只是用来压缩和缩小文件的大小。压缩文件与原始文件具有相同的属性，如时间戳和所有权。`gzip`命令压缩的文件有。gz 作为文件扩展名。

```sh
$ gzip filename      # It will create filename.gz
```

我们可以使用这个命令来压缩和解压缩数据。该命令的一般语法是:

### 句法

```sh
gzip [arguments] [filename]
```

Gzip 不同于 zip，因为 gzip 不同于 zip，不能一次压缩多个文件。它一次只能压缩一个文件，如果您有多个文件，那么您要么必须为多个文件运行命令，要么可以在 Linux 中使用 tar 或 zip 命令捆绑它们，然后用 gzip 压缩它。

`gzip`命令通常用于压缩文本和档案等常规文件。不建议压缩媒体文件，如视频、音频、pdf 和其他可执行文件，因为它们已经被压缩。任何进一步的压缩都会损坏数据。

## gzip 相对于 zip 的优势

1.  Gzip 具有更好的压缩算法，因此从 gzip 生成的归档文件比通过 zip 生成的归档文件更小。
2.  当压缩捆绑在一起的多个文件时，它几乎好 10 倍，因为它不会压缩多个文件，而是将它们作为一个文件，并将文件大小大幅减小。

## gzip 的缺点

1.  与 zip 不同，如果您想从归档文件中提取单个文件，您必须解压缩整个归档文件，然后提取该文件。而在 zip 中，您可以简单地提取和解压缩特定的文件。
2.  压缩和解压缩多个文件需要多个步骤，并且非常耗时。您必须使用 tar 或 zip 将文件捆绑在一起，然后使用 gzip 压缩它们。解压缩也是如此，你必须解压缩它，并使用 tar 或 zip 提取文件。

## gzip 可用的选项/参数

有多个选项/参数可以与 gzip 一起使用，以提高工作效率并节省时间。这些是可选的，您可以使用默认设置压缩和文件，而无需键入任何参数。

**-f(强制压缩):**当已经有同名的压缩文件时，使用此参数。例如，如果您试图压缩一个名为 cars.txt 的文件，并且已经有一个名为 cars.txt 的压缩文件，使用-f 将强制 gz 压缩该文件并保存它。

**-k(压缩并保留):**此参数将告诉 gzip 压缩文件，并保存原始文件和压缩文件。默认情况下，gzip 压缩文件并删除原始文件，只保留压缩文件以节省空间。

**-v** ( **统计显示):**此参数将显示 gzip 运行完成后压缩或解压缩后文件大小的变化。

**-l(进度显示):**此参数显示压缩或解压缩期间的进度百分比。
**-d(解压缩):**此参数与 gzip 一起使用，用于解压缩文件。您也可以将此参数与上述参数一起使用。

## 使用`gzip`命令压缩文件

让我们学习在 Linux 中使用`gzip`命令压缩文件。对文件名使用以下命令。

```sh
$ gzip filename
```

它将在同一目录下创建一个. gz zip 文件，并删除原始文件。

## 使用`gzip`命令时保留原始文件

上面的压缩命令删除了原始文件，如果我们想在压缩后保留这个文件，那么使用命令中的`-k`选项。

```sh
gzip -k filename
```

## 控制台的详细输出

如果您想查看与文件压缩和速度等相关的详细信息，请将`-v`选项与命令一起使用。

```sh
$ gzip -v filename
```

文件名:32% -替换为 filename.gz

## 压缩多个文件

要压缩多个文件，请使用以下命令。它需要命令中所有文件的名称。

```sh
$ gzip filename1 filename2 filename3
```

`gzip`命令不会为所有文件创建一个压缩文件，而是为每个文件创建单独的 zip 文件，如:filename1.gz、filename2.gz、filename3.gz。

## 压缩目录中的所有文件

如果你想压缩一个目录的所有文件，那么使用`gzip`命令的`-r`选项。`-r`用于递归目的。

```sh
$ gzip -r directory-name
```

它将压缩同一目录下的所有文件。

## 指定压缩级别

我们可以为命令指定压缩级别，以设置或多或少的压缩质量。基本上，它使用 1 到 9 个数字来设置压缩级别，这意味着 1 将压缩更少，并以更快的速度完成该过程，而 9 指定最佳压缩级别，但速度很慢。我们可以相应地设置级别。

```sh
$ gzip -9 filename
```

它将进行最大程度的压缩。

## 在 Linux 中解压缩文件

我们可以使用`gzip`命令通过使用`-d`选项来解压缩一个存档文件。以下命令将文件解压缩到相同的目录中。

```sh
$ gzip -d filename.gz
```

## 解压缩多个文件

类似于单个文件，您也可以通过对多个 zip 文件使用相同的命令来解压缩多个文件。

```sh
$ gzip -d filename1.gz filename2.gz filename3.gz
```

## 结论

`gzip`命令是 Linux 中的一个实用命令，可以用来压缩和解压缩文件。在本文中，我们学习了如何将它与几个选项一起使用，例如-k 表示零售原始文件，-v 表示获取详细信息，-d 表示解压缩。gz 文件等。本文包含了在 Linux 中使用`gzip`命令的简化指南。

* * *

* * *