# 如何在 Linux 中重命名文件或目录

> 原文：<https://www.studytonight.com/linux-guide/how-to-rename-a-file-or-directory-in-linux>

如果你想在 Linux 中**重命名一个文件或目录**，没有具体的重命名命令，但是有**移动命令**可以同时使用，将文件/目录移动到一个新的位置或者重命名文件或目录。

移动文件就是以某种方式重命名文件。怎么做？

我们举一个简单的例子。考虑以下目录结构:

*   **目录 1**
    *   **子目录 1**
        *   **somefile.txt**
*   **目录 2**
    *   **子目录 2**

我们有两个名为 **dir1** 和 **dir2** 的目录，然后我们在这些文件中有子目录，在其中一个子目录**子目录**中，我们有一个文件 **somefile.txt** ，一个普通的文本文件。

文件 **somefile.txt** 的完整路径或名称是**dir 1/subdir 1/some file . txt**，对。现在，如果我想把这个文件移到目录**子目录**，那么这个文件的完整路径或完全限定名将变成**目录 2/子目录/somefile.txt** 。

现在，当我们将一个文件从一个位置移动到另一个位置时，在某种程度上，它的完全限定名改变了，或者它的路径改变了，这也是它的名称的一部分。

这里需要注意的另一个要点是，在 Linux 中，文件或目录由它们的完全限定名来管理。所以我们可以在 Linux 中使用 **move 命令来重命名一个文件，这个命令可以用来更新任何文件或者目录的完全限定路径，这个路径无非就是文件名。**

## 在 Linux 中重命名文件/目录- `mv`命令:

我们将使用`mv`命令来重命名 Linux 中的任何文件或目录。`mv`命令用于将文件或目录移动到不同的位置，这类似于重命名文件，我们在上一段中刚刚理解了这一点。

使用`mv`命令的基本语法是:

```sh
mv [Option] <SOURCE_FILE> <DESTINATION_FILE>
```

在上面的命令中，**源文件**是您要重命名的文件或目录的完全限定名，**目标文件**是更改了名称的新路径。

运行`mv`命令时，我们可以使用许多选项。

Linux 中的`mv`命令使用起来非常简单。我们可以将此命令用于:

1.  重命名单个文件或目录

2.  一次重命名多个文件或目录。

让我们从更简单的一个开始，重命名一个文件或一个目录。

### 重命名单个文件/目录

如果您想要按照上面解释的目录结构中描述的那样重命名文件 **somefile.txt** ，以使新名称为 **mynewfile.txt** ，我们可以运行以下命令:

```sh
mv somefile.txt mynewfile.txt
```

没有任何选项，它应该直接重命名。现在运行 ls -l 命令列出目录中的文件，您会看到您的文件被重命名了。

代替 **somefile.txt** ，我们也可以提供文件的全限定路径，代替 **mynewfile.txt** ，我们可以提供更新后的路径，然后使用`mv`命令，它会重命名文件，并将文件移动到新的路径。

同样，您也可以重命名目录:

```sh
mv dir1 mydir
```

名为 **dir1** 的目录将更名为 **mydir** 。

### 重命名多个文件/目录

要一次重命名多个文件，我们不能直接使用`mv`命令。为此，我们必须编写一个小的 bash 脚本。

让我们举个例子，考虑一个目录，其中存储了许多不同扩展名的文件。我们想用**改变文件的扩展名。txt** 扩展并使其成为**。日志**扩展。我们要怎么做？

我们可以使用下面的 bash 脚本来实现:

```sh
for f in *.txt; do mv -- "$f" "${f%.txt}.log"
```

在上面的 bash 脚本中，我们使用了一个`for`循环来遍历所有带有**的文件。txt** 扩展，然后运行`mv`命令重命名它们并替换**。txt** 延伸带**。日志**扩展。

同样，您也可以重命名目录。

### 重命名目录会影响目录中的内容吗？

当使用`mv`命令重命名目录时，目录的组件保持原样。唯一的变化是，现在他们获得了一个新的更新的路径与改变的目录名。

重命名目录后，使用`ls -l`命令列出它的文件和子目录，这样就不会有变化了。

## 摘要

如果你是 Linux 新手，不要被我们使用`mv`命令来重命名文件的事实所迷惑。因为重命名文件和移动文件，或多或少是一样的。

* * *

* * *