# Bash `select`（制作菜单）

> 原文：<https://www.studytonight.com/linux-guide/bash-select-make-menus>

![Bash Select](img/c2c7332dce3c1dfe6ebbc5f3d2774043.png)

本文将研究 **Bash** 中选择构造的基本原理。

选择的结构使您能够构建菜单。

## Bash 选择构造

选择的构造从项目列表中产生一个**菜单**。它具有与 for 循环几乎相同的**语法**:

```sh
select ITEM in [LIST]
do
  [COMMANDS]
done
```

**【列表】**可以是由空格、整数范围、命令输出、数组等分隔的字符串序列。可以使用 **PS3** 环境变量为所选构造提供自定义提示。

当选择的构造被执行时，列表中的每一项都被写入屏幕上的**(标准错误)，以数字为前缀。**

 **如果用户**输入**一个对应于所示项目之一的数字，则**【项目】**的值被分配给该项目。所选项目的值保存在变量 REPLY 中。否则，如果用户输入为空，将再次显示提示和选项列表。

选择循环的**将继续运行并请求用户输入，直到中断指令被调用。**

为了展示所选择的构造是如何工作的，让我们看一下下面的基本示例:

```sh
PS3="Enter a number: "

select character in Sheldon Leonard Penny Howard Raj
do
    echo "Selected character: $character"
    echo "Selected number: $REPLY"
done
```

该脚本将显示一个菜单，该菜单由带有相关数字的项目和 **PS3** 提示组成。当用户输入数字时，**脚本**将输出选择的字符和数字:

```sh
1) Sheldon
2) Leonard
3) Penny
4) Howard
5) Raj
Enter a number: 3
Selected character: Penny
Selected number: 3
Enter a number:
```

## Bash 选择示例

通常情况下，在**连接**时，用 if 语句。

让我们看一个更现实的场景。一个简单的**计算器**要求用户输入并进行基本的算术运算，包括加法、减法、乘法和除法。

```sh
PS3="Select the operation: "

select opt in add subtract multiply divide quit; do

  case $opt in
    add)
      read -p "Enter the first number: " n1
      read -p "Enter the second number: " n2
      echo "$n1 + $n2 = $(($n1+$n2))"
      ;;
    subtract)
      read -p "Enter the first number: " n1
      read -p "Enter the second number: " n2
      echo "$n1 - $n2 = $(($n1-$n2))"
      ;;
    multiply)
      read -p "Enter the first number: " n1
      read -p "Enter the second number: " n2
      echo "$n1 * $n2 = $(($n1*$n2))"
      ;;
    divide)
      read -p "Enter the first number: " n1
      read -p "Enter the second number: " n2
      echo "$n1 / $n2 = $(($n1/$n2))"
      ;;
    quit)
      break
      ;;
    *) 
      echo "Invalid option $REPLY"
      ;;
  esac
done
```

脚本执行时显示菜单和 PS3 **提示**。用户被邀请选择程序并输入两位数。根据用户的输入，脚本将输出结果。

每次**选择**后，用户将被要求完成一个新的动作，直到中断指令被调用。

```sh
1) add
2) subtract
3) multiply
4) divide
5) quit
Select the operation: 1
Enter the first number: 4
Enter the second number: 5
4 + 5 = 9
Select the operation: 2
Enter the first number: 4
Enter the second number: 5
4 - 5 = -1
Select the operation: 9
Invalid option 9
Select the operation: 5
```

这个**脚本**的一个限制就是只能对整数进行运算。

这里有一个更复杂的版本。我们利用 bc 工具允许浮点数进行**数学**计算。此外，重复的代码被捆绑在一个函数中。

```sh
calculate () {
  read -p "Enter the first number: " n1
  read -p "Enter the second number: " n2
  echo "$n1 $1 $n2 = " $(bc -l <<< "$n1$1$n2")
}

PS3="Select the operation: "

select opt in add subtract multiply divide quit; do

  case $opt in
    add)
      calculate "+";;
    subtract)
      calculate "-";;
    multiply)
      calculate "*";;
    divide)
      calculate "/";;
    quit)
      break;;
    *) 
      echo "Invalid option $REPLY";;
  esac
done
```

**输出:**

```sh
1) add
2) subtract
3) multiply
4) divide
5) quit
Select the operation: 4
Enter the first number: 8
Enter the second number: 9
8 / 9 =  .88888888888888888888
Select the operation: 5 
```

## 结论

选择的结构**使您能够设计菜单。方便构建需要用户输入的 shell **程序**。**

* * *

* * ***