# Linux 中的`Tar`命令(创建和提取档案)

> 原文：<https://www.studytonight.com/linux-guide/tar-command-in-linux-create-and-extract-archives>

![Tar](img/df85ab0ea0fe0796e231718f8e54d262.png)

与 **Linux** 发行版捆绑在一起的 GNU tar 工具具有内置压缩功能。它可以生成一个. tar 档案，然后在一次操作中使用 gzip 或 bzip2 压缩来压缩它。这就是为什么结果文件是一个 **.tar.gz 文件或. tar.bz2 文件。**

## 压缩整个目录或单个文件

使用以下命令压缩整个**目录**或 Linux 上的单个文件。它还会压缩您指定的目录中的所有其他目录——换句话说；它递归运行。

```sh
tar -czvf name-of-archive.tar.gz /path/to/directory-or-file
```

以下是那些**开关**真正的含义:

*   -c:创建一个档案。

*   -z:使用 gzip 压缩存档。

*   -v:在构建归档文件时在终端中显示进度，通常称为“详细”模式。在这些说明中，v 通常是可选的，但它是有益的。

*   -f:允许您提供归档文件的文件名。

假设你在当前**目录**中有一个名为“stuff”的目录，你想把它保存到一个名为 archive.tar.gz 的文件中。您将执行以下命令:

```sh
tar -czvf archive.tar.gz things
```

或者，让我们假设在当前系统上有一个位于 **/usr/local/** 的目录，并且您想要将其压缩为一个名为 archive.tar.gz 的文件。您将执行以下**命令**:

```sh
tar -czvf archive.tar.gz /usr/local/something
```

## 一次压缩多个目录或文件

虽然 tar 通常用于压缩单个**目录**，但您也可以使用它来压缩多个目录、大量单个文件或两者。只需提供一个文件或文件夹列表，而不是一个单独的列表。例如，假设您希望压缩 **/home/ubuntu/Downloads** 目录、/usr/local/stuff 目录和/home/Ubuntu/Documents/notes . txt 文件。您将执行以下**命令**:

```sh
tar -czvf archive.tar.gz /home/ubuntu/Downloads /usr/local/stuff /home/ubuntu/Documents/notes.txt
```

只需指定您希望备份的任意数量的**文件夹**或文件。

## 排除目录和文件

您可能希望在极少数情况下压缩整个目录，但不包括特定的文件和文件夹。您可以通过为您希望**排除**的每个指南或文件插入-exclude 选项来实现。

比如，假设你想**压缩/home/ubuntu，**但是不想压缩/home/ubuntu/Downloads 和/home/ubuntu/。缓存文件夹。你会这样做:

```sh
tar -czvf archive.tar.gz /home/ubuntu —exclude=/home/ubuntu/Downloads —exclude=/home/ubuntu/.cache
```

—exclude 开关功能强大。它不取文件夹和**文件**的名称——它取模式。你能做的还有很多。例如，您可以使用以下**命令**归档一个完整的目录并排除所有. mp4 文件:

```sh
tar -czvf archive.tar.gz /home/ubuntu —exclude=*.mp4
```

### 请改用 bzip2 压缩。

而 gzip 压缩通常用于生成. tar.gz 或。tgz 文件，tar 还支持 **bzip2** 压缩。这使您能够生成 bzip2 压缩文件，通常称为. tar.bz2、. tar.bz 或。tbz 文件。为此，将脚本中 gzip 的 **-z** 替换为 bzip2 的 a -j。

**【Gzip】**比较快，但是压缩往往会少一点，所以你收到的文件会稍微大一点。Bzip2 速度较慢，但它会卡住一点，所以你会得到一个稍微小一点的文件。Gzip 也越来越流行，一些精简的 **Linux** 系统默认提供 gzip 支持，但不支持 bzip2。然而，总的来说，gzip 和 bzip2 实际上是相同的，两者的性能相似。

例如，我们给出的第一个例子是**压缩**目录，而不是执行以下命令:

```sh
tar -cjvf archive.tar.bz2 things
```

## 提取档案

一旦你有了一个档案，你可以使用 **tar** 命令提取它。以下命令将把 archive.tar.gz 的内容移至当前目录。

```sh
tar -xzvf archive.tar.gz
```

它与我们之前使用的归档文件创建命令相同，只有 **-x** 选项替代了-c 开关。这表明您希望提取一个归档文件，而不是生成一个。

您可以选择**将档案的内容提取到指定的目录中。您可以通过将-C 开关连接到命令的末尾来实现这一点。例如，以下命令将 archive.tar.gz 文件的内容提取到 **/tmp** 目录。**

```sh
tar -xzvf archive.tar.gz -C /tmp
```

如果文件是**bzip2**-压缩文件，用“ **j** 替换前面说明中的“z”。

这是 **tar** 命令最简单的用法。该命令提供了许多其他选项，因此我们不能合理地将它们都放在这里。欲知详情。在 shell 中执行 info`tar`命令，显示`tar`命令的完整信息页面。完成后按 q 键离开**信息**页面。你也可以在线阅读 tar 手册。

* * *

* * *