# Bash Shebang

> 原文：<https://www.studytonight.com/linux-guide/bash-shebang>

![bash shebang](img/b7d7713ce7d7a19eaebb890ef35e1444.png)

如果你是通过阅读别人的代码来学习 **Bash** 脚本，你可能已经观察到脚本的第一行是以#开头的！字符和 Bash 解释器的路径。

这个序列的**字符** (#！)被称为 Shebang，用于通知操作系统使用哪个解释器来解析文件的剩余部分。

## 希邦口译员指令

舍邦解释器**指令**有以下形式:

```sh
#!interpreter [arguments]
```

*   **指令**必须是脚本中的第一行。
*   指令必须以**开头** #！
*   舍邦字符后面的空格是**可选的**。
*   解释器是一个**二进制**文件的完整路径(例如:/bin/sh，/bin/bash)。
*   解释器**参数**是可选的。

**示例:**

*   **#！/bin/bash -** 使用 bash 解析文件。
*   **#！/usr/bin/env perl -** 使用 env 命令定位 perl 可执行文件的路径。
*   **#！/usr/bin/python -** 使用 python 二进制执行文件。

## 在 Bash 脚本中使用 Shebang

假设没有给出 shebang，执行 **Bash** 脚本的用户正在使用另一个 Shell。在这种情况下，无论 Shell 使用什么作为默认解释器，脚本都将被解释。例如，Bash 的默认解释器是 Bash，而对于 **zsh** 则是 sh。为了保证您的脚本总是被 Bash**翻译**，您需要使用 Shebang 提供可执行路径。

有两种方法可以使用 Shebang 指令和设置解释器。
**使用 bash 二进制的绝对路径:**

```sh
#!/bin/bash
```

**使用环境实用程序:**

```sh
#!/usr/bin/env bash
```

第二种技术的好处是，它将在用户的 **$PATH** 环境变量中寻找 bash 可执行文件。如果有多条路径可以痛击，脚本将选择第一条。
当使用第一个选项时，给 Bash shell 添加一个替代项，并将其发送给解释器。例如，要在调试模式下执行脚本，可以使用 **#！/bin/bash -x.** 如果使用 env 方法，则需要使用集合来定义选项。要激活调试模式，您可以将 set -x 放在 shebang 行之后。

### 示例脚本

让我们用 Shebang 构造一个基本脚本来输出**“你好，世界。”**打开文本编辑器，粘贴如下一行:

```sh
nano hello world
```

```sh
#!/bin/bash

echo "Hello, World" 
```

为了能够在不从命令行提供**解释器**的情况下执行脚本，您需要使文件可执行:

```sh
chmod +x hello world 
```

现在如果你可以通过输入**执行**脚本。/后跟脚本名称:

```sh
./hello world 
```

## 越过沙邦

如果出于任何原因，您希望**覆盖**在 Shebang 行中设置的解释器，您需要通过显式提供预期的 Shell 来执行脚本。比如执行一个有 **#的脚本！在使用 bash shell 的 Shebang 行中提供的/bin/sh** 中，您可以键入:

```sh
bash hello world
```

请注意，覆盖 shell **解释器**不是一个好主意，因为这可能会导致意外的脚本行为。

## 结论

到目前为止，你应该已经对什么是 **Shebang** 以及如何在你的 **Bash 脚本中使用它有了一个相当好的了解。**

如果你有任何问题或建议，请留言。

* * *

* * *