# 如何使用`scp`命令安全复制文件

> 原文：<https://www.studytonight.com/linux-guide/how-to-use-scp-command-to-securely-copy-files>

Linux `scp`是一个用来安全复制文件的命令。当我们在服务器之间传输数据时，会用到它。它类似于在本地机器上复制文件的`cp`命令。

在本文中，我们将学习在以下场景中使用`scp`命令传输文件:

*   本地到远程服务器

*   远程服务器到本地

*   远程到远程服务器

*   AWS 本地的 SCP

让我们从对命令的基本理解开始。该命令的**语法**为:

```sh
scp [OPTION] [user@]SRC_HOST:]file_name1 [user@]DEST_HOST:]file_name2
```

**选项:**可能包括密文、端口号、限制等。

**【用户@】SRC _ HOST:】:**源地址(IP 地址)

**文件名 1:** 源文件名

**【用户@】DEST _ 主机:】:**目的地址(IP 地址)

**文件名 2:** 目标位置(文件或目录)

当使用`scp`命令进行数据传输时，它会提示输入密码，并以加密的形式传输数据，这样就不会有人破坏或访问原始数据。

要复制，文件必须具有读取权限，目标必须具有写入权限。

该命令使用几个选项来处理所有类型的复制操作。其中一些是:

| **选项** | **描述** |
| -3 | 它通过本地主机在两个远程主机之间复制数据，如果没有此选项，数据将直接在两个远程主机之间复制。 |
| -4 | 它仅用于复制 IPv4 地址上的数据。 |
| -6 | 它仅用于复制 IPv6 地址上的数据。 |
| -丙 | 它用于启用压缩。 |
| -c | 它用于选择加密数据传输的密码。 |
| ［构成来自拉丁语、结尾为-us 的名词的复数］ | 它用于选择从中读取公钥身份验证的身份(私钥)的文件。 |
| -j | 它用于指定目的地 |
| -我 | 它用于限制带宽。 |
| -P | 它用于指定运行服务器的端口号。 |
| -p | 它用于保留原始文件的访问和修改时间。 |
| q | 它用于从 ssh 禁用进度指示器和警告。 |
| -r | 它用于将整个目录递归复制到远程服务器。 |

让我们从将文件复制到远程服务器开始。

## 将文件从本地主机复制到远程服务器

使用以下命令将文件从本地主机复制到远程服务器。

```sh
scp myfile.doc remote_username@101.155.10.20:/remote/directory
```

其中 **myfile.doc** 是文件名， **remote_username** 是远程用户的名称。**101.155.10.20**代表远程地址。

如果服务器在默认端口上运行，它可以正常工作，但是如果**端口号不同**，则使用以下命令:

```sh
scp -P 2022 myfile.doc remote_username@101.155.10.20:/remote/directory
```

同样，我们可以通过使用命令中的-r 选项将目录复制到远程服务器。请参见下面的命令。

```sh
scp -r mydirectory remote_username@101.155.10.20:/remote/directory
```

## 将文件从远程服务器复制到本地主机

以下命令用于将文件从远程服务器复制到本地主机。

```sh
scp remote_username@101.155.10.20:/remote/directory/myfile local/directory
```

除了首先使用远程地址，然后使用本地目录路径之外，它类似于上面的命令，我们将本地复制到远程服务器。

## 将文件从远程服务器复制到另一台远程服务器

以下命令用于使用本地系统将文件从一台远程服务器复制到另一台远程服务器。

```sh
scp remote1_username@101.155.10.20:/remote/directory/myfile.txt remote2_username@15.150.15.10:/remote/directory
```

它将询问两个远程系统的密码。因此，请为成功的数据传输提供密码。

## 使用本地主机将文件从远程服务器复制到另一台远程服务器

以下命令用于通过使用本地系统将文件从一台远程服务器复制到另一台远程服务器。

```sh
scp -3 remote1_username@101.155.10.20:/remote/directory/myfile.txt remote2_username@15.150.15.10:/remote/directory
```

注意，通过本地主机传输时使用 **-3 选项**。

## 将文件从本地主机复制到 AWS 服务器

如果您在 AWS 服务器上工作，想要将文件从本地复制到 AWS，请使用以下命令。

```sh
scp -i key-name.pem myfile.doc  bitnami@40.13.23.10:/remote/directory
```

在上面的命令中，我们使用了**。pem** 文件，包含服务器的私钥。我们可以用它通过 ssh 命令访问 AWS 服务器，同样也可以用来在本地和 AWS 服务器之间传输文件。

## 结论

在本文中，我们已经了解了`scp`命令及其在不同场景中的用法，例如在本地到远程服务器之间传输数据，远程服务器到本地机器，以及本地到 AWS 服务器之间的传输。
通过服务器非常安全地传输数据是一种简单且更好的方法。

* * *

* * *