# 如何使用`rsync`排除文件和目录

> 原文：<https://www.studytonight.com/linux-guide/how-to-exclude-files-and-directory-using-rsync>

![rsync](img/b3ba0972d93bca52d53e970a38f7aa25.png)

Rsync(远程同步)是一个功能强大的**命令行**应用，用于同步本地和远程文件和目录。它预装在大多数 Linux 发行版上。它是备份和保持许多站点上的文件和文件夹同步的最强大的应用之一。sync 最令人满意的一点是，它通过仅传输已修改的数据，减少了复制到远程站点的数据量。rsync 还有另一个优秀的特性，我们今天要研究；它从**同步**中省略了文件或目录。当您不想复制一个或多个文件或目录时，这在备份过程中非常有用。

我们将通过几个例子向您展示如何**同步排除**文件或目录。这里展示的例子已经在 Ubuntu 20.04 LTS 上试用过了。然而，它们同样适用于安装了 **rsync** 的其他 Linux 发行版。

## 排除特定文件

同步**目录**时，您可能希望排除放置在其中的特定文件。您可以使用–exclude 选项，后跟用逗号包围的文件名。

该命令的**语法**为:

```sh
$ rsync -a —exclude ‘file name’ source directory/ destination directory/
```

这里，一个选项用于**递归**同步。

例如，在同步 src 目录和 dest 目录时，要从源中排除名为 **sample.txt** 的文件，命令应该是:

```sh
$ rsync -a —exclude ‘sample.txt’ src dir/ dest dir/
```

## 排除特定目录

要在同步源目录和目标目录时从源目录中排除特定目录(及其子目录)，请使用以下语法:

```sh
$ rsync -a —exclude ‘directory name’ src dir/ dest dir/
```

例如，要在同步 src 目录和 dest 目录时排除名为 **sampledir** 的目录，命令应该是:

```sh
$ rsync -a —exclude ‘sampledir’ src dir/ dest dir/
```

如果您希望排除**目录**的内容，但不排除目录本身，请使用目录名后跟/*:

```sh
$ rsync -a —exclude 'sampledir/* ' src dir/ dest dir/
```

上述命令会将目录传输到**目的地**，但不会传输其内容。

## 排除多个文件或目录

要在**同步**操作期间排除多个文件或目录，请按如下方式定义每个文件或目录:

```sh
$ rsync -a —exclude 'file name' —exclude 'directory1 —exclude 'directory2' src dir/ dest dir/
```

不要为每个文件或目录单独提供**–exclude**选项，您可以使用单个–exclude 选项，将所有文件或目录放在花括号中。

```sh
$ rsync -a —exclude={'file name' ,'directory1’,'directory2'} src dir/ dest dir/
```

另一种排除多个文件或目录的方法是通过**将它们列在一个文件中，然后将文件名提供给**-从选项中排除**:**

```sh
$ rsync -a —exclude-from ‘list’ src dir/ dest dir/
```

这里，**列表**包含我们希望排除的文件和文件夹名称。该命令将 src 目录同步到 dest 目录，同时省略“list”文件中指示的文件和目录。

## 排除符合模式的文件或目录

使用 **rsync** ，您也可以排除符合指定模式的文件或文件夹。例如，当**同步**一个目录时，您可能希望排除任何以. txt 后缀结尾的文件。在这种情况下，命令是:

```sh
$ rsync -a —exclude ‘*.txt’ src dir/ dest dir/
```

## 按大小排除文件

使用 rsync，您可以根据文件的最小或最大大小排除文件。在这里，我们将不使用–exclude 选项，而是根据最大和最小大小分别使用**–最大大小=<MB>或–最小大小= =<MB>**选项。

假设我们想要将所有文件同步到目标目录，不包括那些大小超过 **100MB** 的文件。在这种情况下，命令将是:

```sh
$ rsync -av —max-size=100m src dir/ dest dir/
```

同样，为了排除小于指定大小的文件，假设 **50 MB，**命令将是:

```sh
$ rsync -av —min-size=50m src dir/ dest dir/
```

## 结论

这就是全部！本文检查了几个实例，以排除同步中的**文件或目录。我们已经展示了如何排除单个文件或目录、多个文件和目录、符合指定模式的文件，这取决于它们的**最小/最大**大小。**

* * *

* * *