# 如何设置 Nginx 反向代理

> 原文：<https://www.studytonight.com/linux-guide/how-to-setup-a-nginx-reverse-proxy>

![Proxy](img/b3c7b26b91fbb95df4463fad38f1c29e.png)

在 **Linux** 操作系统中，反向代理作为主机(客户端)和服务器之间的连接运行。它收集客户端请求并将其传递给其他服务器，最终将服务器的答案提供给客户端，看起来好像它们来自代理服务器本身。在本指南中，我们将教您什么是 Nginx 反向代理，以及如何在您的 VPS 上设置它！

客户端和服务器不断交换信息以有效运行。**通常**反向代理由网络服务器使用。反向代理或网关在客户端看来就像普通的 web 服务器一样，不需要额外的设置。客户端执行典型的查询，而反向代理选择传递**信息**，将最终结果提供给客户端，就像它是原点一样。

Nginx **反向**代理提供了多种功能。它是互联网上最常用的开源服务器之一。

## 如何设置 Nginx 反向代理？

现在，我们将在一个 **Apache** 网络服务器前设置 Nginx。我们选择了 Apache 服务器，因为它更擅长管理动态材料。

所以，所有的惰性素材都会去 **Nginx** ，而动态内容则去了 Apache。这将通过根据搬运标准优化材料交付来提高**性能**。

接下来，我们将指定 Nginx 代理服务器的 IP 地址为 **192.x.x.1** ，后端 Apache 服务器的 IP 地址为 192.x.x.2。

**1 .安装 engine〔t1〕**

我们将在 Ubuntu 18.04 上使用 apt 命令:

```sh
sudo apt-get update
sudo apt-get install nginx
```

**2。禁用默认虚拟主机**

安装 Nginx 后，运行以下命令停用虚拟主机:

```sh
sudo unlink /etc/nginx/sites-enabled/default
```

**3。创建 Nginx 反向代理**

停用虚拟主机后，我们需要在 etc/Nginx/sites-available 目录中创建一个反向代理文件. conf 来保存反向代理信息。

为此，我们需要首先使用 cd 命令输入目录:

```sh
cd etc/nginx/sites-available/
```

然后我们可以使用 **vi** 编辑器创建文件:

```sh
vi reverse-proxy.conf
```

在文件中我们需要放入这些**字符串**:

```sh
server {
    listen 80;
    location / {
        proxy_pass http://192.x.x.2;
    }
}
```

在前面的命令中，值得注意的一点是代理传递使通过 Nginx 反向代理到达的请求能够传递到 **192.x.x.2:80** ，这是 Apache 远程套接字。因此，两个网络服务器- Nginx 和 Apache 共享材料。

完成后，保存文件并关闭 vi **编辑器**。您可以通过键入 wq 来实现这一点。

要将信息传输到其他**服务器**，您可以使用控制台中的 ngx http 代理模块。

现在，通过使用以下命令连接到**/站点启用/** 来激活指令:

```sh
sudo ln -s /etc/nginx/sites-available/reverse-proxy.conf /etc/nginx/sites-enabled/reverse-proxy.conf 
```

**4。测试 Nginx 和 Nginx 反向代理**

最后，我们需要运行 **Nginx** 配置测试并重启 Nginx 以评估其性能。键入以下**命令**以验证在 Linux 终端上运行的 Nginx:

```sh
service nginx configtest

service nginx restart
```

请记住，如果您获得的**未通过**测试，这可能意味着 Apache 设置不正确。

## 结论

在 Linux 操作系统上设置一个 **Nginx** 反向代理有几个好处。它可以有效地提高速度和加强对病毒的保护。在 **Linux 终端**中，Nginx 反向代理设置是一个简单的操作。尽管安装和配置它有各种不同的方法，这完全取决于您的需求，但以下说明很容易帮助您开始反向代理设置。

* * *

* * *