# 如何在 Ubuntu 18.04 上安装和配置 GitLab

> 原文：<https://www.studytonight.com/linux-guide/how-to-install-and-configure-gitlab-on-ubuntu-1804>

GitLab 是一个基于 web 的开源 **Git** 资源库管理器，在 Ruby 中开发，集成了 wiki、问题管理、代码审查、监控以及持续集成和部署。它允许开发人员构建、评估和启动他们的项目。

有三个主要版本的 **GitLab** 可用，社区版(CE)，企业版(ee)，和一个 GitLab 托管的版本。

如果你想摆脱**git lab 是第一选择**。它可以从包括 GitHub 在内的众多来源导入项目和问题，这简化了迁移过程。GitLab UI 设计良好、清晰、直观，在用户体验和功能方面接近 GitHub。
根据必要的用例，有很多方法可以安装 GitLab。本指南涵盖了使用综合软件包在 **Ubuntu 18.04** 机器上安装和配置 GitLab (CE)所需的步骤。

## 先决条件

本指南假设您安装了全新的 **Ubuntu 18.04** 。根据 GitLab 需求页面，建议使用具有以下功能的服务器:

*   至少 4GB 的内存容量。

*   2 个彩色 CPU。
*   至少 2GB 的交换空间。
*   (可选)链接到服务器 IP 地址的域或子域。

为了获得额外的保护，建议设置一个简单的防火墙。您可以按照我们在 Ubuntu 18.04 教程**如何使用 UFW** 设置防火墙中的说明进行操作。
在继续操作之前，请确保您以具有 **sudo** 权限的用户身份登录。

## 安装必需的依赖项

使用以下**命令**刷新本地包索引并安装依赖项:

```sh
sudo apt update
sudo apt install curl openssh-server ca-certificates
```

为了让 **GitLab** 能够发送通知邮件，您可以安装并使用 Postfix，或者使用一些事务性邮件服务，如 SendGrid、MailChimp、 **MailGun** 或 SES，在这种情况下，您可以在**安装完成后跳过以下步骤并配置【GitLab SMTP 设置】(https://docs.gitlab.com/omnibus/settings/smtp.html)。**

运行以下说明在您的 **Ubuntu** 服务器上安装 Postfix:

```sh
debconf-set-selections <<< "postfix postfix/mailname string $(hostname -f)"
debconf-set-selections <<< "postfix postfix/main_mailer_type string 'Internet Site'"
sudo apt install postfix
```

关于如何**建立自己的邮件服务器**的更多详细信息，请阅读本系列。

## 安装 GitLab

GitLab 安装是一个相对**简单明了**清晰的程序。我们将使用 apt 包管理器安装 **GitLab** CE 包。

首先，使用以下 curl 命令将 **GitLab** 仓库添加到系统源列表中:

```sh
curl https://packages.gitlab.com/install/repositories/gitlab/gitlab-ce/script.deb.sh | sudo bash
```

仓库启用后，通过执行以下**命令**安装 GitLab 包。

```sh
sudo apt install gitlab-ce 
```

安装过程可能需要一段时间，安装成功后，您会看到以下**输出**:

感谢您安装 GitLab！

## 调整防火墙规则

关于设置简单防火墙的说明在需求部分给出。为了能够访问 GitLab 接口，我们需要打开端口 80 和 443:

```sh
sudo ufw allow OpenSSH
sudo ufw allow http
sudo ufw allow https
```

为确保相关端口处于打开状态，您可以通过以下方式验证防火墙的状态:

```sh
sudo ufw status
```

输出

```sh
Status: active

To                         Action      From
--                         ------      ----
80/tcp                     ALLOW       Anywhere
443/tcp                    ALLOW       Anywhere
OpenSSH                    ALLOW       Anywhere
80/tcp (v6)                ALLOW       Anywhere (v6)
443/tcp (v6)               ALLOW       Anywhere (v6)
OpenSSH (v6)               ALLOW       Anywhere (v6)
```

## 设置 GitLab 网址

在使用 GitLab 网络界面之前，我们需要配置 **GitLab** 可用的网址。打开 Gitlab 的**配置**文件，进行以下更改:

```sh
sudo nano /etc/gitlab/gitlab.rb 
```

在**配置**文件的顶部附近，您会发现一行以**外部**网址开始。更改该值以匹配您的域/子域或 IP 地址。如果你有一个使用 HTTP 的域，如果你想通过你的服务器 IP 地址访问 GitLab 接口，使用 **HTTP** 。

```sh
/etc/gitlab/gitlab.rb \sexternal url 'https://gitlab.example.com
```

接下来寻找“**让我们加密集成**”，取消对以 letsencrypt['enable']开头的行的注释，并将其更改为 true。如果您希望收到来自“让我们加密您的域名”的电子邮件，请取消注释以 **letsencrypt** [“联系电子邮件”]开头的行，并输入您的电子邮件地址。

如果您将外部网址指定到一个 **IP** 地址，那么不要激活我们加密集成。

```sh
/etc/gitlab/gitlab.rb
letsencrypt
['enable'] = true \sletsencrypt['contact emails'] = ['admin@example.com'] #
```

这应该是一组电子邮件地址**添加为联系人

最后，保存并关闭文件，并执行以下命令重新配置 Gitlab:**

 **```sh
sudo gitlab-ctl reconfigure 
```

该程序将修改你的 **GitLab** 设置，并产生一个免费的让我们加密 **SSL** 证书。

用网络接口配置 GitLab

现在您已经指定了 **GitLab UR** L，您可以使用 GitLab web 界面从基本配置开始。

启动您的网络浏览器并转到:

```sh
https://your gitlab domain or server IP.com
```

* * *

* * ***