# 你好世界应用

> 原文：<https://www.studytonight.com/docker/docker-hello-world-app>

在 docker 中运行 hello world 应用示例非常简单，您可以在不编写一行代码的情况下完成。我们只需要`docker run`命令。在本教程中，我们将学习如何**从**Docker 中心**下载 Docker 图像**，然后运行该 Docker 图像来启动[Docker 容器](https://www.studytonight.com/docker/introduction-to-containers-and-docker)。

因此，在本教程中，我们将主要使用 docker pull 和 docker run 命令。别担心，我们会在接下来的教程中介绍这些命令。

## 你好，世界应用

Docker 提供了一个【hello-world 示例应用，它将为您设置一个裸的最小容器，在该容器中运行一个 C 程序 hello.c，该程序具有以下代码:

```sh
#include <sys/syscall.h>
#include <unistd.h>

#ifndef DOCKER_IMAGE
	#define DOCKER_IMAGE "hello-world"
#endif

#ifndef DOCKER_GREETING
	#define DOCKER_GREETING "Hello from Docker!"
#endif

#ifndef DOCKER_ARCH
	#define DOCKER_ARCH "amd64"
#endif

const char message[] =
	"\n"
	DOCKER_GREETING "\n"
	"This message shows that your installation appears to be working correctly.\n"
	"\n"
	"To generate this message, Docker took the following steps:\n"
	" 1\. The Docker client contacted the Docker daemon.\n"
	" 2\. The Docker daemon pulled the \"" DOCKER_IMAGE "\" image from the Docker Hub.\n"
	"    (" DOCKER_ARCH ")\n"
	" 3\. The Docker daemon created a new container from that image which runs the\n"
	"    executable that produces the output you are currently reading.\n"
	" 4\. The Docker daemon streamed that output to the Docker client, which sent it\n"
	"    to your terminal.\n"
	"\n"
	"To try something more ambitious, you can run an Ubuntu container with:\n"
	" $ docker run -it ubuntu bash\n"
	"\n"
	"Share images, automate workflows, and more with a free Docker ID:\n"
	" https://hub.docker.com/\n"
	"\n"
	"For more examples and ideas, visit:\n"
	" https://docs.docker.com/get-started/\n"
	"\n";

int main() {
	//write(1, message, sizeof(message) - 1);
	syscall(SYS_write, STDOUT_FILENO, message, sizeof(message) - 1);

	//_exit(0);
	//syscall(SYS_exit, 0);
	return 0;
}
```

上面的代码只是为了让你了解 hello-world 应用运行的程序。没有必要浪费时间去理解它，因为我们在这里是为了理解 docker 容器是如何运行的。

运行 Docker Hello World 应用

打开您的终端(如果使用 Mac OS)或命令提示符，并执行以下命令:

```sh
docker run hello-world
```

本地找不到图片【hello-world:最新】
最新:从库/hello-world
拉取 1b930d010525:拉取完成
摘要:sha 256:F9 dfddf 63636d 84 ef 479d 645 ab 5885156 AE 030 f 611 a 56 F3 a 7 AC 7 F2 FDD 86d 7e 4e
状态:下载了 hello-world 的更新图片:最新

来自 Docker 的 hello
此消息显示您的安装似乎工作正常。

为了生成这条消息，Docker 采取了以下步骤:
1。Docker 客户端联系了 Docker 守护程序。
2。Docker 守护程序从 Docker 集线器中提取“hello-world”映像。
(amd64)
3。Docker 守护程序根据该映像创建了一个新的容器，该容器运行产生您当前正在读取的输出的
可执行文件。
4。Docker 守护程序将该输出流式传输到 Docker 客户端，该客户端将其发送到您的终端。

要尝试更有野心的东西，你可以用:
$ Docker run-it Ubuntu bash

运行一个 Ubuntu 容器，用一个免费的 Docker ID:
https://hub.docker.com/

共享图像、自动化工作流等等。要了解更多的例子和想法，请访问:
https://docs.docker.com/get-started/

由于我们有一个新的 docker 安装，并且我们没有编写任何代码，也没有下载任何项目，那么上面的命令将如何运行 hello-world 应用？它是否可用于默认的 docker 安装？

答案是否定的，我们没有 hello-world 应用的代码或 docker 术语 **docker 图像。但是当我们运行`docker run`命令时，docker 会查找 docker 镜像，在本例中，docker 镜像的名称是 hello-world locally，如果找不到镜像，那么 docker 会通过互联网连接 docker hub，下载镜像后运行。**

我们也可以使用`docker pull`命令手动下载运行 docker 容器的任何图像。因此，如果您想从 docker hub 手动下载名为 hello-world 的 docker 映像，请运行以下命令:

```sh
docker pull hello-world
```

使用默认标签:最新
最新:从库中拉出/hello-world
摘要:sha 256:F9 dfddf 63636d 84 ef 479d 645 ab 5885156 AE 030 f 611 a 56 F3 a 7 AC 7 F2 FDD 86d 7e
状态:hello-world 的图像是最新的:最新的
docker.io/library/hello-world:latest

这将下载 docker 映像，并将其本地存储在您的机器上。在上面的输出中，它表示图像已经是最新的，因为在此之前我运行了`docker run hello-world`命令，并且下载了 hello-world docker 图像。

不要担心什么是 **Docker Hub** 或者什么是 **Docker images** ，我们将在接下来的教程中了解它们。只是给大家简单介绍一下，Docker Hub 是一个在线平台，开发者可以上传自己的 Docker 图片，供任何人下载使用。因此，你**将需要一个互联网连接来下载你好世界 Docker 图像**。

因此，在本教程中，我们在 docker 中运行了一个简单的 hello-world 应用，并使用了两个命令，`docker run`和`docker pull`。在下一个教程中，我们将学习如何使用 Docker Hub，然后我们将开始学习各种 Docker 命令。

* * *

* * *