# Drools：传统方法的问题

> 原文：<https://www.studytonight.com/drools/problem-trad-approach>

**Drools** 广泛应用于 **BFSI 行业**(银行、金融服务和保险)。主要原因是不断变化的要求和不断增加的新规则，考虑到 BFSI 行业的**波动性**。

让我们举一个系统的例子，在这个系统中，交易以`XML`的形式来自外部系统，`JAXB`被使用并铸造成定制的`Java Object`。现在有一些业务规则需要应用于 xml 中的某些参数。

所以代码应该是这样的:

```
if (trade.getProductInformation() == Product.IRS) {
	// do something for IRS (Interest Rate Swap Trade)
} 
else if (trade.getProductInformation() == Product.CDS) {
  	if (trade.getPartyIds() == null) {
    	// do something else for CDS trades with no Party Id
  	} 
  	else {
    	if(trade.getTradeId() ! =null) {
			//do something
      }
  }
}
```

现在 currrent java 代码处理两种产品类型( **IRS** 和 **CDS** )并且应用想要搭载第三种产品 **(Bonds)** ，每次必须引入新的条件时，上面的 java 代码将很难维护和更改。

救援的解决方案是使用`Rule Engine`。使用规则引擎，您的业务逻辑被隔离在规则中，如果有新产品要加入，只需要添加新的规则。

例如:

```
if Trade( productInformation == Product.IRS)
	then do something else for IRS Trade

if Trade( productInformation == Product.CDS)
	then do something for CDS trade

```

现在添加了一个新系统，因此新规则将是:

```
if Trade( productInformation == Product.BONDS)
	then do something for BONDS trade

```

上面的例子很简单**(仅供参考)**。当代码中有大量嵌套的`if`和`else`语句时，使用规则确实有助于轻松地向应用添加新的需求/更改，以及修改现有的规则。

* * *

* * *