# 在 Maven 中构建概要文件

> 原文：<https://www.studytonight.com/maven/build-profiles-in-maven>

maven 中的 Profile 只不过是允许为特定环境定制构建的元素子集。概要文件对于不同的构建环境也是可移植的。

构建环境基本上意味着为生产和开发实例设置的特定环境。当开发人员在开发阶段工作时，他们打算使用生产实例中的数据库，对于生产阶段，将使用实时数据库。

因此，为了配置这些实例，maven 提供了构建概要文件的功能。可以配置任意数量的构建配置文件，也可以覆盖`pom.xml`中的任何其他设置

这些定义的概要文件能够在构建期间修改 pom.xml。即为开发和生产实例配置单独的环境。根据传递的参数，相应的配置文件被激活。**例如**可以为开发、测试和生产阶段设置配置文件。

* * *

## Maven:构建概要文件的类型

下表显示了 Maven 中构建概要文件的类型:

| 构建配置文件类型 | 定义于 |
| 每个项目 | pom.xml 文件 |
| 每个用户/开发人员 | maven settings . XML(% USER _ HOME %/. m2/settings . XML) |
| 全球的 | Maven 全局设置. XML(% M2 _ HOME %/conf/settings . XML) |

* * *

## 马文:构建可移植性

如上所述，可以根据给定项目的需求设置不同的环境。因此，通过这种方式，给定项目的可移植性可以得到保护和有效处理。

构建可移植性可以被定义为一个项目的能力，它可以在不同的环境中成功地编译和部署，这也涉及到为相同的环境应用不同的环境配置。任何可移植的项目应该总是倾向于在没有任何属性定制的情况下工作。

任何可移植的项目都会消除与项目相关的复杂性和问题。

* * *

### 马文:激活配置文件

以下是激活或触发 maven 构建概要文件的方法:

*   显式使用命令
*   Maven 设置
*   基于环境变量
*   操作系统设置
*   存在/缺失的文件

* * *

## Maven:显式使用命令

```
<profiles>
   <profile>
      <id>test</id>
      <build>
         <plugins>
            <plugin>
               <groupId>org.apache.maven.plugins</groupId>
               <artifactId>maven-antrun-plugin</artifactId>
               <version>1.1</version>
               <executions>
                  <execution>
                     <phase>test</phase>
                     <goals>
                        <goal>run</goal>
                     </goals>
                     <configuration>
                     <tasks>
                        <echo>Using app.test.properties</echo>
                        <copy file="src/main/resources/app.test.properties" 
                        	tofile="${project.build.outputDirectory}/env.properties"/>
                     </tasks>
                     </configuration>
                  </execution>
               </executions>
            </plugin>
         </plugins>
      </build>
   </profile>
</profiles> 
```

* * *

## Maven 设置示例

下面是一个基本的 Maven 设置示例:

```
<settings 
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://maven.apache.org/POM/4.0.0
   http://maven.apache.org/xsd/settings-1.0.0.xsd">
   <mirrors>
      <mirror>
         <id>com.testorg.companyname</id>
         <name>Internal Artifactory Maven repository</name>
         <url>http://repo1.maven.org/maven2/</url>
         <mirrorOf>*</mirrorOf>
      </mirror>
   </mirrors>
   <activeProfiles>
      <activeProfile>test</activeProfile>
   </activeProfiles>
</settings>
```

* * *

### 基于环境变量

```
<profile>
   <id>test</id>
      <activation>
      <property>
         <name>env</name>
         <value>test</value>
      </property>
   </activation>
</profile> 
```

* * *

### 操作系统设置

```
<profile>
   <id>test</id>
   <activation>
         <os>
         <name>Windows 7</name>
         <family>Windows</family>
         <arch>x86</arch>
         <version>5.1.2600</version>
         </os>
   </activation>
</profile> 
```

* * *

### 存在/缺失的文件

```
<profile>
   <id>test</id>
   <activation>
      **<file>**
         <missing>
            target/generated-sources/axistools/wsdl2java/com/orgname/group
         </missing>
      **</file>**
   </activation>
</profile> 
```

* * *