# Maven 插件

> 原文：<https://www.studytonight.com/maven/maven-plugins>

maven 中的 Plugin 是一个重要的特性，基本上用于在不同的项目中重用公共的构建逻辑。插件是执行所有任务的工具，比如编译代码、用 junits 测试代码、创建 jar/war/ear 文件和项目文档。maven 中的大部分工作都是使用插件完成的，因为依赖项(jar 文件)只在执行任务时添加到类路径中。

因此，maven 只不过是一个插件执行框架，在这个框架中，每项任务都是通过使用插件来完成的。

下面是 maven 中插件处理的基本任务列表:

*   创建 jar/war/ear 文件。
*   代码编译
*   代码的单元测试。
*   项目文件

任何插件的行为都可以通过使用每个插件目标(也称为 Mojo)公开的一组参数来改变。maven 中的一个 **Mojo** 只是一个目标，基本上指定了一个目标的元数据——目标名称、它适合哪个阶段以及目标期望的参数。

* * *

## 微型插件的类型

maven 中基本上存在两种重要类型的插件，如下所示:

1.  **构建插件** -基本上这些插件将在构建阶段执行。这些插件是在 pom.xml 的`<build>`元素下定义的
2.  **报告插件** -这些插件在站点生成(报告或 javadocs 生成)阶段执行。这些插件将在 pom.xml 的`<reporting>`元素下配置

* * *

## 一些常见的 Maven 插件

以下是使用 maven 构建的任何 java 项目中常用插件的列表:

| 插件名称 | 描述 |
| 干净的 | 用于删除目标目录，以便清理早期的构建工件 |
| 编译程序 | 编译 java 源文件 |
| 准不会有错的 | 执行 Junit 测试并生成报告。 |
| 冲突 | 构建项目的 jar 文件 |
| 战争 | 建立项目的战争档案 |
| 文档 | 生成项目的 javadocs |
| 蚂蚁 | 运行在构建的任何阶段指定的一组 ant 任务 |

* * *

### pom.xml 中的示例插件

```
<project 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://maven.apache.org/POM/4.0.0
    http://maven.apache.org/xsd/maven-4.0.0.xsd">
  <modelVersion>4.0.0</modelVersion>
  <groupId>com.orgname.orggroup</groupId>
  <artifactId>project</artifactId>
  <version>1.0</version>
  <build>
    <plugins>
      <plugin>
        <groupId>org.apache.maven.plugins</groupId>
        <artifactId>maven-antrun-plugin</artifactId>
        <version>1.1</version>
        <executions>
          <execution>
            <id>id.clean</id>
            <phase>clean</phase>
            <goals>
              <goal>run</goal>
            </goals>
            <configuration>
              <tasks>
                <echo>Clean Phase</echo>
              </tasks>
            </configuration>
          </execution>     
        </executions>
      </plugin>
    </plugins>
  </build>
</project> 
```

*   每个插件可以有多个目标来执行不同的任务。
*   任何插件的启动阶段都可以定义。
*   任务可以被配置为与插件定义的每个目标相关联。

* * *

### Maven 插件的优势

*   更详细更好的架构。
*   有管理的生命周期
*   多语言的实现
*   公共构建逻辑的可重用性。
*   完全用 java 编写 maven 插件的能力

* * *