# 在 Maven 中创建您的第一个项目

> 原文：<https://www.studytonight.com/maven/project-creation-in-maven>

在前面的课程中，我们已经了解了 maven 项目架构以及项目涉及的不同配置。现在，我们将了解如何使用 Maven 创建一个示例 **Java 项目**。Maven 还可以用来构建和管理使用 C#、Ruby、Scala 和少数其他语言开发的项目。但是，这主要用于 java 项目，所以我们将以 Java 为例。此外，我们将看到当使用 maven 创建时，项目是如何结构化的。

* * *

## 马文原型

Maven 使用原型来创建任何项目。原型只不过是 maven 提供的创建项目的工具。它也被定义为**‘一种组织模式，所有其他同类事物都是由它构成的’**。

使用原型为开发人员创建项目提供了一种简单而实用的方法，在这种方法中，按照组织级别定义的标准采用最佳实践。此外，原型使开发人员能够快速创建一个项目，并在几个命令内开始运行相同的项目。

为了创建一个新的简单的 maven java 项目，只需在命令行中使用 maven 原型插件。目前列出了 850 多个 maven 原型，以便在不同的框架下创建项目，如 struts、spring、hibernate、web 服务(RESTful/SOAP)和许多其他框架。

让我们用 maven 创建一个简单的项目。打开命令提示符，导航到本地机器中的工作区文件夹**(例如 D:\Java\workspace)** 。您可以在电脑上的任何位置创建工作区文件夹，或者使用您的工作区(如果已经创建)。然后键入下面的 maven 命令(这是一个单行命令)并按 enter 键。

```
mvn archetype:generate -DgroupId=com.java.samples -DartifactId=JavaSamples 
-DarchetypeArtifactId=maven-archetype-quickstart -DinteractiveMode=false

```

这个 maven 命令将创建一个 Java 项目，其细节如下:

*   **groupId** 将是 com.java.samples，代表包。
*   **artifactId** 将是 JavaSamples(在构建时，将创建 JavaSamples.jar)
*   **原型 ArtifactId** 只不过是用来创建这个 Java 项目的模板。
*   **交互模式**在开发人员知道工件 id 的实际拼写时使用。在上面的例子中，maven-prototype-quick start 是被使用的一个，也是合适的一个。如果开发人员不知道这一点，那么交互模式被设置为`TRUE`，这样它将扫描远程仓库中所有可用的原型。这可能需要更长时间。

![Creating first Maven Project](img/dc0e929d6ff042fdfa0bf002e7381d09.png)

![Creating first Maven Project](img/1020c9799c630f3564c02d56e805c63d.png)

上面的命令指示 maven 用**maven-原型-快速启动**模板创建一个项目。

如果您导航到文件夹 **D:\Java\workspace** ，将创建一个名为**javassimples**的新项目，包括 Java 项目的所有基本结构，如下所示:

![Creating first Maven Project](img/7214a298779cd130c2154a392fa7467a.png)

要查看下面的目录结构，您需要在您的 Eclipse IDE 上创建一个新的 Java 项目，并在那里导入下面的项目。

下表将描述作为项目一部分创建的主要目录。

| 插件名称 | 描述 |
| javassimples | 包含源代码和 pom.xml 的项目的根文件夹 |
| src\main\java | 包含包 com.java.samples 下的所有 java 代码 |
| src \主\测试 | 包含包 com.java.samples 下的所有 java 测试代码 |
| 主资源 | 包含所有资源，如 xml \属性文件 |

在文件夹**D:\ Java \ workspace \ JavaSimples \ src \ main \ Java \ com \ Java \ samples**下，将默认创建一个名为**App.java**的示例 Java 文件，该文件将包含一个 print 语句。

```
package com.java.samples;

/**
 * Hello world!
 *
 */
public class App
{
    public static void main (String[] args)
    {
        System.out.println("Hello World!");
    }
}
```

并且在文件夹**D:\ Java \ workspace \ javassimples \ src \ test \ Java \ com \ Java \ samples**下将创建一个示例 Java 测试类(JUnit)**AppTest.java**

```
package com.java.samples;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Unit test for simple App.
 */
public class AppTest extends TestCase{
    /**
     * Create the test case
     *
     * @param testName name of the test case
     */
    public AppTest(String testName)
    {
        super(testName);
    }

    /**
     * @return the suite of tests being tested
     */
    public static Test suite()
    {
        return new TestSuite(AppTest.class);
    }

    /**
     * Rigourous Test :-)
     */
    public void testApp()
    {
        assertTrue(true);
    }
}
```

标记为**严格测试**的测试类代码是在使用 maven 创建示例 java 项目时自动生成的代码。该方法将返回真，测试将在运行后通过。这种方法只是作为一个样本测试。您可以修改此方法或添加自己的测试方法。

此外，**测试用例**类是一个抽象类，来自这里在示例项目中使用的 Junit API。默认情况下，当创建一个示例 maven java 项目时，也会自动包含这个项目(检查 pom.xml 中 junit 的依赖项)。TestCase 类定义了在一个类中运行多个测试的装置。

开发人员需要添加他们的文件，如上表所述。他们可以根据项目开发的需要自由添加任何新的包。上面说的文件夹结构是根据原型插件定义的。

* * *

### Maven 中的版本

任何 maven 项目都有两个主要版本:

*   **SNAPSHOT** :这只不过是开发版。新版本的可用性将在每次结账时进行验证，如果需要，还会下载。此版本不允许发布。
*   **固定**:只下载一次到本地仓库。每当软件发布的主要版本发生时，就会得到这个结果。

* * *