# 在 Maven 中管理外部依赖关系

> 原文：<https://www.studytonight.com/maven/managing-external-dependency-in-maven>

在上一个教程中，我们了解了如何构建和测试 maven 项目以及用于该项目的命令。在本章中，我们将学习在 maven 中管理项目的外部依赖关系。

如前所述，maven 中所有基本的依赖项列表都是由 maven 仓库处理的，项目在该仓库中下载所需的依赖项。但是，在某些情况下，某些特定的依赖关系可能在 maven 远程和中央仓库中不可用。Maven 仍然通过提供外部依赖管理的特性来解决这个问题。

外部依赖项可以是 sqljdbc.jar 或 log4j。在 maven 中，任何外部依赖项都可以像 pom.xml 文件中的其他依赖项一样轻松配置。因此，让我们看一个简单的例子，将 sqljdbc.jar 作为外部依赖项添加到 maven 项目中。

*   在 maven 项目中创建一个名为 **lib** 的文件夹。
*   下载 **sqljdbc.jar** 放入 **lib** 文件夹。
*   现在，打开项目的 **pom.xml** ，添加一个新的依赖项，如下图所示:

*   指定*组号*作为 jar 文件的名称
*   指定 *artifactId* 作为 jar 文件的名称
*   指定系统的*范围*
*   指定 jar 文件到项目位置的*相对路径*。

```
<dependency>
	<groupId>sqljdbc</groupId>
	<artifactId>sqljdbc</artifactId>
	<scope>system</scope>
	<version>1.0</version>
	<systemPath>${basedir}\src\lib\sqljdbc.jar</systemPath>
</dependency>
```

* * *

## 依赖范围

maven 中的依赖范围分为 5 种不同的类型。这些范围中的每一个都控制类路径中可用的依赖项和应用中包含的依赖项。

| 依赖范围 | 描述 |
| 编制 | 这是 maven 中任何外部依赖的默认范围。这些依赖项在类路径中是可用的，并且打包得很好。 |
| 提供的 | 这些依赖项预计将由 JDK 或一个容器提供。最好的例子是 servlet api。这些依赖项在类路径上可用，但在运行时不可用。此外，它们没有包装。 |
| 运行时间 | 这些依赖项不是编译所必需的，而是执行和测试系统所必需的。例如 JDBC 空气污染指数 |
| 试验 | 这些依赖关系只在测试编译和执行阶段需要。 |
| 系统 | 这个范围类似于“提供”。唯一的问题是开发人员需要在本地文件系统上显式地提供 jar 文件的路径。 |

* * *