# Maven 构建自动化

> 原文：<https://www.studytonight.com/maven/maven-build-automation>

**构建自动化**是这样一个过程，在这个过程中，每当在工作空间中进行更改时，项目都会随着构建过程一起启动，并且还会确保项目及其相关项目是稳定的(如果项目被任何其他项目使用的话)。

这在软件开发生命周期中非常重要，因为在开发阶段很难管理失败的构建。因此，需要一个过程来始终确保构建的健康状态并保持关注。

考虑这个场景中的项目**javassimples**。在这里，将编写和测试许多不同 oops 概念的程序。但是，由于编译问题，独立测试每个类总是很困难的，因为它们是在不同的包集合下模块化的。

为了实现这一点，maven 提供了一个功能来实现自动化。考虑一下，开发人员希望在每次签入项目后检查构建稳定性。此外，考虑这个 JavaSamples 项目是另一个名为 **CoreJavaTutorials** 的项目的依赖项目。因此，维护一个稳定的 JavaSamples 构建是强制性的。

下面提到的是两个相关项目的 pom.xml 文件。

**CoreJavautorials 项目**

```
<project  
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
   http://maven.apache.org/xsd/maven-4.0.0.xsd">
   <modelVersion>4.0.0</modelVersion>
   <groupId>CoreJavaTutorials</groupId>
   <artifactId>CoreJavaTutorials </artifactId>
   <version>1.0</version>
   <packaging>jar</packaging>
   <dependencies>
      <dependency>
      <groupId>JavaSamples</groupId>
         <artifactId>JavaSamples</artifactId>
         <version>1.0-SNAPSHOT</version>
      </dependency>
   </dependencies>
</project> 
```

**javascomples 项目:**

```
<project  
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
   http://maven.apache.org/xsd/maven-4.0.0.xsd">
   <modelVersion>4.0.0</modelVersion>
   <groupId>**JavaSamples**</groupId>
   <artifactId>JavaSamples</artifactId>
   <version>1.0</version>
   <packaging>jar</packaging>
</project> 
```

现在考虑一下对 JavaSamples 项目所做的一些更改。开发人员需要通过在相同的上添加一个**后期构建目标**来更新 JavaSamples 项目的 pom.xml。

**后期构建目标**只不过是一个目标，一旦构建成功，它就定义了一组特定的任务。例如，生成 javadocs 是一个后期构建目标。我们将在接下来的教程中研究如何生成 Javadocs。

```
<project  
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
   http://maven.apache.org/xsd/maven-4.0.0.xsd">
   <modelVersion>4.0.0</modelVersion>
   <groupId>JavaSamples</groupId>
   <artifactId>JavaSamples</artifactId>
   <version>1.0-SNAPSHOT</version>
   <packaging>jar</packaging>
   <build>
      <plugins>
         <plugin>
            <artifactId>maven-invoker-plugin</artifactId>
            <version>1.6</version>
            <executions>
               <execution>
                  <id>build</id>
                  <goals>
                     <goal>run</goal>
                  </goals>
               </execution>
            </executions>
         </plugin>
      </plugins>
   </build>
</project> 
```

* * *

## 使用 Jenkins 服务器构建自动化

[**Jenkins Server**](/jenkins/)(*点击查看完整 Jenkins 教程* i >)是一款持续集成工具。使用 Jenkins 构建可以自动化，测试构建的健康状态，还可以管理多个构建。这是一个方便的工具，很容易下载，也很容易设置。

### 设置 Jenkins 服务器

*   从以下链接下载最新的 Jenkins . war:[http://jenkins-ci.org/T3】](http://jenkins-ci.org/)

    ![Installing Jenkins Server](img/da0019f40ca5980c2a7247f1c075287c.png)

*   在我们机器的本地网络服务器上部署 Jenkins. war 文件。例如雄猫
*   启动服务器，打开浏览器，点击网址**http://localhost:8080/Jenkins**

    ![Setting up Jenkins Server and Automating Maven Build](img/30921872bbff60c6756bf32de9b4bf09.png)

* * *

### 创建新作业并部署构建

点击**新建作业**链接，如上图所示，为构建自动化配置项目。如下图输入项目详情，点击**确定**。您必须为 Maven 项目输入名称并选择单选按钮。

![Setting up Jenkins Server and Automating Maven Build](img/6ead03f829c5b93fb4f518653f98e06c.png)

在下一页中，填写所有必需的详细信息，如- Description、项目的 pom.xml 路径和其他详细信息，然后单击 save。请查看下面的图片寻求帮助。填写所有信息，点击**保存**

![Setting up Jenkins Server and Automating Maven Build](img/d0366e30c2862e48470f9b8d15cdda7c.png)

![Setting up Jenkins Server and Automating Maven Build](img/3ead54ca31d15c19fb1bac471f6743e8.png)

![Setting up Jenkins Server and Automating Maven Build](img/22bf6c4d069d654f157fdc2ee1f5fdba.png)

现在在 Jenkins 创建了一个项目/工作。如下图所示:

![Setting up Jenkins Server and Automating Maven Build](img/9d84611f462aa638fe7f798351092042.png)

如上图所示，点击**立即构建**选项。这将读取 **pom.xml** 并拉出最新的代码，执行构建过程并相应地生成 **jar/war** 文件。

![Setting up Jenkins Server and Automating Maven Build](img/1f158c311c357e6c861f1bc658e10ea9.png)

单击内部版本号链接，它会打开内部版本详细信息。点击**控制台输出**查看构建日志。

![Build Automation in Maven using Jenkins Server](img/fc86986dde9780473c51ab866faf2fb1.png)

检查日志，查看您的项目构建是否成功。

![Build Automation in Maven using Jenkins Server](img/33f6133eb7a30ac299e2f31ff7095be8.png)

![Build Automation in Maven using Jenkins Server](img/b58015eda8fc4bd0c11dc5fa8df9c21d.png)

* * *