# 游戏引擎与游戏发展历史

> 原文：<https://www.studytonight.com/3d-game-engineering-with-unity/game-engine>

对于每一款游戏，游戏引擎都扮演着重要的角色，因为游戏引擎通过在场景、人物和图形生成、声音、人工智能、脚本动画、网络等方面提供帮助，帮助游戏设计者将游戏中的人物栩栩如生。游戏引擎就像一个集成的开发环境，有一套现成的可视化开发工具和可重用的软件组件。它通过提供抽象层，将复杂的游戏开发任务变得简单，这使得许多大任务看起来非常容易，而游戏引擎则在后台完成所有的硬件工作。换句话说，它是一个专门为电子游戏的构建和开发而设计的框架。开发人员使用这些游戏引擎为游戏机、移动设备和个人电脑创建游戏。

因此，那些对深入游戏开发、探索新技术和以游戏形式展示你的想象力感兴趣的开发人员或游戏爱好者，或者如果有人只是好奇想知道游戏引擎技术背后发生了什么，这里有一个构成游戏引擎的组件的详细解释。

* * *

## 游戏引擎的组件

游戏引擎是为了开发游戏而创建的，就像任何特定语言编程的其他 IDE 一样。游戏引擎中的所有组件都被构建和集成，以支持游戏开发的动机。

1.  **Input:**

    如果一个游戏不能玩，它就什么都不是，游戏引擎支持一系列输入设备，如鼠标、游戏手柄、触摸等，同时也支持游戏手柄、操纵杆等设备。处理输入有许多不同的方式，最常用的两种是通过:`events`和`polling`。输入`events`被计算机捕获(如鼠标右键点击，或按向上箭头键等)，你的自定义代码根据收到的输入被触发。`Polling`用于获取位置值，例如鼠标指针在哪个坐标(x，y)上，或者你玩游戏时使用的游戏杆或智能手机的倾斜角度。

2.  **Graphics:**

    游戏中的图形决定了它的命运。3D 图形是使用 3D 资产设计的，这些资产在外部 3D 渲染程序(如 Maya、Blender 等)中开发和设计，然后导入游戏引擎。因此，一个好的游戏引擎必须支持多种导入格式。

    游戏引擎提供了许多功能，如灯光效果，阴影，凹凸贴图，混合动画等，使导入的资产看起来真实。

3.  **Physics:**

    游戏引擎有一个子组件，叫做**物理引擎**。物理引擎是一种软件，它允许对大多数现实物理系统进行相当精确的模拟，如刚体的运动(我们将在后面的章节中使用统一 3D 进行实际模拟)、软体质量和速度的改变以及流体动力学、弹性等。这些是集成在最新游戏引擎中的复杂引擎，主要用于视频游戏(通常作为中间件)，其中必须描绘实时和真实生活的模拟。重力、碰撞检测、旋转&旋转、物体速度和其他此类应用由游戏内的物理引擎处理。

4.  **Artificial Intelligence:**

    如今，人工智能在游戏开发中扮演着重要的角色。根据情况或玩家的行为知道玩家将使用哪种武器会被记录下来并相应地执行动作，这可以使用嵌入游戏中的专门软件来完成。在游戏中实现人工智能通常是使用现成的脚本来完成的，这些脚本是由专门从事人工智能的软件工程师设计和编写的。例如:我们的角色如何对撞墙、看到动物等做出反应可以通过构建一系列行为节点来轻松完成，而不是编写复杂的代码。

5.  **Sound:**

    音频和渲染引擎是游戏引擎的一个子部分，用于控制声音效果和在 2D 屏幕上生成三维动画图形。它们使用多渲染应用编程接口(如用于视频渲染的 Direct3D 或 OpenGL)和应用编程接口(如用于音频的 Open-AL、SDL 音频、X-Audio 2、网络音频)来提供图形处理器的软件抽象。

6.  **Networking:**

    从十年前开始，游戏就支持在线多人游戏和社交游戏，这将你的游戏冒险与你的朋友联系起来。大多数游戏引擎都为这些需求提供了完整的支持和脚本，因此您不必担心 TCP/UDP 流量、社交 API 集成等。

* * *

## 游戏发展历史

如何制作游戏？这是游戏行业最难以捉摸的问题。事实上，整个软件行业对于软件工程过程作为一个整体是多么的不成熟是相对开放和前沿的。看看*史蒂夫·麦康奈尔*的**《淘金热之后》**，了解软件行业急需的成熟度的精彩讨论。软件工程界的许多开发工作都在致力于改进我们制作软件的过程。

在 60 年代和 70 年代，从 Fortran 和 COBOL 到 C，编程语言的实力有了很大的提高。在 80 年代，微型计算机在编程领域带来了巨大的进步。每个开发人员都可以有自己的工作站，在那里编辑、运行和调试代码。

在 80 年代末和 90 年代初，软件开发社区的前沿被面向对象编程的功效和 C++的大项目优势所吸引。集成的编辑器、调试器和分析器继续改进。

优化编译器几乎使汇编编程过时，可视化界面布局工具使编程对业务应用来说相当愉快。随着软件开发过程中所有这些奇妙的改进，软件项目预算只会变得更大，只会随着时间的推移和数量的增加而减少。

* * *

* * *