# Unity 的父子游戏对象

> 原文：<https://www.studytonight.com/game-development-in-2D/parenting-game-objects>

![Parenting Game Objects](img/295359b1ed5c73b871e8b83037570c7f.png)

是时候放下你的婴儿玩具和奶瓶了，我们不再照顾小小的 gameObject 宝宝了。相反，我们将学习如何在层次结构中创建主游戏对象的**子**游戏对象，这种技术在与我们刚刚学习的`Instantiate()`方法一起使用时非常有用。

如果您已经直接开始学习本教程，我们建议您查看我们的上一个教程，了解正在进行的示例。

如果你密切关注我们在上一个教程中创建的角色，你会注意到**火球**只是从我们的主游戏角色中间产生的，而不是从你预期的地方(就像在这个例子中，伸出的手)。

![Parenting Game Objects](img/1f09c480d8ce6431ecf8e561aea15f71.png)

现在，如果不是角色，而是一个**看不见的游戏物体**射出火球呢？毕竟，用户(游戏玩家)不会真正看到到底是谁发射了火球。那就这么办吧。首先，**创建一个新的空游戏对象**。

你看，游戏物体一般都有它们相对于**游戏世界**的位置。

但是对于某些对象，比如枪或汽车喇叭，你可能需要它相对于另一个游戏对象。我们可以让游戏对象说*这个游戏对象离另一个游戏对象有 2 个单位，不管它在哪里，而不是说*这个游戏对象离游戏的死点有 2 个单位。**

让我们在游戏中尝试一下，看看它到底是如何工作的。**要使游戏对象成为子对象**，只需**将目标子对象拖放到目标父游戏对象上**。在我们的例子中，我们将把我们的空游戏对象拖到我们的角色对象上。

![Parenting Game Objects](img/da669284e600f8de0d835a53a6c7b582.png)

您会注意到，新的游戏对象现在出现在我们的主要角色下的下拉列表中，并在层次结构中为其名称添加了一个小缩进。这意味着游戏对象现在是我们角色的孩子。如果你现在试图移动角色，你会注意到空的游戏对象也跟着移动，但是保持在相同的相对距离。

但是空的游戏物体漂浮在我们角色的头附近，而不是他的手附近！要解决这个问题，只需使用**变换**视图中的`position`值调整空游戏对象的位置，直到空游戏对象到达您需要的位置。

![Parenting Game Objects](img/4cf56972f92e95967e32db8b229f9153.png)

同样，子游戏对象相对于其父对象将有其位置，而不是游戏世界。也就是说，如果你将位置设置为`(0, 0, 0)`，子游戏对象将被定位在父游戏对象的死点，而不是屏幕。

在我们的例子中，如果你还记得上一个的话，我们在**射击萨维**游戏对象附带的脚本中添加了每次按空格键时实例化一个新火球的代码。同样的脚本还保存了使**射击萨维**游戏物体移动的代码。

因此，我们将不得不从`Shooter`类的`update()`方法中移除火球预设创建代码。

让我们创建一个新的类`ShootingBehaviour`并将代码添加到这个类的`update()`方法中，并将这个脚本附加到**射击 Savi** 游戏对象的新的隐形子游戏对象中。

```cs
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ShootingBehaviour : MonoBehaviour
{
    public GameObject fireball;

    void update() 
    {

        // When spacebar is hit
        if(Input.GetKeyDown(KeyCode.Space))
        {
            // instantiate the fireball object
            Instantiate(fireball,
                new Vector3(gameObject.transform.position.x, gameObject.transform.position.y, 0),
                new Quaternion(0, 0, 0, 0));
        }
    }

}
```

正在进行**射击萨维**动作的`Shooter`类看起来像，

```cs
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Shooter : MonoBehaviour
{
    public RigidBody2D body;
    public float speed;

    void update() 
    {
        body.velocity = new Vector2(Input.GetAxisRaw("Horizontal")*speed, Input.GetAxisRaw("Vertical")*speed);
    }

}
```

现在，我们已经将拍摄脚本附加到空的游戏对象上，并使其成为我们角色的游戏对象的子对象，让我们现在测试我们的游戏。

![Parenting Game Objects](img/ebfc588f4e200e3944272ef454f27136.png)

有效！那么这一课我们学到了什么呢？我们已经了解了 **gameObject 育儿**是如何工作的，以及我们可以如何利用它来为自己谋利，我们不需要换一个脏尿布(我们不需要做太多工作)。

* * *

* * *