# Unity 中的场景处理

> 原文：<https://www.studytonight.com/game-development-in-2D/scene-handling>

要理解这一点，我们首先要意识到什么是场景。场景是指包含特定游戏场景的物体。

假设你有一个游戏，它的世界由两部分组成:一个城市和一个森林。这里我们可以说这个世界可以定义为两个场景(虽然对于大型游戏来说可能不是这样)，一个是城市场景，一个是森林场景。

引用 Unity 手册:

> *场景包含你游戏的对象。它们可以用来创建主菜单、单个级别和其他任何东西。将每个唯一的场景文件视为一个唯一的级别。在每个场景中，你将放置你的环境、障碍和装饰，本质上是设计和构建你的游戏。*

在最新的几个更新中，Unity 已经开始使用一个新的库来访问场景并在它们之间遍历。这个库叫做场景管理。

要使用这个库，我们必须首先包含它。我们通过写作做到这一点

```cs
using UnityEngine.SceneManagement
```

在剧本的开头。

在这个库中，您将遇到和使用最多的类是场景管理器。

* * *

## 在构建中包含场景

为了能够通过**场景管理器**类访问场景，我们首先需要将场景添加到构建设置中

为此，通过 **CTRL+S** 保存场景。它将保存在**素材**文件夹中。

现在进入菜单栏中的文件，选择**构建设置**。

在打开的窗口中，将场景图标从“项目”选项卡拖放到“构建中的场景”下的空间中。

我们可以以类似的方式添加多个场景，并对它们进行重新排序。场景的顺序决定了它们的场景号和游戏开始时首先载入的场景。

### 场景经理

场景管理器类包含以下内容:

#### 描述:

运行时的场景管理。

#### 静态属性:

| [场景账户](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager-sceneCount.html) | 当前加载的场景总数 |
| [场景取消建筑设置](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager-sceneCountInBuildSettings.html) | 构建设置中的场景数。 |

#### 静态方法:

| [创建场景](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.CreateScene.html) | 在运行时用给定的名称创建一个空的新场景。 |
| get active scene | 获取当前活动的场景。 |
| [山羊场景](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.GetSceneAt.html) | 在场景管理员的已加载场景列表中获取索引处的场景。 |
| [山羊场景图像索引](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.GetSceneByBuildIndex.html) | 从构建索引中获取场景结构。 |
| [获取场景名称](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.GetSceneByName.html) | 在加载的场景中搜索具有给定名称的场景。 |
| getscenebypath | 在加载的所有场景中搜索具有给定素材路径的场景。 |
| 加载场景 | 在构建设置中按场景的名称或索引加载场景 |
| [loadsceneeasync](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.LoadSceneAsync.html) | 在后台异步加载场景。 |
| [合并场景](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.MergeScenes.html) | 这将把源场景合并到目标场景中。 |
| [移动游戏对象价格](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.MoveGameObjectToScene.html) | 将游戏对象从当前场景移动到新场景。 |
| setactive scene | 将场景设置为活动状态。 |
| [卸载场景](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.UnloadSceneAsync.html) | 销毁与给定场景相关联的所有游戏对象，并将场景从场景管理器中移除。 |

#### 事件:

| [激活已更改的](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager-activeSceneChanged.html) | 订阅此事件，以便在活动场景发生变化时获得通知。 |
| [场景加载](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager-sceneLoaded.html) | 向其中添加一个委托，以便在场景加载后获得通知。 |
| [场景加载](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager-sceneUnloaded.html) | 向其中添加一个代理，以便在场景卸载时获得通知。 |

<small>礼遇:[团结场景经理](https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.html)</small>

* * *

* * *