# Unity3D：实时更新画布上的用户界面元素

> 原文：<https://www.studytonight.com/game-development-in-2D/update-ui-element-in-realtime-unity>

在上一个教程中，我们学习了如何将文本标签用户界面元素添加到我们的游戏画布中。

我们只要进口一瓶雪碧就能轻松做到，对吗？我们为什么要费心制作画布？其中一个主要原因是，我们希望能够使用脚本修改文本、计数器和图像。事实上，让我们试试看！

从**文本**游戏对象中清除文本字段，这样它就什么也不会说了。

![Text UI element with empty text field](img/d4719ebf98e0d9dd338ac3763ed6f620.png)

创建一个名为`ScoreBehavior`的新脚本，并将其打开。

```cs
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class ScoreBehaviour : MonoBehaviour
{
    private Text thisText;
    private int score;

    void Start()
    {
        thisText = GetComponent<Text>();

        // set score value to be zero
        score = 0;
    }

    void Update() 
    {
        // When P is hit
        if(Input.GetKeyDown(KeyCode.P))
        {
            // add 500 points to score
            score += 500;
        }
        // update text of Text element
        thisText.text = "Score is " + score;
    }

}
```

**注:**4 号线是这里相当重要的一条代码线。如果您忘记使用`using`指令在代码中包含您正在使用的任何资源/类/包，您的 IDE 将会给您一个**缺失引用**错误。

我们还在这里做什么？首先，我们正在初始化一个名为`thisText`的`Text`类变量。**文本**类只有在顶部添加`using UnityEngine.UI`时才可用，因为该类是`UnityEngine.UI`包的一部分。

在`Start()`功能中，你会看到可识别的语句，没有什么异常。第一个语句将`thisText`变量分配给附加到游戏对象的文本组件，另一个语句只是将`score`初始设置为`0`。

在`Update()`方法中，我们定义一个输入控件，在每次按下`P`键时将`500`点添加到分数中。

现在，`Text`类有一个`text`属性，它被存储为一个字符串，这个值就是那个实例将在游戏中实际显示的内容。事实上，每次在**检查器视图**的文本字段中键入内容时，您都将`Text.text`属性设置为一个值。我们正在做的是在每一帧中更新我们的`thisText`对象的文本值。

保存这个脚本，然后返回 Unity。标签好像消失了，但是当你运行游戏的时候。

![Adding UI Elements](img/d17fbd1a9fc8ddf41657be3e49c280d4.png)

按几下`P`，就应该看到分数更新了！

![Adding UI Elements](img/9678103c006fcc086704cc3108ea059d.png)

* * *

### 从其他脚本更新文本用户界面元素

您可以通过在您的脚本中添加一个**公共静态方法**，并从其他**行为**脚本中调用它们来扩展这个概念。

#### 什么是静态关键字？

关键字`static`使一个方法或变量保持一个状态直到结束。使用定义`static`方法的类名可以在其他类中调用。

此外，在`static`方法中只能使用`static`变量。

这通常是一个通用的概念，在 Java、C# 等编程语言中也是如此。

我们班`ScoreBehaviour`会是这样的:

```cs
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class ScoreBehaviour : MonoBehaviour
{
    private Text thisText;
    private static int score;

    void Start()
    {
        thisText = GetComponent<Text>();

        // set score value to be zero
        score = 0;
    }

    void Update() 
    {
        // update text of Text element
        thisText.text = "Score is " + score;
    }

    // adding a new method to our class
    public static void AddScore()
    {
        // add 500 points to score
        score += 500;
    }

}
```

如果你还记得，在我们捕捉到[火球与目标](detecting-collisions)碰撞的教程中，我们定义了一个类`TargetBehaviour`，它定义了一个`OnCollisionEnter2D`方法。让我们更新该方法，以便在子弹击中目标时更新分数。

```cs
public class TargetBehaviour : MonoBehaviour
{

    void onCollisionEnter2D(Collision2D col) 
    {
        // When target is hit
        if(col.gameObject.tag == "Bullet")
        {
            Debug.Log("Target was Hit!");

            // calling AddScore method
            ScoreBehaviour.AddScore();

            Destroy(col.gameObject);
            Destroy(gameObject);
        }
    }

}
```

这个代码现在会在你每次命中目标时将分数改变`500`。创建几个目标游戏对象的副本，并尝试它。

![Updating the Text UI Element from other scripts](img/b2e3d2fd60439907482102fb459c383b.png)

![Updating the Text UI Element from other scripts](img/3a1c40db1c81b95bd78a43164a46ceb3.png)

太好了。当然，UI 系统不仅仅是制作静态或动态文本。使用这种方法可以添加图像、滑块、按钮和很多熟悉的 UI 元素。我们敦促您尝试探索这些元素，并弄清楚它们在编辑器和脚本中是如何工作的。

* * *

* * *