# 安卓系统中的意图

> 原文：<https://www.studytonight.com/android/intents-in-android>

你有没有想过当我们点击某个按钮时，一个新的[活动](activity-in-android)是如何打开的，假设设置按钮在任何应用中显示设置屏幕？当我们点击它的通知时，应用是如何打开的？我们如何在手机中获得低电量警报？所有这些都是可能的，因为安卓的意图。

意图是一个消息对象，您可以使用它向应用组件请求操作。意图基本上是做一件事的意图。这是安卓组件之间的一种通信方式，通过不同的组件请求组件的动作。

这就像是安卓监听的一条消息，然后通过识别和调用应用的适当组件(比如活动、服务、内容提供商等)做出相应的反应。).它可以在同一个应用中，也可以在其他应用中。

如果多个应用能够响应该消息，那么安卓系统会向用户提供一份这些应用的列表，用户可以从中进行选择。

* * *

### 安卓系统中意图的使用

意图有三种基本用途:

#### 1.开始一项活动

一个[活动](activity-in-android)代表一个应用中的一个屏幕。您可以通过向`startActivity()`传递意图来启动活动的新实例。意图描述要开始的活动，并携带任何必要的数据。

#### 2.启动服务

服务是在后台执行操作的组件，没有用户界面。您可以通过向`startService()`传递一个意向来启动一个服务以执行一次操作(如下载文件)。意图描述了启动哪个服务并携带任何必要的数据。

#### 3.进行广播

广播是任何应用都能接收到的消息。系统为系统事件提供各种广播，例如当系统启动或设备开始充电时。您可以通过向`sendBroadcast()`或`sendOrderedBroadcast()`传递一个意图来将广播传递给其他应用。

* * *

### 意向类型

在安卓系统中，有两种意图:

1.  明确的意图
2.  隐含意图

* * *

### 明确的意图

当你明确定义哪个安卓组件应该在某个用户动作上打开时，你就使用了明确的意图。你通常使用明确的意图在你自己的应用中启动一个新组件，因为你知道你想要启动哪个确切的活动或服务。例如，您可以启动一个新的活动来响应用户操作，或者启动一个服务来在后台下载文件。

#### 创建明确的意图

为了创造一个明确的意图，

1.  You need to make an `Intent` object. The constructor of the Explicit Intent's object needs two parameters as follows:

    **上下文 c** :这表示活动的对象，您从这里调用意图。

    **Java 文件名**:这代表你要打开的 Activity 的 Java 文件名。

    > **注意** : *需要提到扩展名为`.class`的 java 文件名*

    ```kt
    Intent i  = new Intent(this, MyJavaFile.class);
    ```

2.  调用`startActivity()`方法，将意图的对象作为参数传递。这个方法导航到意图对象中提到的 java 文件。

    ```kt
    startActivity(i);
    ```

3.  If you need to pass some information or data to the new Activity you are calling, you can do this by calling `putExtra()` method before the `startActivity()` method. This method accepts key-value pair as its parameter.

    ```kt
    i.putExtra("key1", "I am value1");
    i.putExtra("key2", "I am value2");
    startActivity(i);
    ```

    > **注意** : *要接收新活动中的数据并相应地使用它，您需要调用`getIntent()`方法，然后调用您想要通过显式意图打开的活动的 java 类中的`getStringExtra()`方法。`getStringExtra()`方法以键为参数。*

    ```kt
    String a = getIntent().getStringExtra("key1");
    ```

    这样做，将存储在**键 1** 的值存储到字符串变量`a`中。

* * *

### 隐含意图

当你只需要说出你想执行什么动作而不用担心哪个组件会执行它时，那么你可以使用隐式意图。

隐式意图并不指定执行特定操作的特定组件，而是声明要执行的一般操作，这允许任何组件，甚至来自另一个应用的组件来处理它。

例如，如果您想在地图上显示用户的特定位置，您可以使用隐式意图通过该意图传递坐标，然后任何其他能够在地图上显示坐标的应用都将接受该意图。

#### 创建隐含意图

为了产生隐含的意图，

1.  你需要制作一个`Intent`物体。隐式意图对象的构造器需要一个你想要执行的**类型的动作**。

    **动作**是指定要执行的一般动作的字符串。动作很大程度上决定了意图的其余部分是如何构造的，尤其是作为数据和附加信息包含在意图对象中的信息。例如，

    **ACTION_VIEW** :当你有一些活动可以展示给用户的信息，比如在**图库**应用中查看的照片，或者在**地图**应用中查看的地址时，使用这个动作。

    **ACTION_SEND** :当你有一些用户可以通过另一个应用分享的数据时，比如**邮箱**应用或者一些**社交网络**应用，就会用到这个动作。

    > **注意** : *你可以指定你自己的动作，让你自己的应用内的意图使用(或者让其他应用使用来调用你的应用内的组件)，但是你通常指定由意图类或者其他框架类定义的动作常量。*

    ```kt
    Intent i = new Intent(Intent.ACTION_VIEW);
    ```

2.  您需要为要执行的操作提供一些数据。数据通常表示为 URI(统一资源标识符)，它向其他应用提供数据，以便能够处理 URI 数据的任何其他应用可以执行所需的操作。例如，如果你想通过你的应用打开一个网站，你可以使用 **setData()** 方法传递 Uri 数据，如下所示:

    ```kt
    i.setData(Uri.parse("http://www.google.co.in"));
    ```

3.  最后以意向对象为参数调用`startActivity()`方法。

    ```kt
    startActivity(i);
    ```

* * *

* * *