# 科学测验安卓应用——大结局

> 原文：<https://www.studytonight.com/android/second-android-application-3>

现在我们的布局已经完全设置好了，是时候定义**真**和**假**按钮的动作了。由于这是一个简单的应用，因此只有一个问题，当用户点击“真”时，我们会显示一条消息，说`Correct!`因为石墨是用来做铅笔的，这是真的。如果用户按下“假”按钮，我们将显示消息`Incorrect!`

我们的`ScienceActivity`类默认情况下是这样的:

```kt
package quiz.studytonight.com.sciencequiz;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;

public class ScienceActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_science);
    }
}
```

* * *

## 将按钮部件连接到科学活动类

我们将在我们的`ScienceActivity`类中定义两个类型为`Button`的私有变量，然后将它们与布局 xml 文件中定义的小部件挂钩。首先让我们定义两个私有变量:

```kt
public class ScienceActivity extends AppCompatActivity {

    private Button mTrueButton;
    private Button mFalseButton;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_science);
    }
}
```

当你将这两个新变量引入你的类时，AndroidStudio 会给出错误，说*不能解析符号【按钮】*，因为类`Button`必须导入我们的类才能使用。点击文本`Button`并按**选项+返回**如果你使用的是 Macbook，按 **Alt +回车**如果你是 Windows 用户，命令 Android Studio 自动为你导入类。记住这个快捷方式以备将来使用。

* * *

## 获取小部件引用并设置侦听器

变量创建只是一个开始，我们现在必须将 Button 小部件引用分配给这些变量，然后设置监听器，来监听这个事件上的 click 事件。

为了引用布局 xml 中定义的任何小部件，我们使用`findViewById`方法，其语法为:

```kt
public View *findViewById*(int id)
```

该方法以小部件的资源 id(定义为属性`android:id`)为参数，返回一个`View`对象。

在`ScienceActivity.java`类中，使用`Button`小部件的资源 id 来获取视图对象，并将它们分配给您的成员变量。您必须将返回的`View`对象转换为`Button`对象。每当您引用活动类中布局 xml 中定义的任何小部件时，总是需要将返回的视图对象转换为相应的小部件。

```kt
public class ScienceActivity extends AppCompatActivity {

    private Button mTrueButton;
    private Button mFalseButton;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_science);

        mTrueButton = (Button) findViewById(R.id.true_button);
        mFalseButton = (Button) findViewById(R.id.false_button);
    }
}
```

安卓应用是*事件驱动的*，因此一旦一个活动加载了一个布局，它将保持这种状态，直到被任何事件指示改变。这些事件可以是任何事情，人类接触，操作系统启动，定时器事件等。名为**侦听器**的对象被附加到一个小部件上，使该小部件可以侦听任何事件，侦听器为该事件实现一个侦听器接口。安卓为各种事件提供监听器接口。在我们的例子中，因为我们必须监听“点击”事件，所以我们将让我们的监听器实现`View.OnClickListener`接口。

```kt
mTrueButton.setOnClickListener(new View.OnClickListener() {
	@Override
	public void onClick(View v) {
		// Does nothing yet, but soon!
	}
});
```

添加 aboe 代码，就在您使用`findViewById`方法将小部件引用分配给我们的`mTrueButton`成员变量的那一行的下面。然后同样地把一个听众也连接到`mFalseButton`上。上面的侦听器实现为 Java 匿名内部类。

* * *

### 点击时显示消息

现在我们已经将监听器连接到我们的[按钮](android-button-view)，我们将知道用户何时点击“真”或“假”按钮。我们将在侦听器接口实现的相应`onClick()`方法中编写显示消息的代码。

安卓提供了一种非常简单的显示消息的方式，不需要任何输入或动作，它被称为`Toast`。因此，我们将基于按钮按压创建显示`Correct!`或`Incorrect!`的`Toast`。以下是用于创建`Toast`的方法:

<

```kt
public static Toast makeText(Context context, int resId, int duration)
```

在此，`Context`将会以我们的[活动](activity-in-android)为例(`Activity`是`Context`的子片段)。第二个参数是字符串消息的资源标识，将显示在`Toast`中。因此，我们将不得不在我们的`strings.xml`文件中增加两个条目，一个用于`Correct!`，第二个用于`Incorrect!`。将下面几行添加到`strings.xml`文件中。

```kt
<string name="correct_toast">*Correct!*</string>
<string name="incorrect_toast">*Incorrect!*</string>
```

现在添加代码，在`mTrueButton`和`mFalseButton`的`onClick()`方法中创建`Toast`。我们将向您展示如何为一个按钮做，为另一个按钮自己做。

```kt
mTrueButton.setOnClickListener(new View.OnClickListener() {
	@Override
	public void onClick(View v) {
		Toast.makeText(ScienceActivity.this,
                           R.string.correct_toast,Toast.LENGTH_SHORT).show();
	}
});
```

方法`show()`用于显示创建的`Toast`。要导入`Toast`类，只需按下**选项+返回**为 Mac 和 **Alt +输入**为 Windows 自动导入所需的类。

**注意:**如果我们只是用`this`来引用`makeText`方法中的`ScienceActivity`，那就行不通了，因为这里的`this`会引用`View.OnClickListener`对象，因为这一切都是在匿名内部类内部完成的。

* * *

### 是时候运行我们的应用了

您可以使用模拟器来运行应用，但我们建议您使用真实的设备来运行应用。只需将安卓智能手机连接到电脑上，AndroidStudio 就会自动检测到它，然后点击**运行**按钮(绿色播放按钮)。

啊！你的第二个安卓应用正在运行，尽情享受吧！

* * *

* * *