# Kotlin 变量和常量

> 原文：<https://www.studytonight.com/kotlin/kotlin-variables-and-constants>

在本教程中，我们将讨论 Kotlin 中的变量。变量基本上是用来保存一些数据的内存位置。每个变量都被赋予一个唯一的名称，即它的标识符。

在 Kotlin 中，我们可以使用两个关键字声明一个变量:

1.  英国压力单位

2.  定义变量

## Kotlin `val` 关键字

`val`关键字用于声明一个“只读”变量，即一个**不可变的**变量。简单来说，无法将值重新分配给标有`val` 关键字的变量。

例如:

```kt
val name = "Hello"
name = "World!!"    //Error: Val cannot be reassigned
```

当在一个变量的生命周期内，它只需要像创建一个类的对象一样被赋值一次时，建议使用`val`。它还确保开发人员不会意外地将值重新分配给不应更改的变量。

## Kotlin `var` 关键字

`var`关键字用于声明**可变的**变量，即其值可以改变并重新分配给它的变量。

```kt
var name = "Hello"
println(name)     
name = "World!!"
println(name)
```

你好
世界！！

## Kotlin 常量

Kotlin 常量用于定义具有常量值的变量。`const`关键字用于定义常量变量。`const` 关键字只能与`val`关键字一起使用，不能与`var`关键字一起使用。

```kt
const val empName = "employee_1"
println(empName) 
```

员工 _1

如果我们试图用`var`关键字声明一个常量，我们会得到错误:“*修饰符‘const’不适用于‘vars’*”

## `const`和`val`的区别

`val`和`const`这两个关键字似乎在做同样的工作，即声明常量变量。但是它们之间有细微的差别。`const`关键字用于声明**编译时常量**，而`val`关键字可以声明**运行时常量**。让我们用一个例子来理解它:

假设我们声明了一个变量`empName`，我们想给它赋值，这个值将由函数`sayHello()`返回。如果我们使用`val`关键字，我们将不会得到任何错误:

```kt
val empName = sayHello()        // No error

fun sayHello():String{
    return "Hello"
} 
```

但是，如果我们用`const`关键字声明这个变量，我们会得到一个错误，因为这个值将在运行时分配给`empName`:

```kt
const val empName = sayHello()        // we will get error

fun sayHello():String{
    return "Hello"
} 
```

因此，`const`关键字用于声明变量，这些变量的值只有在编译时才知道。

## 摘要

在本教程中，我们讨论了 Kotlin 中的变量类型。我们也看到了`const`关键字的使用以及`val`和`const`关键字的区别。在下一个教程中，我们将讨论 Kotlin 中的数据类型。

* * *

* * *