# Kotlin 数据类型

> 原文：<https://www.studytonight.com/kotlin/kotlin-data-types>

Kotlin 是一种**静态类型的**语言。在静态类型语言中，变量的**数据类型在编译时**是已知的。这意味着，如果程序员想要定义一个**字符串**，它的数据类型必须是编译器在编译时知道的**。静态类型语言的其他例子有:Java、Kotlin、C、C++。**

在动态类型语言的编程语言中，变量的数据类型是在运行时确定的。动态类型语言的一些例子有 [Python](https://studytonight.com/python) 、 [JavaScript](http://studytonight.com/javascript) 、 [PHP](http://studytonight.com/php) 。

因此，在 Kotlin 中，变量的数据类型必须在编译时为编译器所知，因为它是静态类型语言。但是如果您尝试运行以下代码，它将毫无错误地执行:

```kt
val marks = 5
println(marks) 
```

![](img/4765334125b448ec4c4bdf8285a1da72.png)Here we **haven't mentioned any data type** for `marks` variable, but it is executed successfully. It is because, Kotlin uses something called as **Type Inference** too, which means if the compiler can figure out what is the data type of the variable using type inference, then programmer need not to explicitly mention its type, the compiler will manage it itself.

我们可以通过这样声明变量来检查为声明的变量自动推断了哪些数据类型:

```kt
val subjects = 5
println("Data type of subjects: " + subjects::class.simpleName)

val marks = 47.5
println("Data type of marks: " + marks::class.simpleName)

val name = "Deepak"
println("Data type of name: " + name::class.simpleName) 
```

受试者数据类型:Int
标记数据类型:Double
名称数据类型:String

## Kotlin 中的数据类型

现在我们将讨论 Kotlin 中的基本数据类型。以下是支持的基本数据类型:

*   民数记

*   特性

*   布尔运算

*   数组

*   用线串

### 用数据类型定义变量的语法:

这里我们有定义指定数据类型的变量的基本语法:

```kt
val variable_name: datatype = value
```

因此，我们在 Kotlin 中主要使用`val`关键字来声明变量，我们可以在变量名后面使用**冒号来指定数据类型。我们将在下面讨论各种数据类型时看到示例。**

### 1.Kotlin 数字

Kotlin 提供了一些内置的数据类型来表示数字。Kotlin 数可以是**整数值或浮点数值**。

对于整数，数据类型为:

*   字节

*   短的

*   （同 Internationalorganizations）国际组织

*   长的

下表给出了它们各自所占的范围和空间:

| 类型 | 大小(字节) | 最小值 | 最大值 |
| --- | --- | --- | --- |
| 字节 | one | -128 | One hundred and twenty-seven |
| 短的 | Two | -32768 | Thirty-two thousand seven hundred and sixty-seven |
| （同 Internationalorganizations）国际组织 | four | -2,147,483,648 | Two billion one hundred and forty-seven million four hundred and eighty-three thousand six hundred and forty-seven |
| 长的 | eight | -9,223,372,036,854,775,808 | 9,223,372,036,854,775,808 |

您可以根据要存储的数据所需的范围和内存来使用它们。下面是我们如何声明每一个:

```kt
val byte: Byte = 1
val short: Short = 1
val int: Int = 1
val long: Long = 1
```

*   如果不超过`Int`的最大值，所有积分变量都推断为`Int`。

*   若要明确指定`Long`，请在该值中添加后缀 **L** 。

例如:

```kt
val normalNumber = 1
val explicitlyMarkedLong = 1L
val longByRange = 100000000000

println("Data type of normalNumber is: " + normalNumber::class.simpleName)
println("Data type of explicitlyMarkedLong is: " + explicitlyMarkedLong::class.simpleName)
println("Data type of longByRange is: " + longByRange::class.simpleName)
```

对于**浮点数**，提供的数据类型有:

*   浮动

*   两倍

它们的有效十进制位数不同:

| 类型 | 大小(字节) | 十进制数字 |
| --- | --- | --- |
| 浮动 | four | 6-7 |
| 两倍 | eight | 15-16 |

例如:

```kt
val marks: Float = 1.0f
val percentage: Double = 1.0
```

对于分数数据类型，编译器默认推断**双**数据类型。要明确指定**浮动**，请在值中添加后缀 **f** 或 **F** 作为后缀。

### 2.Kotlin 字符

Kotlin 中的字符使用 **Char** 关键字声明。字符应该放在单引号中，如**‘a’**。一个字符的大小是 **4 位**。

让我们举个例子:

```kt
val letter: Char = 'p'
```

与 Java 不同，数字在 Kotlin 中不能被视为字符:

```kt
val letter: Char = 65   // Error
```

### 3.Kotlin 布尔型

一个布尔变量用来表示两个值，或者**真**或者**假**。它们的用法与任何其他语言相同:

```kt
val isQualified: Boolean = true
val isPromoted: Boolean = false
```

### 4.Kotlin 数组

Kotlin 数组是相同数据类型的值的集合。如果我们想存储 7 个主题的标记，那么我们可以声明一个大小为 7 的数组，并保存其中的所有数字，而不是创建 7 个变量。

在 Kotlin 中，我们可以使用`Array` 类来声明一个数组。例如:

```kt
val marks: Array<Int> = arrayOf(10,9,2,7,8,6,10)
```

我们将在后面的章节中详细讨论数组。

### 5\. 琴弦 Kotlin

一个字符串可以使用 Kotlin 中的**字符串**类来表示。字符串基本上是字符、单词或句子的集合，可以包含字符、数字、特殊字符，但所有内容都应该用双引号括起来。比如“*嗨我是一根弦*”就是一根弦。字符串总是在双引号内声明。

让我们举个例子:

```kt
val message: String = "Corona Go, Go Corona!!"
```

在编写任何程序时，字符串都非常有用。我们将在单独的教程中详细介绍 String 类。

### 摘要

在本教程中，我们学习了 Kotlin 中的静态类型和类型推断。我们还研究了 Kotlin 中存在的各种数据类型。我们将在单独的教程中详细讨论数组和字符串。

* * *

* * *