# Kotlin 运算符

> 原文：<https://www.studytonight.com/kotlin/kotlin-operators>

在本教程中，我们将讨论 Kotlin 运算符。运算符是用于对一个或多个操作数执行操作的特殊字符。

例如:

```kt
var num1: Int = 10
var num2: Int = 20
var sum: Int = num1 + num2
println(sum) 
```

在上面的代码示例中，`num1`和`num2`是**操作数**，而`+`是**运算符**。

Kotlin 有各种类型的运营商。它们分为以下几类:

*   算术运算符

*   比较运算符

*   赋值运算符

*   等式运算符

*   一元运算符

*   逻辑运算符

*   杂项操作员

现在，我们将详细讨论每一个。

## 1.算术运算符

Kotlin 中的算术运算符用于执行基本的数学运算，如**加法**、**减法**、**乘法**、**除法**和**模数**。

在下表中，我们列出了所有算术运算符，并给出了每个运算符的基本示例。

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `+` | 两个变量相加 | a + b |
| `-` | 两个变量的减法 | 美国罗克韦尔 |
| `*` | 两个变量的乘法 | a * b |
| `/` | 两个变量的除法 | a / b |
| `%` | 两个变量的模。当 a 除以 b 时，它将返回余数。 | a % b |

让我们举一个代码示例:

```kt
var num1: Int = 25
var num2: Int = 6

println("Sum: " + (num1 + num2))
println("Difference: " + (num1 - num2))
println("Multiplication: " + (num1 * num2))
println("Division: " + (num1 / num2))
println("Modulus: " + (num1 % num2)) 
```

和:31
差:19
乘:150
除:4
模:1

## 2.比较运算符

Kotlin 中的比较运算符用于比较变量。比较运算符根据比较结果返回**真**或**假**。

以下是 Kotlin 支持的比较运算符:

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `<` | 检查一个变量是否小于另一个变量。如果左边的操作数小于右边的操作数，则返回**真**，否则返回**假**。 | a < b |
| `>` | 检查一个变量是否大于另一个变量。如果左边的操作数大于右边的操作数，则返回**真**，否则返回**假**。 | a > b |
| `<=` | 检查一个变量是否小于或等于另一个变量。如果左边的操作数小于或等于右边的操作数，则返回**真**，否则返回**假**。 | a <= b |
| `>=` | 检查一个变量是否大于或等于另一个变量。如果左边的操作数大于或等于右边的操作数，则返回**真**，否则返回**假**。 | a >= b |

让我们举一个代码示例:

```kt
var num1: Int = 25
var num2: Int = 6

println("Less than: " + (num1 < num2))
println("Greater than: " + (num1 > num2))
println("Less than or equal to: " + (num1 <= num2))
println("Greater than or equal to: " + (num1 >= num2)) 
```

小于:假
大于:真
小于或等于:假
大于或等于:真

## 3.赋值运算符

这些运算符用于给变量赋值。我们有**一个简单赋值运算符**和**五个增广赋值运算符**。

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `=` | 给变量赋值 | a = 10 |
| `+=` | 向变量添加并赋值 | a+=b |
| `-=` | 对变量进行减法运算并赋值 | a-=b |
| `*=` | 将一个值相乘并赋给一个变量 | a*=b |
| `/=` | 给变量赋值 | a/=b |
| `%=` | 模数并为变量赋值 | a%=b |

让我们通过代码示例来理解赋值运算符:

```kt
var num1: Int = 25
var addAndAssign: Int = 0
addAndAssign += num1
println(addAndAssign)

var subAndAssign: Int = 40
subAndAssign -= num1
println(subAndAssign)

var multiplyAndAssign: Int = 1
multiplyAndAssign *= num1
println(multiplyAndAssign)

var divideAndAssign: Int = 50
divideAndAssign /= num1
println(divideAndAssign)

var modulusAndAssign: Int = 30
modulusAndAssign %= num1
println(modulusAndAssign) 
```

25
15
25
2
5

## 4.等式运算符

这些运算符用于检查两个变量是否相等。我们有四个等式运算符。

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `==` | 检查两个对象是否相等，并返回 true | a == b |
| `!=` | 检查两个对象是否不相等，并返回 true | a！= b |
| `===` | 检查两个变量是否引用同一个对象 | a === b |
| `!==` | 检查两个变量是否引用了同一个对象 | a！== b |

运算符`===`和`!==`被称为**参考等式运算符**。它们检查变量是否引用同一个对象。

让我们举个例子，

```kt
val num1: Int = 25
var num2: Int = 25

println(num1 == num2)
println(num1 != num2)

num2 = num1
println(num1 === num2)
println(num1 !== num2)
```

真
假
真
假

## 5.一元运算符

一元运算符仅适用于一个操作数。下表包含所有一元运算符:

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `+` | 一元加号，返回正值 | +a |
| `-` | 一元负值，返回负值 | -b |
| `++` | 递增运算符，将值增加 1 | a++，a++ |
| `--` | 递减运算符，将值减少 1 | b -，- b |

让我们举一个代码示例:

```kt
var num1: Int = 25
var num2: Int = 10

println("+num1 :"+ +num1)
println("-num2 :"+ -num2)
println("++num1 :"+ ++num1)
println("--num2 :"+ --num1)
```

+num 1:25
—num 2:-10
++ num 1:26
--num 2:25

## 6.逻辑运算符

这些运算符用于执行逻辑与、逻辑或和逻辑非运算。

| 操作员 | 描述 | 表示 |
| --- | --- | --- |
| `&&` | 与运算符，如果两个输入都为真，则返回真 | a && b |
| `&#124;&#124;` | 或运算符，如果其中任何一个为真，则返回真 | a &#124;&#124; b |
| `!` | 非运算符，返回变量的否定 | ！a |

让我们举一个代码示例:

```kt
var num1: Int = 25
var num2: Int = -10

var andResult = num1 > 0 && num2 > 0
var orResult = num1 > 0 || num2 > 0
var notResult = !true
println("Check if both are positive: " + andResult)
println("Check if either one is positive: "+ orResult)
println("Not operator on true: "+ notResult)
```

检查两者是否都为正:假
检查其中一个是否为正:真
非运算符 on true: false

## 7.杂项操作员

Kotlin 还支持一些更杂的操作符。我们将在此讨论其他一些运算符:

### 1.可空运算符(`?`)

默认情况下，Kotlin 不允许字段为空。为了使一个字段可以为空，我们需要分配`?`运算符。

```kt
var message: String = null       // Error
var nullableMessage: String? = null       // No error 
```

### 2.`!!`操作员

空指针断言操作符(`!!`)将**将任何值转换为非空类型**，如果值为**空**，则抛出异常。

```kt
val message: String? = null
println(message!!.length)
```

这段代码在**编译时**不会抛出任何错误，但会在**运行时**抛出错误。不建议使用此运算符。

### 3.安全呼叫操作员(`?.`)

这个运算符是 Kotlin 中最重要的运算符之一。它**将我们从空指针异常**中拯救出来。顾名思义，它通过检查对象是否为空来帮助我们安全地调用对象的任何变量或方法。

```kt
val message: String? = null
println(message?.length)       // It will return null
println(message!!.length)     // It will through null pointer exception
```

在第一种情况下，它将检查`message`是否为空。如果是，则不调用方法，而是返回`null`。

### 4.埃尔维斯运算符

如果引用为空，则使用 Kotlin 中的 Elvis 运算符来赋值。

例如:

```kt
var message: String? = null
println(message?:"Message is null")       

message = "Hello World"
println(message?:"Message is null") 
```

消息为空
你好世界

在第一种情况下，当`message`为**空**时，使用**猫王运算符**后的条件，并打印“T7”消息为空。在第二种情况下，当`message`不为空时，`message`本身被打印。

## 摘要

在本教程中，我们讨论了 Kotlin 中的 variuos 运算符。最后，我们还讨论了一些操作符，这些操作符在空指针或空指针异常的情况下会对我们有所帮助。在下一个教程中，我们将讨论如何在 kotlin 中获取输入和显示输出。

* * *

* * *