# Kotlin 范围

> 原文：<https://www.studytonight.com/kotlin/kotlin-range>

在本教程中，我们将讨论 Kotlin 中的`range`。在数学意义上，一个**范围是一系列数字、字符等。在限定的边界内**。边界点为**起点** & **终点**，两者都包含在范围内。`range`也可以有一个`step`(步骤用于**跳转数字**或字符，同时定义从开始到结束边界的范围)。

我们可以借助 Kotlin 中的`rangeTo()`功能或者使用`..`运算符来创建一个范围。

## Kotlin:创建一个范围

如上所述，我们可以使用`..`运算符和`rangeTo()`函数，让我们一个接一个地讨论它们。

### 使用`..`运算符的 Kotlin 范围:

让我们使用`..`操作符创建一个从 **1 到 9 的**。

```kt
val range = 1..9
```

在上面的代码示例中，我们使用`..`运算符创建了一个范围。如果您想创建一个包含所有数字的数字范围，那么使用`..`操作符既简单又容易。

唯一的缺点是，我们不能用我们跳过/跳转数字的模式创建一个范围，例如，如果您想创建一个 1、3、5、7 等数字的**范围。跳一号**，或者 **1、4、7、10 等。跳跃两个数字**。

### 使用`rangeTo()`运算符的 Kotlin 范围:

我们也可以使用`rangeTo()`功能来创建范围。这是一个基本的例子:

```kt
val range = 1.rangeTo(9)
```

在上面的代码示例中，我们正在创建一个从 1 到 9 的**范围**，其中包括 **1** 和 **9** 。

### 检查数字是否在给定范围内

创建范围变量后，如果您想检查给定的数字是否在该范围内，那么我们可以使用带有`if`条件的`in`运算符轻松完成。

下面是一个简单的代码示例:

```kt
fun main() {
    val range = 1..9
    if (1 in range)
        println("1 is in $range")
    if(10 in range)
        println("10 is in $range")
}
```

1 合 1..9

我们也可以在各种不同的场景中使用`range`:

```kt
var lowerCase = 'a'..'z'          // Range for lowercase alphabet
var upperCase = 'A'..'Z'          // Range for uppercase alphabet
var digit = 0..9                 // Range for digits
```

这样我们就可以根据我们的要求轻松地定义不同类型的范围。

## Kotlin 步幅

要定义一个范围内两个连续值之间的距离，我们可以使用`step()`函数。例如，要用 2 的`step`打印 1 到 10 的数字，我们可以将范围写成:

```kt
val range = 1..10 step 2
```

让我们使用`for`循环打印该范围:

```kt
fun main() {
    val range = 1..10 step 2
    for (number in range)
        println(number)
}
```

1
3
5
7
9

同样，我们可以为`step`函数提供任何数字作为参数，并基于此创建我们的范围变量。

## Kotlin `downTo()`功能

如果我们想按**相反的顺序**打印数字，即从 10 到 1，我们**不能使用** `rangeTo()`功能或`..`运算符。如果我们试着像下面的代码一样使用它们，它不会打印任何东西，因为默认步骤是 **1** ，并且它只会向前进行。

```kt
fun main() {
    val range = 10..1
    for (number in range)
        println(number)     // print nothing
}
```

因此，为了以相反的顺序创建一个范围，我们将使用`downTo()`函数:

```kt
fun main() {
    val range = 10 downTo 1
    for (number in range)
        println(number)
}
```

10
9
8
7
6
5
4
3
2
1

我们也可以用`step`配合`downTo()`功能:

```kt
fun main() {
    val range = 10 downTo 1 step 3
    for (number in range)
        println(number)
}
```

10
7
4
1

## 摘要

在本教程中，我们讨论了`rangeTo()`、`step`和`downTo()`函数。还有许多其他功能可用，如`first()`、`last()`、`until()`，可与`range`一起使用。接下来我们将讨论`continue`、`break`和`repeat`语句。

* * *

* * *