# Kotlin `continue`，`break`和`repeat`语句

> 原文：<https://www.studytonight.com/kotlin/kotlin-continue-break-and-repeat-statement>

在本教程中，我们将讨论 Kotlin 中的`continue`、`break`和`repeat`语句。这些语句在 Kotlin 循环中用于管理循环的执行流程，例如，如果您想跳过一个迭代，或脱离循环或重复一个迭代，那么可以使用这些语句。

在本教程中，我们将通过示例介绍所有这三个方面。

## Kotlin `continue`声明

`continue`语句用于**跳过循环**的当前迭代，**从下一个**迭代开始。它主要与`if`表达式一起使用，根据条件决定是否跳过循环的当前迭代。

让我们用一个例子来理解`continue`的说法。我们将打印从 1 到 10 的所有数字**，除了 3 的倍数**:

```kt
fun main() {
    for (number in 1..10){
        if (number % 3 == 0)
            continue
        println("Number is $number")
    }
}
```

号为 1
号为 2
号为 4
号为 5
号为 7
号为 8
号为 10

### 该计划的流程:

*   对于 1 到 10 之间的每个`number`值，将执行循环。

*   在`if`表达式内部，会检查`number`是否能被 3 整除:

    *   如果是，由于`continue`语句，循环的其余部分将不会被执行，因此不会打印数字。它将转到下一个值并执行循环。

    *   如果否，则执行循环并执行`println`语句。

在嵌套循环的情况下，最里面的循环将遵循`continue`语句。

## Kotlin `break`声明

`break`语句用于**停止循环**的执行，执行退出或跳出循环。它还与`if`表达式一起使用，根据特定条件中断循环。

让我们编写一个程序来接收用户的输入。它将继续接受输入，直到用户输入“*停止*”:

```kt
fun main() {
    while (true){
        println("Enter the input: ")
        val input: String? = readLine()
        if(input == "stop")
            break
        println("Input entered is: $input")
    }
    println("Outside the loop!!")
}
```

输入输入:
你好
输入输入为:你好
输入为:
世界
输入输入为:世界
输入为:
停止
外循环！！

### 该计划的流程:

*   因为 while 循环中的条件总是真的，所以它永远不会停止自己。

*   如果输入为“停止”，则获取并检查输入:

    *   如果是，循环结束，打印循环外的最后一条语句“*”。*

    **   如果否，循环将继续执行并打印输入的内容。* 

 *在嵌套循环的情况下，`break`语句将断开最里面的循环。因此，您将需要多个`break`语句来分解或嵌套循环，这取决于循环的数量。

## Kotlin `repeat`声明

`repeat`语句类似于 Kotlin 中的循环。它被用来重复一个任务多次，就像循环一样。

`repeat`语句的语法是:

```kt
repeat(Number_of_time){
    // Statements to be executed
}
```

让我们使用`repeat`语句打印一个语句 3 次:

```kt
fun main() {
    repeat(3){
        i ->
        println("This statement will be printed 3 times!!")
        println("Index is: $i")
    }
}
```

本声明将打印 3 次！！
指数为:0
本声明将打印 3 次！！
指数为:1
本声明将打印 3 次！！
指数为:2

如上面的代码所示，如果我们想使用它，我们可以得到`repeat()`语句的索引。在上面的代码中，我们使用它来打印索引。

## 摘要

在本教程中，我们讨论了`continue`、`break`和`repeat`语句。在下一个教程中，我们将开始详细讨论 Kotlin String。

* * *

* * **