# Kotlin 字符串

> 原文：<https://www.studytonight.com/kotlin/kotlin-string>

在本教程中，我们将向您介绍 Kotlin 字符串，包括 Kotlin 字符串类、其属性和函数以及代码示例。

字符串是组合在一起的**字符数组**。字符串通常使用**双引号** **`""`** 创建。我们也可以使用**三重引号** **`"""`** 创建**多行字符串**。这根弦也被称为**生**弦。

字符串的一个基本例子是*“今晚学习”*，或*“学习 123”*等。都是字符串。在内部，它被视为字符数组，您将会理解，因为我们将介绍一些代码示例。

和 Java 类似，字符串本质上是**不可变的**。不可变并不意味着我们不能改变字符串变量的值。这意味着每当我们改变一个字符串的值，而不是改变该字符串的实例时，**编译器会创建该字符串的新实例**。

让我们用一个例子来理解它:

```kt
fun main() {
    var string: String = "Hello"
    string = "Bye"
    println(string)
}
```

在**第 2 行**中，我们创建了一个变量`string`，并为其分配了`"Hello"`值。编译器将在字符串池中创建新字符串。现在，当我们将`"Bye"`分配给`string`时，编译器将再次创建一个新字符串，将其存储在字符串池中，并将其实例分配给`string`变量。并且先前创建的字符串“`Hello`”将仍然存在于字符串池中。

## 字符串类的属性和方法

String 类包含许多属性和方法，用于管理 Kotlin 字符串并对其执行操作。一些重要的属性和功能是:

### Kotlin 字符串属性:

*   `length`:表示字符串的长度。

*   `lastIndex`:表示字符串中最后一个字符的索引。

### Kotlin 字符串方法:

*   `get(index)`:返回字符串中**指定索引**处的**字符**或者抛出`IndexOutOfBoundsException`。

*   `first()`:返回字符串中的**第一个字符**，如果字符串为空则抛出`NoSuchElementException`。

*   `last()`:返回字符串中最后一个字符**，如果字符串为空则抛出`NoSuchElementException`。**

*   `plus(string)`:返回一个新的字符串，这个新的字符串是通过将连接到调用这个方法的字符串上而得到的，这个字符串作为参数给出。它不会改变实际的字符串，因为字符串是不可变的。

*   `subSequence(startIndex, endIndex)`:返回`startIndex`(包含)和`endIndex`(不包含)之间的**子序列**。

*   `contains(subString, ignoreCase)`:如果该字符串**中包含给定的子字符串**，则返回`true`。`ignoreCase`参数为真/假，指定是否忽略大小写。

*   `capitalize()`:返回该字符串的副本，其第一个字母大写。

*   `decapitalize()`:返回该字符串的副本，其第一个字母以开头。

*   `reversed()`:以相反的顺序返回一个带有**字符的字符串**。

*   `toLowerCase()`:返回这个字符串的一个副本**转换成小写**。

*   `toUpperCase()`:返回转换为大写的字符串**的副本。**

让我们在一个例子中使用这些方法和属性:

```kt
fun main() {
    var message = "Hello World!!"
    // Properties
    println("Length of string: ${message.length}")
    println("Last index number: ${message.lastIndex}")

    // Functions
    println("Character at index 0: ${message[0]}")
    println("Character at index 1: ${message.get(1)}")
    println("First character in string: ${message.first()}")
    println("Last character in string: ${message.last()}")

    println("Add Bye to message for printing: ${message.plus(" Bye")}")
    println("Subsequence from message: ${message.subSequence(0,5)}")
    println("Message contains 'll'?: ${message.contains("ll")}")

    println("Capitalize message: ${message.capitalize()}")
    println("decapitalize message: ${message.decapitalize()}")
    println("Reversed message: ${message.reversed()}")
    println("Message in lower case: ${message.toLowerCase()}")
    println("Message in upper case: ${message.toUpperCase()}")

}
```

字符串长度:13
最后一个索引号:12
索引 0 处字符:H
索引 1 处字符:e
字符串中第一个字符:H
字符串中最后一个字符:！
给消息添加 Bye 进行打印:你好世界！！再见
消息子序列:你好
消息包含‘ll’？:true
大写留言:你好世界！！
去大写信息:你好世界！！
反转消息:！！dlroW olleH
小写留言:你好世界！！
大写信息:你好世界！！

不要被语法`${ .. }`搞糊涂了，它是用来在 Kotlin 的 println [输出中追加一个变量值的。](https://www.studytonight.com/kotlin/kotlin-input-and-output)

## 字符串模板

我们可以添加一段代码并将其连接到字符串(在将其转换为字符串之后)。这段代码被称为**字符串模板**。我们在使用`println()`函数打印值时也使用了字符串模板。字符串模板以`$`(美元)符号开始。

让我们看一个例子，其中我们将添加一个字符串模板:

```kt
fun main() {
    var message = "Hello World!!"
    var multiLineMessage = """Adding message in
         multiline
         comment: 
         $message
    """
    println(multiLineMessage)
}
```

多行
添加消息评论:
你好世界！！

正如您在上面的代码中看到的，我们已经使用`$`符号在`println`方法中打印的消息中添加了一个字符串。当我们打印带有字符串值变量的输出时，这非常有用。

## 摘要

在本教程中，我们讨论了 Kotlin 字符串、它的属性和方法。当我们编写实际程序时，字符串非常有用，当您使用 Kotlin 开发您的安卓应用时，所有这些方法都会派上用场。在下一个教程中，我们将讨论 Kotlin 数组。

* * *

* * *