# Kotlin 数组

> 原文：<https://www.studytonight.com/kotlin/kotlin-array>

在本教程中，我们将讨论 Kotlin 数组。**数组是数据类型**的集合。在大多数语言中，数组元素应该是相同的数据类型，但是在 Kotlin 中，我们可以有包含不同数据类型的数据的**数组。意思是，我们可以存储**整数、字符串、字符等。在同一个数组中**。**

数组的属性有:

*   数组是基于 **0 索引的**，即第一个元素的索引为 0。

*   阵的大小是**固定的**。申报后不能增减。

*   数组是**可变的**，因为数组元素在声明后可以改变。

在 Kotlin 中，可以使用`Array<T>`类和一些 Kotlin 函数来创建数组。我们将首先看到如何使用函数创建**数组，然后我们将看到如何使用`Array`类创建。**

## 使用函数创建数组

创建数组最简单的方法是使用`arrayOf()`函数。调用`arrayOf()`函数时，我们可以将**数组元素作为参数**传递。

让我们创建一个整数数组:

```kt
val marks = arrayOf(10,9,3,4,5)
```

在上面的代码中，我们创建了一个整数数组。由于**数组的大小是固定的**，我们以后不能在此添加元素。该数组的大小将是固定的，即 **5** 。

在上面的例子中，没有提到数组的类型。因此，**不同类型的元素可以添加到这个数组中**:

```kt
val differentTypeArray = arrayOf(10,4,5,"Array string", 'c', 10.5f)
```

正如您在上面的代码示例中看到的，不同类型的元素被添加到这个数组中。

如果我们想**固定数组中元素**的类型，可以在创建数组时提到类型，如下所示:

```kt
val marks = arrayOf<Int>(10,4,5,8,9)
```

现在在上面定义的数组中，只能存储整数值。

为了限制数组只存储特定类型的数据，我们也可以在 Kotlin 中使用特定类型的函数。它们是:

*   `intArrayOf()` -对于整数数组

*   `charArrayOf()` -对于字符数组

*   `byteArrayOf()` -对于字节数组

*   `shortArrayOf()` -对于短值数组

*   `longArrayOf()` -对于长值数组

*   `doubleArrayOf()` -对于双值数组

*   `floatArrayOf()` -对于浮点值数组

*   `booleanArrayof()` -对于布尔值数组

让我们举一个使用上述所有函数的简单代码示例:

```kt
var intArray = intArrayOf(1,2,3,4,5)
var charArray = charArrayOf('a','b','c')
var byteArray = byteArrayOf(1,2,5,6,7)
var shortArray = shortArrayOf(2,3,5,6)
var longArray = longArrayOf(1,2,3)
var doubleArray = doubleArrayOf(10.0, 1.1, 3.14)
var floatArray = floatArrayOf(10.0f, 3.14f)
var booleanArray = booleanArrayOf(true, false, true)
```

所以如果你想限制一个数组存储相同类型的数据，你可以通过使用上面的，特定类型的`arrayOf`函数或者使用简单的`arrayOf`函数以及像`<Int>`、`<Char>`等类型信息来实现。

## 使用数组类创建数组

可以使用`Array`类的构造器创建 Kotlin 数组。构造器需要两个参数:第一个是数组的`size`，第二个是`init`函数。`init`功能用于初始化数组:

```kt
var numbers = Array(3, init = {
    i -> i * 3
})
```

这里，使用公式**索引* 3** 创建大小为 3 的数组并由元素初始化。创建的数组将包含 **0，3，6** 。

## 访问和修改数组

使用`get()`和`set()`功能可以访问和修改数组的元素。

`get()`函数只取一个参数:元素的**索引。**

而`set()`函数取两个参数:第一个作为元素的`index`，第二个作为该`index`的**新值**。

让我们举一个代码例子，

```kt
fun main() {
    val marks = arrayOf<Int>(10,4,5,8,9)
    println(marks.get(0))
    println(marks.get(1))
    // update the value of the first element of the array
    marks.set(0,100)
    println(marks.get(0))
}
```

10
4
100

除了使用`get()`和`set()`，我们还可以使用`[]`来访问方括号内提供索引值的数组元素。以上使用`[]`的代码可以写成:

```kt
fun main() {
    val marks = arrayOf<Int>(10,4,5,8,9)
    println(marks[0])
    println(marks[1])
    // setting new value for first element of array
    marks[0] = 100
    println(marks[0])
}
```

10
4
100

### 获取数组的大小

Kotlin 数组的大小可以通过其`size`属性找到:

```kt
fun main() {
    val marks = arrayOf<Int>(10,4,5,8,9)
    println(marks.size)
}
```

5

## 遍历数组

可以使用`for`循环遍历数组。下面是一个简单的代码示例，

```kt
fun main() {
    val marks = arrayOf<Int>(10,4,5,8,9)
    for (i in marks)
        println(i)
}
```

10
4
5
8
9

也可以使用 Kotlin 中的`forEach()`来访问数组元素:

```kt
fun main() {
    val marks = arrayOf<Int>(10,4,5,8,9)
    marks.forEach { i ->
        println(i)
    }
}
```

10
4
5
8
9

## 摘要

在本教程中，我们讨论了使用方法和数组类构造器创建数组。我们还讨论了如何访问和修改数组元素、查找数组大小以及遍历数组。在下一个教程中，我们将讨论 Kotlin 函数。

* * *

* * *