# Kotlin 用户定义函数

> 原文：<https://www.studytonight.com/kotlin/kotlin-userdefined-functions>

在本教程中，我们将讨论 Kotlin 函数，包括 Kotlin 库函数和用户定义函数。函数用于将巨大的单片代码分解成可重用的更小的代码块。理想情况下，我们应该**为单个任务**创建一个函数。函数也**增加了代码的可重用性**因为一旦被编写，函数可以在需要的时候被多次调用。

功能可以有两种类型:

1.  标准库函数

2.  用户定义的函数

标准库函数由 Kotlin 标准库提供，可以直接使用。我们已经使用了许多标准库函数，如:`print()`、`println()`、`main()`、`arrayOf()`等。您可以在这里探索更多关于 Kotlin 标准库[的信息。现在，我们将看到如何创建用户定义的函数。](https://kotlinlang.org/api/latest/jvm/stdlib/)

## Kotlin 用户定义函数

顾名思义，用户定义的功能是由**用户**创建的。Kotlin 中的函数是使用`fun`关键字创建的。函数的语法是:

```kt
fun <name_of_function>(<argument_name>: <argument_data_type>):<return_type>{
    // body of the function
}
```

在语法中:

*   **<函数名>** :是给函数起的名字。

*   **<自变量 _ 名称>** :代表自变量名称。

*   **<参数 _ 数据 _ 类型>** :表示参数的数据类型。

*   **< return_type >** :表示函数返回值的数据类型。

对于绝对初学者来说，**参数**代表调用函数时提供给函数的数据值，函数使用这些数据值，**返回类型**是函数作为结果返回的值的数据类型。

让我们创建一个简单的函数，将一个整数作为输入，并返回它的平方:

```kt
fun getSquare(number: Int): Int {
    return number * number
}
```

在上面的代码中，我们提供了输入**参数**作为`Int`的数据类型和**返回值**也作为`Int`的数据类型。

让我们从`main()`函数调用这个函数:

```kt
fun main() {
    println("The square of 9 is : ${getSquare(9)}")
}

fun getSquare(number: Int): Int {
    return number * number
}
```

9 的平方是:81

关于功能的几个要点是:

*   一旦我们定义了一个函数，我们可以随意调用它多次。

*   如果在调用函数时，我们提供了错误的数据类型参数，那么我们将得到一个编译时异常。

*   我们还可以定义不返回任何内容的函数，这将在本教程的下一节中介绍。

## 不返回任何内容的 Kotlin 函数

我们可以定义在 Kotlin 中返回任何东西的函数。有三种不同的方法。

### 无返回类型的 Kotlin 函数:

如果函数没有返回任何东西，那么就不需要提到返回类型:

```kt
fun sayHello(){
    println("Hello World!!")
}
```

在上面的函数中，如果我们愿意，我们可以添加参数(参数)，但是函数可能不会返回任何东西。例如，我们可以更新上面定义的 getSquare()函数，只打印结果而不是返回结果。

```kt
fun getSquare(number: Int) {
    println("Square is: ${number * number}")
}
```

### 带有`Unit`返回类型的 Kotlin 函数:

如果我们想指定返回类型，我们可以添加`Unit`作为不返回任何有意义的函数的返回类型。类似于 Java 中的**虚空。如果没有提到任何返回类型，也没有从函数中返回任何值，那么默认情况下，返回类型被认为是`Unit`。**

让我们举一个代码示例:

```kt
fun sayHello(): Unit{
    println("Hello World!!")
}
```

### 带有`Nothing`返回类型的 Kotlin 函数:

在 Kotlin 中，Nothing 是一种特殊类型，它也可以用作用户定义函数的返回类型，用于不返回任何内容的函数。或者，我们可以说，以`Nothing`为返回类型的函数，**从不返回任何东西**，甚至不是默认的`Unit`类型。

例如，下面的函数总是引发异常:

```kt
fun exceptionEveryTime(): Nothing {
    throw IllegalArgumentException()
}
```

<u>**注意:**</u> 如果我们在代码中调用了上面的函数，那么这个函数调用后的代码语句将不会被执行，**编译器将显示警告**。

## 为什么不能用 Void？

你一定在想，为什么我们不能像在 Java 中那样对不返回任何东西的 Kotlin 函数使用 Void。我们可以，但不能直接说。

例如，

```kt
fun setReturnTypeVoid() : Void {
    println("This function has return type as Void")
}
```

但是该函数不会被编译，您将看到以下错误:

错误:Kotlin:在具有块体的函数中需要“return”表达式(' { 0...}')

您一定认为该函数根据错误消息需要一个返回类型，所以继续，并尝试在末尾添加一个`return null`语句。

```kt
fun setReturnTypeVoid() : Void {
    println("This function has return type as Void")
    return null
}
```

这也不行。

错误:Kotlin: Null 不能是非 Null 类型的值 Void

看这也行不通。为什么呢？因为 Kotlin 没有将`Void`视为**空类型**，所以提供`return null`语句会产生编译错误。\

但是在 Kotlin 中，我们可以通过使用`?`运算符使函数返回类型为可空的。

例如，

```kt
fun setReturnTypeVoid() : Void? {
    println("This function has return type as Void")
    return null
}
```

但是，这也适用于任何其他返回类型，如`Int`等。而不仅仅是针对`Void`数据类型。

## 摘要

在本教程中，我们讨论了 Kotlin 用户定义函数。我们看到了为什么要使用函数，以及如何使用`fun`关键字创建用户定义的函数。我们学习了用不同的返回类型定义新函数。我们还介绍了如何使用`Unit`和`Nothing`类型定义不返回任何内容的函数。

在接下来的教程中，我们将讨论递归、内联函数、函数中不同类型的参数、lambda 函数等。

* * *

* * *