# Kotlin 位置、默认和命名函数参数

> 原文：<https://www.studytonight.com/kotlin/kotlin-positional-default-and-named-function-arguments>

在本教程中，我们将讨论 Kotlin 函数中不同类型的参数。参数是调用函数时传递给函数的值。

在 Kotlin 中，有多种类型的参数可以在声明和调用[Kotlin 用户定义函数](https://www.studytonight.com/kotlin/kotlin-userdefined-functions)时使用。它们是:

1.  位置参数

2.  默认参数

3.  命名参数

最后我们还会看到什么是`vararg`。

## Kotlin 位置论点

这些是任何语言中存在的基本类型的参数。这些是基于位置的参数。第一个参数对应函数定义中的第一个参数，第二个参数对应第二个参数，依此类推。

例如，

```kt
fun main() {
    printInfo("Groot", 2)
}
fun printInfo(name: String, age: Int) {
    println("Hi! My name is $name and I'm $age months old.")
}
```

在上面的代码中，`"Groot"`和`2`是`name`和`age`功能参数的位置参数。如果我们先试着颠倒他们的位置，即`2`后试着颠倒`"Groot"`，这在位置论证中是行不通的。我们可以通过使用命名参数来实现这一点。

## Kotlin 默认参数

默认参数用于为函数参数提供**默认值。考虑这样一种情况:如果用户在调用函数时没有传递任何值，我们希望为函数参数指定一个默认值，那么将使用默认值。我们可以使用默认参数来实现这一点。**

我们可以在函数定义中定义默认值:

```kt
fun printInfo(name: String = "XYZ", age: Int = 18) {
    println("Hi! My name is $name and I'm $age months old.")
}
```

这里，我们为`name`定义了默认值 **XYZ** ，为`age`定义了默认值 **18** 。让我们使用不同数量的参数来调用这个函数:

```kt
fun main() {
    // Providing both the arguments
    printInfo("Groot", 2)

    // Providing none of the arguments
    printInfo()

    // Providing only name
    printInfo("Groot")
}

// function definition
fun printInfo(name: String = "XYZ", age: Int = 18) {
    println("Hi! My name is $name and I'm $age months old.")
}
```

嗨！我叫格鲁特，今年 2 个月。
嗨！我叫 XYZ，今年 18 个月。
嗨！我叫格鲁特，今年 18 个月。

**说明:**

*   在第一种情况下，提供了两个参数，并且选择这些参数而不是默认参数。

*   在第二种情况下，没有提供任何参数。因此，使用默认参数。

*   在第三种情况下，为`name`提供参数，但为`age`采用默认参数。

但是在这种情况下，如果我们试图只通过`age`，我们将会得到一个错误。

```kt
// Providing only age
printInfo(10)          // ERROR
```

这是因为编译器会尝试将第一个参数即`10`与**第一个参数** `name`进行映射。为了实现这种功能，我们将使用命名参数。

## Kotlin 命名论证

在调用函数时，我们可以使用参数的名称来指定特定参数的特定参数。这些类型的参数被称为**命名参数**。

让我们通过只传递`age`来调用同一个`prinfInfo()`方法。这次我们就用**命名的论点**来称呼它:

```kt
fun main() {
    // Providing only age
    printInfo(age = 10)         
}
fun printInfo(name: String = "XYZ", age: Int = 18) {
    println("Hi! My name is $name and I'm $age months old.")
}
```

嗨！我叫 XYZ，今年 10 个月。

使用命名参数，我们还可以**重新排列参数**。我们只需要给出参数的名称，在调用函数时使用`name = value`格式即可。

请记住一件事，如果我们开始在函数中使用命名参数，我们不能对其余参数使用位置参数。例如:

```kt
fun main() {
    printInfo("XYZ", gender = "Male", "India")          // ERROR

}
fun printInfo(name: String, gender: String, Nationality: String) {
    println("Hi! My name is $name")
    println("My gender is $gender")
    println("I'm from $name")
}
```

在使用命名参数性别后，我们需要为每个参数命名。

## 锅`vararg`

`vararg`代表**可变数量的参数**。Kotlin 允许我们使用`vararg`向函数传递可变数量的参数。

让我们创建一个函数，它可以将变量数作为参数并返回它们的和:

```kt
fun main() {
    findSum(1,2,10,6,5)
    findSum(1)
}
// function taking variable number of arguments
fun findSum(vararg numbers: Int): Int {
    var sum = 0
    // loop around the arguments
    for (number in numbers)
        sum += number
    return sum
}
```

## 摘要

在本教程中，我们讨论了各种类型的参数及其用法。我们还讨论了 Kotlin 中的 **varargs。在下一个教程中，我们将讨论 Kotlin 中的 Lambda 函数/表达式。**

* * *

* * *