# Kotlin Lambda 表达式

> 原文：<https://www.studytonight.com/kotlin/kotlin-lambda-expression>

在本教程中，我们将讨论 Kotlin 中的**λ表达式**。Lambda 函数或表达式在 Kotlin 中并不新鲜，在 Python、Java 和 Javascript 等许多其他语言中都存在。

Lambda 函数类似于匿名函数。一个**匿名函数**是一个没有名字的函数。基本上，Lambda 表达式是一种简洁地创建函数并将它们作为参数传递、返回等的方式。我们可以称它们为简单函数。

λ表达式可以被视为一个**变量**。这意味着，我们可以**将其作为参数传递给函数**、**从函数**等返回。

## Kotlin Lambda 表达

Kotlin 中 lambda 表达式的语法是:

```kt
val nameOfLambda : DataType = { argruments -> bodyOfLambdaFunction } 
```

在兰达斯:

*   `->`左侧提到论点。如果左边没有参数，可以去掉`->`(我们将在例 1 中看到)。

*   λ的体在`->`之后出现，它**不能为空**。

*   λ的最后一个表达式被认为是**返回语句**(见例 2)。

*   如果没有返回值或者没有提到返回类型，`Unit`类型将被认为是返回类型，就像我们在 [Kotlin 用户定义函数](https://www.studytonight.com/kotlin/kotlin-userdefined-functions)中解释的那样。

*   使用`invoke()`方法或通过在 Lambda 名称后添加`()`来调用 lambda 函数(带参数)。

这与 [Javascript 箭头函数](https://www.studytonight.com/javascript/javascript-arrow-function)非常相似。

让我们举几个代码示例。

### Kotlinλ表达式-示例 1:

让我们从创建一个简单的 lambda 开始，它打印一个字符串:

```kt
fun main() {
    // lambda expression with no argument
    val lambda = { println("Lambdas are awesome!")}
    // Calling lambda function using ()
    lambda()
    // Calling lambda function using invoke() function
    lambda.invoke()
}
```

兰姆达斯真棒！
兰姆达斯真棒！

在这个例子中，参数和返回类型被删除了。

### Kotlinλ表达式-示例 2:

让我们创建另一个寻找矩形区域的例子:

```kt
fun main() {
    val area = {length: Int, breadth: Int -> length*breadth} 
/*    
    This lambda is same as:
    fun area(length: Int, breadth: Int){
        return length*breadth
    }
*/
    println("Area of rectangle of dimension 4 and 5 is: ${area(4,5)}")
}
```

尺寸为 4 和 5 的矩形面积为:20

这里返回类型自动推断为`Int`。

## *它在 Kotlinλ表达式中*

如果 lambda 表达式中只有一个参数，则可以用`it`关键字替换它。这是 Kotlin 使用的速记，非常有用。`it`关键字将代表传递给 lambda 函数的单个参数。

让我们创建一个数组，并使用`forEach`循环打印其中元素的方块:

```kt
fun main() {
    val array = arrayOf(10,2,3)
    // Long way
    array.forEach { num -> println(num * num) }
    // Shorthand
    array.forEach { println(it*it) }
}
```

100
4
9
100
4
9

当我们在数组上使用 forEach 循环时，`it`关键字指的是**当前元素**。

## 摘要

在本教程中，我们讨论了 Kotlin lambdas 或 Lambda 表达式。Lambdas 是有用的，使我们的代码简洁。Lambdas 在安卓应用开发中也大量使用。在下一个教程中，我们将讨论高阶函数。

* * *

* * *