# Kotlin 高阶函数

> 原文：<https://www.studytonight.com/kotlin/kotlin-higher-order-function>

在上一个教程中，我们讨论了 Kotlin lambda 函数。在本教程中，我们将前进一步，讨论 Kotlin 中的**高阶函数。**

Kotlin 认为它的功能是作为一级公民。它允许一个函数被**用作变量**。因此，一个函数可以作为参数传递给另一个函数，从一个函数返回，存储在变量或数据结构中，等等。

## Kotlin 高阶函数

将另一个函数作为自变量或返回一个函数的函数称为**高阶函数**。lambda 表达式通常作为参数传递给高阶函数，或者从高阶函数返回。匿名函数也可以用于同样的目的。

我们将看到一些例子，其中我们将传递函数和 lambdas 作为参数，或者从另一个函数返回它们。

## Kotlin 函数作为参数

在本例中，函数`sayHello()`作为参数传递给`higherOrderFunction()`，并从`main()`函数调用:

```kt
fun sayHello(name: String){
    println("In sayHello() function")
    println("Say hello to $name")
}

fun higherOrderFunction(functionName: (name: String)-> Unit, name: String){
    println("In higher order function")
    println("Calling sayHello() function...")
    functionName(name)
}

fun main() {
    higherOrderFunction(::sayHello, "Ninja")
}
```

在高阶函数
中调用 sayHello()函数...
在 sayHello()功能中
向忍者问好

**上面的代码发生了什么:**

*   `sayHello()`函数只打印两个字符串。

*   `higherOrderFunction()`函数接受两个参数。第一个参数是一个**函数**，第二个是一个字符串。要接受函数作为参数，我们需要在参数中以 lambda 表达式的形式定义它的定义。让我们看看它的分段:

    *   作为参数的函数名称为`functionName`。所以我们现在开始用`functionName()`调用接受的函数(即`sayHello()`)。

    *   接下来我们添加了`(name: String)`，它反映了`sayHello()` 函数的参数。

    *   `->`之后我们提到了`sayHello()`功能的返回类型。

*   在`higherOrderFunction()`函数内部我们调用`functionName()`(也就是`sayHello()`)并传递`name`作为参数。

*   T **o 传递一个函数作为参数**我们使用`::`运算符。我们从`main()`调用`higherOrderFunction()`函数，并通过`sayHello()`作为参数。

## 作为返回值的 Kotlin 函数

在本例中，我们将从`higherOrderFunction()`函数返回`sayHello()`函数。

```kt
fun sayHello(name: String){
    println("In sayHello() function")
    println("Say hello to $name")
}

fun higherOrderFunction(): (name:String) -> Unit{
    println("In higher order function")
    // return the sayHello function
    return ::sayHello
}

fun main() {
    val functionName = higherOrderFunction()
    functionName("Ninja")
} 
```

在高阶功能
中在 sayHello()功能
中向忍者问好

**代码说明:**

*   在`main()`函数中，调用`higherOrderFunction()`，返回值存储在`functionName`变量中。

*   在`higherOrderFunction()`功能中，返回类型被称为`(name:String) -> Unit`。它**表示`sayHello()`函数的参数和返回类型**(这是要返回的函数)。

*   使用`::`操作符返回`sayHello()`功能。

*   返回的函数存储在`functionName`变量中。用`functionName("Ninja")`叫，和叫`sayHello("Ninja")`一样。

## Kotlin·拉姆达作为论据

大多数情况下，我们传递[λ表达式](https://www.studytonight.com/kotlin/kotlin-lambda-expression)作为参数或者返回它，而不是函数。让我们看看我们讨论过的相同的例子，但这次我们将使用 lambdas。

```kt
fun higherOrderFunction(functionName: (name: String)->Unit, name: String){
    println("In higher order function")
    println("Calling received function...")
    functionName(name)
}

fun main() {
    higherOrderFunction({ name: String ->
        println("Inside the lambda function")
        println("Say hello to $name")
    }, "Ninja")
}
```

在高阶函数
中调用接收函数...
在 lambda 功能里面
跟忍者打招呼

在这个例子中，我们没有单独创建一个函数`sayHello()`，然后将其名称作为参数传递，而是创建了一个 lambda 表达式，并将其直接传递给我们的高阶函数。它的工作方式与在函数作为参数的情况下解释的方式相同。

## Kotlin Lambda 作为返回值

最后，让我们看一个例子，其中 lambda 是从一个函数返回的:

```kt
fun higherOrderFunction(): (name:String) -> Unit{
    println("In higher order function")
    return {name ->
        println("Inside the lambda function")
        println("Say hello to $name")}
}
fun main() {
    val functionName = higherOrderFunction()
    functionName("Ninja")
}
```

在高阶功能
里面的λ功能
跟忍者打招呼

## 摘要

在本教程中，我们用多个例子讨论了 Kotlin 高阶函数。在下一个教程中，我们将讨论 Kotlin 中的内联函数。

* * *

* * *