# Kotlin `inline`关键字

> 原文：<https://www.studytonight.com/kotlin/kotlin-inline-keyword>

在本教程中，我们将使用`inline`关键字讨论 Kotlin 中的内联函数。内联函数帮助我们在运行时节省内存，从而提高应用的性能。

在之前的教程中，我们讨论了 lambda 表达式和高阶函数。让我们举同一个例子:

```kt
fun higherOrderFunction(functionName: (name: String)->Unit, name: String){
    println("In higher order function")
    println("Calling received function...")
    functionName(name)
}
fun main() {
    higherOrderFunction({ name: String ->
        println("Inside the lambda function")
        println("Say hello to $name")
    }, "Ninja")
} 
```

在 IntelliJ 中，我们可以生成我们的 Kotlin 程序的字节码。为此，请转到**工具>Kotlin>显示 Kotlin 字节码**。我们可以反编译这个字节码，生成等价的 Java 代码。

我们将观察到，对于λ表达式，创建了一个新的函数对象。但这不是我们想要的。

每个高阶函数将**创建一个新对象，并为其分配内存**。这会**增加运行时间开销**。为了克服这个问题，我们**使用内联函数**。

## Kotlin 内联函数

为了避免为每个高阶函数创建新对象，我们可以使用`inline`关键字。它将帮助我们提高代码的性能。`inline`关键字不是为高阶函数创建新对象，而是将内联函数内部的代码复制到调用它的地方。

功能前增加`inline`关键字。

```kt
inline fun higherOrderFunction(functionName: (name: String)->Unit, name: String){
    println("In higher order function")
    println("Calling received function...")
    functionName(name)
}

fun main() {
    higherOrderFunction({ name: String ->
        println("Inside lambda function")
        println("Say hello to $name")
    }, "Ninja")
}
```

如果我们在普通函数之前添加 inline 关键字，它不会导致任何性能变化。甚至 Intellij 也会建议去掉。

请记住**内联关键字只应在高阶函数短**时使用。如果高阶函数包含大量代码，那么生成的代码将非常长。

## 摘要

在本教程中，我们讨论了内联函数。他们一开始有点难以理解。添加 inline 关键字的唯一目的是提高性能。

* * *

* * *