# Kotlin 类和对象

> 原文：<https://www.studytonight.com/kotlin/kotlin-class-and-object>

在本教程中，我们将开始讨论 Kotlin 中的面向对象编程。

不同的语言遵循几种类型的编程范例来提供不同的特性。主要的编程范例有:

*   必要的

*   逻辑学的

*   功能的

*   面向对象的

最常用的范例是**面向对象编程**。Kotlin 还提供了**抽象**、**封装**、**继承**等 OOP 特性。以类、对象、接口等形式。但是 Kotlin**并不是一个纯粹的 OOP 语言**，因为它还提供了**功能编程特性**像 **lambdas** 、**高阶函数**等。因此，Kotlin 支持函数式和面向对象编程。

这是一段精彩的视频，解释了基本的 OOPs 概念:

现在我们将讨论 OOPs 的基础知识:**类**和**对象**

实际上，我们可能会发现不同的同类物体，但性质不同。让我们举一个手机的例子。每个手机都有一些属性，如**型号**、**价格**、**颜色**、**尺寸**、**内存**、**内存**等。为了能够定义不同的移动配置，我们必须有一些空白空间来归档，就像一个蓝图，使用它我们可以创建多个移动设备对象。我们可以通过一个类来实现这一点。

该类用于创建对象的**蓝图。让我们继续这个例子，下面我们将定义一个名为**移动**的类，在其中我们将定义它的所有属性和方法，然后我们将创建该类的对象，这些属性有不同的值。把对象看成不同公司提供的手机，或者不同型号的手机，像 **iPhone 11 Pro** 可以是一个对象，**三星 Galaxy S 20** 可以是另一个有自己配置的对象，然后**一加 7** 等等。**

## Kotlin 班

使用`class`关键字定义一个类。创建类的语法是:

```kt
class <class-name> // class header
{
    // class body
}
```

Kotlin 课程有两个主要部分:

*   **类头**:包含类名、主构造器、父构造器等。(我们将在后续教程中了解构造器)

*   **类体**:类体包含属性、方法、二级构造器、init 块等。

我们将在接下来的教程中详细讨论它们。

让我们从创建一个简单的类 **Mobile** 开始。它包含以下属性和方法:

*   **属性:**
    *   品牌

    *   模型

    *   物资需求计划(material requirements planning)

    *   折扣

*   **方法:**
    *   getActualPrice():会返还手机的**折扣价**。

    *   printDetails():该功能将**打印手机**的详细信息。

```kt
class Mobile {
    // brand of type String
    var brand: String = ""
    // model of type String
    var model: String = ""
    // mrp of type float
    var mrp: Float = 0f
    // discount of type float
    var discount: Float = 0f

    fun getActualPrice():Float{
        return mrp - discount
    }

    fun printDetails(){
        println("Mobile details:")
        println("Brand: $brand")
        println("Model: $model")
        println("MRP: $mrp")
        println("Discount: $discount")

    }
} 
```

我们已经创建了一个包含属性和方法的基本类。

关于 Kotlin 课程的要点是:

*   属性必须在创建对象时**初始化。我们已经将`brand` & `model`初始化为空字符串，并将`mrp` & `discount`初始化为 **0** 作为默认值。**

*   默认情况下，Kotlin 中的类是**公共的**。

## Kotlin 类对象

对象是真实世界的实体。它拥有类中声明的所有属性和方法。声明类的对象的语法是:

```kt
var varName = ClassName()
```

我们可以使用`.`(点)运算符来访问一个类的属性和方法。在对象名称后添加`.`和属性/方法名称:

```kt
var varName = ClassName()
varName.property = 0
varName.functionName()
```

让我们创建一个 **Mobile** 类的对象，并调用它的方法:

```kt
fun main() {
    val mobile = Mobile()
    mobile.brand = "iPhone"
    mobile.model = "11 pro"
    mobile.mrp = 100000f
    mobile.discount = 1000f

    println("Discounted price is: ${mobile.getActualPrice()}")

    mobile.printDetails()
}
```

折扣价为:99000.0
手机详情:
品牌:iPhone
型号:11 pro
MRP: 100000.0
折扣:1000.0

**说明:**

*   在第 2 行中，创建了移动类的对象。

*   从第 3 行到第 6 行，提供了所有类属性的值。

*   在第 8 行，使用 getActualPrice()函数打印折扣价。

*   在第 10 行，调用 printDetails()函数。

## 摘要

在本教程中，我们讨论了类和对象。我们创建了一个基本类并创建了它的对象。在下一个教程中，我们将讨论构造器。

* * *

* * *