# Kotlin 伴随对象

> 原文：<https://www.studytonight.com/kotlin/kotlin-companion-object>

在本教程中，我们将了解 Kotlin 伴随对象。在一个类中，属性链接到**对象**，即我们可以使用对象名来访问它们。每个对象都有自己值的所有属性。

可能会有这样一种情况，我们希望类的所有对象都有一些共同的属性。这些类型的属性和方法被称为**类级别字段**。它们由编译器在创建类时初始化，并在类的所有对象之间共享。在 Java 等其他语言中，它们是使用`static`关键字创建的。在 Kotlin 中，**伴随对象**用于声明类级别字段。

## 创建和访问伴随对象

伴随对象是使用`companion`关键字创建的。让我们创建一个类**员工**并创建一个名为**测试**的伴随对象:

```kt
class Employee {
    var salary:Int = 0
    fun printSalary(){
        println("Salary is: ${this.salary}")
    }
    companion object Test{
        var i: Int = 1
        fun printI(){
            println("Value of i: $i")
            i++
        }
    }
}
```

**雇员**类包含一个名为**测试**的`companion`对象，该对象包含一个变量`i`和函数`printI()`。该类还包含一个变量`salary`和一个函数`printSalary()`，可以使用该类的对象进行访问。

使用类名访问伴随对象中的字段。也可以使用类名或对象名来访问它们。让我们在`main()`函数中使用这个类:

```kt
fun main() {
    Employee.printI()       // Access printI() method using class name
    Employee.Test.printI()  // Access printI() method using class name and companion object name
}
```

I 值:1
I 值:2

关于伴随对象的几个要点:

*   使用类名而不是对象名来访问伴随对象。

*   如果缺少伴随对象名称，则为其指定默认名称`Companion`。

*   一个类中只能有**一个伴随对象**。

*   当加载**类**时，伴随对象被**初始化**。

*   If we try to access class level fields using objects or objects fields using the class name, an error will be thrown:

    ```kt
    val employeeObject = Employee()
    employeeObject.printI()        // Error
    Employee.printSalary()         // Error
    ```

## 摘要

在本教程中，我们讨论了 Kotlin 中的伴随对象。它们可以被认为是 Java `static`关键字的替换。它们在创建类时会派上用场。在下一个教程中，我们将讨论 Kotlin 中的获取者和设置者。

* * *

* * *