# Kotlin 获取器和设置器函数

> 原文：<https://www.studytonight.com/kotlin/kotlin-getter-and-setter-functions>

在本教程中，我们将学习 Kotlin 中用于获取类属性值和设置类属性值的获取器和设置器。在前面的教程中，我们看到类内部声明的属性是使用`.`运算符访问的。如果我们有一个定义如下的类**员工**:

```kt
class Employee{
    var salary: Int = 0
    var name: String = ""
}
```

我们可以创建**员工**类的对象，并使用`.`运算符访问属性:

```kt
val employee = Employee()
employee.salary = 340000
employee.name = "Ninja"
println("The salary of ${employee.name} is ${employee.salary}")
```

每当我们试图**获取**或**设置**某个属性的值时，属性不会被直接访问。获取器和设置器函数用于获取和设置属性值。

## 什么是吸气剂和沉降剂？

Getter 和 Setter 是由 Kotlin 为每个类属性默认生成的函数**。它们用于访问该属性。**

如果我们试图调用`classname.property = value`内部调用`set()`函数，如果我们试图使用`classname.property`获取属性值，则内部调用`get()`函数。

### 为什么 Getter 和 Setter 函数？

最好不要将类的变量暴露在它之外。如果您来自 Java，那么您必须已经将类属性声明为私有，并为其创建了获取器和设置器方法。默认情况下，Kotlin 提供此功能。

## Kotlin 的吸气剂和设置剂

默认`get()`和`set()`功能如下:

```kt
class Person{
    var name: String = ""
        get() = field
        set(value) {
            field = value
        }
    val age: Int = 0
        get() = field
}
```

用`var`声明的属性同时具有`get()`和`set()`功能。但是用`val`声明的属性只有`get()`功能。这是因为`val`的值不能重新分配。

`field`关键字用于表示变量。`value`用于表示要分配给变量的值。它也可以改变。这些`get()`和`set()`功能是多余的，因为 Kotlin 默认提供它们。

## 定义自定义获取器和设置器

我们还可以提供**自定义** `get()`和`set()`功能:

```kt
class Person{
    var name: String = ""
        get() {
            println("Inside get() of name")
            return field.toString()
        }
        set(value) {
            println("Inside set() of name")
            if (value.length < 3)
                field = "INVALID NAME"
            else
                field = value
        }
    val age: Int = 18
        get(){ 
            println("Inside get() of age")
            return field
        }
}
```

这里我们为`name`创建了自定义`get()`和`set()`功能，为`age`创建了自定义`get()`。让我们创建这个类的对象并打印输出:

```kt
fun main() {
    val person = Person()
    person.name = "Ninja"       // calls set() function
    println("The age of ${person.name} is ${person.age}")        // calls get() functions 
} 
```

姓名
内定()姓名
内定()年龄
忍者年龄 18

### 摘要

在本教程中，我们讨论了 Kotlin 中的获取器和设置器函数，并**创建了自定义的获取器和设置器**。使用自定义的获取器和设置器，我们可以在给属性赋值之前添加验证，或者对值执行一些操作。我们将在下一个教程中讨论继承。

* * *

* * *