# Kotlin 访问修饰符

> 原文：<https://www.studytonight.com/kotlin/kotlin-access-modifiers>

在本教程中，我们将介绍 Kotlin 中的可见性修改器或访问修改器。访问修饰符或可见性修饰符用于定义类、函数、字段、接口等的范围。可见性修饰符关键字限制类、函数、属性等的使用，并声明它们是否在它们的子类、其他文件、类、其他包中可用。

在 Kotlin 中，可见性修饰符可以应用于类、构造器、对象、接口、函数、属性及其设置器。Getters 与属性具有相同的可见性。

Kotlin 中有四个可见性修饰符:

*   私人的

*   保护

*   内部的

*   公众

**默认可见性修改器是公共的**。这意味着，如果我们没有为类、函数、属性等指定任何可见性修饰符，那么默认情况下，编译器会将其视为公共的。

根据放置位置的不同，可见性修饰符有不同的含义。我们会一个一个来看。

## 顶级字段的可见性修饰符

顶级字段是放置在类或接口之外的字段。它们直接存在于任何 Kotlin 文件中。

对于顶级字段，不同的可见性修饰符意味着:

*   `public` -是默认修饰符，可以省略。这意味着声明随处可见。它们可以用于不同的文件、类、包等。

*   `internal` -内部标记的声明在同一个模块中可见。模块是指一起编译的一组 Kotlin 文件。在项目开发过程中，我们可以在同一个项目中有多个模块。其他模块可以是支持主应用的库或助手应用。

*   `private` -标有`private`的声明仅在同一 Kotlin 文件中可用。它们不能在 T2 之外使用。kt 文件。

受保护的修饰符不适用于顶级字段。

## 类和接口中的可见性修饰符

类中的函数、属性和对象可以访问修饰符。请注意，整个类或接口的可见性取决于它在顶层的可见性修饰符。

类中的可见性修饰符表示:

*   `public` -任何能看到该类的人也能看到它的所有公开声明。这意味着公开声明随处可见。它们在其他文件、类、包甚至模块中都是可见的。

*   `internal` -与顶级字段相同，它们在同一个模块中可见。

*   `protected` -标记有`protected`的声明仅在类及其子类中可见。他们在课外是看不见的。这意味着标有`protected`关键字的函数不能在类或其子类之外使用。

*   `private` -标有`private`关键字的声明仅在该类中可见。它们在类外不可见，甚至在子类中也不可见。

让我们看一个类中可见性修饰符的例子:

```kt
package oop
open class Employee {
    // Function visible only inside class
    private fun privateFunction(){
    }

    // Function visible in same
    internal fun internalFunction(){
    }

    // Function visible everyWhere
    fun publicFunction(){
    }

    // Function visible only in Employee class and its subclasses
    protected fun protectedFunction(){
    }
}

class Developer: Employee() {
    // privateFunction() is not visible here
}

fun main() {
    // privateFunction() and protectedFunction() are not visible here
}
```

*有关继承概念，请参见下一个教程。

### 摘要

在本教程中，我们详细讨论了访问修饰符，即公共、私有、内部和受保护。在下一个教程中，我们将学习 Kotlin 中的继承概念。

* * *

* * *