# Kotlin 抽象类

> 原文：<https://www.studytonight.com/kotlin/kotlin-abstract-class>

在上一个教程中，我们讨论了继承。我们现在就先走一步，讨论一下 Kotlin 中的抽象类。

假设我们有一个类叫做`Shape`。它具有计算形状面积的功能`area()`。现在我们希望每个子类都必须实现这个`area()`函数来计算它们各自的面积。不提供`Shape`类的`area()`法体，我们可以标记为`abstract`。

通过将其标记为**摘要**，我们确保以下内容:

*   现在不需要在`Shape`类中提供`area()`函数的函数定义体。

*   子类**必须覆盖**这个`area()`函数并提供自己的实现，否则编译器会给出错误。

然后如果类像`Square`、`Rectangle`、`Circle`等。继承`Shape`类，这些类必须覆盖`area()`函数，否则编译器会抛出错误。

## Kotlin 抽象类

如果一个类的任何功能都标有`abstract`关键字，那么这个类也应该标有`abstract`关键字。让我们首先看一个抽象类的基本例子:

```kt
abstract class Shape{
    abstract fun area()
}

class Square: Shape() {
    override fun area() {
        println("Area of square: side*side")
    }
}

class Circle: Shape() {
    override fun area() {
        println("Area of circle: 3.14*r*r")
    }
}

fun main() {
    val square = Square()
    val circle = Circle()
    square.area()
    circle.area()
}
```

正方形面积:边*边
圆形面积:3.14*r*r

在这个例子中，我们创建了一个抽象类`Shape`。`Square`类和`Circle`类继承了 Shape 类并覆盖了`area()`方法。

让我们讨论一些关于抽象类的要点:

*   如果一个类有抽象属性或抽象函数，那么这个类必须被标记为抽象的。

*   **抽象类不能被实例化**。这意味着我们不能创建抽象类的对象。

*   不需要在抽象类中添加 open 关键字，因为它们是要被继承的，因此默认情况下是 open。

*   抽象可以具有抽象和非抽象(通常定义的)功能和属性。

*   抽象函数没有主体。

*   在抽象类中，默认情况下所有成员都是非抽象的。我们需要添加`abstract`关键字，让它们变得抽象。

让我们看一个例子来说明以上几点:

```kt
abstract class Shape{
    abstract var sides: Int
    abstract fun area()

    fun sayShape(){
        println("It is a shape...")
    }
}

class Square: Shape() {
    override var sides: Int = 4
    override fun area() {
        println("Area of square: side*side")
    }
}

class Circle: Shape() {
    override var sides: Int = 0
    override fun area() {
        println("Area of circle: 3.14*r*r")
    }
}

fun main() {
    val square = Square()
    val circle = Circle()
    println("Side of square: ${square.sides}")
    println("Side of Circle: ${circle.sides}")
    square.area()
    circle.area()
    square.sayShape()
    circle.sayShape()
}
```

正方形边:4
圆边:0
正方形面积:边*边
圆面积:3.14*r*r
是一个形状...
是一个形状...

## 摘要

在本教程中，我们讨论了抽象类。在下一个教程中，我们将讨论接口及其实现。

* * *

* * *