# Kotlin 接口

> 原文：<https://www.studytonight.com/kotlin/kotlin-interface>

在本教程中，我们将学习 **Kotlin 接口**。Kotlin 中的接口类似于抽象类，但有一些关键区别。

一个接口可以被认为是一个**完全抽象类**。这意味着默认情况下，一个**接口的所有**功能**和**属性**都是抽象的**。

接口用于定义类的**蓝图，这意味着我们可以在接口中提供函数的名称以及函数的完整声明，包括其参数和返回类型，当任何类将**实现**该接口时，该类将必须为这些函数提供定义。**

在 Java 8 之前，**接口中只允许函数声明**。我们无法在接口中定义函数体。但是**在 Java 8** 中，我们得到了功能**来添加功能体也**。Kotlin **默认情况下**提供此功能。因此在 Kotlin 中，**函数在接口**中也可以有一个主体。

这使得接口和抽象类非常相似。抽象类和接口的关键区别是:**一个类只能继承一个抽象类**，但是它**可以继承很多接口**。如果需要继承多个类，那么我们可以选择接口。

## Kotlin 接口

在 Kotlin 中定义接口的语法是:

```kt
interface A{
    var x:Int       // abstract property
    fun sayHello()  // asbtract method
    fun sayBye(){   
        // Default implementation of sayBye()
    }
}
```

默认情况下，接口的所有属性和功能都是抽象的，除非我们提供它们的实现。

## Kotlin:实现接口

接口也是使用用于继承类的相同`:`运算符继承的。让我们创建一个继承接口`A`和`B`的类`C`:

```kt
// first interface
interface A{
    fun sayHelloByA()
    fun sayByeByA(){
        println("Bye from A....")
    }
}
// second interface
interface B{
    fun sayHelloByB()
    fun sayByeByB(){
        println("Bye from B....")
    }
}
// class implementing first and second interface
class C: A,B{
    override fun sayHelloByA() {
        println("Hello from overridden A....")
    }

    override fun sayHelloByB() {
        println("Hello from overridden B....")
    }
}
```

在这个例子中，两个接口`A`和`B`都有**两个功能**:一个是抽象的，一个是默认实现的。类`C`继承了两个接口，并覆盖了它们的抽象函数。

让我们创建类`C`的对象，并调用它的函数:

```kt
fun main() {
    val c = C()
    c.sayHelloByA()
    c.sayHelloByB()
    c.sayByeByA()
    c.sayByeByB()
}
```

超驰 A 的你好....
来自被覆盖的乙的你好....
拜拜....
再见....

### 如果两个接口功能相同？

假设接口`A`和接口`B`都有一个名为`sayHello()`的函数，默认实现。现在如果类`C`继承了两个接口`A`和`B`，那么**就会有冲突**。类`C`会给出一个错误:

```kt
interface A{
    fun sayHello(){
        println("Hello from A....")
    }
}
interface B{
    fun sayHello(){
        println("Hello from B....")
    }
}
class C: A,B {      // Error

}
```

错误:(11，1) Kotlin:类‘C’必须覆盖公共开放趣味 sayHello():A 中定义的单元，因为它继承了它的多个接口方法

这是因为类`C`从接口`A`和`B`获得了方法`sayHello()`的实现。为了解决这个冲突，类`C`必须覆盖`sayHello()`方法并提供其实现:

```kt
interface A{
    fun sayHello(){
        println("Hello from A....")
    }
}
interface B{
    fun sayHello(){
        println("Hello from B....")
    }
}
class C: A,B {
    override fun sayHello() {
        println("Hello from C....")
    }
}

fun main() {
    val c = C()
    c.sayHello()
}
```

你好，来自 C....

### **调用 A 或 B 的实现:**

如果我们想调用`sayHello()`的`A`或`B`实现，而不是提供我们自己的实现，那么我们可以使用`super`关键字和接口名称来调用它，如下所示:

```kt
interface A{
    fun sayHello(){
        println("Hello from A....")
    }
}
interface B{
    fun sayHello(){
        println("Hello from B....")
    }
}
class C: A,B {
    override fun sayHello() {
        super<A>.sayHello()
        super<B>.sayHello()
    }
}

fun main() {
    val c = C()
    c.sayHello()
}
```

你好，来自 A....
你好，来自 B....

## 摘要

在本教程中，我们学习了 Kotlin 中的接口及其实现。我们还看到了如果两个接口有相同的方法声明，如何解决冲突，并且我们讨论了在多个接口的情况下函数调用的顺序。在下一个教程中，我们将讨论嵌套类和内部类。

* * *

* * *