# Kotlin 嵌套类和内部类

> 原文：<https://www.studytonight.com/kotlin/kotlin-nested-and-inner-class>

在本教程中，我们将讨论在 Kotlin 的另一个类中**创建类的两种方法，第一种是 Kotlin**嵌套类**，另一种是 Kotlin**内部类**。**

## Kotlin 嵌套类

我们可以直接在另一个类中创建一个嵌套类。默认情况下，嵌套类本质上是**静态的**。这意味着我们可以使用嵌套类的属性和函数，而无需创建外部类的对象。可以使用`.`运算符直接访问它们。

在嵌套类中:

*   在嵌套类中，我们**不能访问外部类**(动物)的成员。

*   使用`.`运算符直接访问嵌套类成员，而不创建外部类的对象。

以下是嵌套类的**语法**:

```kt
class Outer{
    // Members of Outer class
    class Nested{
        // Members of Nested class
    }
}
```

以及创建嵌套类对象的语法:

```kt
val obj = Outer.Nested()
```

我们可以使用外部类名创建嵌套类的对象。

### Kotlin 嵌套类示例:

让我们举个例子，

```kt
class Animal{
    // outer class property
    val legs = 4
    class Dog{
        // nested class proprty
        val say = "Woof"
        val hasTail = true
        fun tail(){
            println("Dog has tail: $hasTail")
        }
    }
}

fun main() {
    // Creating object of nested class directly
    val dog = Animal.Dog()
    // Accessing inner class
    dog.tail()
    println("Dog says: ${dog.say}")
}
```

狗有尾巴:真
狗说:汪汪

## Kotlin 内班

Kotlin 内部类是使用`inner`关键字创建的。可以认为是**特殊嵌套类**。

在内部类中:

*   内部类维护外部类的一个实例，因此，它可以访问外部类的成员。

*   我们不能在接口或非内部类中声明内部类。

*   我们不能直接创建内部类的对象。它可以使用外部类对象创建。

以下是**语法**:

```kt
class Outer{
    // Members of Outer class
    inner class Inner{
        // Members of Inner class
    }
}
```

为了创建内部类的对象，

```kt
val outerObj = Outer()
// using outer class object to create inner class object
val innerObj = outerObj.Inner()
```

正如您在上面的语法中看到的，我们首先创建外部类的对象，然后使用它来创建内部类的对象。

### Kotlin 内部类示例:

让我们举个例子，

```kt
class Animal{
    // outer class property
    val legs = 4
    inner class Dog{
        // inner class property
        val say = "Woof"
        val hasTail = true
        fun tail(){
            println("Dog has tail: $hasTail")
        }
        fun printLegs(){
            println("No of legs are: $legs")
        }
    }
}

fun main() {
    // Creating object of outer class
    val animal = Animal()
    // Creating object of inner class
    val dog = animal.Dog()
    // Accessing inner class
    dog.tail()
    dog.printLegs()
    println("Dog says: ${dog.say}")

}
```

狗有尾巴:真
腿数:4
狗说:汪汪

## 摘要

在本教程中，我们讨论了 Kotlin 嵌套类和内部类。我们还介绍了如何从`main()`功能访问他们的成员。在下一个教程中，我们将介绍 Kotlin 的数据类。

* * *

* * *