# Kotlin 枚举

> 原文：<https://www.studytonight.com/kotlin/kotlin-enum>

在本教程中，我们将了解 Kotlin Enum。在开发应用时，可能会出现这样一种情况，即我们希望一个变量只具有一组给定的允许值，例如，如果我们有一个变量`pizzaSize`，那么它应该具有以下值:小、中、大。

在 Kotlin 和 Java 中，枚举帮助我们实现了这一点。

在 Kotlin 中，我们可以借助`enum`关键字创建一个**枚举类**。Kotlin 枚举可以有**属性**、**功能**，可以**实现接口**等。

## Kotlin 枚举类

让我们创建一个包含比萨饼大小的简单枚举类:

```kt
enum class pizza{
    SMALL, MEDIUM, LARGE
}
```

让我们在`main()`函数中使用这个枚举:

```kt
fun main() {
    val pizzaSize = pizza.LARGE
    println("Size of pizza ordered is $pizzaSize")
}
```

订购的披萨尺寸很大

每个枚举常量充当一个单独的对象。它们用逗号隔开。在上例中，`SMALL`、`MEDIUM`和`LARGE`为对象。

## Kotlin 枚举:初始化常量

在 Kotlin 枚举中可以有**主构造器**。因为枚举中的常量是实例，所以可以通过向构造器传递值来初始化它们:

```kt
enum class pizza(val diameter: Int){
    SMALL(10),
    MEDIUM(12),
    LARGE(14)
} 
```

让我们在`main()`函数中使用这个枚举:

```kt
fun main() {
    val pizzaSize = pizza.LARGE
    println("Size of pizza ordered is $pizzaSize")
    println("Diameter of LARGE pizza is ${pizzaSize.diameter}")
}
```

点的披萨尺寸大
大披萨的直径是 14

正如您在上面的示例中所看到的，我们在枚举类中包含了更多的数据，并将其与枚举实例相关联。同样，如果我们愿意，我们可以添加更多的信息。

## Kotlin 枚举:实现接口

在 Kotlin 中，我们甚至可以在枚举类中实现一个接口。**常量分别覆盖**接口功能**:**

```kt
// interface for implementing
interface Price{
    fun getPrice(): Int
}

// enum class
enum class pizza(val diameter: Int): Price{
    // enum constant implementing interface function
    SMALL(10){
        override fun getPrice(): Int {
            return 250
        }
    },
    MEDIUM(12){
        override fun getPrice(): Int {
            return 450
        }
    },
    LARGE(14){
        override fun getPrice(): Int {
            return 600
        }
    }
}
```

现在我们可以使用枚举常量访问这些函数:

```kt
fun main() {
    val pizzaSize = pizza.LARGE
    println("Size of pizza ordered is $pizzaSize")
    println("Diameter of LARGE pizza is ${pizzaSize.diameter}")
    println("Price of LARGE pizza is ${pizzaSize.getPrice()}")
}
```

点的披萨尺寸大
大披萨直径 14
大披萨价格 600

因此，使用这种方法，我们甚至可以向枚举常量提供函数，以便在代码需要时提供任何逻辑。

通过首先定义一个 [Kotlin 接口](https://www.studytonight.com/kotlin/kotlin-interface)，然后在我们的枚举类中使用它，我们可以对我们定义的枚举常量有更多的控制，甚至可以在其中包含更多的信息。

## Kotlin 枚举:`values`和`valueOf`功能

在 Kotlin 中，默认情况下，我们在每个枚举中都有两个函数。`values()`函数**返回一个包含枚举类所有常量的数组**。使用`valueOf(name: String)`函数，我们可以使用枚举常量的字符串值获得常量。

让我们使用`values`和`valueOf`功能:

```kt
fun main() {
    for(pizza in pizza.values()){
        println(pizza)
    }
    val largePizza = pizza.valueOf("LARGE")
    println("Diameter: ${largePizza.diameter}")
}
```

小
中
大
直径:14

在上面的代码示例中，我们使用`values()`函数获取所有枚举值，然后使用 for 循环迭代这些值，最后使用`valueOf`函数使用其字符串值获取枚举常量。

## 摘要

在本教程中，我们了解了 Kotlin Enums 及其用法。在下一个教程中，我们将讨论 Kotlin Sealed 类。

* * *

* * *