# Kotlin 泛型

> 原文：<https://www.studytonight.com/kotlin/kotlin-generics>

在本教程中，我们将学习 Kotlin 泛型。泛型的概念允许我们使我们的类和函数数据类型独立。

让我们考虑一个场景，其中我们想要创建一个具有一些功能的类。该类的功能适用于特定的数据类型:`String`。现在需要同样的函数来支持数据类型`Int`。那你会怎么做？为此创建一个新的函数，或者创建一个新的类。嗯！使用泛型，您可以使用相同的类、相同的函数，并通过使函数通用来处理任何数据类型。

泛型允许我们定义**类、函数和属性**，可以使用不同的数据类型访问**。泛型声明的数据类型是在编译时**检查的**。因此，如果有任何错误，那么它将只在编译时给出。**

泛型类型类和函数使用尖括号 **`<>`定义为**参数化类型**。**

## Kotlin 参数化类

让我们创建一个参数化的类，它有一些函数:

```kt
class Rank<T>(var rank: T){
    fun printRank(name: String) {
        println("The rank of $name is $rank")
    }
}

fun main(){
    val rank = Rank<Int>(12)
    rank.printRank("Ninja")

    val rankNew = Rank<String>("First")
    rankNew.printRank("New Ninja")
}
```

忍者等级为 12
新忍者等级为第一

在这个例子中，我们创建了一个参数化的类`Rank`。它以同类型`T`的参数`rank`作为类类型。它包含一个打印等级的函数。在`main()`函数中，我们创建了两个等级类的对象。第一个对象是`Int`类型，第二个对象是`String`类。

事实上，编译器也可以通过传递的构造器参数的数据类型，使用**类型推断**来解释类的数据类型。因此，这段代码也将像上面的代码一样工作:

```kt
fun main(){
    val rank = Rank(12)
    rank.printRank("Ninja")

    val rankNew = Rank("First")
    rankNew.printRank("New Ninja")
}
```

忍者等级为 12
新忍者等级为第一

## Kotlin 参数化函数

同样，我们也可以创建通用函数:

```kt
fun <T>printMessage(message:T) {
    println("Message is: $message")
}
fun main(){
    printMessage("Hello World!!")
    printMessage(123)
    val map = mapOf("Maths" to 1, "Science" to 2, "English" to 3)
    printMessage(map)
}
```

消息是:你好世界！！
消息为:123
消息为:{数学=1，科学=2，英语=3}

在本例中，我们创建了一个`printMessage()`函数，该函数获取通用数据类型参数并打印它们。

## 摘要

在本教程中，我们学习了 Kotlin 中泛型的基础知识。在下一个教程中，我们将学习 Kotlin 中的扩展函数。

* * *

* * *