# Kotlin 扩展函数

> 原文：<https://www.studytonight.com/kotlin/kotlin-extension-function>

在本教程中，我们将讨论 Kotlin 中的扩展函数。Kotlin 提供了向现有类添加新功能的功能。为此，没有必要继承它们。可以通过名为**扩展**的特殊声明来实现。

## Kotlin 扩展函数

Kotlin Extensions 提供了向现有类添加新函数的功能。该功能称为**扩展功能**。我们可以向**用户定义类**以及**库类**添加扩展函数。

让我们创建一个类**兴趣计算器**，它包含一个函数`simpleInterest()`来计算简单的兴趣:

```kt
class InterestCalculator(var principal: Double, var rate: Double, var time: Double){
    fun simpleInterest(): Double{
        return this.principal * this.rate * this.time * 0.01
    }
}
```

假设，稍后我们想要添加计算复利的功能，但是类结构不能改变。在这个场景中，我们可以使用扩展函数。

在类名后使用`.`运算符添加扩展函数。以下是为类添加扩展函数的**语法:**

```kt
fun ClassName.functionName(): returnType {
    // body of function
}
```

让我们给**兴趣计算器**类添加一个扩展函数`compoundInterest()`并调用它。扩展函数的调用方式与类函数的调用方式相似。

下面是代码:

```kt
fun InterestCalculator.compoundInterest(): Double {
    val amount = this.principal * Math.pow(1 + (this.rate / 100), this.time)
    return amount - this.principal

}
fun main() {
    val educationLoanCalculator = InterestCalculator(100000.0, 11.0, 4.0)
    println("Simple interest for this education loan is ${educationLoanCalculator.simpleInterest()}")
    println("Compound interest for this education loan is ${educationLoanCalculator.compoundInterest()}")
}
```

本教育贷款单利为 44000.0
本教育贷款复利为 51807.04100000056

同样，我们也可以给任何库类添加**扩展函数。**

## 伴随对象的扩展功能

我们还可以向类中的伴随对象添加一个扩展函数。让我们编辑**兴趣计算器**类，并添加一个包含函数`printSimpleInterestFormula()`的**伴随对象**:

```kt
class InterestCalculator(var principal: Double, var rate: Double, var time: Double){
    fun simpleInterest(): Double{
        return this.principal * this.rate * this.time * 0.01
    }
    companion object {
        fun printSimpleInterestFormula(){
            println("Simple interest formula is: principal * rate * time * 0.01")
        }
    }
}
```

现在向伴随对象添加一个函数`printCompoundInterestFormula()`，并从`main()`函数调用它:

```kt
fun InterestCalculator.Companion.printCompoundInterestFormula(){
    println("Compound interest formula is: principal * ( 1 + rate / 100) ^ time")
}
fun main() {
    InterestCalculator.printSimpleInterestFormula()
    InterestCalculator.printCompoundInterestFormula()
}
```

单利公式为:本金*利率*时间* 0.01
复利公式为:本金* ( 1 +利率/ 100) ^时间

## 摘要

在本教程中，我们学习了 Kotlin 中的扩展函数，如果您想为不同库中的任何类添加更多的功能，这将非常有用。扩展函数主要用于库类。从下一个教程中，我们开始学习 Kotlin 中的异常处理。

* * *

* * *