# Kotlin `try-catch`

> 原文：<https://www.studytonight.com/kotlin/kotlin-try-catch>

在本教程中，我们将了解 Kotlin 中的`try`和`catch`块，以及我们如何使用它们来处理运行时可能导致异常/错误的代码。`try`和`catch`块用于处理异常。可能抛出异常的代码放在`try`块内，由`try`块抛出的异常使用`catch`块捕获。

让我们看看在 Kotlin 中使用`try`和`catch`块的语法。

### Kotlin `try` & `catch`块

`try-catch`块的**语法**是:

```kt
try {
    // The code which may throw an error
}catch (e: SomeException){
    // Handling the exception 
}
```

在上面的语法中， **SomeException** 是异常类的名称。您可以提供父类的名称来捕获单个 catch 块中的多个子类异常类，或者提供某个特定异常类的名称来处理单个异常。

### Kotlin `try`&`catch`——例子

让我们首先看看一个会抛出异常的程序，如果我们不处理它会发生什么:

```kt
fun main() {
    val a: Int = 101
    val b: Int = 0
    println("Division of $a and $b is: ${a/b}")
}
```

线程“main”Java . lang . arithmetic 异常:/在 Try_catchKt.main(try-catch.kt:4)
在 Try _ catch kt . main(Try-catch . kt)被零
取代

这里我们得到了`ArithmeticException`，因为我们试图将一个数除以零。

让我们使用`try`和`catch`块来处理这个异常:

```kt
fun main() {
    val a: Int = 101
    val b: Int = 0
    try {
        println("Division of $a and $b is: ${a/b}")
    }catch (exception: ArithmeticException){
        println("Exception is handled....")
        println("$a and $b cannot be divided!!")
    }
}
```

异常被处理....
101 和 0 不能分！！

在上面的代码中，我们已经特别提到了在我们的`catch`块中捕捉`ArithmeticException`。如果我们的代码有更多的逻辑，并且一些其他的语句导致了一些非`ArithmeticException`类型的异常，那么我们的程序将会再次突然停止执行异常消息。

所以我们必须**找到合适的异常类来捕捉**。

## Kotlin `try` & `catch`的表达

Kotlin `try-catch`区块的独特之处在于可以**作为表达**。这意味着它将返回值。`try`和`catch`块的最后语句被认为是返回值。

让我们编写一个程序，将两个数字相除，并将结果赋给`res`变量。如有异常，我们将`-1`分配给`res`:

```kt
fun main() {
    val a: Int = 100
    val b: Int = 10
    val res: Int = try {
         a/b
    }catch (exception: ArithmeticException){
        -1
    }
    println("The result is: $res")
}
```

结果是:10

现在将`b`的值改为`0`，输出将是:

结果为:-1

## 摘要

在本教程中，我们学习了 Kotlin 中简单的`try-` `catch`块以及如何使用它们。在下一个教程中，我们将学习如何使用多个`catch`块，根据异常类型不同地处理异常。

* * *

* * *