# Kotlin 多重`catch`块

> 原文：<https://www.studytonight.com/kotlin/kotlin-multiple-catch-blocks>

在本教程中，我们将学习如何以及为什么在 Kotlin 中使用多个`catch`块和`try`块来处理异常。一个`try`区块可以有多个`catch`区块。多个 catch 块用于捕获不同类型的异常。

**多重`catch`块**的语法是:

```kt
try {
    // Code which may throw multiple exceptions
}catch (exception: ExceptionType1){
    // Handling exception
}catch (exception: ExceptionType2){
    // Handling exception
}catch (exception: ExceptionType3){
    // Handling exception
}
```

如上所述，我们为每个`catch`块指定了不同的异常类型。多个`catch`块用于不同地处理不同类型的异常，例如，在不同的异常情况下为用户打印不同的消息。

### Kotlin 多重`catch`块-示例

让我们首先看一个例子，在这个例子中，我们将捕捉多个异常。我们将从用户那里获得两个数字作为输入，并对它们进行划分:

```kt
fun main() {
    try {
        val a: Int = Integer.parseInt(readLine())
        val b: Int = Integer.parseInt(readLine())
        println("The Division of $a and $b is: ${a/b}")
    }catch (exception: NumberFormatException){
        println("Caught NumberFormatException: Numbers entered are invalid!!")
    }catch (exception: ArithmeticException){
        println("Caught ArithmeticException: Divided by zero!!")
    }catch (exception: Exception){
        println("Caught Exception!!")
    }

}
```

这里我们抓到了`NumberFormatException`、`ArithmeticException`和`Exception`将军。对于不同的输入，输出为:

*   a = 10, b = 5

    10 和 5 的除法是:2

*   a = 10, b = 0

    捕捉到算术异常:被零除！！

*   a = 10, b = "Hello"

    捕获的数字格式异常:输入的数字无效！！

正如您在上面的代码示例中看到的，我们已经处理了 3 个异常，使用了 3 个不同的`catch`块。我们已经习惯了特定的异常类，即`NumberFormatException`和`ArithmeticException`，它们将处理特定的用例。

然后我们有第三个带有`Exception`类的 catch 块，它是许多异常类的父类。多个`catch`区块中**异常**的顺序也很重要。

*   `catch`区块的顺序必须是**特定于**将军。特定的异常必须先被捕获(就像我们`NumberFormatException`和`ArithmeticException`一样)，然后广义的异常应该最后被捕获。
    如果我们将`Exception`类放在第一位，所有其他异常将仅被该 catch 块捕获。

*   另一个需要记住的要点是，只有**一个`catch`区块会被执行**。一次只能出现一个异常，并执行该特定异常的`catch`块。

## 摘要

在本教程中，我们学习了如何在 Kotlin 中使用多个`catch`块来处理多个不同的异常类型。在下一个教程中，我们将讨论 Kotlin 中嵌套的`catch`块。

* * *

* * *