# Kotlin `finally`块

> 原文：<https://www.studytonight.com/kotlin/kotlin-finally-block>

在本教程中，我们将了解 Kotlin 中的`finally`块，以及它在 Kotlin 的异常处理中扮演什么角色。`finally`块用于执行重要的清理操作，以防代码执行被异常中断。

`finally`块可以放在`catch`块之后，也可以直接放在`try`块之后。与`catch`街区不同的是，**只能有一个`finally`街区**。

## Kotlin `finally` 关键字

`try-finally`块的**语法**是:

```kt
try {
  // Code to be executed  
}finally {
    // Body of finally block
}
```

`try-catch-finally`块的**语法**是:

```kt
try {
    // Code to be executed
}catch (exception: SomeException) {
    // Body of Exception
}
finally { 
    // Body of finally block
}
```

在以下情况下将执行`finally`块:

1.  完全不会出现异常。

2.  异常发生并得到处理。

3.  异常发生并且没有被处理。

让我们看看他们每个人的例子。

### Kotlin `finally`:完全没有异常发生

在这种情况下，异常不会发生，但将执行`finally`块:

```kt
fun main() {
    try {
        val a: Int = 10
        val b: Int = 5
        println("Division of $a and $b results in: ${a/b}")
    }catch (exception: ArithmeticException) {
        println("Division by zero!!")
    }
    finally {
        println("Finally block is always executed.")
    }
}
```

10 和 5 的除法结果为:2
最终总是执行块。

### Kotlin `finally`:异常发生并处理

在这种情况下，异常发生并由`catch`块处理。最后，执行`finally`块:

```kt
fun main() {
    try {
        val a: Int = 10
        val b: Int = 0
        println("Division of $a and $b results in: ${a/b}")
    }catch (exception: ArithmeticException) {
        println("Division by zero!!")
    }
    finally {
        println("Finally block is always executed.")
    }
}
```

除以零！！
最终始终执行块。

### Kotlin `finally`:？？？？？？？异常发生并且没有被处理

出现异常，但没有处理。程序将停止工作，但将执行`finally`块:

```kt
fun main() {
    try {
        val a: Int = 10
        val b: Int = 0
        println("Division of $a and $b results in: ${a/b}")
    } finally {
        println("Finally block is always executed.")
    }
}
```

最后始终执行块。
线程“main”中的异常 Java . lang . arithmetic 异常:/在 finallykt . main(finallykt . main:5)被零
取代
在 FinallyKt.main(finally.kt)

## 什么时候用 Kotlin `finally`？

如果你想知道我在哪里可以使用这个`finally`块，那么这里有几个强有力的竞争者:

1.  在发生异常之前关闭代码执行期间打开的文件。

2.  关闭数据库连接(如果已创建)。

3.  通过发送电子邮件向开发团队报告执行情况，或者可能将异常存储在数据库中以供以后分析。

4.  如果你有一个支付系统，在执行过程中出现异常，那么`finally`块可以用来做代币的清理，状态维护等。

说到使用`finally`区块，这只是冰山一角。

## 摘要

在本教程中，我们学习了如何以及为什么在异常处理期间使用 Kotlin 中的`finally`块。在下一个教程中，我们将看到如何使用`throw`关键字故意**抛出异常**。

* * *

* * *