# Kotlin 列表

> 原文：<https://www.studytonight.com/kotlin/kotlin-list>

在本教程中，我们将讨论 Kotlin 列表。列表包括:

*   元素的有序集合。

*   排序是通过索引(与数组相同)来维护的。

*   一个元素在列表中可以出现多次。

*   可变列表可以被认为是一个动态数组，其大小可以改变。

在 Kotlin，我们可以有一个**可变**列表和一个**不可变**列表。

## Kotlin 不可变列表

使用`List`接口创建不可变列表。`List`接口继承了`Collection`接口。它包含许多有用的功能，如`contains()`、`indexOf()`、`isEmpty()`等。我们将借助一个例子来看它们。

在 Kotlin 中，我们可以使用`listOf()`和`listOf<T>()`函数创建不可变列表。`listOf()`函数用于创建一个通用列表，该列表可以包含任何对象，如整数、字符串、浮点数等。`listOf<T>()`用于创建特定类型的列表。

让我们使用这两个函数创建列表:

```kt
fun main() {
    var genericList = listOf("Ninja", 10, 1.05f, 'a')
    var specificList = listOf<String>("Ninja", "Study", "tonight")
    println("Printing $genericList")
    println("Printing $specificList")
}
```

印刷【忍者，10，1.05，a】
印刷【忍者，今晚学习】

这里我们已经创建了两个列表，一个是泛型，一个是字符串。

### Kotlin 遍历列表:

```kt
fun main() {
    val list = listOf<String>("Ninja", "Study", "tonight", "Ninja", "Kotlin")
    // printing list
    for (element in list)
        println(element)
}
```

忍者
今晚学习

忍者
Kotlin

## Kotlin 列表函数和属性

`List`接口提供的一些重要功能和属性有:

**属性**:

*   `size`:表示列表中存在的元素数量。

*   `lastIndex`:表示列表中最后一个元素的索引。

**功能**:

*   `get(index)`:返回列表中指定索引处的元素或抛出`IndexOutOfBoundsException`。

*   `contains(element)`:如果列表中存在元素，则返回 true，否则返回 false。

*   `indexOf(element)`:返回列表中指定元素第一次出现的索引，如果列表中不包含指定元素，则返回-1。

*   `lastIndexOf(element)`:返回列表中指定元素最后一次出现的索引，如果列表中不包含指定元素，则返回-1。

*   `first()`:返回列表中的第一个元素，如果列表为空则抛出`NoSuchElementException`。

*   `last()`:返回列表中的最后一个元素，如果列表为空则抛出`NoSuchElementException`。

*   `isEmpty()`:如果列表为空则返回真，否则返回假。

*   `subList(start, end)`:返回开始(包含)和结束(不包含)之间的子列表。

同样的例子是:

```kt
fun main() {
    val list = listOf<String>("Ninja", "Study", "tonight", "Ninja", "Kotlin")
    // Properties
    println("The size of list is: ${list.size}")
    println("The index of last element is: ${list.lastIndex}")

    // Functions
    println("Element at index 2 is: ${list.get(2)}")
    println("Element at index 3 is: ${list[3]}")     // Other way to get an element

    println("Does Ninja exist in list: ${list.contains("Ninja")}")
    println("Does Hatori exist in list: ${list.contains("Hatori")}")

    println("The first index of Ninja is: ${list.indexOf("Ninja")}")
    println("The first index of Hatori is: ${list.indexOf("Hatori")}")

    println("The last index of Ninja is: ${list.lastIndexOf("Ninja")}")
    println("The last index of Hatori is: ${list.lastIndexOf("Hatori")}")

    println("First element in list: ${list.first()}")
    println("Last element in list: ${list.last()}")

    println("Is list empty: ${list.isEmpty()}")

    println("Sublist from index 1 to 3 ${list.subList(1,3)}")

}
```

列表大小为:5
最后一个元素的索引为:4
索引处的元素为:今夜
索引处的元素为:忍者
列表中是否存在忍者:真
列表中是否存在哈托利:假
忍者第一个索引为:0
哈托利第一个索引为:-1
忍者最后一个索引为:3
哈托利最后一个索引为:-1
列表中第一个元素:忍者
列表中最后一个元素:Kotlin
列表是否为空:假
从索引 1 到 3 的子列表【今晚学习】

## Kotlin 可变列表

使用`MutableList`接口创建可变列表。`MutableList`接口也继承了`Collection`接口。可变列表本质上是动态的。在可变列表声明之后，我们可以在可变列表**中添加或删除元素。因此可变列表的大小不是固定的。**

与不可变列表类似，可变列表是使用`mutableListOf()`和`mutableListOf<T>()`函数创建的。`mutableListOf()`函数用于创建一个通用列表，该列表可以包含任何对象，如整数、字符串、浮点数等。`mutableListOf<T>()`用于创建特定类型的列表。

让我们使用这些方法创建可变列表:

```kt
fun main() {
    var genericList = mutableListOf("Ninja", 10, 1.05f, 'a')
    var specificList = mutableListOf<String>("Ninja", "Study", "tonight")
    println("Printing $genericList")
    println("Printing $specificList")
}
```

印刷【忍者，10，1.05，a】
印刷【忍者，今晚学习】

存在于不可变列表中的所有属性和方法也存在于可变列表中。可变列表有一些额外的功能来支持可变性:

*   `add(element)`:将指定的元素添加到列表的末尾。

*   `add(index, element)`:在列表中指定的索引处插入一个元素。

*   `remove(element)`:从列表中删除第一个出现的元素。

*   `removeAt(index)`:从列表中删除指定索引处的元素。

*   `set(index, element)`:用指定的元素替换列表中指定索引处的元素。

*   `clear()`:移除列表中的所有元素。

使用这些方法的示例:

```kt
fun main() {
    val list = mutableListOf<String>("Ninja", "Study", "tonight", "Ninja", "Kotlin")
    // New Functions
    list.add("Java")
    println(list)
    list.add(2, "C++")
    println(list)
    list.remove("Ninja")
    println(list)
    list.removeAt(1)
    println(list)
    list.set(1, "PHP")
    println(list)
    list.clear()
    println(list)
}
```

【忍者，学习，今晚，忍者，Kotlin，Java】
【忍者，学习，C++，今晚，忍者，Kotlin，Java】
【学习，C++，今晚，忍者，Kotlin，Java】
【学习，今晚，忍者，Kotlin，Java】
【学习，PHP，忍者，Kotlin，Java】
【】

## 摘要

在本教程中，我们学习了不可变和可变列表，它们的创建使用了`listOf()`和`mutableListOf()`函数以及提供的一些重要函数。在下一个教程中，我们将讨论 Kotlin 的映射。

* * *

* * *