# Kotlin 映射

> 原文：<https://www.studytonight.com/kotlin/kotlin-map>

在本教程中，我们将讨论 Kotlin 映射。映射用于存储**键和值对**。键和值都是用户定义的。在映射中:

*   密钥应该是唯一的，并且每个唯一的密钥只能存储一个值。

*   值可以重复。

*   键和值可以是不同的数据类型。

*   `to`关键字用于将一个键映射到一个值。

*   键值对也称为条目。

在 Kotlin，我们既可以有一张**可变**映射，也可以有一张**不可变**映射。

## Kotlin 不可变映射

使用`Map<K, V>`接口创建不可变映射。我们只能从不可变的映射中阅读。

在 Kotlin 中，不可变映射是使用`mapOf()`和`mapOf<K, V>()`函数创建的。与列表类似，`mapOf()`函数用于创建一个通用映射，其中键和值可以是任何数据类型。`mapOf<K, V>()`用于创建一个特定的映射，分别具有 K 和 V 数据类型的键和值。

让我们使用这两个函数创建不可变的映射:

```kt
fun main() {
    val generalMap = mapOf("Rank" to 1, 1 to "First", 'A' to "Excellent")
    val specificMap = mapOf<String, Int>("Physics" to 80, "Maths" to 97, "C++" to 89)
    println(generalMap)
    println(specificMap)
}
```

{Rank=1，1 =第一，A =优秀}
{物理=80，数学=97，C++=89}

让我们使用`for`和`forEach`循环迭代这些映射:

```kt
fun main() {
    val generalMap = mapOf("Rank" to 1, 1 to "First", 'A' to "Excellent")
    val specificMap = mapOf<String, Int>("Physics" to 80, "Maths" to 97, "C++" to 89)
    for ((k,v) in generalMap) {
        println("Key is: $k and Value is $v")
    }
    specificMap.forEach { (k, v) ->
        println("Key is: $k and Value is $v")
    }
}
```

键为:秩和值为 1
键为:1 和值为第一
键为:A 和值为优秀
键为:物理和值为 80
键为:数学和值为 97
键为:C++和值为 89

## Kotlin 映射的性质和函数

`Map`接口提供的一些重要功能和属性有:

**属性**:

*   `size`:返回映射的大小。

*   `entries`:返回映射中所有键值对的集合。

*   `keys`:返回映射中所有按键的集合。

*   `values`:返回映射中所有值的集合。

**功能**:

*   `get(key)`:返回对应键的值。如果键不存在，则返回 null。

*   `getValue(key)`:返回给定键的值，如果映射中没有这样的键，则抛出`NoSuchElementException`异常。

*   `contains(key)`:如果映射包含指定的键，则返回真，否则返回假。

*   `containsKey(key)`:如果映射包含指定的键，则返回真，否则返回假。这个函数与前面的函数相同。

*   `containsValue(value)`:如果映射中存在一个或多个指定值的关键点，则返回真。

*   `getOrDefault(key, defaultValue)`:返回该键对应的值，如果映射中没有该键，则返回`defaultValue`。

使用这些方法和属性的示例如下:

```kt
package collections

fun main() {
    val marks = mapOf<String, Int>("Physics" to 80, "Maths" to 97, "C++" to 89, "Chemistry" to 95)

    // Properties
    println("Size of map: ${marks.size}")
    println("Set of entries: ${marks.entries}")
    println("Set of keys: ${marks.keys}")
    println("Set of values: ${marks.values}")

    // Methods
    println("Marks in Physics: ${marks.get("Physics")}")
    println("Marks in English: ${marks["English"]}")
    println("Marks in Maths: ${marks.getValue("Maths")}")

    println("Does map contains Physics: ${marks.containsKey("Physics")}")
    println("Does map contains C++: ${marks.contains("C++")}")
    println("Does map contains Chemistry: ${"Chemistry" in marks}")

    println("Does any subject has 100 marks: ${marks.containsValue(100)}")

    println("Marks in English: ${marks.getOrDefault("English",0)}")
}
```

映射大小:4
条目集:【物理=80，数学=97，C++=89，化学= 95】
键集:【物理，数学，C++，化学】
值集:【80，97，89，95】
物理分:80
英语分:空
数学分:97
映射是否包含物理:真
映射是否包含 C++:真
映射是否包含

## Kotlin 可变映射

可变映射使用`MutableMap` 接口创建。可变映射支持动态特性。在可变映射声明之后，我们可以在其中添加、删除或更新条目。因此可变映射的大小不是固定的。

可变映射使用`mutableMapOf()`和`mutableMapOf<K, V>()`功能创建。`mutableMapOf()`功能用于创建一个通用映射，`mutableMapOf<K, V>()`用于创建一个特定键和值数据类型的映射。

让我们使用以下方法创建可变映射:

```kt
fun main() {
    val generalMap = mutableMapOf("Rank" to 1, 1 to "First", 'A' to "Excellent")
    val specificMap = mutableMapOf<String, Int>("Physics" to 80, "Maths" to 97, "C++" to 89)
    println(generalMap)
    println(specificMap)
}
```

{Rank=1，1 =第一，A =优秀}
{物理=80，数学=97，C++=89}

我们可以像迭代不可变映射一样迭代可变映射。

不可变映射中存在的所有属性和方法在可变映射的情况下也存在。可变映射有一些额外的功能来支持动态特性。它们是:

*   `put(key, value)`:将指定的键值对添加到映射中。如果键已经存在，它将替换该值。

*   `putIfAbsent(key, value)`:仅当键之前不存在时，将指定的键值对添加到映射中。

*   `replace(key, newValue)`:用新值替换指定键的值。

*   `replace(key, oldValue, newValue)`:仅当键和旧值对存在时，用新值替换指定键的旧值。

*   `remove(key)`:从映射中移除带有指定键的条目。

*   `remove(key, value)`:如果存在具有指定键和值的条目，则从映射中移除条目。

*   `clear()`:从映射中移除所有条目。

使用这些方法的示例:

```kt
fun main() {
    val marks = mutableMapOf<String, Int>("Physics" to 80, "Maths" to 97, "C++" to 89, "Chemistry" to 95)

    marks.put("C++", 92)
    println(marks)
    marks["Chemistry"] = 93
    println(marks)
    marks.putIfAbsent("English", 95)
    marks.putIfAbsent("Physics", 0)
    println(marks)
    marks.replace("Maths", 70)
    println(marks)
    marks.replace("Maths", 70, 95)
    println(marks)
    marks.remove("C++")
    println(marks)
    marks.remove("Maths", 95)
    println(marks)
    marks.clear()
    println(marks)
}
```

{物理=80，数学=97，C++=92，化学=95}
{物理=80，数学=97，C++=92，化学=93 }
{物理=80，数学=97，C++=92，化学=93，英语= 95 }
{物理=80，数学=70，C++=92，化学= 93，英语= 95 }
{物理=80，数学= 95 }

## 摘要

在本教程中，我们讨论了不可变和可变映射，它们的创建使用了`mapOf()`和`mutableMapOf()`函数以及提供的一些重要函数。在下一个教程中，我们将讨论 Kotlin 中的集合。

* * *

* * *