# Kotlin 集合

> 原文：<https://www.studytonight.com/kotlin/kotlin-set>

在本教程中，我们将讨论 Kotlin 集。集合有:

*   元素的无序集合。

*   集合中不允许有重复的元素。

在 Kotlin，我们既可以有一个**可变**集，也可以有一个**不可变**集。

## Kotlin 不变集

使用`Set`接口创建不可变集。`Set`接口继承了`Collection`接口。

在 Kotlin 中，我们可以使用`setOf()`和`setOf<T>()`函数创建不可变集。`setOf()`函数用于创建一个通用集合，该集合可以包含任何对象，如整数、字符串、浮点数等。`setOf<T>()`用于创建一组特定类型。

让我们使用这两个函数创建集合:

```kt
fun main() {
    val genericSet = setOf("Hello", 1, "Bye", 'A', "Hello")
    val specificSet = setOf<String>("C++", "Maths", "English")
    println(genericSet)
    println(specificSet)
}
```

【你好，1，拜拜，A】
【c++，数学，英语】

这里我们已经创建了两个集合，一个是泛型类型，一个是字符串。

迭代一个集合:

```kt
fun main() {
    val genericSet = setOf("Hello", 1, "Bye", 'A', "Hello")
    for (item in genericSet)
        println(item)
}
```

你好
1
再见
A

## Kotlin 集的性质和函数

`Set`接口提供的一些重要功能和属性有:

**属性**:

*   `size`:表示集合中存在的元素数量。

**功能**:

*   `elementAt(index)`:返回集合中指定索引处的元素或抛出`IndexOutOfBoundsException`。

*   `contains(element)`:如果元素存在于集合中，则返回`true`或者返回`false`。

*   `indexOf(element)`:返回集合中指定元素的索引，如果集合中不存在指定元素，则返回`-1`。

*   `lastIndexOf(element)`:返回集合中指定元素最后一次出现(或唯一一次出现)的索引，如果集合中不存在指定元素，则返回`-1`。

*   `first()`:返回集合中的第一个元素，如果集合为空，则抛出`NoSuchElementException`。

*   `last()`:返回集合中的最后一个元素，如果集合为空，则抛出`NoSuchElementException`。

*   `isEmpty()`:如果设置为空则返回`true``false`。

*   `count()`:返回该集合中的元素个数。

*   `max()`:返回最大的元素，如果没有元素则返回`null`。

*   `min()`:返回最小的元素，如果没有元素则返回`null`。

*   `sum()`:返回集合中所有元素的总和。

*   `average()`:返回该集合中所有元素的平均值。

同样的例子是:

```kt
fun main() {
    val languages = setOf<String>("Kotlin", "C++", "C", "Java", "Angular", "Kotlin")
    val marks = setOf<Int>(95,96,94,90)

    // Properties
    println("The size of set is: ${languages.size}")

    // Functions
    println("Does Java exist in set: ${languages.contains("Java")}")
    println("Does PHP exist in set: ${languages.contains("PHP")}")
    println("Element at index 1: ${languages.elementAt(1)}")

    println("The index of Kotlin is: ${languages.indexOf("Kotlin")}")
    println("The index of PHP is: ${languages.indexOf("PHP")}")

    println("The last index of Kotlin is: ${languages.lastIndexOf("Kotlin")}")

    println("First element in set: ${languages.first()}")
    println("Last element in set: ${languages.last()}")

    println("Is set empty: ${languages.isEmpty()}")

    // Mathematical functions
    println("No. of elements in set: ${marks.count()}")
    println("Max element in set: ${marks.max()}")
    println("Min element in set: ${marks.min()}")
    println("Sum of elements in set: ${marks.sum()}")
    println("Average of elements in set: ${marks.average()}")
}
```

集合的大小为:5
集合中是否存在 Java:true
集合中是否存在 PHP:false
索引处的元素:c++
Kotlin 的索引为:0
PHP 的索引为:-1
Kotlin 的最后一个索引为:0
集合中的第一个元素:Kotlin
集合中的最后一个元素:Angular
被设置为空:false
集合中的元素个数:4
集合中的 Max 元素:

## Kotlin 可变集

使用`MutableSet`接口创建可变集。`MutableSet`接口也继承了`Collection`接口。可变集合本质上是动态的。我们可以在可变集合声明之后，在可变集合**中添加或移除元素。因此可变集合的大小不是固定的。**

与不可变集类似，可变集是使用`mutableSetOf()`和`mutableSetOf<T>()`函数创建的。`mutableSetOf()`功能用于创建通用集合，而`mutableSetOf<T>()`用于创建特定类型的集合。

让我们使用这些方法创建可变集:

```kt
fun main() {
    val generalSet = mutableSetOf("Kotlin", 10, 1.0f, 'A', "Kotlin")
    val specificSet = mutableSetOf<String>("Kotlin", "C++", "C", "Java", "Angular", "Kotlin")
    println(generalSet)
    println(specificSet)
}
```

【kot Lin，10，1.0，a】【kot Lin，C++，c，Java，角度】

不可变集合中存在的所有属性和方法在可变集合的情况下也存在。可变集合有一些额外的功能来支持可变性:

*   `add(element)`:将指定的元素添加到集合中。如果元素已经添加，返回`true`，如果元素已经包含在集合中，返回`false`。

*   `remove(element)`:从集合中移除元素。

*   `clear()`:移除集合中的所有元素。

使用这些方法的示例:

```kt
fun main() {
    val languages = mutableSetOf<String>("Kotlin", "C++", "C", "Java", "Kotlin")
    println(languages)
    languages.add("Angular")
    println(languages)
    languages.remove("Java")
    println(languages)
    languages.clear()
    println(languages)
}
```

【kot Lin，C++，c，Java】【kot Lin，C++，c，Java，角度】
【kot Lin，C++，c，角度】

## 摘要

在本教程中，我们讨论了不可变集和可变集，它们的创建使用了`setOf()`和`mutableSetOf()`函数以及提供的一些重要函数。我们已经完成了这个 Kotlin 教程系列的所有主要主题。我们将讨论其他部分留下的一些重要话题。

* * *

* * *