# Kotlin 文件处理

> 原文：<https://www.studytonight.com/kotlin/kotlin-file-handling>

在本教程中，我们将讨论 Kotlin 中文件处理的基础知识。文件用于将数据保存在内存中，因为程序执行后，如果不存储数据，数据就会丢失。

有许多方法可以创建文件，读取和写入文件。我们将简要讨论其中的一些。

## 创建文件

通常在许多写方法中，文件是自己创建的，但是我们会看到一种创建文件的方法。我们将使用`java.io`包中提供的`File`类。构造器以文件名作为参数。我们将使用`createNewFile()`方法创建一个文件。

如果给定文件名的文件不存在，`createNewFile()`方法将创建一个新文件，并返回 **true** 。如果文件名为的文件已经存在，它将返回 false:

```kt
import java.io.File

fun main() {
    val fileName = "Demo.txt"
    // Create file object
    val file = File(fileName)
    // Create file
    var isCreated = file.createNewFile()
    if (isCreated)
        println("File is created")
    else
        println("File is not created")
    // Again create file
    isCreated = file.createNewFile()
    if (isCreated)
        println("File is created")
    else
        println("File is not created")
}
```

文件已创建
文件未创建

我们也可以使用`file.exists()`方法检查文件的存在

## Kotlin 写文件

我们可以使用`writeText()`方法将数据写入文件。

*   它会将字符串作为参数，并将其写入文件。

*   如果不存在具有指定名称的文件，它将创建一个新文件。

*   如果文件已经存在，它将**替换**文件。

*   默认情况下，首先使用 UTF-8 字符集对给定数据进行编码。我们还可以指定任何其他字符集。

```kt
import java.io.File

fun main() {
    val fileName = "Demo.txt"

    val file = File(fileName)
    file.writeText("Hello World")
    file.writeText("Bye world")
}
```

如果我们查看 **Demo.txt** 文件，我们将只能在其中看到*再见世界*。因为`writeText()`会替换文件中存在的所有内容。如果想防止现在的数据丢失，可以用`appendText()`功能代替`writeText()`功能。

## Kotlin 从文件中读取

对于逐行阅读内容，我们可以使用`forEachLine()`方法。它将从文件中逐行读取数据。

```kt
import java.io.File

fun main() {
    val fileName = "Demo.txt"
    val file = File(fileName)
    file.forEachLine {
        println(it)
    }
}
```

我们也可以使用`readText()`功能从文件中读取数据:

```kt
import java.io.File

fun main() {
    val fileName = "Demo.txt"
    val file = File(fileName)
    val data = file.readText()
    println(data)
}
```

## 摘要

在本教程中，我们讨论了创建文件、从中读取数据以及向其中写入数据的基本方法。

* * *

* * *