# Kotlin 正则表达式

> 原文：<https://www.studytonight.com/kotlin/kotlin-regular-expression>

在本教程中，我们将讨论 Kotlin 中的正则表达式。正则表达式是用来定义模式的字符序列。这种模式也被称为正则表达式。

正则表达式可以用于很多事情，比如字符串中的模式匹配，字符串中的查找和替换等等。在 Kotlin 中，`Regex`类用于创建和管理正则表达式。

## 创建正则表达式

为了定义一个正则表达式，我们将创建一个`Regex`类的对象。创建仅包含字母数字字符(至少有一个长度)的用户名的模式是:

```kt
val usernamePattern = "[a-zA-Z0-9]+"
```

可以通过多种方式创建具有模式的正则表达式对象:

### 1.Regex 构造器

正则表达式模式作为参数传递给构造器:

```kt
val usernamePattern = "[a-zA-Z0-9]+"
val regex = Regex(usernamePattern)
```

### 2.使用 toRegex()函数

调用`toRegex()`函数创建正则表达式对象:

```kt
val usernamePattern = "[a-zA-Z0-9]+"
val regex = usernamePattern.toRegex()
```

### 3.使用 fromLiteral()函数

我们也可以使用`fromLiteral()`函数创建一个正则表达式。该函数返回一个正则表达式，该表达式与指定的模式字符串匹配。这意味着该字符串中没有字符会有特殊含义。因此`/w`将仅被视为`/w`字符串，而不是元字符:

```kt
val usernamePattern = "[a-zA-Z0-9]+"
val regex = Regex.fromLiteral(usernamePattern)
```

使用这三种方法中的任何一种，我们都可以创建一个 regex 对象。现在让我们看看如何对它进行操作。

## 匹配部分字符串

让我们看看如何使用正则表达式匹配部分字符串。如果输入的子串匹配正则表达式，那么我们将得到真:

```kt
fun main() {
    val usernamePattern = "[a-zA-Z0-9]+"
    val regex = Regex(usernamePattern)
    println(regex.containsMatchIn("Ninja__Nin"))
    println(regex.containsMatchIn("!#$%"))
}
```

真
假

在第一种情况下，仅匹配第一个字符“N”后，我们将得到真。但是在第二种情况下，甚至没有一个子串与模式匹配。因此，我们得到错误。

## 匹配完整字符串

要用正则表达式匹配全字符串，我们可以使用`matches()`函数或`matches`中缀运算符。只有当完整的字符串满足以下模式时，它们才会返回 true:

```kt
fun main() {
    val usernamePattern = "[a-zA-Z0-9]+"
    val regex = Regex(usernamePattern)
    println(regex.matches("Ninja"))
    println(regex matches "Ninja")
    println(regex.matches("Ninja__Nin"))
}
```

真
真
假

这里，第一个和第二个字符串遵循模式，因此返回 true。在第二种情况下，字符串包含`_`，因此我们得到假。

## 提取部分匹配字符串

如果我们想匹配然后提取部分匹配字符串，可以使用`find()`和`findAll()`函数。`find()`函数返回包含第一个匹配子串的`MatchResult`的对象，如果不存在，则返回 null。`findAll()`函数返回包含所有匹配子串的`MatchResult`集合:

```kt
fun main() {
    val usernamePattern = "[a-zA-Z0-9]+"
    val regex = Regex(usernamePattern)
    println(regex.find("Nin_ja")?.value)
    regex.findAll("Ninja__Nin-123").forEach {
        println(it.value)
    }
}
```

Nin
忍者
Nin
123

## 提取完整的匹配字符串

如果我们想要匹配然后提取完整的匹配字符串，我们可以使用 matchEntire()函数。它将返回包含字符串的`MatchResult`类的对象。

```kt
fun main() {
    val usernamePattern = "[a-zA-Z0-9]+"
    val regex = Regex(usernamePattern)
    println(regex.matchEntire("Ninja")?.value)
}
```

忍者

## 摘要

在本教程中，我们讨论了 Kotlin Regex。我们看到了如何创建 regex 对象并使用它们来匹配模式。在下一个教程中，我们将讨论 Kotlin 运算符重载。

* * *

* * *