# Kotlin 运算符重载

> 原文：<https://www.studytonight.com/kotlin/kotlin-operator-overloading>

在本教程中，我们将学习 Kotlin 的**运算符重载**。我们使用的每个操作符，如`+`、`-`、`++`等，都转化为一个功能。例如，以下算术函数转换为:

| 操作员 | 表示 | 基础函数 |
| --- | --- | --- |
| + | a + b | a .加(b) |
| - | 美国罗克韦尔 | a 减 b |
| * | a * b | a .时代(b) |
| / | a / b | 英格兰足球俱乐部 |

此外，对于不同的数据类型，所有这些函数也可能被重载。例如，`plus()`函数为`Int`类型添加两个数字，为`String`类型连接两个字符串。

## Kotlin 运算符重载

运算符重载可以通过重载该运算符的基础函数来实现。意思是过载`+`操作符，我们要过载`plus()`功能。

让我们创建一个类`ComplexNumber`并为其重载`+`运算符。我们将使用`operator`关键字来重载它:

```kt
class ComplexNumber(var real: Int, var imaginary: Int){
    // Operator Overloading
    operator fun plus(c: ComplexNumber): ComplexNumber{
        return ComplexNumber(this.real + c.real, this.imaginary + c.imaginary)
    }

    override fun toString(): String {
        return "${this.real} + ${this.imaginary}i"
    }
}

fun main() {
    val c1 = ComplexNumber(2,4)
    val c2 = ComplexNumber(3,3)
    println("Complex no. obtained by adding c1 & c2: ${c1.plus(c2)}")
}
```

加 c1 & c2: 5 + 7i 得到的复数

在这个例子中，我们重载了`plus()`函数来添加两个复数。它会给复数加上实数和虚数。

## 摘要

在本教程中，我们讨论了运算符重载，并看到了一个示例。至此，我们结束了这个 Kotlin 教程系列。有关参考资料，您可以随时参考官方文档:

*   [釜底医生](https://kotlinlang.org/docs/reference/)
*   [科顿医生 PDF](https://kotlinlang.org/docs/kotlin-docs.pdf)
*   [Kotlin 手控](https://play.kotlinlang.org/koans/overview)

* * *

* * *