# Python 中的运算符

> 原文：<https://www.studytonight.com/python/operators-in-python>

在每种编程语言中，运算符用于对任何给定的操作数执行各种类型的操作。它们用于计算不同类型的表达式，并通过对它们执行不同的操作来操作操作数或[变量](variables-in-python)的值。

在 python 中，我们有 7 种不同类型的运算符，它们是:

1.  算术运算符
2.  比较运算符
3.  赋值运算符
4.  逻辑运算符
5.  按位运算符
6.  成员操作符
7.  身份操作符

前五个是常用的操作符，后两个即**成员身份**和**身份**操作符是 python 独有的。

* * *

## Python:算术运算符

算术运算符是用于对**数值**操作数进行除、减、加等算术运算的运算符。

以下是不同的算术运算符:

To multiply values on either side of the operator.

| 操作员 | 使用 | 描述 |
| `+` | `a + b` | 将运算符两侧的值相加。 |
| `-` | `a - b` | 从左侧操作数中减去右侧操作数。 |
| `*` | `a*b` |  |
| `/` | `a/b` | 用左手操作数除以右手操作数(返回浮点值)。 |
| `%` | `a % b` | 返回左手操作数除以右手操作数的余数。 |
| `**` | `a**b` | 返回指数–左操作数的右次方 |
| `//` | `a//b` | **场内除法**–操作数的除法，其结果是去掉小数点后数字的商。但是如果其中一个操作数是负的，则结果是二进制的，即从零开始舍入(向负无穷大)。 |

让我们看几个代码示例:

```py
>>>3+2
5
>>>4-3
1
>>>3/2
1.5
```

* * *

## Python:比较运算符

这些运算符用于比较这类运算符两侧的操作数值。这些运算符返回`true`或`false`布尔值。如果条件满足，他们返回**真**，否则返回**假**。

以下是不同的比较运算符:

| 操作员 | 使用 | 描述 |
| `==` | `a == b` | 如果运算符两侧的值相等，则返回“真”，否则返回“假”。 |
| `!=` | `a != b` | 如果运算符两侧的值不相等，则返回“真”，否则返回“假”。 |
| `>` | `a > b` | 如果运算符左侧的操作数的值大于运算符右侧的值，则返回 True。 |
| `<` | `a < b` | 如果运算符左侧的操作数的值小于运算符右侧的值，则返回 True。 |
| `>=` | `a >= b` | 如果运算符左侧的操作数的值大于或等于运算符右侧的值，则返回 True。 |
| `<=` | `a <= b` | 如果运算符左侧的操作数的值小于或等于运算符右侧的值，则返回 True。 |

让我们看几个代码示例:

```py
>>> 3 == 2
False
>>> 3 != 2
True
>>> 2<=4
True
```

* * *

## Python:赋值运算符

赋值运算符用于为变量或操作数赋值。

如果我们使用任何算术运算符(`+`、`-`、`/`等，则等于(`=`)运算符用于将值直接赋给操作数。)与等于运算符一起，它将对给定变量执行算术运算，然后将结果值赋给该变量本身。

让我们看几个代码示例:

```py
>>> x=2
>>> x
2
>>> x+=1
>>> x
3
>>> x-=1
>>> x
2 
```

* * *

## Python:逻辑运算符

逻辑运算符用于执行逻辑运算(如**和**、**或**、**而非**)并组合两个或多个条件以提供特定结果，即真或假。

以下是不同的逻辑运算符:

| 操作员 | 使用 | 描述 |
| `and` | `x and y` | 如果运算符的两边都为真，则为真 |
| `or` | `x or y` | 如果任一操作数为真，则为真 |
| `not` | `not x` | 补充操作数 |

* * *

## Python:按位运算符

按位运算符一点一点地作用于操作数。这些运算符接受一个或两个操作数。一些按位运算符看起来类似于逻辑运算符，但实际上并非如此。

以下是不同的按位运算符:

It copies a bit if it exists in either operand.

| 操作员 | 使用 | 描述 |
| `&`二进制“与” | `(a & b)` | 如果结果在两个操作数中都存在，运算符会将一个位复制到结果中。 |
| `&#124;`二进制或 | `(a &#124; b)` |  |
| `^`二进制异或 | `(a ^ b)` | 如果在一个操作数中设置了该位，而不是在两个操作数中都设置了该位，则复制该位。 |
| `~` 1 的补码 | `(~a)` | 它是一元的，具有“翻转”位的效果。 |
| `<<`二进制左移 | `a << 2` | 左操作数值向左移动右操作数指定的位数。 |
| `>>`二进制右移 | `a >> 2` | 左操作数值向右移动右操作数指定的位数。 |

让我们看几个代码示例:

```py
>>> a = 3
>>> b = 4
>>> a = 3   # equivalent binary is 0011
>>> b = 4   # equivalent binary is 0100
>>> a & b
0
>>> a | b
7
>>> # 7 is equivalent to 0111 in binary 
```

* * *

## Python:成员操作符

成员操作符用于测试一个值是否在特定的序列中，比如列表、元组、字符串等。它返回真或假作为输出。

以下是不同的成员操作符:

| 操作员 | 使用 | 描述 |
| `in` | `x in y` | 如果运算符左侧的值/操作数出现在运算符右侧的序列中，则为 True。 |
| `not in` | `x not in y` | 如果运算符左侧的值/操作数不在运算符右侧的序列中，则为 True。 |

让我们看几个代码示例:

```py
>>> lst=[2,3,6,7,9,1]
>>> x=2
>>> y=5
>>> x in lst
True
>>> y in lst
False
```

* * *

## Python:标识运算符

标识运算符用于测试变量是否引用相同的值/对象。它返回真或假作为输出。

以下是不同的标识运算符:

| 操作员 | 使用 | 描述 |
| `is` | `x is True` | 如果两个操作数引用同一个对象，则为 True。 |
| `is not` | `x is not True` | 如果运算符两侧的[变量](variables-in-python)指向同一对象，则计算结果为假，否则为真。 |

让我们看几个代码示例:

```py
>>> x=4
>>> y=4
>>> z=2
>>> x is y
True
>>> z is x
False
```

* * *

* * *