# Python 中的字符串

> 原文：<https://www.studytonight.com/python/string-in-python>

自从我们开始学习 python 以来，这已经不是我们第一次遇到 Strings 了。在前面的许多教程中，我们已经在示例中使用了字符串或者讨论了它，所以它不应该成为你的埋伏。尽管如此，这一章将让您更深入地了解如何在 python 世界中使用、操作和实现它们。我们还将检查一些方便的[字符串函数](string-functions)来操作字符串。所以，在不浪费时间的情况下，让我们马上投入其中。

* * *

## 什么是字符串？

字符串可以定义为**字符序列**，这是你能提供的最基本的字符串解释。在这个定义中，我们可以看到两个重要的术语，一个是**序列**，另一个是**人物**。如果你在完成了[最后一个教程](data-types-in-python)之后在这里，那么在那里，我们已经解释了——什么是**序列** [数据类型](data-types-in-python)以及**字符串**是如何成为序列类型的。只是为了修订，在 python 中，Sequence 是一种由几个相同类型的元素组成的数据类型，即整数、浮点数、字符、字符串等。

> **注:** *所有已有字符都有唯一编码。编码惯例被标记为 **Unicode 格式**。它由几乎所有可能语言的字符组成，事实上也包括表情符号(是的，表情符号也被声明为字符)。*

因此，字符串可以被认为是一种特殊类型的序列，它的所有元素都是字符。比如字符串`"Hello, World"`基本上就是一个序列 **['H '，' e '，' l '，' l '，' o '，'，'，'，' W '，' o '，' r '，' l '，' d']** 它的长度可以通过统计序列内部的字符数来计算，就是`12`。

> **注意:** *是的，空格、逗号那些引号里面的所有东西如果长度是 1 的话都会是一个字符。*

一般在编程语言中有一种不同的[数据类型](data-types-in-python)只专用于字符，而在 Python 中则没有字符数据类型。相反，字符被视为长度为 1 的字符串。

* * *

### 字符串声明

```py
>>> mystring = "This is not my first String"
>>> print (mystring);
This is not my first String
```

[现场示例→](/code/python/introduction-to-strings.php)

您也可以访问字符串的每个单独的字符。就像访问序列的每个元素一样，我们可以为此使用索引号。要访问`mystring`的第一个字符，我们可以执行以下操作:

```py
>>> print (mystring[0]);
T
```

由于`T`是我们的字符串`This is not my first String`的第一个字符，因此它的索引号为`0`(零)。类似地，对于进一步的字符，我们可以使用索引 1、2、3 等等，也就是说，为了访问具有元素的**，我们将不得不使用第 **(i-1)个**索引。**

还有另一个技巧，从序列的末尾访问序列的元素。例如，如果您想访问序列的最后一个元素，只需执行以下操作:

```py
>>> print (mystring[-1])
```

在索引中写下`-1`将意味着您要求从最后一个元素开始的第一个元素。类似地，为了访问第二个最后一个元素，使用`-2`作为索引，对于第三个最后一个使用`-3`以此类推，即对于最后一个使用`-ith`作为索引的**和**元素。这样就解决了从字符串的前向和后向访问每个字符的一般化问题。请注意，正索引号意味着您正从前端访问字符，而负索引号意味着您正从后端访问它。

我们可以用一张简单的表格来总结我们到目前为止所学的内容。考虑一根绳子`PYTHON`。为此，可以通过两种方式访问每个字符-从前面，或从后面。

| **字符** | **P** | **Y** | **T** | **H** | **O** | **N** |
| **前进指数** | Zero | one | Two | three | four | five |
| **倒排索引** | -6 | -5 | -4 | -3 | -2 | -1 |

* * *

### 换码顺序

假设您想要一个字符串来存储圣雄甘地的一句话。

> **“你一定是你希望在这个世界上看到的改变”——甘地**

这正是您想要在控制台中显示的行。你也希望这句话能被引用。当你继续打印声明时，你会发现事情并没有那么简单。

Python 会立即返回一个语法错误。这是因为我们添加了额外的双引号。在上图中，你可以注意到甘地引用的文字是黑色的，而**-【甘地】**是绿色的。此外，如果您已经使用了足够的 IDLE，您可能知道字符串中的所有字符在[IDLE](introduction-to-idle)中都以绿色突出显示(根据文本编辑器、python 版本、操作系统等，它也可以是其他颜色)。这显然意味着 Python 没有把*你一定是你希望在这个世界上看到的变化*部分当成一根弦。因此，这就得出结论，每当我们打开一个引用并关闭它时，声明一个字符串，无论我们在结束引用后写什么，都只是被认为是一些 python 关键字。

就像上面的引用文本一样，我们用两个双引号开始字符串，并在它旁边写道**你一定是你希望在世界上看到的变化**，因为双引号在这个短语之前就已经关闭了，因此 python 认为整个句子是一些不可理解的 Python 关键字。在这个短语之后，另一个双引号开始了，然后是 **-甘地**在那之后，最后是结束双引号，因为**-甘地-T7】部分在一对双引号内，因此它是完全合法的。**

现在你明白了，如果我们使用不均匀数量的双引号，我们可能会面临的问题。现在让我们看看如何在字符串中引用。有两种方法可以做到:

1.  First one is a bit compromising. You can use single quotes inside of double quotes, like:

    ```py
    >>> print ("'You must be the change you wish to see in the world' - Gandhi");

    ‘You must be the change you wish to see in the world' - Gandhi
    ```

    因此，在双引号中使用单引号是合法的，但是，反过来就不正确了，即，

    ```py
    >>> '"You must be the change you wish to see in the world" - Gandhi'
    ```

    会给出一个错误。

2.  Second one is for those who hate to compromise, or just want to use the double quotes. For you people, there is something called **escape sequence** or literally speaking, a **back-slash**`\`. You can use it like:

    ```py
    >>> print ("\"You must be the change you wish to see in the world\" – Gandhi");
    ```

    你能猜到发生了什么吗？我们在两个地方使用了反斜杠或转义序列，就在我们直接想要打印的引号之前。如果您想通知编译器简单地打印您键入的任何内容，而不是试图编译它，只需在它之前添加一个转义序列。还要记住，一个字符必须使用一个转义序列。例如，为了打印 5 个双引号，我们必须使用 5 个反斜杠，每个引号前一个，如下所示:

    ```py
    >>> print ("\"\"\"\"\"");
    ```

* * *

## 字符串的输入和输出

输入输出方法已经在[输入输出教程](input-and-output)中详细讨论过了。如果您还没有完成教程，建议您完成它。

* * *

## 字符串上的操作

python 中的字符串处理可能需要最少的努力。因为在 python 中，与其他语言相比，字符串操作的复杂性非常低。让我们看看如何玩弦乐。

1.  **Concatenation:** No, wait! what? This word may sound a bit complex for absolute beginners but all it means is - **to join two strings**. Like to join `"Hello"` with `"World"`, to make it `"HelloWorld"`. Yes, that's it.

    ```py
    >>> print ("Hello" + "World");

    HelloWorld 
    ```

    是的。一个加号`+`就足够了。与字符串一起使用时，`+`符号连接两个字符串。我们再举一个例子:

    ```py
    >>> s1 = "Name Python "
    >>> s2 = "had been adapted "
    >>> s3 = "from Monty Python"
    >>> print (s1 + s2 + s3)

    Name Python had been adapted from Monty Python 
    ```

    [现场示例→](/code/python/string-operation-examples.php)

3.  **Repetition:** Suppose we want to write same text multiple times on console. Like repeat **"Hi!"** a 100 times. Now one option is to write it all manually, like **"Hi!Hi!Hi!..."** hundred times or just do the following:

    ```py
    >>> print ("Hi!"*100)
    ```

    假设，你想让用户输入某个数字`n`，基于此你想让一个文本在控制台`n`上打印几次，你怎么做？很简单。只需创建一个变量`n`并使用`input()`功能从用户那里获取一个数字，然后将文本乘以`n`。

    ```py
    >>> n = input("Number of times you want the text to repeat: ")

    Number of times you want the text to repeat: 5

    >>> print ("Text"*n);

    TextTextTextTextText
    ```

5.  **Check existence of a character or a sub-string in a string:** The keyword `in` is used for this. For example: If there is a text **India won the match** and you want to check if **won** exist in it or not. Go to IDLE and try the following:

    ```py
    >>> "won" in "India won the match"

    True
    ```

    在 python 中的其他数据类型中，有**布尔**数据类型，它可以有两个可能的值之一，即`true`或`false`。由于我们正在检查字符串中是否存在某个东西，因此，可能的结果要么是*是，它存在*或*不，它不存在*，因此返回**真**或**假**。这也应该让你知道在编写程序时在哪里使用布尔数据类型。

6.  `not in` **关键词:**这正好和`in`关键词相反。如果你猜对了，你就相当聪明了。它的实现也非常类似于`in`关键词。

```py
>>> "won" not in "India won the match"

False
```

通过单击下面的“实时示例”按钮，您可以看到上述所有字符串操作都在运行。另外，我们建议您练习使用**实时编译器**，并尝试更改代码并运行它。

[现场示例→](/code/python/string-operation-examples.php)

* * *

### 将字符串转换为整型或浮点型数据类型，反之亦然

这在初学者中是一个非常常见的疑问，因为在 python 中，用引号括起来的数字会变成一个字符串，然后如果您试图对它执行数学运算，就会出错。

```py
numStr = '123'
```

在上面的语句中`123`不是数字，而是字符串。

因此，在这种情况下，要将数字字符串转换为`float`或`int`数据类型，我们可以使用`float()`和`int()`函数。

```py
numStr = '123'
numFloat = float(numStr)
numInt = int(numFloat)
```

[现场示例→](/code/python/python-string-to-int-float-coversion.php)

然后你可以很容易地对数值进行数学运算。

同样，要将`int`或`float`变量转换为`string`，我们可以使用`str()`功能。

```py
num = 123
# so simple
numStr = str(num)
```

* * *

### 限幅

切片是另一个字符串操作。切片允许您基于开始索引和结束索引提取任何字符串的一部分。例如，如果我们有一个字符串**这是 Python 教程**，我们想提取这个字符串的一部分或者只是一个字符，那么我们可以使用切片。首先让我们熟悉一下它的用法语法:

```py
string_name[starting_index : finishing_index : character_iterate]
```

*   **String_name** 是保存字符串的变量的名称。
*   **starting_index** 是子字符串中想要的起始字符的索引。
*   **finishing_index** 比子串中最后一个字符的索引多一个。
*   **character_iterate**: To understand this, let us consider that we have a string `Hello Brother!`, and we want to use the slicing operation on this string to extract a sub-string. This is our code:

    ```py
    >>> str = "Hello Brother!"
    >>> print(str[0:10:2]);
    ```

    [现场示例→](/code/python/python-string-slicing.php)

    现在`str[0:10:2]`的意思是，我们要从索引`0`(字符串的开头)开始提取一个子字符串，到索引值`10`，最后一个参数的意思是，我们要每隔一个字符，从起始索引开始。因此在输出中我们会得到， **HloBo** 。

    `H`在索引`0`处，然后离开`e`，将打印`H`的第二个字符，为`l`，然后跳过第二个`l`，打印第一个`l`的第二个字符，为`o`以此类推。

再举几个例子会更清楚:

我们取一个 10 个字符的字符串，`ABCDEFGHIJ`。索引号将从`0`开始，到`9`结束。

| A | B | C | D | E | F | G | H | 我 | J |
| Zero | one | Two | three | four | five | six | seven | eight | nine |

现在尝试以下命令:

```py
>>> print s[0:5:1]
```

这里，通过在每次跳转中迭代`1`字符，从第 0 个字符到第 4 个字符(5-1)进行切片。

现在，去掉最后一个数字和`colon`只写这个。

```py
>>> print (s[0:5]);
```

您将看到两个输出都是相同的。

你可以通过改变价值观来练习。也可以尝试将字符迭代变量的值更改为某个值`n`，然后它将打印从起始索引到最终索引的每个`nth`字符。

* * *

* * *