# Python 中的列表

> 原文：<https://www.studytonight.com/python/lists-in-python>

在[最后一节](string-functions)中，我们讨论了字符串以及字符串的各种属性和功能，比如它如何被认为是一个列表一样的各种字符的集合。换句话说，列表是一组有序的值，用方括号`[ ]`括起来。

需要注意的一个重要区别是`list`是**可变的**，即它的值可以修改。

因为它只不过是一组值，所以我们可以使用方括号`[ ]`中的`index`来标识属于列表的值。

组成列表的值称为其**元素**，它们可以是任何类型。我们也可以说`list` [数据类型](data-types-in-python)是一个以给定顺序容纳多个元素的容器。为了访问列表中的元素，使用了索引，可以从向前和向后两个方向调用索引(类似于字符串)。

* * *

## 构建列表

如前所述，`list`是相似类型数据的集合。该数据可以是一个**整数**、一个**浮点数**、一个**复数**、一个 **[字符串](string-in-python)** 或 python 中的任何合法数据类型。列表总是提供一些名称，类似于一个[变量](variables-in-python)，每个元素通过它们的索引号来访问。Python 有向前和向后的索引号，所以每个元素都有一个正数和一个负数来访问该元素(在下一个主题中讨论)。定义列表时，我们必须将列表的每个元素放在方括号内，每个元素用逗号分隔。

假设，如果您想创建一个空列表(如果您想在以后的程序中添加元素或者当用户给出输入时，这是可能的)，那么您可以通过声明空的方括号来初始化它，

```py
>>> myEmptyList = []
```

例如，一些整数的列表将是，

```py
>>> myIntegerList = [9, 4, 3, 2, 8]
```

浮点值列表，

```py
>>> myFloatList = [2.0, 9.1, 5.9, 8.123432]
```

一个字符列表，

```py
>>> myCharList = ['p', 'y', 't', 'h', 'o', 'n']
```

字符串列表，

```py
>>> myStringList = ["Hello", "Python", "Ok done!"]
```

[现场示例→](/code/python/python-list.php)

这些是创建列表的一些基本方法。现在让我们尝试一些其他的方法。

* * *

### 从另一个名单开车

假设有一个现有列表，

```py
>>> myList1 = ['first', 'second', 'third', 'fourth', 'fifth']
```

现在你想创建一个新的列表，它由`myList1`的部分或全部元素组成，那么你可以直接赋值完成元素的复制或使用切片，只取部分元素。

为了完全复制，

```py
>>> myList2 = myList1
```

使用切片，只复制前三个元素，

```py
>>> myList2 = myList1[0:3]
```

[现场示例→](/code/python/python-list.php)

为了复制最后三个元素，

```py
>>> myList2 = myList1[-3]
```

* * *

### 在列表中添加序列号

假设您想要添加连续的整数(即 0，1，2，3，...)到你的列表中，只是不想把它们一个个都写出来，不用担心，这样做有捷径。

要在列表中存储`0`到`(n-1)`的数字，请使用`range(n)`功能。

```py
>>> myList1 = range(9)
```

这将创建一个列表，其中包含数字 **0 到 8** 。

```py
>>> myList1 = range(5, 9)
```

[现场示例→](/code/python/python-list.php)

这将创建一个包含数字 **5、6、7、8** 的列表，即*参数的第一个数字*到*(参数的最后一个数字- 1)* 。

该`range()`功能可用于各种使用情况。

假设您想要创建一个包含所有整数的方块的列表。虽然对于这个问题有各种各样的编程方法，但是这里有一个 python 中的单行方法。我们将引入一些新的东西，所以可能会有点棘手。

```py
>>> myQuickList = [x**2 for x in range(5)]
```

最终列表将包含类似`[0, 1, 4, 9, 16]`的元素，即`x**2`，其中`x`从`0`到`(5-1)`不等。

`for`是这里你可能不熟悉的关键词。`for`是让编程为程序员做很多平凡而多余的任务的关键词之一，例如，它可以创建执行循环。虽然会有一整章专门介绍这个，但这里需要注意的重要一点是`for`是负责在 **0 到 4** 范围内迭代(或重复)`x`并最终将迭代值的平方即`(x<sup>2</sup>)`存储在列表中的关键字。

* * *

### 附加到列表

追加基本上就是在现有的基础上增加**。如果你还记得，我们告诉过你如何在 python 中通过声明一个空的方括号来创建一个空列表。现在，当您必须在列表中插入一些元素时，该怎么办？这就是`append`功能发挥作用的地方。您可以在一行中将任意数量的元素添加到列表的末尾，没有任何麻烦。**

```py
>>> emptyList = []
>>> emptyList.append('The Big Bang Theory')
>>> emptyList.append('F.R.I.E.N.D.S')
>>> emptyList.append('How I Met Your Mother')
>>> emptyList.append('Seinfeld')
```

[现场示例→](/code/python/python-list.php)

因此，这将基本上创建一个最好的情景喜剧的列表(不再是空的)。如果你把名单打印出来。

```py
>>>print (emptyList)
```

[《生活大爆炸》，《美国电影电视艺术学院》，《我如何遇见你的母亲》，《宋飞正传》]

* * *

## 元素索引

我们已经在[字符串教程](/python/string-in-python)中介绍了使用索引访问字符串中的字符序列。同样，在 python 中，索引号也可以用来访问列表的元素。让我们创建一个由**字符串**组成的**列表**，并尝试使用索引号访问单个字符串。这里有一个例子，

```py
>>> fruitsList = ["Orange", "Mango", "Banana", "Cherry", "Blackberry", "Avocado", "Apple"] 
```

正如您在上面的代码中看到的，我们有一个包含 7 个元素的列表。要找到一个列表中的元素数量，就像字符串一样使用函数`len`。

```py
>>> print (len(fruitsList));
```

seven

[现场示例→](/code/python/python-list.php)

对于列表中的每个元素，下面是我们应该使用的索引号:(试着理解我们是如何分配索引号的。)

| 元素 | 远期指数 | 向后索引 |
| 柑橘 | Zero | -7 |
| 芒果 | one | -6 |
| 香蕉 | Two | -5 |
| 樱桃 | three | -4 |
| 黑莓 | four | -3 |
| 鳄梨 | five | -2 |
| 苹果 | six | -1 |

* * *

* * *