# Python 中的循环

> 原文：<https://www.studytonight.com/python/looping-in-python>

在本节中，我们将看到 python 中的循环是如何工作的。循环只是编程中常用的一种功能，用于完成重复性任务。它可以从迭代数组或字符串的每个元素，到修改整个数据库。

使用循环的经验法则是:

> 如果你正在一次又一次地写一段类似的代码，那么是时候进行循环了。

与其做，

```py
>>> a = 1
>>> b = 2
>>> c = 3
>>> d = 4
```

等等，像这样做，

```py
>>> a = []
>>> {run a loop in this line to store 1, 2, 3, 4 in list a}
```

在第二个代码片段中，我们将使用一个循环，在这里我们只需要编写我们必须完成的任何繁琐的任务，只需要一次，然后将它放在一个循环中。有了这个，我们将能够实现一个迭代流程来执行。

在 python 中，有两种方法可以实现迭代流:

1.  使用`for`循环
2.  使用`while`循环

* * *

## `for`循环

让我们先看看语法是什么，

```py
for [ELEMENT] in [ITERATIVE-LIST]:
	[statement to execute]
else:
	[statement to execute when loop is over]
	[else statement is completely optional]
```

`for`循环常用于迭代列表的元素。考虑到上面的语法，假设有一个列表`myList`:

```py
>>> myList = [8, 9, 2, 3, 4, 6]
```

如果我们想使用`for`循环迭代列表`myList`的所有元素:

```py
for i in myList:
	print (i)
```

正如我们所看到的，我们正在使用一个变量`i`，它一个接一个地表示列表中存储的每个元素。只要列表中有元素，我们的循环就会运行很多次。例如在`myList`中有 6 个元素，因此上面的循环将运行 6 次。

在第一次迭代中，`i`的值将是`8`，而在下一次迭代中，它将是`9`等等，直到最后一次迭代中的`6`。这样做，可以很容易地在循环中使用这些单独的列表元素值，就像在我们的例子中，我们已经打印了它们。

除此之外，还有另一种方法。如果你还记得的话，我们通过索引访问列表中某个元素的传统方式- `myList[i]`。虽然，在这种情况下，我们将使用另一个功能`range()`(或者也可以使用`xrange()`)。`range()`功能也已经在前面的章节中提到过了。如果你能记住`range()`函数可以根据你提供的参数返回一个数字列表。例如:

```py
>>> range(5)
```

[0, 1, 2, 3, 4]

或者，

```py
>>> range(5, 10)
```

[5, 6, 7, 8, 9]

或者，

```py
>>> range(2, 12, 2)
```

[2, 4, 6, 8, 10]

我们可以使用`range()`函数和`for`循环来迭代从`0`到`len(myList)`的索引号。这将非常像:

```py
for i in range(0, len(myList)):
	print (myList[i])
```

正如你可能已经注意到的，在这种情况下，我们将遍历一个**临时列表**，它包含**实际列表**的索引号。该临时列表是使用`range()`功能生成的。

**在`for`循环**中的`else`块

一旦列表的所有元素都被迭代或者列表中没有更多元素需要迭代，就执行带有`for`循环的`else`块。可以肯定地说`else`语句是在循环结束时执行的。虽然，正如语法中已经提到的，它完全可以随意使用，事实上，它甚至不经常使用。

看一些更复杂的例子，假设有一个列表:

```py
>>> bigList = [[1, 3, 6], [8, 2,], [0, 4, 7, 10], [1, 5, 2], [6]]
```

你认为，我们将如何访问列表的每个元素？

答案是，在另一个循环中使用一个循环。由于列表中有列表，因此外部循环将有助于访问`bigList`的每个列表，而在该循环中，对于每个列表元素，我们将使用另一个循环。

```py
for i in bigList:
	for j in i:
		print ("Element of list within a list - ", j)
```

列表中的列表元素- 1 列表中的列表元素- 3 列表中的列表元素- 6 列表中的列表元素- 8 列表中的列表元素- 2 列表中的列表元素- 0 列表中的列表元素- 4 列表中的列表元素- 7 列表中的列表元素- 10 列表中的列表元素- 1 元素 列表中的列表元素-列表中的列表元素-列表中的列表元素- 6

* * *

## `while`循环

是时候学习 while 循环了。

**语法:**

```py
while [condition]:
	[statement to execute]
else:
	[statement to execute if condition is false]
	[else statement is completely optional]
```

同样，在`while`循环中，也有一个`else`块，尽管它是可选的，很少使用。

在第一条语句中，`while`循环设置一个**条件**，然后是一个**语句**，编译器按照执行流程，首先检查条件块中提供的条件，如果条件成立`True`，则执行该语句。

一旦该语句被执行，编译器再次检查条件，如果再次是`True`，则该语句再次被执行，否则执行`else`块(如果提供的话)或者仅仅是流控制脱离`while`循环(如果没有提到 else 语句)。

这里有一个例子:

**注意:**不要在 IDE、IDLE 或者任何地方尝试这个例子。

```py
while True:
	print ("I am printing because the condition is True")
```

由于这里我们已经将条件设置为`True`，因此编译器将第一次执行该语句。在下一次迭代中，条件仍然是`True`，因此语句将再次执行。这将继续发生，正如你可能已经猜到的，这个循环不会结束。这种循环叫做**无限循环**，在程序中应该避免。

再举一个例子:

```py
i = 0
while i < 5:
	i=i+1
	print ("i =", i)
```

在这种情况下，在第一次迭代中检查条件`i < 5`，由于`0 < 5`，因此执行语句。在执行过程中，`i`的值增加`1`。

`for`循环，常用于迭代一个列表的元素，`while`循环则可以服务于多个目的，也可以迭代一个列表！使用索引访问元素的逻辑非常相似。运行从 **0** 到`len(myList)`的循环，只需访问元素。并且，不需要使用`range()`或`xrange()`功能。

```py
myList = [8, 9, 2, 3, 4, 6]
i = 0
while i < len(myList):
    print (myList[i])
    i = i+1;
```

快速浏览列表中的列表示例:

```py
bigList = [[1, 3, 6], [8, 2,], [0, 4, 7, 10], [1, 5, 2], [6]]
i = 0
j = 0
while i<len(bigList):
	while j<len(bigList[i]):
		print (“Element of list within a list -”,bigList[i][j])
		j=j+1;
	i=i+1
```

* * *

### `continue`关键词

`continue`关键字在循环中用于改变循环执行。在循环内使用`continue`将跳过当前语句的执行，并再次检查条件。假设有一个字符串，

```py
>>> name = "StudyTonight"
```

让我们来看一个演示使用`continue`关键字的快速例子:

```py
for i in name:
	continue
	print (i)
```

**不会打印任何东西**。让我们看看为什么？在第一次迭代中，将选择列表`name`的第一个元素，即`"S"`，`for`循环中的下一个语句是`continue`，因此一旦找到该关键字，将跳过其余`for`循环语句的执行，流程返回到`for`循环，开始获取下一个元素并检查条件。相同的步骤之后是字符串的下一个元素，即`"t"`，并且`continue`再次中断流程，并且这将在每次执行流程到达`continue`键时发生。

所以，现在如果我们想编写一个循环程序，只打印存储在`name`变量中的字符串的**小写**字母，那么，我们可以使用`continue`关键字跳过那些不小写的字母。

```py
for i in name:
	if not i.islower():
		continue
	print (i)
```

`if`条件使用`islower()`功能检查元素`i`是否小写。如果它不是小写的，那么剩下的语句就被跳过，并且`print`语句永远不会被执行，但是，如果`i`是小写的，那么`if`语句返回`False`并且`continue`语句不会被执行。

`continue`关键字的工作方式与`while`循环完全相同。

* * *

### `break`关键词

`break`关键字在循环内部使用，用于脱离循环。假设在迭代存储在变量`name`中的字符串的字符时，一旦遇到字符`"T"`，您就想要脱离它。这是如何做到的:

```py
for i in name:
	if i == "T":
		break;
	print (i)
```

现在，一旦`if`条件得到字符`"T"`，编译器将执行`break`语句，执行流程将脱离循环。

* * *

* * *