# 使用 Python 编写用户定义函数

> 原文：<https://www.studytonight.com/python/functions-in-python>

在这一点上，很明显你们都知道什么是函数！您已经在之前的教程中遇到过几个内置函数。虽然，由于所有这些函数都是内置的，我们所要做的就是通过调用它们并在需要时提供所需的参数来直接使用它们。

程序中显式定义的函数(由用户定义)也有助于将整个程序划分为子部分，从而使其可读性更强，易于修改代码和修复任何错误或 bug。

是时候学习如何在 python 中创建自己的函数了，这些函数也被称为**用户自定义函数**。

正如我们在前面的教程中已经看到的，要使用任何内置函数，我们必须在程序中导入定义函数的模块。例如，在下面的程序中，我们已经导入了`math`模块来使用`floor()`内置功能。

```py
import math

a = 2.3
print ("The floor of 2.3 is : "+ math.floor(a))
```

如果您打开模块文件，这只是一个 python 文件，您将能够看到各种函数的定义，就像您很快就会做的那样，那时您将开始定义自己的用户定义函数。

* * *

### 函数定义的结构

让我们看看如何创建一个简单的函数。语法是这样的，

```py
def functionName(parameter1, parameter2, ...):
    logic/algorithm statements
    ...
    return someData
```

这里的第一点，**缩进**非常重要，函数的定义应该在`def functionName(parameter1, parameter2):`后面缩进一个 **tabspace**

现在让我们试着逐一理解每一行。第一行称为**函数头**以关键字`def`开始，实际上是**定义**，因为这是开始定义函数的起点。接下来是**函数的名字**，在这里你给函数取一个名字，比如说*加*、*乘*、*交换*或者任何表示函数实际将要做什么的东西。

接下来，在圆形支架内，出现了**参数**。这些是一些必需的值，用户可以输入，并在操作过程中在函数内部使用。大家可能还记得，我们在调用数学函数的时候是怎么放几个数字的，比如`sin(3.14)`，这里 **3.14** 是参数值。我们知道，如果没有像 **3.14** 这样的值，`sin()`功能将没有值来执行**正弦**操作。同样，您也可以在定义函数时指定用户定义的函数需要一些参数才能成功执行。

来到第二行，我们有**逻辑/算法语句**。在这里，我们将利用所有的参数(如果有的话)来实现函数应该做的事情。我们可以有各种操作、循环、条件语句等。在这里完成它。以`add()`函数为例，在这个函数中执行简单的加法- `a + b`并将结果存储到某个变量中，比如说`c`，因此在`add()`函数中，我们有一个表达式，`c = a + b`、`a`和`b`是输入值。

最后是**返回**语句。关于**返回**语句，首先要知道的是，函数中没有强制要求。如果您的函数应该在任何操作后返回值，那么您必须使用 **return** 语句来输出该值，否则您的函数不需要它。因此，您必须始终知道何时有一个**返回**语句。返回的数据可以是任何东西-一个**号**、**字符串**、一个**布尔**值、一个**列表**或其他任何东西。

在函数`add()`的情况下，我们期望它给我们一些(数据)值吗？**是**。这是什么？*作为参数传递的两个数相加的结果*。所以，`add()`函数应该有一个**返回**的语句。要返回任何值，我们只需在 **return** 关键字旁边提到我们想要返回的值。

```py
def add(a, b):
    c = (a+b)
    return c
```

或者，您可以直接返回 **(a+b)** ，而不将其存储到其他变量中。

```py
def add(a, b):
    return (a+b)
```

一旦定义了一个函数，我们就可以像调用内置函数一样简单地调用它，也就是说，如果我们想**添加** `5`和`9`，那么，

```py
>>> print add(5, 9)
```

Fourteen

事实上，你甚至可以传递一个函数作为参数！例如:

```py
>>> print add(5, add(7, 6))
```

Eighteen

迷茫？别担心，让我们解释一下。首先对`add(7, 6)`进行求值，其结果即`13`作为参数传递到第二个`add()`函数中，与`5`相加。所以最后的结果就是，`add(5, 13)`的输出，也就是`18`。

* * *

### 函数的返回类型

每个函数都有一个**返回类型**，它只不过是它返回的值的类型。决定任何函数的返回类型非常简单。在`add()`函数中，如果`a`和`b`是**整数**，那么`add()`函数将返回一个**整数**值，这将是它的**返回类型**。同样，如果函数返回一个**列表**，那么它的返回类型将是一个**列表**。对于内置函数，您可以在官方文档中找到每个函数的**返回类型**。

但是怎么可能每个函数都有一个**返回类型**，因为我们前面提到过，有一个**返回**语句是完全可选的，完全取决于函数中是否需要它。因此，问题出现了，什么是不返回任何东西的函数的返回类型？答案是，`void`，这几乎是*空*或*无*的同义词，表示如果没有 return 语句，那么函数将有`void`返回类型。

让我们看看在哪里可以使用返回类型的函数`void`。

**提示:**由于它们不返回任何东西，这些可以用来将你的程序分成更小的单元。

假设有一个简单的程序，其中，你从用户输入一个正数，打印所有偶数，所有奇数的两倍，从`1`开始到那个数字。没有任何功能的程序如下所示:

```py
n = input()
for i in xrange(1, n+1):
	if i%2 == 0:
		print i
	else:
		print 2*i
```

现在让我们试着用一个函数来实现它。我们将从定义顶部的函数开始。尽管如此，在哪里定义函数并不重要，因为这对执行流程没有影响。只有调用函数才会开始执行函数。但是在程序开始时定义所有的函数是一个很好的做法，因为这是所有程序员在查看任何代码时寻找所有用户定义函数的地方。

```py
def check(k):
	if (k%2==0):
		print k
	else:
		print 2*k

n = input()
for i in xrange(1, i+1):
	check(i)
```

如你所见，我们只是拿起了检查数字是否为偶数的逻辑，并在`check()`函数中定义了它。然后我们在`for`循环中调用它，在每次迭代中向它传递一个新值。这实际上稍微清理了一下的**循环，使其看起来更加整洁。**

上面的程序是一个简单的程序，但是当你要用 100 行代码编写程序时，那么把程序占卜成函数是一个非常好的做法。

使用函数的一个优点是，您可以随时重用该函数，只需调用它。在上面的例子中，如果我们想打印一个偶数，或者打印它的两倍，如果它是奇数，那么我们所要做的就是简单地调用这个函数，并将这个数字作为参数传递，就完成了。`check(9)`，汉迪，对吧？

* * *

### 默认参数

当您需要预先设置参数值时，将使用默认参数。也就是说，如果将来我们在调用函数时不传递任何变量作为参数，那么函数将采用默认值来执行其语句。

现在，如何定义默认参数？我们以`add()`函数为例。如果我们这样做，会发生什么:

```py
>>> print add()
```

没有任何默认参数，python 会立即抛出一个错误。因此，让我们为`add()`函数设置默认参数，这样它就可以工作，即使没有参数值。我们认为 defulat 值应该为零。这样，返回值将是`0 + 0`，即`0`，这也是有意义的，因为我们没有传递任何参数/参数值。

更新后的`add()`功能将是，

```py
def add(a=0, b=0):
    return (a+b)
```

一切都结束了。

```py
>>> print add(10, 6)
>>> print add()
```

16 0

* * *

### 别名函数名

Python 有一个特别的功能，可以为任何函数创建一个别名，即如果你认为一个函数名太长，不值得每次都输入，你可以为它决定一个新的名字，而不改变原来的函数。以`add()`函数为例，假设我们想要为这个函数取一个更短或不同的名称，但不需要编辑原始函数，我们可以通过使用函数别名功能来实现。假设我们想把`add()`改名为`a()`，那么，

```py
>>> a = add
```

完成了。在这一行之后，`add()`和`a()`将调用相同的函数，因此，显然，参数也需要相同。因此现在下面将像`add()`功能一样工作，

```py
>>> print a(9, 8)
```

Seventeen

* * *

* * *