# Python 类

> 原文：<https://www.studytonight.com/python/class-in-python>

在本教程中，我们将学习如何用 Python 定义一个类。

正如在上一个教程中所讨论的，类是绑定在一起的变量和函数的集合。

* * *

### 定义类的语法

定义一个类很简单，你所要做的就是使用关键字`class`，后跟你想给你的类起的名字，然后是一个冒号符号`:`。标准的做法是以大写字母作为类名的开头，然后遵循 camel case 样式。

包含了类定义，从下一行开始，应该缩进，如下面的代码所示。此外，一个类中可以有变量和成员函数。

```py
class MyClass:
    # member variables
	variable1 = something
	variable2 = something

	# member functions
	def function1(self, parameter1, ...):
		self.variable1 = something else
		# defining a new variable 
		self.variable3 = something
		function1 statements...

	def function2(self, parameter1, ...):
		self.variable2 = something else
		function2 statements...
```

让我们试着理解上面的代码，尽管它是不言自明的。如前所述，我们使用了关键字`class`，通知编译器从这里开始一个新的类定义，然后是类名，即`MyClass`。

在第 2 行，我们添加了一个注释，在第 3 行和第 4 行，我们声明了两个变量`variable1`和`variable2`，并用一些值初始化了它们。

这只是一个解释我们如何定义一个类的例子，我们将在这一节之后看到一个类的例子。

下面定义了两个函数。同样，我们提到示例函数只是为了解释语法。

正如您在代码中看到的，这几乎是我们在没有类的情况下使用`def`关键字所做的常见函数定义，除了一个名为`self`的新参数。这就是类的功能不同于通常功能的地方。

对于类中定义的每个函数来说，这是一个强制参数。`self`表示类的当前活动对象，使用该对象调用类的函数。不要担心，如果你不能理解它，我们将在了解对象时再次解释这一点。

这就是我们在 python 中定义类的方式，现在让我们了解如何创建类的实例/对象

* * *

## 为类创建对象

班级只是一个蓝图或模板。当我们定义一个类时，没有分配存储。对象是类的实例，它保存类中声明的数据变量，成员函数对这些类对象起作用。

要创建一个对象，我们要做的就是:

```py
myObject = MyClass()
```

其中，`MyClass`是类名，`myObject`是对象变量

如您所见，我们简单地指定了对象的名称，并调用了一个函数，该函数与它所属的类具有相同的名称**。**

 **你还记得我们是如何通过写`myList = list()`来初始化列表的吗？这里的情况类似，我们创建了一个名为`MyClass`的用户定义数据类型(一个类)，为了通知 python`myObject`变量将属于该数据类型，我们调用了这个函数。

* * *

### 举个例子

到目前为止，它只是理论，帮助你理解类是如何定义的，对象是如何在 python 中创建的。接下来，我们将看到如何使用对象来调用成员函数和变量(在类中定义)。

让我们编写一个小的 python 程序，其中我们将定义一个具有一个变量和两个方法的类，然后我们将创建该类的一个对象，并尝试访问变量和成员函数。

```py
class Apollo:
    # define a variable
    destination = "moon";

    # definig the member functions
    def fly(self):
        print ("Spaceship flying...");

    def get_destination(self):
        print ("Destination is: " + self.destination)
```

我们已经定义了一个名为`Apollo`的类。如您所见，在函数`get_destination`中，我们编写了`self.destination`，这将给出存储在变量`destination`中的值，该变量用于调用函数`get_destination`的**对象**。

迷茫？别担心，你会明白的，让我们为这个类快速创建两个对象。所以为了创造物体，我们知道该做什么，

```py
class Apollo:
    # define a variable
    destination = "moon"

    # defining the member functions
    def fly(self):
        print ("Spaceship flying...");

    def get_destination(self):
        print ("Destination is: " + self.destination);

# 1st object
objFirst = Apollo()
# 2nd object
objSecond = Apollo()
```

现在我们已经为我们的类定义了两个对象。到目前为止，我们的两个对象都有一个变量`destination`，它被赋予了值**“月亮”**。

要使用对象访问任何成员变量或成员函数，我们使用`.`(点)，如下所示。

```py
class Apollo:
    # define a variable
    destination = "moon"

    # defining the member functions
    def fly(self):
        print ("Spaceship flying...");

    def get_destination(self):
        print ("Destination is: " + self.destination);

# 1st object
objFirst = Apollo();
# 2nd object
objSecond = Apollo();

# lets change the destination for objFirst to mars
objFirst.destination = "mars";
```

在上面的代码中，我们已经为对象`objFirst`将变量`destination`的值更新为**“火星”**

现在让我们调用成员函数。

```py
class Apollo:
    # define a variable
    destination = "moon"

    # defining the member functions
    def fly(self):
        print ("Spaceship flying...");

    def get_destination(self):
        print ("Destination is: " + self.destination);

# 1st object
objFirst = Apollo();
# 2nd object
objSecond = Apollo();

# lets change the destination for objFirst to mars
objFirst.destination = "mars";

# objFirst calling fly function
objFirst.fly();
# objFirst calling get_destination function
objFirst.get_destination();

# objSecond calling fly function
objSecond.fly();
# objSecond calling get_destination function
objSecond.get_destination();
```

宇宙飞船飞行...目的地是:火星飞船飞行...目的地是:月球

### 需要注意的几点:

1.  我们在定义成员函数时添加了`self`参数，但是在调用函数时没有指定。
2.  当我们为`objFirst`调用`get_destination`函数时，它给出的输出为**目的地为:火星**，因为我们为对象`objFirst`更新了变量`destination`的值
3.  要使用对象访问成员函数或成员变量，我们使用点`.`符号。
4.  为了创建任何类的对象，我们必须调用与该类同名的函数。

* * *

* * ***