# Python 中的多态

> 原文：<https://www.studytonight.com/python/python-polymorphism>

多态是[面向对象编程](oops-basics-python)的一个概念，意思是多种形式或者多种形式。多态允许使用单个接口输入不同的数据类型、不同的类或不同数量的输入。

在 python 中，因为所有的东西都是一个对象，所以默认情况下，函数可以接受任何东西作为参数，但是函数的执行可能会失败，因为每个函数都有一些逻辑。

例如，

```py
len("hello")      # returns 5 as result
len([1,2,3,4,45,345,23,42])     # returns 8 as result
```

在这种情况下，函数`len`是多态的，因为它在第一种情况下将**字符串**作为输入，而在第二种情况下将**列表**作为输入。

在 python 中，多态是一种让函数接受行为相似的不同类的对象的方式。

**方法覆盖**是一种多态类型，其中扩展父类的子类可以根据自己的需求为父类中定义的任何函数提供不同的定义。

* * *

## 方法重载

[方法覆盖](method-overriding-in-python)或函数重载是多态的一种类型，在这种类型中，我们可以定义许多具有相同名称但具有不同数量参数的方法，并且参数可以是不同的类型。这些方法可以执行相似或不同的功能。

Python 不支持基于函数中不同参数数量的方法重载。

* * *

## 定义多态类

想象一个情况，我们有一个不同的形状类，如正方形，三角形等，作为一个资源来计算该形状的面积。每个形状都有不同的维数，用于计算相应形状的面积。

现在一种方法是用不同的名称定义不同的函数来计算给定形状的面积。描述这种方法的程序如下所示:

```py
class Square:
    side = 5     
    def calculate_area_sq(self):
        return self.side * self.side

class Triangle:
    base = 5
    height = 4
    def calculate_area_tri(self):
        return 0.5 * self.base * self.height

sq = Square()
tri = Triangle()
print("Area of square: ", sq.calculate_area_sq())
print("Area of triangle: ", tri.calculate_area_tri())
```

正方形面积:25 三角形面积:10.0

这种方法的问题是开发人员必须分别记住每个函数的名称。在一个大得多的程序中，很难记住每个小操作的函数名。方法重载的作用来了。

现在让我们更改函数的名称来计算面积，并赋予它们相同的名称`calculate_area()`，同时在两个定义不同的类中分别保留函数。在这种情况下，对象的类型将有助于解析对函数的调用。下面的程序展示了用类方法实现这种类型的多态:

```py
class Square:
    side = 5     
    def calculate_area(self):
        return self.side * self.side

class Triangle:
    base = 5
    height = 4
    def calculate_area(self):
        return 0.5 * self.base * self.height

sq = Square()
tri = Triangle()
print("Area of square: ", sq.calculate_area())
print("Area of triangle: ", tri.calculate_area())
```

正方形面积:25 三角形面积:10.0

如您所见，在两个类的实现中，即`Square`和`Triangle`具有相同名称的函数`calculate_area()`，但是由于不同的对象，其调用被正确解析，即当使用对象`sq`调用函数时，调用类`Square`的函数，当使用对象`tri`调用函数时，调用类`Triangle`的函数。

### 类方法的多态

我们在上面的例子中看到的是明显的行为。让我们使用一个循环来迭代各种形状的对象元组，并调用面积函数来计算每个形状对象的面积。

```py
sq = Square()
tri = Triangle()

for(obj in (sq, tri)):
    obj.calculate_area()
```

这是多态的一个更好的例子，因为现在我们把不同类的对象当作一个对象，在这个对象上调用同一个函数。

在这里，python 不关心调用函数的对象类型，因此使类方法本质上是多态的。

### 函数的多态

就像我们在上面的例子中使用了一个循环一样，我们也可以创建一个函数，该函数将某个形状类的对象作为输入，然后调用该函数为其计算面积。例如，

```py
find_area_of_shape(obj):
    obj.calculate_area()

sq = Square()
tri = Triangle()

# calling the method with different objects
find_area_of_shape(sq)
find_area_of_shape(tri)
```

在上面的例子中，我们使用了相同的函数`find_area_of_shape`来计算两个不同形状类别的面积。同一个函数以不同的类对象作为参数，完美地执行以返回结果。这就是多态。

* * *

* * *