# Python 中的静态变量和方法

> 原文：<https://www.studytonight.com/python/python-static-keyword>

定义静态变量和方法是一个常见的编程概念，在 [C++](/cpp/introduction-to-cpp.php) 、 [Java](/java/overview-of-java.php) 、Php 和许多其他编程语言中被广泛使用，用于创建属于该类并由该类的所有对象共享的类变量和方法。

在 Python 中，没有创建静态变量和方法的特殊关键字。Python 遵循一种不同但简单的方法来定义静态变量和方法，我们将在本教程中学习。

## Python 中的类或静态变量

类或静态变量是属于类而不属于对象的变量。类或静态变量在类的对象之间共享。在类声明中被赋值的所有变量都是类变量。在类方法中赋值的变量是实例变量。

让我们举个例子来理解这一点:

在上面的程序中，`cat`是一个类变量，因为它是在所有类方法之外和类定义之内定义的，`type`是一个实例变量，因为它是在一个方法之内定义的。

这可以通过`print`语句来确认，其中`cat`变量使用类名`Shape`来引用，而`type`变量使用不同的对象引用来引用。

上面的例子展示了一个场景，其中有不同的形状对象，每个都属于相同的类别，即**几何**，但是属于不同的类型，因此类的每个对象都有相同的类别，我们已经将该类别作为类变量，并且`type`变量对于所有对象都是不同的，因此它是一个实例变量。

**注意:** Python 允许为类/静态变量和实例变量提供相同的变量名。但是我们建议您不要为这些变量提供相同的名称变量，以避免混淆。

* * *

## Python 中的静态方法

就像静态变量一样，静态方法是绑定到类而不是类的对象的方法，因此使用类名而不是类的对象来调用。

由于静态方法绑定到类，因此它们不能改变对象的状态。

要调用静态方法，我们不需要任何类对象，它可以直接使用类名来调用。

在 python 中，有两种定义静态方法的方法:

1.  使用`staticmethod()`
2.  使用`@staticmethod`

### 使用`staticmethod()`定义静态方法

让我们举个例子来看看这是如何做到的:

```py
class Shape:

    def info(msg):
        # show custom message
        print(msg)
        print("This class is used for representing different shapes.")

# create info static method
Shape.info = staticmethod(Shape.info)

Shape.info("Welcome to Shape class") 
```

欢迎来到形状类这个类用于表示不同的形状。

在上面的程序中，我们使用`staticmethod()`函数方法将`info`方法声明为类外的静态方法，之后我们可以直接使用类`Shape`调用`info()`方法。

* * *

### 使用`@staticmethod`定义静态方法

让我们举个例子来看看这是如何做到的:

```py
class Shape:

    @staticmethod
    def info(msg):
        # show custom message
        print(msg)
        print("This class is used for representing different shapes.")

Shape.info("Welcome to Shape class") 
```

欢迎来到形状类这个类用于表示不同的形状。

使用`@staticmethod`是定义静态方法的更现代的方法，我们推荐这种方法。

* * *

### 静态变量和方法的注意事项

以下是一些重要的要点:

1.  当我们想要定义一些特定于类的行为或属性时，静态变量和方法被使用，这对于所有的类对象来说是通用的。
2.  如果仔细观察，对于静态方法，我们不提供参数`self`，因为静态方法不对对象进行操作。

* * *

* * *