# Python 中的运算符重载

> 原文：<https://www.studytonight.com/python/python-operator-overloading>

[运算符](operators-in-python)在 Python 中用于对给定的操作数执行特定的操作。Python 中已经定义了任何特定运算符对任何预定义数据类型执行的操作。

对于不同类型的操作数，每个运算符都可以以不同的方式使用。例如，`+`运算符用于**将两个整数**相加，得到一个整数，但是当我们将其与**浮点操作数**一起使用时，结果是一个浮点值，而当`+`与**字符串操作数**一起使用时，它将所提供的两个操作数连接起来。

对于不同类型的操作数，单个操作符的这种不同行为被称为**操作符重载**。不同操作数类型的`+`运算符的用法如下所示:

```py
>>> x=10
>>> y=20
>>> x+y
30

>>> z=10.4
>>> x+z
20.4

>>> s1 = 'hello '
>>> s2 = 'world'
>>> s1+s2
'hello world' 
```

### `+`运算符可以添加任何内容吗？

答案是否定的，不能。可以使用`+`运算符添加一个类的两个对象吗。`+`运算符可以添加两个整数值、两个浮点值，或者仅用于连接两个字符串，因为这些行为已在 python 中定义。

因此，如果您想使用同一个操作符来添加某个用户定义类的两个对象，那么您必须自己定义该行为并通知 python。

如果你还不清楚，我们创建一个类，试着用`+`运算符添加该类的两个对象，

```py
class Complex:
    def __init__(self, r, i):
        self.real = r
        self.img = i

c1 = Complex(5,3)
c2 = Complex(2,4)
print("sum = ", c1+c2) 
```

回溯(最近一次调用最后一次):File/tmp/sessions/1 DFB e78 bb 701d 99d/main . py "，第 7 行，在<module>print(“sum =，c1+c2”)类型错误:不支持+:“Complex”和“Complex”</module>的操作数类型

所以我们可以看到在一个用户定义的类中不支持`+`运算符。但是我们可以通过为我们的类`Complex`重载`+`运算符来实现同样的目的。但是我们怎么做呢？

* * *

## Python 中的特殊函数

python 中的特殊函数是用于执行特殊任务的函数。这些特殊函数的名字有`__`作为前缀和后缀，正如我们在`__init__()`方法中看到的，这也是一个特殊函数。用于重载运算符的一些特殊函数如下所示:

### 数学运算符

下面是 python 中重载数学运算符的特殊函数的名称。

| 名字 | 标志 | 特殊函数 |
| 添加 | `+` | `__add__(self, other)` |
| 减法 | `-` | `__sub__(self, other)` |
| 分开 | `/` | `__truediv__(self, other)` |
| 楼层划分 | `//` | `__floordiv__(self, other)` |
| 模数(或余数) | `%` | `__mod__(self, other)` |
| 力量 | `**` | `__pow__(self, other)` |

### 赋值运算符

下面是 python 中重载赋值运算符的特殊函数的名称。

| 名字 | 标志 | 特殊函数 |
| 增量 | `+=` | `__iadd__(self, other)` |
| 减量 | `-=` | `__isub__(self, other)` |
| 产品 | `*=` | `__imul__(self, other)` |
| 分开 | `/=` | `__idiv__(self, other)` |
| 系数 | `%=` | `__imod__(self, other)` |
| 力量 | `**=` | `__ipow__(self, other)` |

### 关系运算子

下面是 python 中重载关系运算符的特殊函数的名称。

| 名字 | 标志 | 特殊函数 |
| 不到 | `<` | `__lt__(self, other)` |
| 大于 | `>` | `__gt__(self, other)` |
| 等于 | `==` | `__eq__(self, other)` |
| 不平等 | `!=` | `__ne__(self, other)` |
| 小于或等于 | `<=` | `__le__(self, other)` |
| 大于或等于 | `> =` | `__gt__(self, other)` |

是时候看一些代码示例了，在这些示例中，我们实际上使用了上面指定的特殊函数并重载了一些运算符。

* * *

### 超载`+`操作员

在下面的代码示例中，我们将为我们的类`Complex`重载`+`运算符，

```py
class Complex:
    # defining init method for class
    def __init__(self, r, i):
        self.real = r
        self.img = i

    # overloading the add operator using special function
    def __add__(self, sec):
        r = self.real + sec.real
        i = self.img + sec.img
        return complx(r,i)

    # string function to print object of Complex class
    def __str__(self):
        return str(self.real)+' + '+str(self.img)+'i'

c1 = Complex(5,3)
c2 = Complex(2,4)
print("sum = ",c1+c2)
```

总和= 7 + 7i

在上面的程序中， `__add__()`用于重载`+`运算符，即当`+`运算符用于两个`Complex`类对象时，调用函数`__add__()`。

`__str__()`是另一个特殊功能，用于提供适合打印的对象格式。

* * *

### 超载`<`操作员

现在让我们重载小于运算符，这样我们就可以通过使用小于运算符`<`轻松比较两个`Complex`类对象的值。

我们现在知道，要做到这一点，我们必须在我们的类中定义`__lt__`特殊函数。

根据您对比较类对象的要求，您可以为覆盖运算符的特殊函数定义逻辑。在上面的代码中，我们给出了复数的实数部分的优先级，如果该部分小于，则整个复数小于，如果该部分等于，则我们检查虚数部分。

### 结论

在 python 中，使用特殊函数重载操作符很容易，也不容易混淆。

* * *

* * *