# Python 异常处理

> 原文：<https://www.studytonight.com/python/exception-handling-python>

异常处理是 Python 中使用的一个概念，用于处理任何程序执行过程中出现的异常和错误。异常是代码执行过程中可能出现的意外错误。在上一个教程中，我们已经介绍了 python 中的 [**异常和错误。**](/python/introduction-to-error-exception-python)

嗯，是的，异常会发生，您的代码中可能会有错误，但是我们为什么要投入时间来处理异常呢？

这个问题的答案是**提升用户体验**。发生异常时，会发生以下情况:

*   程序执行突然停止。
*   控制台上会打印完整的异常消息以及文件名和代码行号。
*   直到代码中的那个点之前执行的所有计算和操作都将丢失。

现在想想有一天你在用**study south**的网站，你点击了某个链接打开了一个教程，不知什么原因，导致了一些异常。如果我们没有处理异常，那么你会看到异常消息，而网页也没有加载。你会喜欢吗？

因此，异常处理对于优雅地处理错误和显示适当的消息来通知用户故障是非常重要的。

* * *

## 使用`try`和`except`处理异常

为了在 Python 中处理异常，我们使用了两种类型的块，即`try`块和`except`块。

在`try`块中，我们编写了可能出现任何错误或异常的代码。

而`except`块负责捕获异常并执行其中指定的语句。

下面是执行**除以零**的代码:

```py
a = 10
b = 0
print("Result of Division: " + str(a/b)) 
```

回溯(最近一次调用最后一次):文件“main.py”，第 3 行，在<module>打印中(“除法结果:“+ str(a/b))”零除法错误:被零除</module>

上述代码导致异常，异常消息作为输出打印在控制台上。

如果我们使用`try`和`except`块，我们可以优雅地处理这个异常。

```py
# try block
try:
    a = 10
    b = 0
    print("Result of Division: " + str(a/b))
except:
    print("You have divided a number by zero, which is not allowed.") 
```

你把一个数除以零，这是不允许的。

* * *

### `try`块

如您在上面的代码示例中所见，`try`块用于将整个要执行的代码放入程序中(您认为这会导致异常)，如果在执行`try`块中的代码时发生任何异常，那么它会导致代码的执行被定向到`except`块，并且在`try`块中正在进行的执行被中断。但是，如果没有异常发生，则整个`try`块被执行，并且`except`块从不被执行。

### `except`块

`try`块后面一般是`except`块，里面保存着异常清除代码(*异常已经发生，如何有效处理这种情况*)像一些`print`语句到**打印一些消息**或者可能是**触发一些事件**或者**在数据库**中存储一些东西等等。

在**例外块**中，连同关键字`except`我们还可以提供预计会出现的例外类的**名称。如果我们不提供任何异常类名，它将捕获所有异常，否则它将只捕获所提到的类型的异常。**

以下是**语法**:

```py
# except block
except(<Types of Exceptions to catched>):
    # except block starts 
```

如果你仔细注意，我们已经提到了**类型的异常**，是的，我们甚至可以在**中提供多个异常类的名称，用逗号分隔，除了**语句。

### 代码执行在`except`块后继续

这里需要注意的另一点是，异常发生时`try`块中的代码执行被中断，导致异常的那一行后面的`try`块中的代码语句不执行。

然后执行跳转到`except`块。而在`except`内部的代码语句执行完毕后，就像其他任何正常执行一样，在代码语句执行完毕后对其进行阻塞。

让我们举个例子:

```py
# try block
try:
    a = 10
    b = 0
    print("Result of Division: " + str(a/b))
    print("No! This line will not be executed.")
except:
    print("You have divided a number by zero, which is not allowed.")

# outside the try-except blocks
print("Yo! This line will be executed.") 
```

你把一个数除以零，这是不允许的。哟！这一行将被执行。

* * *

## 捕捉 Python 中的多个异常

有多种方法可以实现这一点。我们可以有多个`except`块，每个块处理一个特定的异常类，或者我们可以在一个`except`块中处理多个异常类。

* * *

### 多个`except`块

如果您认为您的代码可能在不同的情况下生成不同的异常，并且您想要单独处理这些异常，那么您可以有多个`except`块。

当涉及用户输入时，通常会出现异常。让我们举一个简单的例子，我们将要求用户输入两个数字，对它们执行除法运算，并向它们显示结果。

我们将尝试使用多个`except`块来处理多个可能的异常情况。

尝试运行上面的代码，提供 **0** 作为分母的值，看看会发生什么，然后为任何变量提供一些**字符串**(非整数)值。我们已经处理了上面代码中的两种情况。

* * *

### 使用`except`块处理多个异常

正如您在上面的示例中看到的，我们根据发生的异常打印了不同的消息。如果您没有需要单独处理不同异常的需求，那么您也可以在单个异常块中捕获一组异常。

这里是上面代码的单个`except`块:

```py
# try block
try:
    a = int(input("Enter numerator number: "))
    b = int(input("Enter denominator number: "))
    print("Result of Division: " + str(a/b))
# except block handling division by zero
except(ValueError, ZeroDivisionError):
    print("Please check the input value: It should be an integer greater than 0") 
```

在这里，我们使用单个`except`块处理了这两个异常，同时向用户显示了一条有意义的消息。

* * *

### 处理未知异常的通用`except`块

虽然我们确实试图通过测试和使用异常处理来使我们的代码没有错误，但是可能会有一些我们可能错过的错误情况。

因此，当我们使用`except`块来处理特定的异常类时，我们应该总是在末尾有一个**通用** `except`块来处理任何运行时异常(意外事件)。

```py
# try block
try:
    a = int(input("Enter numerator number: "))
    b = int(input("Enter denominator number: "))
    print("Result of Division: " + str(a/b))
# except block handling division by zero
except(ZeroDivisionError):
    print("You have divided a number by zero, which is not allowed.")
# except block handling wrong value type
except(ValueError):
    print("You must enter integer value")
# generic except block
except:
    print("Oops! Something went wrong!") 
```

在上面的代码中，第一个`except`块将处理**零除错误**，第二个`except`块将处理**值错误**，对于可能出现的任何其他异常，我们有第三个`except`块。

在接下来的教程中，我们将学习`finally`块以及如何使用`raise`关键字引发异常。

* * *

* * *