# Python 文件处理操作

> 原文：<https://www.studytonight.com/python/reading-and-writing-file>

在本教程中，我们将学习如何从文件中读取内容，然后将文本写入任何文件，以及如何将文件内容复制到另一个文件中。我们还将使用`tell`和`seek`方法处理[文件](file-handling)。

* * *

## Python -读取文件

让我们从学习如何阅读文件开始。

`readline()`功能用于读取文档中的一行。它可以像这样使用:

```py
>>> myFile.readline()
```

其中`myFile`是文件的实例。`readline()`功能将简单打印从光标位置开始的整行。

为了打印文件的全部内容，逐行迭代，我们可以使用`for`循环:

```py
for line in myFile:
    # will print all the lines one by one
    print (line)
```

除了使用迭代，还有另一种读取整个文件的方式，使用`readlines()`函数(注意是 readline，不同于 readline)。使用函数将返回一个包含文件每行的列表。正因为如此，人们在使用这个功能时应该小心。如果文件中有大量数据，列表可能会占用大量空间，从而使整个读取时间更长。因此，建议仅在读取可以有效存储在列表中的较短文件时使用此功能。

它的使用非常类似于`readlines()`，只是在这种情况下，我们需要将返回值存储在某个变量中:

```py
>>> content = myFile.readlines()
```

类似事情可以使用迭代方法手动完成:

```py
content = []
for line in myFile:
    content.append(line)
```

这将在内容列表中反复追加文件的每一行。

* * *

## Python -写入文件

`write()`函数用于将单个字符串写入文件。例如，有一个字符串

```py
>>> content = "Hello, World. I am learning Python."
# In order to write this line in a file
>>> myFile.write(content)
```

**或**

```py
>>> myFile.write("Hello, World. I am learning Python")
```

Write 不能用于写入列表或元组的内容。在这种情况下，使用`writelines()`函数。

```py
 >>> content = ["Python 3.x\n", "Hello, World. I am learning Python"]
>>> myFile.writelines(content) 
```

执行此操作将使用以下内容写入文件内容:

```py
 Python 3.x
Hello, World. I am learning Python 
```

* * *

## Python -讲述和寻找

正如我们之前提到的，一旦你打开一个文件，就会有一个光标在你读或写的时候不停地移动。有时，移动光标而不每次都读取或写入任何变量是很重要的，为此，有一个`seek()`函数可用于移动到文件中的所需位置。

```py
>>> myFile.seek(offset, [start_from])
```

offset 决定您想要跳过多少字节，这里第二个参数 start_from 是可选的，它决定您想要从哪个位置开始。可能的值可以是-

*   **0 -** 文件开始
*   **1 -** 文件的当前位置
*   **2 -** 文件结束

> *如果没有指定参数，默认情况下为 0。*

假设有一个文件(file.txt)，内容为**你好，世界！**

然后使用如下寻道功能:

```py
>>> myFile = open('file.txt','r+')
>>> myFile.seek(5)
>>> myFile.read()
', World!'
```

这里可以看到，`seek()`函数跳过了前 5 个字节(即**‘你好’**)，读取下一个字节直到行尾。为了获得指针的当前位置，可以使用`tell()`功能。它将返回字节指针远离开始的位置。

```py
>>> myFile.tell()
```

* * *

## Python -复制文件

选择要复制的文件并创建其对象。创建另一个对象并使用`open()`创建一个新文件(如果文件不存在，在`open()`函数中写入路径会创建该文件)。`read()`内容来自第一档。`write()`其他文件中相同。

```py
>>> file1 = open("original.txt", "r")
>>> file2 = open("duplicate.txt", "w")
>>> l = file1.readline()
>>> while l:
 		file2.write(l)
		l = file1.readline()
>>> file1.close()
>>> file2.close()
```

打开文件**replicate . txt**，应该可以看到复制的文字。

* * *

* * *