# Python 中的条件对象——线程同步

> 原文：<https://www.studytonight.com/python/python-threading-condition-object>

为了更有效地同步对任何资源的访问，我们可以将条件与任务相关联，让任何线程等待，直到满足某个条件，或者通知其他线程该条件正在满足，以便它们可以解除对自身的阻止。

让我们举一个简单的例子来理解这一点。在**生产者消费者问题**中，如果有一个生产者生产某一物品，一个消费者消费该物品，那么在生产者生产该物品之前，消费者不能消费该物品。因此，消费者要等到产品生产出来。生产者有责任告知消费者，一旦产品成功生产，就可以消费。

如果有多个消费者消费生产者生产的产品，那么生产者必须通知所有消费者生产的新产品。

这是 python 多线程中条件对象的完美用例。

* * *

## 条件对象:`wait()`、`notify()`和`notifyAll()`

现在我们知道了 python 多线程中条件对象的用途，让我们看看它的语法:

```py
condition = threading.Condition([lock])
```

条件对象接受一个可选的锁对象作为参数。如果我们不提供任何东西，那么它会创建一个默认锁。

条件对象有`acquire()`和`release()`方法，调用关联锁的相应方法。还有`wait()`方法、`notify()`方法、`notifyAll()`方法。这三个只能在调用线程获得锁后调用。

* * *

## 条件类方法

以下是条件类方法:

### `acquire(*args)`方法

此方法用于获取锁。该方法对条件对象中存在的基础锁调用相应的`acquire()`方法；返回值是该方法返回的任何值。

### `release()`方法

此方法用于释放锁。该方法对条件对象中存在的基础锁调用相应的`release()`方法。

### `wait([timeout])`方法

此方法用于阻塞线程，并使其等待，直到其他线程通过在同一条件对象上调用`notify()`或`notifyAll()`方法通知它，或者直到超时发生。

只有当调用线程获得锁时，才能调用这个函数。

当被调用时，这个方法释放锁，然后阻塞线程，直到被其他线程对相同条件变量的`notify()`或`notifyAll()`调用唤醒，或者直到超时发生。

如果由于`notify()`或`notifyAll()`方法而被释放，该方法返回`True`，否则如果超时，该方法将返回`False`布尔值。

### `notify()`方法

它会唤醒任何等待相应条件的线程。只有当调用线程获得锁时，才能调用这个函数。此外，调用此方法只会唤醒一个等待的线程。

### `notifyAll()`方法

它会唤醒所有等待这个条件的线程。这个方法的行为类似于`notify()`方法，但是唤醒了所有等待的线程，而不是一个。

* * *

## 是时候举个例子了！

在下面的代码示例中，我们实现了一个简单的生产者-消费者解决方案，生产者生产一个项目，并将其添加到消费者消费这些项目的列表中。

上面的代码示例中有几个重要的要点:

1.  我们创建了一个类`SomeItem`，它有一个`list`，作为生产者和消费者线程之间的共享资源。
2.  **生产者线程**正在随机生成一些列表项，并将其添加到列表中。
3.  **消费线程**尝试消费物品，如果没有找到物品，则开始等待。如果生产者在超时前向消费者发送关于项目创建的通知，那么消费者消费该项目，否则由于超时而退出。

这是一个非常简单的例子，涵盖了条件对象的所有用例。尝试用 2 个使用者线程和一个生产者线程运行上面的程序。

* * *

* * *