# 屏障对象——Python 多线程

> 原文：<https://www.studytonight.com/python/python-threading-barrier-object>

使用`threading`模块中可用的`Barrier`类创建屏障对象。这个对象可以用在我们希望一组线程相互等待的地方。

例如，如果我们有两个线程，并且我们希望两个线程都准备好了就执行。在这种情况下，一旦准备好，两个线程都将调用屏障对象上的`wait()`方法，并且只有当两个线程都调用了`wait()`方法时，两个线程才会同时释放。

以下是初始化屏障对象的`Barrier`类的语法:

```py
threading.Barrier(parties, action=None, timeout=None)
```

其中，`parties`指定等待屏障的线程数，`action`可用于指定等待屏障的任何一个线程将执行的功能，`timeout`用于指定超时值(以秒为单位)，超过该值后，屏障将从所有等待的线程中释放。

* * *

## `Barrier`类提供的功能

以下是`Barrier`类提供的功能:

### `wait(timeout=None)`方法

当我们希望一组线程相互等待时，我们在创建屏障对象时用指定为`parties`参数的线程数初始化屏障对象。

然后，只有当相同数量的线程调用屏障对象的`wait()`方法时，屏障才会被释放。

如果在一个线程中，我们在调用`wait()`方法时提供了超时值，那么一旦超时时间过去，该线程将从屏障中被释放。

该方法返回一个从 **0** 到**方-1** 的整数值。我们可以使用这个值来识别哪些线程已经到达了屏障的等待点，哪些线程还没有到达，例如:

```py
i = barrier.wait()
if i == 0:
    # Only one thread Will be allowed to print this
    print("0th thread passed the barrier")
```

`wait()`方法的返回值可以用于执行一些清理任务，例如，如果我们有 3 个线程在做一些工作，并使用一个临时文件来存储数据，一旦线程完成，我们可以对`wait()`方法进行检查，当最后一个线程到达其等待点并且屏障要被释放时，在此之前删除该文件。

```py
i = barrier.wait()
if i == 2:
    # delete the temporay file
```

如果等待呼叫超时，屏障进入**断开状态**。

如果当线程等待时屏障破坏或重置，则`wait()`方法可能会发出`BrokenBarrierError`。

### `reset()`方法

该功能将屏障重置为默认的空状态。如果有线程等待屏障被释放，将会收到`BrokenBarrierError`。

### `abort()`方法

当在屏障上调用此方法时，它会进入**破碎状态**。一旦该方法被任何等待线程调用，等待屏障释放的其余线程将接收`BrokenBarrierError`。

我们可能希望在一些死锁情况下使用这个方法来释放等待的线程。

### `parties`

这将返回我们通过屏障所需的线程数。

### `n_waiting`

这将返回当前等待释放屏障的线程数。

### `broken`

这是一个布尔值，如果屏障处于**断开状态**，则该值为`True`。

* * *

## 是时候举个例子了！

下面我们有一个简单的例子，其中我们有两个线程分别代表**服务器**和**客户端**，其中客户端线程将等待服务器准备就绪后再向其发送任何请求。

在上面的代码中，尝试在客户端或服务器端调用`abort()`方法，看看会发生什么。您可能需要使用`try`块并捕捉代码中的`BrokenBarrierError`。

* * *

* * *