# Python 闭包

> 原文：<https://www.studytonight.com/python/python-closures>

为了理解 python 中闭包的概念，我们必须知道什么是嵌套函数和非 loc al 变量。所以我们先从他们开始。

## 嵌套函数和非局部变量

当一个函数在另一个函数中定义时，这被称为函数嵌套，其中，在其中定义另一个函数的函数被称为**外部函数**，而在另一个函数中定义的函数被称为**内部函数**。描述嵌套函数使用的示例如下所示:

```py
#defining nested function
def outer(message):
    #text is having the scope of outer function
    text = message
    def inner():
        #using non-local variable text
        print(text)
    #calling inner function
    inner() 

# main method
if __name__=='__main__':
    outer('Hello!')
```

你好！

在上面的代码片段中，内部函数`inner()`能够访问外部函数`outer()`的局部变量`text`，其范围扩展到`outer()`函数的整个主体。外部函数的局部变量`text`是内部函数的**非局部变量**，它可以访问但不能修改。

* * *

## 理解闭包的概念

闭包是一个函数对象(一个行为类似于对象的函数)，它会记住封闭范围中的值，即使它们不在内存中。

当一个函数在另一个函数中可用时，就创建了闭包。即使在外部函数返回之后，内部函数也可以访问外部函数的变量和参数。这意味着我们可以稍后调用内部函数，它将可以访问外部函数的变量和参数。实际上，闭包引用了外部函数的变量和参数。我们可以说，闭包是一个记录，它将一个函数和一个环境存储在一起。

```py
#defining nested function
def outer(message):
    #text is having the scope of outer function
    text = message
    def inner():
        #using non-local variable text
        print(text)
    #return inner function
    return inner 

# main method
if __name__=='__main__':
    func = outer('Hello!')
    func()
```

你好！

在上面的例子中，我们使用闭包来访问其范围之外的`inner()`函数，因为`inner()`函数只在`outer()`函数内部可用，但是通过返回它，我们可以在`outer()`函数外部访问它。

然后在主方法中，我们调用了`outer()`函数，并返回了对`func`变量的`inner()`函数引用。

现在，`func`变量引用了`inner()`函数，这意味着当我们将括号用于`func`变量时，它就像`inner()`函数一样工作，访问在声明`func`变量时调用的`outer()`函数的`text`变量。

我们再举一个例子:

这个例子稍微复杂一点，因为这里我们在内部`operation(n)`函数中使用了参数。因此，当调用`inrementor(m)`函数时，它返回对`operation(n)`函数的引用。

在定义变量`incrementby1`、`incrementby5`和`incrementby9`时，我们每次都传递了`m`参数的值。

因此，变量`incrementby1`、`incrementby5`和`incrementby9`分别引用`operation(n)`函数，其中`m`参数的值设置为 **1** 、 **5** 和 **9** 。

然后在使用变量`incrementby1`、`incrementby5`和`incrementby9`调用`operation(n)`函数时，我们也传递了`n`的值，因此得到了期望的输出。

* * *

### 关于闭包需要记住的要点

以下是一些有用的要点，它们也是在 python 中实现闭包的必要条件:

1.  应该有嵌套函数，即函数内部的函数。
2.  内部函数必须引用非局部变量或外部函数的局部变量。
3.  外部函数必须返回内部函数。

* * *

### 何时使用闭包？

以下是 python 中应该使用闭包的一些用例。

*   闭包可以避免使用全局值。
*   它提供了某种形式的数据隐藏。
*   当一个类中实现的方法很少(大多数情况下只有一个方法)时，闭包可以提供更好的解决方案。但是当属性和方法的数量较多时，最好实现一个类。

* * *

* * *