# Python 中的垃圾收集

> 原文：<https://www.studytonight.com/python/python-garbage-collection>

在任何程序中，垃圾都是程序没有使用的内存集合，或者已经在给定的时间点使用但不再使用的内存集合。由于该内存空间仍分配给程序，但未被程序使用，因此需要清理的是浪费的内存。

**垃圾收集**是在给定的时间实例中释放特定程序未使用的内存的过程。

这个过程有助于内存管理，并最大限度地减少内存浪费。垃圾收集释放的内存可用于存储同一程序或其他程序的其他重要数据或变量。

* * *

## Python:自动垃圾收集

Python 中的垃圾收集自动工作。当没有对变量/数据/值或对象的引用时，python 的垃圾收集机制会释放该对象占用的内存。因此，python 提供了良好的内存管理，防止了内存的浪费。

下面的例子展示了 python 垃圾收集的工作原理:

```py
class SomeObj:

    def __init__(self):
        print('The object is created.')

    def __del__(self):
        print('The object is destroyed.')

obj1 = SomeObj()
obj2 = obj1
obj3 = obj1
print("Set obj1 to None...")
obj1 = None
print("Set obj2 to None...")
obj2 = None
print("Set obj3 to None...")
obj3 = None 
```

对象被创建。将对象 1 设置为无...将对象 2 设置为无...将 obj3 设置为无...物体被摧毁了。

在上例中，创建了一个类`SomeObj`的对象，该对象由**对象 1** 引用。然后， **obj2** 和 **obj3** 也指与 **obj1** 相同的存储位置。

创建对象后， [`__init__` (init)方法称为](constructors-in-python)，当对象被破坏时，由于垃圾收集 [`__del__` (del)方法称为](destructors-in-python)。

在示例中，首先，我们创建了一个`SomeObj`类的对象，并将其引用传递给 **obj1** ，然后传递给 **obj2** 和 **obj3** ，这使得该对象的引用计数为 3。但是当所有这些变量都分配给 **None** 时，对象的引用就被移除了。

最后，当对象没有引用时，python 的垃圾收集器会自动销毁该对象，并执行`__del__()`方法。

* * *

## Python:强制垃圾收集

有时，用户可能需要明确地为内存管理进行垃圾收集，以便释放一些内存空间。因此，python 也允许显式垃圾收集，这可以使用 **gc** 模块来完成。垃圾收集可以使用**垃圾收集模块**的`collect()`功能强制进行，如下图所示:

```py
 import gc

class SomeObj:

    def __del__(self):
        print('The object is destroyed.')

obj1 = SomeObj()
obj2 = obj1
obj3 = obj1
obj1 = None
obj2 = None
obj3 = None

for i in range(10):
    dic = {}
    dic[0] = dic

print('Collecting...')
n = gc.collect()
print('Unreachable objects:', n)
```

物体被摧毁了。收集...无法访问的对象:9

在上面的例子中，创建的简单对象(属于`SomeObj`类)被 python 的隐式垃圾收集器销毁。但是对象`dic`的情况就不一样了，它是一个字典，一次又一次地指向自己，形成一个循环。在这个循环中形成的对象不能被 python 垃圾收集器隐式销毁。

因此，为了销毁由循环创建的对象(即由`for`循环运行的对象)，我们使用了 **gc 模块**的`collect()`方法。

`collect()`方法运行垃圾收集并销毁未使用的对象，这些对象是引用计数为 **0** 的对象。collect 方法返回不可达对象的数量，这里不可达对象是指引用计数为 0 的对象。

* * *

* * *