# Python 浅和深复制

> 原文：<https://www.studytonight.com/python/python-shallow-and-deep-copy>

在理解浅复制和深复制的概念之前，我们必须首先清除(如果有)围绕 python 中复制如何工作的疑虑。

在 python 中，就像任何其他编程语言一样，我们可以使用运算符`=`将一个变量的值复制到另一个变量中。

在 python 中，当我们使用`=`运算符为当前被其他变量引用的变量赋值时，不会创建新的数据副本，而是由两个不同的变量/对象引用相同的数据副本。

例如，

```py
old_str = "Hello World!"
new_str = old_str

print("Id of old string:" + old_str +" is: ", id(old_str))
print("Id of new string:" + new_str +" is: ", id(new_str)) 
```

老串的 Id:你好世界是:139681093231344 新字符串的 Id:Hello World！是:139681093231344

从上面的代码中可以看到，两个变量引用了同一个字符串。不仅仅是字符串，而是每个对象，python 中的所有东西都是对象。

那么，我们如何在 python 中实现深度复制和深度复制，让我们看看。

* * *

## Python `copy`模块

Python 有一个**复制模块**，允许用户将对象从一个变量复制到另一个变量。我们知道，当我们将一个变量赋给另一个变量时，这两个变量都只指向一个对象。因此，我们使用 python 的复制模块来管理对象的复制过程。

主要使用复制模块的两个功能:

*   `copy.copy()`
*   `copy.deepcopy()`

让我们一个接一个地理解如何使用这两个函数。

* * *

### Python 深度复制

`copy.deepcopy(x)`函数用于在 python 中执行深度复制。此方法用于创建任何对象的深度副本`x`。对于深度复制，通过从主对象获取数据并将其复制到新对象中来创建额外的单个对象。因此，如果复制的引用有任何变化，主对象将保持原样。

例如:

```py
import copy

l1=[1,3,[9,4],6,8]
l2=copy.deepcopy(l1) #Making a deep copy

print('List 1 = ', l1)
print('List 2 = ', l2)

print('Performing change in list 2')
l2[2][0] = 5

print('List 1 = ',l1)
print('List 2 = ',l2)
```

列表 1 = [1，3，[9，4]，6，8]列表 2 = [1，3，[9，4]，6，8]在列表 2 中执行更改列表 1 = [1，3，[9，4]，6，8]列表 2 = [1，3，[5，4]，6，8]

从上面的例子中我们可以看到，`l1`(第一个列表)是`l2`(第二个列表)的深度复制。所以，当我们在`l2`中更新一些数据项时，它并没有反映在`l1`中。

* * *

### Python 浅拷贝

`copy.copy(x)`函数用于在 python 中执行浅复制。此方法用于创建任何对象的浅拷贝`x`。对于浅复制，对象的引用被复制到另一个对象。所以如果复制的引用有什么变化，也会改变主对象的内容。在某种程度上，这就像 python 中正常的复制工作一样。

例如:

```py
import copy

l1 = [1,3,[9,4],6,8]
l2 = copy.copy(l1) #Making a shallow copy

print('List 1 = ', l1)
print('List 2 = ', l2)

print('Performing change in list 2')
l2[2][0] = 5

print('List 1 = ',l1)
print('List 2 = ',l2) 
```

列表 1 = [1，3，[9，4]，6，8]列表 2 = [1，3，[9，4]，6，8]在列表 2 中执行更改列表 1 = [1，3，[5，4]，6，8]列表 2 = [1，3，[5，4]，6，8]

从上面的例子可以看出，`l2`(第二个列表)提供了`l1`(第一个列表)的浅拷贝。这意味着`l2`所指的对象与`l1`所指的对象相同。所以，如果我们在`l2`做任何改变，它也会改变列表`l1`。

* * *

* * *