# NumPy 数组创建——`empty`、`zeroes`和`ones`

> 原文：<https://www.studytonight.com/numpy/python-numpy-array-creation-empty-zeroes-and-ones>

在本教程中，我们将学习如何在 Numpy 库中创建数组。

在 Numpy 中，可以通过以下给定的数组创建例程或使用低级别的数组构造器来构造新的**数组**对象

*   `numpy.empty`

*   `numpy.zeroes`

*   `numpy.ones`

## 1.空数组-使用`numpy.empty`

这用于创建指定形状和`dtype`的未初始化数组。

使用此构造器的语法如下:

```py
numpy.empty(shape, dtype, order) 
```

下面是此构造器对参数的描述:

*   **形状:**
    此参数用于指示指定数组的所需形状。

*   **数据类型:**
    该参数表示数组项的数据类型。此参数的默认值是 float。

*   **顺序:**
    此选项的默认顺序或值是 c 风格的行-主顺序。对于 FORTRAN 风格的(列-主顺序)，该参数可设置为 **F**

### 使用`numpy.empty`基本示例:

下面的代码用于创建一个空数组。此外，数组中的元素将显示随机值，因为它们没有初始化:

```py
import numpy as np 

# an array with 4 rows and 3 columns
x = np.empty([4,3], dtype = int) 
print (x)
```

[[206 0 0]
[0 0 0]
[0 0]
[0 0 0]]

## 2.零值数组-使用`numpy.zeroes`

这用于返回一个指定大小的新数组，每个数组项都将被 **0** 初始化。

使用此构造器的语法如下:

```py
numpy.zeros(shape, dtype, order) 
```

下面是此构造器对参数的描述:

*   **形状:**
    此参数用于指示指定数组的所需形状。

*   **数据类型:**
    该参数表示数组项的数据类型。此参数的默认值是 float。

*   **顺序:**
    此选项的默认顺序或值是 c 风格的行-主顺序。对于 FORTRAN 风格的(列-主顺序)，该参数可设置为 **F**

### 使用`numpy.zeroes`基本示例:

下面的代码示例将创建一个维度 3x3 的数组，所有元素都初始化为 0。

```py
import numpy as np  

arr = np.zeros((3,3), dtype = int)  
print(arr) 
```

[[0 0 0]
[0 0 0]
[0 0]]

## 3.一值数组-使用`numpy.ones`

这用于返回指定大小的新数组，每个数组项将被初始化为 **1** 。

使用此构造器的语法如下:

```py
numpy.ones(shape, dtype, order) 
```

下面是此构造器对参数的描述:

*   **形状:**
    此参数用于指示指定数组的所需形状。

*   **数据类型:**
    该参数表示数组项的数据类型。此参数的默认值是 float。

*   **顺序:**
    此选项的默认顺序或值是 c 风格的行-主顺序。对于 FORTRAN 风格的(列-主顺序)，该参数可设置为 **F**

### 使用`numpy.ones`基本示例:

这里有一个基本的例子:

```py
import numpy as np  

arr = np.ones((3,3), dtype = int)  
print(arr) 
```

[[1 1 1]
[1 1 1]
[1 1 1]]

## 摘要

本教程是关于 Numpy 库中的数组创建技术的，我们介绍了不同的数组创建方法及其语法、参数和示例。

* * *

* * *