# 从数值范围创建 Numpy 数组

> 原文：<https://www.studytonight.com/numpy/python-numpy-array-creation-from-numerical-ranges>

在本教程中，我们将学习如何使用一些给定的指定数值范围来创建 NumPy 数组。

Numpy 库提供了一些从给定的指定范围创建数组的函数。这些功能如下:

1.  `numpy.arange`

2.  `numpy.linspace`

3.  num py . logs space

现在我们将逐一讨论上面给出的函数。

## 1.使用`numpy.arange`

该函数用于通过在任意给定间隔内使用均匀间隔的值来创建数组。

使用此函数的语法如下:

```py
numpy.arrange(start, stop, step, dtype) 
```

**参数:**

上述函数的参数如下:

*   **开始:**
    该参数主要表示一个区间的开始。此参数的默认值为 0。

*   **stop:**
    该参数用于表示区间结束时的值，不包括该值。

*   **步:**
    此参数表示间隔值变化的次数。

*   **数据类型:**
    该参数表示 numpy 数组项的数据类型。

### 例 1:

```py
import numpy as np 

x = np.arange(15) 
print (x)
```

【0 1 2 3 4 5 6 7 8 9 10 11 12 13 14】

### 例 2:

下面我们有一个使用这个函数的代码片段，其中我们将创建一个带有虚拟数字的数组。

```py
import numpy as np  

arr = np.arange(0,10,2,complex)  
print(arr) 
```

【0。+0.j 2。+0.j 4。+0.j 6。+0.j 8。+0.j]

## 2.使用`numpy.linspace`

该功能类似于`arange()`功能。但是有一个主要的区别，就是在这个函数中，不是**步长**，而是使用`num`参数指定间隔之间的均匀间隔值的数量。

使用此函数的语法如下:

```py
numpy.linspace(start, stop, num, endpoint, retstep, dtype) 
```

**参数:**

上述函数的参数如下:

*   **开始:**
    该参数用于表示区间的开始值。

*   **停止:**
    该参数用于表示区间的停止值。

*   **num:**
    该参数表示在要生成的间隔内**数量的均匀间隔样本**。该参数的默认值为 **50** 。

*   **终点:**
    该参数的真值用于表示区间中包含停止值。

*   **retstep:**
    该参数的值是一个**布尔**值，用于**表示连续数字之间的步数和样本**。

*   **数据类型:**
    该参数用于表示数组项的数据类型。

### 例 1:

下面我们有一个使用这个函数的例子，在这个例子中，我们将得到一个数字在 20 和 30 之间的数组，并且我们将从这个范围中得到**个均匀间隔的 5 个数字**，因此，20，22.5，25，27.5 和 30 被选取。

```py
import numpy as np  

# start=20, end=30, num=5
arr = np.linspace(20, 30, 5)  
print("The array in this range is ",arr) 
```

这个范围内的数组是【20。22.5 25.27.5 30.]

### 例 2:

下面我们有一个例子，我们将找出`retstep`参数的值:

```py
import numpy as np 

x = np.linspace(2,4,5, retstep = True) 
print (x) 
```

(阵(【2。, 2.5, 3., 3.5, 4.]), 0.5)

在上面的输出中，`retstep`值为 0.5

## 3.使用`numpy.logspace`

该函数用于使用对数刻度上均匀分隔的数字**创建数组。**

使用此函数的语法如下:

```py
numpy.logspace(start, stop, num, endpoint, base, dtype) 
```

**参数:**

上述函数的参数如下:

*   **开始:**
    此参数用于表示基数中区间的开始值。

*   **止损:**
    此参数用于表示区间在基数上的止损值。

*   **num:**
    此参数用于指示范围之间的数值个数。

*   **端点:**
    该参数的值为布尔值。它用于将 stop 表示的值作为区间的最后一个值。

*   **基底:**
    此参数用于表示原木空间的基底。

*   **数据类型:**
    该参数用于表示数组项的数据类型。

### 例 1:

下面我们有一个使用这个函数的例子:

```py
import numpy as np  

a = np.logspace(20, 30, num = 5, endpoint = True)  
print("The array will be",a) 
```

数组将为[1.00000000 e+20 3.16227766 e+22 1.00000000 e+25 3.16227766 e+27
1.00000000 e+30]

### 例 2:

```py
import numpy as np  
arr = np.logspace(5, 30, num = 5,base = 3, endpoint = True)  
print("The array is: ",arr) 
```

数组为:【2.43000000 e+02 2.33138563 e+05 2.23677324 e+08 2.14600041 e+11
2.05891132 e+14】

## 摘要

本教程是关于如何使用给定的指定数值范围来创建 NumPy 数组。为此，我们有三个函数，我们已经用它们的语法、参数和它们各自的例子介绍了它们。

* * *

* * *