# NumPy `arange()`函数

> 原文：<https://www.studytonight.com/numpy/numpy-arange-function>

在本教程中，我们将介绍用于数组创建的 Numpy 库的`numpy.arange()`功能。

NumPy `arange()`函数是数组创建例程**之一，通常基于数值范围**。这个方法基本上创建了一个**等间距值**的`ndarray`实例，并返回对它的引用。

*   在此功能中，您可以定义包含在数组中的**值的间隔、它们之间的空间以及它们的类型**。

*   数值通常使用**半开间隔** : **【开始，停止】**生成。这通常意味着间隔包括**开始**，但不包括**停止**。

*   `numpy.arange()`相对于普通的内置`range()`函数有一个优势，那就是在`numpy.arange()`的帮助下，我们可以生成非整数的数字序列。

### `numpy.arange()`的语法

下面是使用该函数所需的语法:

```py
numpy.arange(start, stop, step, dtype) 
```

<u>**注意:**</u> 在上面的语法中，前三个参数用于确定值的范围，而第四个参数用于指定元素的类型。

**参数:**

现在让我们讨论这个函数的上述参数:

*   **开始**
    这是一个可选参数，用于指示间隔的开始。该参数的默认值为 **0** 。该值包含在时间间隔中。

*   **stop**
    此参数是一个数字(整数或十进制)，用于表示区间结束时的值，不包括此值。

*   **步长**
    这是一个可选参数，表示区间的步长，是区间值变化的一个数字。

*   **数据类型**
    该选项用于指示 numpy 数组项的数据类型。该参数的默认值为**无**。

**返回值:**

此方法将返回指定范围内的数组。

现在是时候介绍几个例子了。

## 示例 1:创建一个基本数组

在下面给出的示例中，我们将提供所有范围参数，并将检查结果输出:

```py
import numpy as np

a=np.arange(start=2, stop=12, step=2)
print("The Output is :",a)
```

输出为:[ 2 4 6 8 10]

## 例 2:

在下面给出的示例中，我们将只提供两个范围参数，然后检查结果:

```py
import numpy as np

a=np.arange(start=2, stop=12)
print("The Output is :",a)
```

在上面的代码片段中，由于我们没有通过`step`参数，因此它将采用步骤的默认值，即 **1** 。因此，输出如下:

输出为:[ 2 3 4 5 6 7 8 9 10 11]

## 示例 3:单参数使用`arange()`

您需要为`arange()`函数提供至少一个参数。并且建议您提供的一个参数应该是`stop`(而不是`start`)，然后该方法自动取`start`和`step`的默认值。这样**开始**将作为 **0** ，而**步骤**将作为 **1** 。在下面给出的例子中，我们将只提供一个**范围参数**，然后检查结果。代码片段如下:

```py
import numpy as np

a=np.arange(12)
print("The Output is :",a)
```

输出为:【0 1 2 3 4 5 6 7 8 9 10 11】

## 示例 4:提供否定论点

如果我们想为`start`或同时为`start`和`stop`提供负值，并为`step`参数提供正值，则 arange()函数将在负值下正常工作，并将创建一个具有负值的数组。现在让我们看看下面给出的代码片段:

```py
import numpy as np

a=np.arange(-10, -1)
print("The output is:")
print(a)
```

输出为:
[-10 -9 -8 -7 -6 -5 -4 -3 -2]

## 摘要

本教程讲述的是`numpy.arange()`函数，它是 Numpy 库中的主要数组创建例程。我们还介绍了它的语法、参数以及这个函数返回的值。

* * *

* * *