# NumPy `array()`函数

> 原文：<https://www.studytonight.com/numpy/numpy-array-function>

在本教程中，我们将介绍 NumPy 库中`array()`函数的概念。

NumPy 库中的`array()`函数主要用于创建数组。就像 [Numpy arange()功能](https://www.studytonight.com/numpy/numpy-arange-function)一样。

*   在 NumPy 库中，**同构多维数组**是主要对象。齐次多维数组基本上是一个元素表，这些元素都是同一类型的，**由正整数元组**索引。数组的维度在 NumPy 中称为**轴**。

*   Numpy 库中的`array`类主要被称为 **ndarray** 或**别名数组**。

*   `numpy.array()`与标准 python 库类`array.array`不同，因为在 Python 中`array.array`仅用于处理一维数组，因此它提供的功能较少。

### `numpy.array()`的语法:

使用此方法所需的语法如下:

```py
numpy.array(object, dtype=None, copy=True, order='K', subok=False, ndmin=0) 
```

**参数:**

现在让我们看看这个函数的参数:

*   **对象**
    该参数表示一个数组，也可以是任何暴露数组接口的对象，主要可以是`__array__`方法返回数组的对象，也可以是任何嵌套序列。

*   **数据类型**
    该参数定义了数组所需的数据类型。如果没有给出这个参数，那么类型将被确定为在序列中保持对象所需的最小类型。

*   **复制**
    如果该参数的值设置为**真**，则对象将被复制，否则只有当对象是嵌套序列时，或者如果只需要一个副本来满足任何其他要求，如数据类型、顺序等，才会进行复制。

*   **顺序**
    这个参数用来指定数组的内存布局。如果对象不是一个数组，那么新创建的数组将按照 **C 顺序**排列，即行顺序，除非指定了**‘F’**，在这种情况下，它将按照 **Fortran 顺序**排列，即列顺序。如果对象主要是一个数组，则以下内容成立:

| **订单** | **无复制** | **副本=真** |
| k ' | 未改变的 | 如果在这种情况下副本为真，则 F & C 顺序保留了最相似的顺序 |
| a′ | 未改变的 | 在这种情况下，如果复制为真，输入为 F 而不是 C，则顺序为 F，否则顺序为 C |
| c′ | 订单 | 在这种情况下，顺序是 C |
| f ' | 订单 | 在这种情况下，顺序是 f。 |

*   **subok**
    这是一个**可选的**参数，当这个参数的值为 **True** 时，子类将通过，否则默认情况下返回的数组将强制为基类数组。

*   **ndmin**
    这是一个**可选的**参数，用于指定结果数组应该具有的最小维数。

**返回值:**

numpy 库中的`array()`函数用于返回满足指定要求的数组对象。

## 示例 1:`array()`功能的基本示例

下面我们有一个基本的例子，我们借助`array()`函数创建一个只有一维的数组:

```py
import numpy as np  

a = np.array([1,4,9])  
print("The Array is:")
print(a)
```

数组为:
【1 4 9】

## 示例 2:多维数组

现在我们将创建一个具有多个维度的数组，其代码如下:

```py
import numpy as np  

a = np.array([[1, 7], [6, 4]])  
print("The Array with more than one dimension:")
print(a)
```

多维数组:
[[1 7]
[6 4]]

## 示例 3:使用`dtype`参数

下面我们有一个例子，我们将使用`dtype`参数:

```py
import numpy as np  

a = np.array([1, 7,9], dtype='complex')  
print("The Array with more than one dimension:")
print(a)
```

一维以上的数组:
【1。+0.j 7。+0.j 9。+0.j]

<u>**注:**</u> 上述代码片段的输出以复数形式表示数组元素的值。

## 摘要

本教程是关于 Numpy 库中的`array()`函数的。我们已经介绍了如何使用它的语法、参数和这个函数返回的值。在接下来的教程页面中，我们将介绍更多这样的功能。

* * *

* * *