# NumPy `std()`函数

> 原文：<https://www.studytonight.com/numpy/numpy-std-function>

在本教程中，我们将介绍 Numpy 库的另一个名为`numpy.std()`的统计函数。

在`numpy.std()`功能中**“标准”**代表**标准偏差**。让我们首先告诉你什么是标准差均值，然后我们将介绍这个方法。

### 什么是标准差？

标准差基本上是一组值的变异量或**离差的**度量。****

它也被称为平均值的平方偏差平均值的平方根。

让我们看看标准差公式:

```py
std = sqrt(mean(abs(x - x.mean())**2))
```

要了解如何计算数组值的平均值，您可以查看: [Numpy numpy.mean()函数](http://www.studytonight.com/numpy/numpy-mean-method)。

## NumPy `numpy.std()`功能:

`numpy.std()`功能用于**计算沿指定轴的标准偏差**。

*   该函数用于寻找**标准偏差**，该标准偏差是阵列元素分布的**扩散的度量。**

*   默认情况下，**标准偏差是为展平数组**计算的，否则，它是在指定的轴上计算的。

### `numpy.std()`的语法:

使用该函数所需的语法如下:

```py
numpy.std(a, axis, dtype, out)
```

**参数:**

下面是这个函数使用的参数描述:

*   **a**
    该参数用于指示输入数组。

*   **轴**
    这个参数用来表示我们要计算中位数的轴。默认情况下，输入数组被展平(即在所有轴上工作)。这里，对于轴的值，**轴= 0** 表示沿列的**，**轴= 1** 表示沿行**工作的**。**

*   **out**
    这是一个**可选的**参数，用于指示输出将存储在其中的替代数组。数组必须具有与预期输出相同的维度。

*   **数据类型**
    这是一个**可选的**参数，用于在计算标准差时指示我们想要的类型。

**返回值:**

此函数返回数组的标准偏差(如果轴为无，它将返回标量值)或具有沿指定轴的标准偏差值的数组。如果`out` 参数为 **None** ，则该函数将返回一个包含标准差的新数组，否则将返回一个对输出数组的引用。

## 例 1:

下面我们有一个代码示例，其中我们将使用`numpy.std()`函数来计算 2D 阵列的标准偏差:

```py
import numpy as np 

a = np.array([[11, 2], [13, 44]])
print("The array is:\n",a)
print("Standard Deviation is :")
print(np.std(a))

print("Standard Deviation along axis 0:")
print(np.std(a, axis=0))
print("Standard Deviation along axis 1:")
print(np.std(a, axis=1)) 
```

数组为:
【【11 2】
【13 44】】
标准差为:
15.850867484147358
沿 0 轴标准差:
【1。21.】
沿轴 1 的标准偏差:
【4.5±15.5】

## 例 2:

```py
import numpy as np 

inp = [22, 2, 17, 11, 34] 

print("The input array is : ")
print(inp)
print("The standard deviation of the Input Array is: ")
print(np.std(inp)) 

print ("\nTo get More precision with float32") 
print("Thus std of array is : ", np.std(inp, dtype = np.float32)) 

print ("\nTo get More accuracy with float64") 
print("The std of array is : ", np.std(inp, dtype = np.float64)) 
```

输入数组为:
【22，2，17，11，34】
输入数组的标准差为:
10.721940122944167

用 float32
获得更高的精度因此数组的 std 为:10.72194

用 float64
获得更高的精度数组的 std 为:10.720000000006

**<u>注:</u>** 为了更准确地计算标准差`dtype`使用了`float64`。

## 摘要

在本教程中，我们介绍了`numpy.std()`统计函数。我们还介绍了标准差的含义及其数学公式。然后我们通过一些代码示例理解了`numpy.std()`函数的语法、参数以及该方法返回的值。

* * *

* * *