# Pandas 数据帧`backfill()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-backfill-method>

在本教程中，我们将学习 PythonPandas`DataFrame.backfill()`方法。此方法向后填充数据帧中缺少的值。这个方法类似于`method='bfill'`的`DataFrame.fillna()`方法。

下图显示了`DataFrame.backfill()`方法的语法。

### 句法

```py
DataFrame.backfill(axis=None, inplace=False, limit=None, downcast=None)
```

### 因素

**轴:“0”**或指数。不支持 1 和列。

**就位:**为布尔型、真型或假型。默认值为假。如果为真，则填充缺少的值，但不创建新对象。

**限制:**为 int，默认为无。如果指定了方法，这是向后填充的连续 NaN 值的最大数量。

### 示例:创建数据帧

创建一个无值的数据帧并打印输出。在本教程中，我们将使用这个数据帧。

```py
import pandas as pd
df = pd.DataFrame({'A': [None, 3, None, None],'B': [2, 4, None, 3],'C': [None, None, None, 1],'D': [0, 1, 5, 4]}, columns=['A', 'B', 'C', 'D'])
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

A B C D
0 NAn 2.0 NAn 0
1 3.0 4.0 NAn 1
2 NAn NAn 5
3 NAn 3.0 1.0 4

### 示例 1:使用`DataFrame.backfill()`方法填写数据帧的缺失值

以下示例显示了`DataFrame.backfill()` 方法如何填充缺失值。

```py
import pandas as pd
df = pd.DataFrame({'A': [None, 3, None, None],'B': [2, 4, None, 3],'C': [None, None, None, 1],'D': [0, 1, 5, 4]}, columns=['A', 'B', 'C', 'D'])
print(df.bfill())
```

一旦我们运行该程序，我们将获得以下输出。

A B C D
0 3.0 2.0 1.0 0
1 3.0 4.0 1.0 1
2 NaN 3.0 1.0 5
3 NaN 3.0 1.0 4

### 例 2:用`axis=1`用`DataFrame.backfill()`方法填写数据帧的缺失值

这个例子类似于前面的例子`DataFrame.backfill()` 方法用`axis=1`填充缺失的值。

```py
import pandas as pd
df = pd.DataFrame({'A': [None, 3, None, None],'B': [2, 4, None, 3],'C': [None, None, None, 1],'D': [0, 1, 5, 4]}, columns=['A', 'B', 'C', 'D'])
print(df.bfill(axis=1))
```

一旦我们运行该程序，我们将获得以下输出。

A B C D
0 2.0 2.0 0.0 0.0
1 3.0 4.0 1.0 1.0
2 5.0 5.0 5.0 5.0
3 3.0 3.0 1.0 4.0

### 示例 3:通过设置`limit`值，使用`DataFrame.backfill()`方法填写数据帧的缺失值

我们可以在`DataFrame.backfill()`方法中设置限值。这表示向后填充的连续 NaN 值的最大数量。

```py
import pandas as pd
df = pd.DataFrame({'A': [None, 3, None, None],'B': [2, 4, None, 3],'C': [None, None, None, 1],'D': [0, 1, 5, 4]}, columns=['A', 'B', 'C', 'D'])
print(df.bfill(limit=2))
```

一旦我们运行该程序，我们将获得以下输出。

A B C D
0 3.0 2.0 NAn 0
1 3.0 4.0 NAn 1
2 NAn 3.0 1.0 5
3 NAn 3.0 1.0 4

### 例 4:用`inplace=True`用`DataFrame.backfill()`方法填写数据帧的缺失值

如果在`DataFrame.backfill()`方法中`inplace=True` ，它将填充数据帧的缺失值，但不创建新对象。如果我们想检查缺失值是否被填充，我们可以通过打印数据帧来检查。

```py
import pandas as pd
df = pd.DataFrame({'A': [None, 3, None, None],'B': [2, 4, None, 3],'C': [None, None, None, 1],'D': [0, 1, 5, 4]}, columns=['A', 'B', 'C', 'D'])
print(df.bfill(inplace=True))
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

无
A B C D
0 3.0 2.0 1.0 0
1 3.0 4.0 1.0 1
2 NaN 3.0 1.0 5
3 NaN 3.0 1.0 4

### 结论

在本教程中，我们学习了 Pandas`DataFrame.backfill()`方法。我们学习了该函数的语法和参数，并将该函数应用于包含无值的数据帧，并理解了`DataFrame.backfill()`方法向后填充 Pandas 数据帧中存在的`NaN`值。

* * *

* * *