# Pandas 数据帧`corrwith()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-corrwith-method>

在本教程中，我们将学习 Pandas`DataFrame.corrwith()`方法。它计算成对的相关性。成对相关性是在数据帧的行或列与序列或数据帧的行或列之间计算的。在计算相关性之前，数据帧首先沿两个轴对齐。

下图显示了`DataFrame.corrwith()`方法的语法。

### 句法

```py
DataFrame.corrwith(other, axis=0, drop=False, method='pearson')
```

**参数**

**其他:**数据帧，系列。用来计算相关性的对象。

**轴:** {0 或'索引'，1 或'列' }，默认为 0。要使用的轴。0 或“index”表示按列计算，1 或“columns”表示按行计算。

**drop:** bool，默认 False。从结果中删除缺失的索引。

**方法:** {'pearson '，' kendall '，' spearman'}或 callable。

关联方法:

*   皮尔逊:标准相关系数

*   肯德尔:肯德尔τ相关系数

*   斯皮尔曼:斯皮尔曼等级相关性

*   callable:可调用，输入两个 1d 数组并返回一个 float。

### 示例:创建两个数据帧。

创建两个数据帧，在本教程中，我们将使用这些数据帧。

```py
import pandas as pd
chart_1 = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,160,175],'Weight': [55,60,75]}
df1 = pd.DataFrame(chart_1)
print(df1)
chart_2 = {'Name':['Pooja','Sindu','Renuka'],'Age':  [18,25,20],'Height': [145,155,165],'Weight': [45,55,65]}
df2 = pd.DataFrame(chart_2)
print(df2)
```

一旦我们运行程序，我们将得到以下结果。

姓名年龄身高体重
0 车坛 20 155 55
1 雅夏 25 160 60
2 尤瓦拉吉 30 175 75
姓名年龄身高体重
0 普贾 18 145 45
1 辛杜 25 155 55
2 雷努卡 20 165 65

### 示例:使用`DataFrame.corrwith()`方法和`pearson`方法查找两个数据帧之间的相关性。

下面的例子展示了如何使用`pearson`方法找到两个数据帧之间的相关性。

```py
import pandas as pd
chart_1 = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,160,175],'Weight': [55,60,75]}
df1 = pd.DataFrame(chart_1)
chart_2 = {'Name':['Pooja','Sindu','Renuka'],'Age':  [18,25,20],'Height': [145,155,165],'Weight': [45,55,65]}
df2 = pd.DataFrame(chart_2)
print(df1.corrwith(df2,method='pearson'))
```

一旦我们运行该程序，我们将获得以下输出。

年龄 0.277350
身高 0.960769
体重 0.960769
体型:浮动 64

### 示例:使用`DataFrame.corrwith()`方法和`kendall`方法查找两个数据帧之间的相关性。

下面的例子展示了如何使用`kendall`方法找到两个数据帧之间的相关性。

```py
import pandas as pd
chart_1 = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,160,175],'Weight': [55,60,75]}
df1 = pd.DataFrame(chart_1)
chart_2 = {'Name':['Pooja','Sindu','Renuka'],'Age':  [18,25,20],'Height': [145,155,165],'Weight': [45,55,65]}
df2 = pd.DataFrame(chart_2)
print(df1.corrwith(df2,method='kendall'))
```

一旦我们运行该程序，我们将获得以下输出。

年龄 0.333333
身高 1.000000
体重 1.000000
体型:浮动 64

### 示例:使用`DataFrame.corrwith()`方法和`spearman`方法查找两个数据帧之间的相关性。

下面的例子展示了如何使用`spearman`方法找到两个数据帧之间的相关性。

```py
import pandas as pd
chart_1 = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,160,175],'Weight': [55,60,75]}
df1 = pd.DataFrame(chart_1)
chart_2 = {'Name':['Pooja','Sindu','Renuka'],'Age':  [18,25,20],'Height': [145,155,165],'Weight': [45,55,65]}
df2 = pd.DataFrame(chart_2)
print(df1.corrwith(df2,method='spearman'))
```

一旦我们运行该程序，我们将获得以下输出。

年龄 0.5
身高 1.0
体重 1.0
体型:浮动 64

### 结论

在本教程中，我们学习了 PythonPandas`DataFrame.corrwith()`方法。我们使用皮尔逊、肯德尔和斯皮尔曼方法找到了两个数据帧之间的相关性。

* * *

* * *