# Pandas 数据帧`count()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-count-method>

在本教程中，我们将学习 Pandas`DataFrame.count()`的方法。该方法对每一列或每一行的`non-NA`单元格进行计数。值 None、NaN、NaT 和可选的 numpy.inf 被认为是 NA。它为每一列/每一行返回数据帧或数据系列非空条目数。如果指定了级别，则返回一个数据帧。

下图显示了`DataFrame.count()`方法的语法。

### 句法

```py
DataFrame.count(axis=0, level=None, numeric_only=False)
```

### 因素

**轴:** {0 或'索引'，1 或'列' }，默认为 0。如果为 0，则为每列生成“索引”计数。如果每行生成 1 或“列”计数。

**级别:** int 或 str，可选。如果轴是一个多索引(分层)，则与特定级别一起计数，折叠成一个数据帧。Str 指定级别名称。

**仅限数值:** bool，默认为 False。只包括浮点、整型或布尔型数据。

## 示例 1:使用`DataFrame.count()`方法计算每个`row`的`non-NA`元素

以下示例显示了`DataFrame.count()`方法如何计算数据帧中沿`row`轴出现的非空元素的数量。

```py
import pandas as pd
df= pd.DataFrame([['Abhishek','Science',90], ['Anurag',101,None,85]], columns=['Name', 'Roll No', 'Subject', 'Marks'])
print(df)
print("Counting the number of elements in the dataframe-----")
print(df.count())
```

一旦我们运行该程序，我们将获得以下输出。

名称卷无主题标记
0 Abhishek Science 90.0 NaN
1 Anurag 101 NaN 85.0
计算数据帧中的元素数量-
名称 2
卷无主题标记 2
主题 1
标记 1
数据类型:int64

## 示例 2:使用`DataFrame.count()`方法计算每个`row`的`non-NA`元素

考虑一个包含所有空元素的数据帧，并使用`DataFrame.count()`方法计数。

```py
import pandas as pd
import numpy as np
df= pd.DataFrame([[np.nan,np.nan,np.nan], [None,np.nan,None,np.nan]], columns=['Name', 'Roll No', 'Subject', 'Marks'])
print(df)
print("-------Counting the number of elements in the dataframe-----")
print(df.count())
```

一旦我们运行该程序，我们将获得以下输出。

名称卷无主题标记
0 楠楠楠
1 楠楠楠
-计算数据帧中的元素数量-
名称 0
卷无 0
主题 0
标记 0
数据类型:int64

## 示例 3:使用`DataFrame.count()`方法计算每个`row`的`non-NA`元素

以下示例显示了`DataFrame.count()`方法如何计算数据帧中沿`column`轴出现的非空元素的数量。

```py
import pandas as pd
df= pd.DataFrame([['Abhishek',101,'Science',90], ['Anurag',102,None,85]], columns=['Name', 'Roll No', 'Subject', 'Marks'])
print(df)
print("Counting the number of elements in the dataframe-----")
print(df.count(axis=1))
```

一旦我们运行该程序，我们将获得以下输出。

名称卷无主题标记
0 Abhishek 101 Science 90
1 Anurag 102 None 85
计算数据帧中的元素数量-
0 4
1 3
数据类型:int64

## 示例 4:使用`DataFrame.count()`方法计算每个`row`的`non-NA`元素

以下示例显示了`DataFrame.count()`方法如何使用`numeric_only=True`计算数据帧中沿`row`轴出现的非空数字元素的数量。方法。

```py
import pandas as pd
df= pd.DataFrame([['Abhishek',101,'Science',90], ['Anurag',102,None,85]], columns=['Name', 'Roll No', 'Subject', 'Marks'])
print(df)
print("Counting the number of elements in the dataframe-----")
print(df.count(numeric_only=True))
```

一旦我们运行该程序，我们将获得以下输出。

名称卷无主题标记
0 Abhishek 101 Science 90
1 Anurag 102 None 85
计算数据帧中的元素数量-
卷无 2
标记 2
数据类型:int64

### 结论

在本教程中，我们学习了 Pandas`DataFrame.count()`方法。我们学习了语法、参数，并通过解决示例了解了该方法如何计算数据帧的行轴和列轴上的非空元素的数量。

* * *

* * *