# Pandas 数据帧`cov()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-cov-method>

**协方差**是对两个随机变量之间关系的度量，它告诉我们两个随机变量一起变化的程度。A **正** **协方差**表示资产收益一起运动，而 a **负**协方差表示它们反向运动。

在本教程中，我们将学习 Pandas`DataFrame.cov()`的方法。这种方法通常用于分析时间序列数据，以了解不同度量之间跨时间的关系。

它计算列的成对协方差，不包括 NA/null 值。它计算数据帧系列之间的成对协方差，返回的数据帧是数据帧各列的[协方差矩阵](https://en.wikipedia.org/wiki/Covariance_matrix)。

下图显示了`DataFrame.cov()`方法的语法。

### 句法

```py
DataFrame.cov(min_periods=None, ddof=1)
```

### 因素

**min_periods:** int，可选。每对列获得有效结果所需的最小观察次数。

**ddof:** int，默认 1。δ自由度。计算中使用的除数是`N - ddof`，其中`N`代表元素的数量。

### 示例 1:使用`DataFrame.cov()`方法找到协方差

下面的例子展示了如何找到数据帧各列之间的协方差。

```py
import pandas as pd
chart = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,170,165],'Weight': [59,60,75]}
df = pd.DataFrame(chart)
print(df)
print("------Covariance between the columns---------")
print(df.cov())
```

一旦我们运行该程序，我们将获得以下输出。

姓名年龄身高体重
0 车坛 20 155 59
1 雅夏士 25 170 60
2 yuvraj 30 165 75
-列间协方差-
年龄身高体重
年龄 25.0 25.0000000 40.000000
身高 25.0 58.3333316.66667
体重 40.0 16

### 示例 2:使用`DataFrame.cov()`方法找到协方差

下面的示例显示了如何找到由空值组成的数据帧的列之间的协方差。

```py
import pandas as pd
chart = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,None,30],'Height': [155,170,None],'Weight': [59,60,75]}
df = pd.DataFrame(chart)
print(df)
print("------Covariance between the columns---------")
print(df.cov())
```

一旦我们运行该程序，我们将获得以下输出。

姓名年龄身高体重
0 车坛 20.0 155.0 59
1 雅夏士 NaN 170.0 60
2 yuvraj 30.0 NaN 75
-列间协方差-
年龄身高体重
年龄 50.0 NaN 80.000000
身高 NaN 112.5 7.500000
体重 80.0 7.5 80.3333333

### 示例 3:使用`DataFrame.cov()`方法找到协方差

下面的示例显示了如何找到数据帧的两列之间的协方差。

```py
import pandas as pd
chart = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,170,165],'Weight': [59,60,75]}
df = pd.DataFrame(chart)
print(df)
print("------Covariance between the Height and weight column is---------")
print(df.Height.cov(df.Weight))
```

一旦我们运行该程序，我们将获得以下输出。

姓名年龄身高体重
0 车坛 20 155 59
1 雅夏斯 25 170 60
2 尤瓦拉吉 30 165 75
-身高体重栏之间的协方差为-
16。56660 . 66666666666

### 结论

在本教程中，我们学习了 Pandas`DataFrame.cov()`方法。通过求解例子，我们可以找到数据帧各列之间的协方差。

* * *

* * *