# Pandas 数据帧`eq()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-eq-method>

在本教程中，我们将学习 Pandas`DataFrame.eq()`T4 法。它用于逐个元素地检查数据帧中的相等值。它返回由真和假组成的布尔值的数据帧。相当于`==`运算符，支持选择轴(行或列)和级别进行比较。

下图显示了`DataFrame.eq()`方法的语法。

### 句法

```py
DataFrame.eq(other, axis='columns', level=None)
```

### 因素

**其他:**标量、序列、序列或数据帧。任何单个或多个元素数据结构，或类似列表的对象。

**轴:** {0 或‘索引’，1 或‘列’，默认‘列’。是按索引(0 或“索引”)还是按列(1 或“列”)进行比较。

**级别:** int 或 label。跨级别广播，匹配传递的多索引级别上的索引值。

## 示例:查找 dataframe 元素与指定值的比较

通过对数据帧应用`DataFrame.eq()`方法，我们可以得到与指定值的比较。下面的例子显示了同样的情况。

```py
import pandas as pd
df = pd.DataFrame({"Roll no": [100, 101, 102, 103],"Marks": [60, 62, 65, 59]},index= ["Saanvi", "Hasini", "Lakshmi", "Kushi"])
print("-------The DataFrame is---------")
print(df)
print("----Find the comparison of the dataframe element with value----")
print(df.eq(62))
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
滚动无标记
萨昂威 100 60
哈西尼 101 62
拉克什米 102 65
库什 103 59
-找到数据帧元素与值的比较-
滚动无标记
萨昂威假假假
哈西尼假真
拉克什米假假
库什假假假假

## 示例 2:查找 dataframe 元素与指定值的比较

这里，使用`DataFrame.eq()`方法，我们可以将数据帧元素与特定值进行比较。见下面的例子。

```py
#Comparing different column with different value
import pandas as pd
df = pd.DataFrame({"Roll no": [100, 101, 102, 103],"Marks": [60, 62, 65, 59]},index= ["Saanvi", "Hasini", "Lakshmi", "Kushi"])
print("-------The DataFrame is---------")
print(df)
print("----Find the comparison of the dataframe element----")
print(df.eq([101,62]))
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
无标记滚动
萨昂威 100 60
哈西尼 101 62
拉克希米 102 65
库什 103 59
-找到数据帧元素的对比-
无标记滚动
萨昂威假
哈西尼真
拉克希米假
库什假假假

## 示例:查找数据帧元素与不同值的比较

通过使用`DataFrame.eq()`方法，我们可以将数据帧元素的选定列与值进行比较。下面的例子显示了同样的情况。

```py
#Comparing selected column with different value
import pandas as pd
df = pd.DataFrame({"Roll no": [100, 101, 102, 103],"Marks": [60, 62, 65, 59]},index= ["Saanvi", "Hasini", "Lakshmi", "Kushi"])
print("-------The DataFrame is---------")
print(df)
print("----Find the comparison of the dataframe element----")
print(df["Marks"].eq(62))
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
滚动无标记
萨昂威 100 60
哈西尼 101 62
拉克什米 102 65
库什 103 59
-找到数据帧元素的对比-
萨昂威假
哈西尼真
拉克什米假
库什假
名称:标记，数据类型:bool

## 示例:查找数据帧元素的比较

使用`DataFrame.eq()`方法，我们可以将数据帧元素的选定列与值进行比较。下面的例子显示了同样的情况。

```py
#Comparing selected columns with different value
import pandas as pd
chart = {'Name':['Chetan','yashas','yuvraj'],'Age':  [20,25,30],'Height': [155,170,165],'Weight': [59,60,75]}
df = pd.DataFrame(chart)
print("-------The DataFrame is---------")
print(df)
print("----Find the comparison of the dataframe element----")
print(df[["Age", "Weight"]].eq([20,60]))
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
名称年龄身高体重
0 车坦 20 155 59
1 雅夏 25 170 60
2 尤瓦拉吉 30 165 75
-查找数据帧元素的比较-
年龄体重
0 真假
1 假真
2 假假

## 示例:查找数据帧元素的比较

使用`DataFrame.eq()`方法，我们可以比较数据帧的列，并将结果放入数据帧列中。下面的例子显示了同样的情况。

```py
#Comparing selected columns with different value
import pandas as pd
df = pd.DataFrame({"col1": [10, 30, 60, 40, 20],"col2": [10, 15, 60, 45, 20]})
print("-------The DataFrame is---------")
print(df)
print("----Find the comparison of the dataframe element----")
df['Result'] = df['col1'].eq(df['col2'])
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
col 1 col 2
0 10
1 30 15
2 60 60
3 40 45
4 20 20
-查找数据帧元素的比较-
col1 col2 结果
0 10 10 True
1 30 15 False
2 60 60 True
3 40 45 False
4 220

### 结论

在本教程中，我们将学习 Pandas`DataFrame.eq()`方法。我们解决了一些例子，并比较了数据帧元素、具有特定值的列，得到了 bool 的数据帧。

* * *

* * *