# Pandas 数据帧`expanding()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-expanding-method>

在本教程中，我们将学习 Pandas`DataFrame.expanding()`方法。这是 Pandas 的窗口方法之一，它提供了扩展转换。它返回一个为特定操作分类的窗口。

下图显示了`DataFrame.expanding()`方法的语法。

### 句法

```py
DataFrame.expanding(min_periods=1, center=None, axis=0)
```

### 因素

**min_periods:** int，默认 1。窗口中具有一个值所需的最小观察次数(否则结果为“无”)。

**中心:** bool，默认 False。将标签设置在窗口的中心。

**轴:** int 或 str，默认为 0

## 示例 1:扩展数据帧

在下面的例子中，`DataFrame.expanding()`方法计算整个数据帧的累积总和。

```py
import pandas as pd
df = pd.DataFrame({"A": [1, 2, 3],"B": [1, 1, 1]})
print("---The DataFrame is---")
print(df)
print("------Output of the function is-------")
print(df.expanding().sum())
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
A B
0 1 1
1 2 1
2 3 1
-方法输出为-
A B
0 1.0 1.0
1 3.0 2.0
2 6.0 3.0

## 示例 2:扩展数据帧

在下面的示例中，`DataFrame.expanding()`方法计算数据帧中所选列的累积和，并将结果存储在另一列中。

```py
import pandas as pd
df = pd.DataFrame({"A": [1, 2, 3],"B": [1, 1, 1]})
print("---The DataFrame is---")
print(df)
print("------Output of the function is-------")
df["result"]=df.A.expanding().sum()
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
A B
0 1 1
1 2 1
2 3 1
-方法输出为-
A B 结果
0 1 1 1.0
1 2 1 3.0
2 3 1 6.0

## 示例 3:扩展数据帧

在下面的例子中，`DataFrame.expanding()`方法计算了沿着行轴的整个数据帧的累积总和。

```py
import pandas as pd
df = pd.DataFrame({"A": [1, 2, 3],"B": [1, 1, 1]})
print("---The DataFrame is---")
print(df)
print("------Output of the function is-------")
print(df.expanding(axis=1).sum())
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
A B
0 1 1
1 2 1
2 3 1
-方法输出为-
A B
0 1.0 2.0
1 2.0 3.0
2 3.0 4.0

## 示例 4:用最小周期扩展数据帧

在以下示例中，`DataFrame.expanding()`方法使用`min_periods=2.`计算整个数据帧的累积总和

```py
import pandas as pd
df = pd.DataFrame({"A": [1, 2, 3],"B": [1, 1, 1]})
print("---The DataFrame is---")
print(df)
print("------Output of the function is-------")
print(df.expanding(min_periods=2).sum())
```

一旦我们运行该程序，我们将获得以下输出。

-数据帧为-
A B
0 1 1
1 2 1
2 3 1
-方法输出为-
A B
0 NaN NaN
1 3.0 2.0
2 6.0 3.0

### 结论:

在本教程中，我们学习了 Pandas`DataFrame.expanding()` 法。我们通过将这种方法应用于数据帧来解决不同的例子。我们将该方法应用于具有**均值、中值、方差、协方差、相关性、**等的数据帧。，并观察输出。

* * *

* * *