# Pandas 数据帧`from_records()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-from_records-method>

在本教程中，我们将学习 Pandas`DataFrame.from_records()`的方法。它将结构化或记录数组转换为数据帧。它从结构化的数组中创建一个数据帧对象，该数组由[元组](https://www.studytonight.com/python/tuples-in-python)或[字典](https://www.studytonight.com/python/dictionaries-in-python)或数据帧组成。

下面是`DataFrame.from_records()`方法的语法。

### 句法

```py
DataFrame.from_records(data, index=None, exclude=None, columns=None, coerce_float=False, nrows=None)
```

### 因素

**数据:**结构化数组，元组或字典的序列，或数据帧。结构化输入数据。

**索引:**字符串，字段列表，类似数组。要用作索引的数组字段，或者要使用的一组特定输入标签。

**排除:**序列，默认无。要排除的列或字段。

**列:**序列，默认无。要使用的列名。如果传递的数据没有关联的名称，则此参数为列提供名称。否则，此参数指示列在结果中的顺序(任何在数据中找不到的名称都将成为全无列)。

**要挟 _float:** bool，默认 False。尝试转换非字符串、非数字对象(如十进制)的值。十进制)转换为浮点型，对 SQL 结果集很有用。

**n 显示:** int，默认无。如果数据是迭代器，要读取的行数。

## 示例:使用`DataFrame.from_records()`方法创建数据帧

数据可以作为结构化的数组提供。`DataFrame.from_records()`方法将数组记录转换为数据帧。见下面的例子。

```py
#import pandas as pd
import pandas as pd
#import numpy as np
import numpy as np
data = np.array([(3, 'a'), (2, 'b'), (1, 'c'), (0, 'd')],dtype=[('col_1', 'i4'), ('col_2', 'U1')])
print("ndarray is:",data)
df=pd.DataFrame.from_records(data)
print("----------The DataFrame is----------")
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

n 数组为:[(3，' a') (2，' b') (1，' c') (0，' d')]
-数据帧为-
col _ 1 col _ 2
03 a
12 b
21 c
30d

## 示例 2:使用`DataFrame.from_records()`方法创建数据帧

在这里，我们使用一个字典列表。`DataFrame.from_records()`方法将字典记录列表转换为数据帧。下面的例子显示了同样的情况。

```py
#import pandas as pd
import pandas as pd
#import numpy as np
import numpy as np
data = [{'col_1': 3, 'col_2': 'a'},{'col_1': 2, 'col_2': 'b'},{'col_1': 1, 'col_2': 'c'},{'col_1': 0, 'col_2': 'd'}]
print("list of dicts:",data)
df=pd.DataFrame.from_records(data)
print("----------The DataFrame is----------")
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

字典列表:[{'col_1': 3，' col_2': 'a'}，{'col_1': 2，' col_2': 'b'}，{'col_1': 1，' col_2': 'c'}，{'col_1': 0，' col_2': 'd'}]
-数据帧为-
col _ 1 col _ 2
0 3a
1 2b
2 1c
3 0d

## 示例 2:使用`DataFrame.from_records()`方法创建数据帧

这里，我们使用作为元组列表。`DataFrame.from_records()`方法将元组记录列表转换为数据帧。下面的例子显示了同样的情况。

```py
#import pandas as pd
import pandas as pd
#import numpy as np
import numpy as np
data = [(3, 'a'), (2, 'b'), (1, 'c'), (0, 'd')]
print("list of tuples:",data)
df=pd.DataFrame.from_records(data)
print("----------The DataFrame is----------")
print(df)
```

一旦我们运行该程序，我们将获得以下输出。

元组列表:[(3，' a ')、(2，' b ')、(1，' c ')、(0，' d')]
-数据帧为-
0 1
0 3a
1 2b
2 1c
3 0d

### 结论

在本教程中，我们学习了 Pandas`DataFrame.from_records()`方法。我们学习了语法、参数，并通过在数据帧上应用该方法，理解了 `DataFrame.from_records()`方法。

* * *

* * *