# Pandas 数据帧`idxmin()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-idxmin-method>

在本教程中，我们将讨论和学习 Pandas`DataFrame.idxmin()`的方法。该方法用于获取请求轴上**最小值**的第一次出现的索引。如果有任何空值或缺失值，将被排除。此方法返回一个序列，该序列由沿指定轴的最大值索引组成。如果数据帧中的行或列为空，它会引发**值错误**。

下图显示了`DataFrame.idxmin()`方法的语法。

### 句法

```py
DataFrame.idxmin(axis=0, skipna=True)
```

### 因素

**轴:“0”**或**【指数】**代表行方向，**【1】**或**【列】**代表列方向。它表示使用哪个轴。

**skipna:** 代表 bool(真或假)，默认值为 True。当此参数为真时，它排除所有空值或缺失值。如果数据帧中的整行或整列为空值，结果也将为空。

## 示例 1:使用`DataFrame.idxmin()`方法查找索引

这里，我们使用数据集，并使用`DataFrame.idxmin()`方法获取每列中**最小**值的索引。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
df = pd.DataFrame({'Marks_1': [85,90,45],'Marks_2': [85,96,100]},index=['Kannada', 'English', 'Science'])
print("-----The DataFrame is----")
print(df)
print("----- Index of the minimum value over the row axis----")
print(df.idxmin())
```

-数据帧为-
Marks_1 Marks_2
卡纳达语 85 85
英语 90 96
科学 45 100
-行轴上最小值的索引-
Marks_1 科学
Marks_2 卡纳达语
数据类型:对象

## 示例 2:使用`DataFrame.idxmin()`方法查找索引

这里，我们使用`DataFrame.idxmin()`方法获取每行最小值的索引。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
df = pd.DataFrame({'Marks_1': [85,90,45],'Marks_2': [95,46,100]},index=['Kannada', 'English', 'Science'])
print("-----The DataFrame is----")
print(df)
print("----- Index of the minimum value over the column axis----")
print(df.idxmin(axis="columns"))
```

-数据帧为-
Marks_1 Marks_2
卡纳达语 85 95
英语 90 46
科学 45 100
-列轴上最小值的索引-
卡纳达语 Marks_1
英语 Marks_2
科学 Marks_1
数据类型:对象

## 示例 2:使用`DataFrame.idxmin()`方法查找索引

我们有一个由**空值**组成的数据集，并试图使用`DataFrame.idxmin()`方法获取每行中**最小值**的索引。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
df = pd.DataFrame({'Marks_1': [85,None,45],'Marks_2': [None,46,None]},index=['Kannada', 'English', 'Science'])
print("-----The DataFrame is----")
print(df)
print("----- Index of the minimum value over the column axis----")
print(df.idxmin(axis="columns"))
```

-数据帧为-
Marks_1 Marks_2
卡纳达 85.0 NaN
英语 NaN 46.0
科学 45.0 NaN
-列轴上最小值的索引-
卡纳达 Marks_1
英语 Marks_2
科学 Marks_1
dtype: object

### 结论

在本教程中，我们学习了 Pandas`DataFrame.idxmin()`方法。我们学习了语法，通过在数据帧上应用这个方法，我们理解了这个方法的工作原理。

* * *

* * *