# Pandas 数据帧`join()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-join-method>

在本教程中，我们将学习 Pandas`DataFrame.join()`的方法。此方法用于连接另一个数据帧的列。它将列与索引或键列上的其他数据帧连接起来。通过索引，该方法可以通过传递一个列表来连接多个数据帧对象。

下图显示了`DataFrame.join()`方法的语法。

### 句法

```py
DataFrame.join(other, on=None, how='left', lsuffix='', rsuffix='', sort=False)
```

### **参数**

**其他:**代表数据帧、序列或数据帧列表。

**on:** 表示 str，str 列表，或数组状，可选。

**如何:**包括‘左’、‘右’、‘外’、‘内’，默认为‘左’。

**lsuffix:** 表示字符串，默认为' '。用于左框架重叠列的后缀。

**rsuffix:** 表示字符串，默认为' '。右框架重叠列中使用的后缀。

**排序:**表示 bool，默认为 False。它按照连接键对生成的数据帧进行字典排序。如果为 False，连接键的顺序取决于连接类型(how 关键字)。

### 示例:使用`DataFrame.join()`方法连接两个数据帧

这里，在这个例子中，我们将创建两个数据帧，并使用`DataFrame.join()`方法连接这两个数据帧。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df_1=pd.DataFrame({"A":[0,1],"B":[3,4]})
print("-----------The DataFrame is-------")
print(df_1)
df_2=pd.DataFrame({"C":[0,1],"D":[3,4,]})
print("----------------------------------")
print(df_2)
print("------------------")
print(df_1.join(df_2))
```

-数据帧为-
A B
0 0 3
1 1 4
-
C D
0 0 3
1 1 4
-
A B C D
0 3 0 3
1 4 1 4

### 示例:使用 lsuffix 和 rsuffix 连接两个数据帧

这里，我们使用**后缀**的方法来区分左右框架的重叠列。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df_1=pd.DataFrame({"A":[0,1],"B":[3,4]})
print("-----------The DataFrame is-------")
print(df_1)
df_2=pd.DataFrame({"A":[0,1],"B":[3,4,]})
print("----------------------------------")
print(df_2)
print("------------------")
print(df_1.join(df_2,lsuffix='_first', rsuffix='_second'))
```

-数据帧为-
A B
0 0 3
1 1 4
-
A B
0 0 3
1 1 4
-
A _ first B _ first A _ second B _ second
0 0 3 0 3
1 1 4 1 4

### 示例:`DataFrame.join()`方法

如果我们想使用“A”列进行连接，我们需要将“A”设置为 df_1 和 df_2 中的索引。连接的数据帧将以“A”作为其索引。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df_1=pd.DataFrame({"A":[0,1],"B":[3,4]})
print("-----------The DataFrame is-------")
print(df_1)
df_2=pd.DataFrame({"A":[0,1],"D":[3,4,]})
print("----------------------------------")
print(df_2)
print("------------------")
print(df_1.set_index('A').join(df_2.set_index('A')))
```

-数据帧为-
A B
0 0 3
1 1 4
-
A D
0 3
1 1 4
-
B D
A
0 3 3
1 4 4

### 结论

在本教程中，我们学习了 Pandas`DataFrame.join()`方法。我们学习了语法，通过在数据帧上应用这种方法，我们解决了一些例子并理解了 `DataFrame.join()`方法。

* * *

* * *