# Pandas 数据帧`mad()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-mad-method>

任何数据集中的变化都可以由**平均绝对偏差(MAD)** 确定，它可以定义为每个数据值和平均值之间的平均距离。在本教程中，我们将学习 [Python](https://www.studytonight.com/python/getting-started-with-python) Pandas **`DataFrame.mad()`** 方法。当`DataFrame.mad()`方法应用于数据帧时，它返回所请求的`axis`值的平均绝对偏差。

下图显示了`DataFrame.mad()`方法的语法。

### 句法

```py
DataFrame.mad(axis=None, skipna=None, level=None)
```

### 因素

**轴:“0”**代表索引，**“1”**代表列。当`axis=0`方法应用于`index`轴时，以及当`axis=1`方法应用于`column`轴时。

**skipna:** 代表布尔(真或假)。默认值为“无”。如果该参数为`True`，则在计算结果时，排除所有 NA/null 值。

**级别:**代表 int 或级别名称，默认值为 None。如果数据帧是多索引的，则它与特定级别一起计算，折叠成一个系列。

## 示例:`DataFrame.mad()`方法

让我们创建一个数据帧，并通过在`DataFrame.mad()`方法中指定参数`axis=0` 获得`index`轴上的值的**平均绝对偏差**。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,2,3],"B":[4,5,6],"C":[7,8,9],"D":[10,11,12]}) 
print("----------The DataFrame is------")
print(df)
print("---The mean absolute deviation of the DataFrame is---")
print(df.mad(axis=0))
```

-数据帧为-
A B C D
0 1 4 7 10
1 2 5 8 11
2 3 6 9 12
-数据帧的平均绝对偏差为-
A 0.666667
B 0.666667
C 0.66667
D 0.66667
dttype:float 64

## 示例:沿`column`轴的`DataFrame.mad()`方法

让我们创建一个数据帧，通过在`DataFrame.mad()`方法中指定参数``axis=1`` ，得到列轴上值的**平均绝对偏差**。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,2,3],"B":[4,5,6],"C":[7,8,9],"D":[10,11,12]}) 
print("----------The DataFrame is------")
print(df)
print("---The mean absolute deviation of the DataFrame is---")
print(df.mad(axis=1))
```

-数据帧为-
A B C D
0 1 4 7 10
1 2 5 8 11
2 3 6 9 12
-数据帧的平均绝对偏差为-
0 3.0
1 3.0
2 3.0
数据类型:float64

## 示例:排除空值的`DataFrame.mad()`方法

让我们创建一个具有空值的数据帧，并通过在`DataFrame.mad()`方法中传递参数`skipna` 来获得除空值之外的索引轴上的值的**平均绝对偏差**。在计算结果时，它会排除所有 NA/null 值。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,None,3],"B":[None,5,6],"C":[7,8,9],"D":[10,11,None]}) 
print("----------The DataFrame is------")
print(df)
print("---The mean absolute deviation of the DataFrame is---")
print(df.mad(axis=0,skipna=True))
```

-数据帧为-
A B C D
0 1.0 NaN 7 10.0
1 NaN 5.0 8 11.0
2 3.0 6.0 9 NaN
-数据帧的平均绝对偏差为-
A 1.000000
B 0.500000
C 0.666667
D 0.500000
dtype

### 结论

在本教程中，我们学习了 Pandas`DataFrame.mad()`方法。我们学习了语法、参数，并将该方法应用于数据帧，以理解 `DataFrame.mad()`方法。

* * *

* * *