# Pandas 数据帧`min()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-min-method>

在本教程中，我们将学习 Pandas`DataFrame.min()`的方法。该方法可用于获得要求轴上的值的**最小值**。它返回序列，如果指定了级别，它将返回数据帧。

下面是`DataFrame.min()`方法的语法。

### 句法

```py
DataFrame.min(axis=None, skipna=None, level=None, numeric_only=None, **kwargs)
```

### 因素

**轴:**表示索引或列轴，索引为“0”，列为“1”。当`axis=0`方法应用于`index`轴时，以及当`axis=1`方法应用于`column`轴时。

**skipna:** bool(真或假)。默认值为“无”。如果该参数为`True`，则在计算结果时，排除所有 NA/null 值。

**级别:**代表 int 或级别名称，默认值为 None。如果轴是一个多索引(分层)，则与特定级别一起计数，折叠成一个系列。

**仅限数值:**布尔(真或假)，默认值为无。如果此参数为`True`，则仅包括浮点、整数、布尔列。

****kwargs** :要传递给方法的附加关键字参数。

## 示例 1:使用`DataFrame.min()`方法找到最小值

让我们创建一个数据帧，并通过在`DataFrame.min()`方法中分配参数`axis=0` 获得`index`轴上的**最小值**。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[0,52,78],"B":[77,45,96],"C":[16,23,135],"D":[17, 22, 56]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.min(axis=0))
```

-数据帧为-
A B C D
0 0 77 16 17
1 52 45 23 22
2 78 96 135 56
-
A 0
B 45
C 16
D 17
数据类型:int64

## 示例 2:使用`DataFrame.min()`方法找到最小值

让我们创建一个数据帧，通过在`DataFrame.min()`方法中指定参数`axis=1` 获得**列轴**上的**最小值**。下面的例子显示了同样的情况。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[0,52,78],"B":[77,45,96],"C":[16,23,135],"D":[17, 22, 56]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.min(axis=1))
```

-数据帧为-
A B C D
0 0 77 16 17
1 52 45 23 22
2 78 96 135 56
-
0
1 22
2 56
数据帧:int64

## 示例 3:使用`DataFrame.min()`方法找到最小值

在这里，我们创建了一个空值的数据帧，并通过在`DataFrame.min()`方法中传递参数`skipna=False` 来获得包含空值的`index`轴上的**最小值**值。在计算结果时，它包括所有的 NA/null 值。下面的例子显示了同样的情况。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[0,None,78],"B":[77,45,None],"C":[16,23,None],"D":[17, 22, 56]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.min(axis=0,skipna=False))
```

-数据帧为-
A B C D
0 0.0 77.0 16.0 17
1 NAn 45.0 23.0 22
2 78.0 NAn 56
-
A NAn
B NAn
C NAn
D 17.0
数据类型:float64

## 示例 4:使用`DataFrame.min()`方法找到最小值

让我们创建一个具有**空值**的数据帧，并通过在`DataFrame.min()`方法中传递参数`skipna=True` 来获得除空值之外的`index`轴上的最小**值。在计算结果时，它会排除所有 NA/null 值。下面的例子显示了同样的情况。**

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[0,None,78],"B":[77,45,None],"C":[16,23,None],"D":[17, 22, 56]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.min(axis=0,skipna=True))
```

-数据帧为-
A B C D
0 0.0 77.0 16.0 17
1 NaN 45.0 23.0 22
2 78.0 NaN 56
-
A 0.0
B 45.0
C 16.0
D 17.0
数据类型:float64

### 结论

在本教程中，我们学习了 Pandas`DataFrame.min()`方法。我们学习了语法、参数，并将其应用于数据帧，以理解 `DataFrame.min()`方法。

* * *

* * *