# Pandas 数据帧`mul()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-mul-method>

在本教程中，我们将讨论和学习 Pandas`DataFrame.mul()`的方法。该方法用于获取数据帧和其他元素的乘积。它返回一个带有乘法运算结果的数据帧。

语法如下所示。

### 句法

```py
DataFrame.mul(other, axis='columns', level=None, fill_value=None)
```

### 因素

**其他:**可以是标量、序列、序列或数据帧。它可以是单个或多个元素数据结构，或者类似列表的对象。

**轴:**表示索引或列轴，索引为“0”，列为“1”。当`axis=0`方法应用于`index`轴时，以及当`axis=1`方法应用于`column`轴时。对于输入`Series`，轴要匹配系列索引。

**级别:**代表 int 或标签。它跨级别广播，匹配传递的多索引级别上的索引值。

**fill_value:** 表示浮动或无，默认值为无。它会在计算之前用该值填充现有的缺失值或空值，以及成功的数据帧对齐所需的任何新元素。如果两个相应数据帧位置的数据都丢失，结果也将丢失。

## 示例 1:使用`DataFrame.mul()`方法乘以数据帧

这里，我们使用返回数据帧的`DataFrame.mul()`方法将数据帧乘以`scalar`值。它由乘法运算的输出组成。请看下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [1,1,1],'b': [2,2,2],'c': [3,3,3]})
print(df1.mul(2))
```

a b c
0 2 4 6
1 2 4 6
2 2 4 6

## 示例 2:使用`DataFrame.mul()`方法乘以数据帧

这里，我们使用`DataFrame.mul()`方法将数据帧与`other DataFrame`相乘，该方法返回由乘法运算的输出组成的数据帧。请看下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [1,5,6],'b': [4,6,5],'c': [2,8,7]})
df2 = pd.DataFrame({'a': [2,1,1],'b': [1,5,8],'c': [7,5,6]})
print("------------The result is-----------")
print(df1.mul(df2))
```

-结果是-
a b c
0 2 4 14
1 5 30 40
2 6 40 42

## 示例 3:使用`DataFrame.mul()`方法乘以数据帧

这是另一个乘法数据帧的例子，与前一个非常相似。如果两个数据帧没有对齐，则结果输出由 NaN 值组成。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [1,5,6],'b': [4,6,5],'c': [2,8,7]})
df2 = pd.DataFrame({'a': [2,1,1],'b': [1,5,8]})
print("------------The result is-----------")
print(df1.mul(df2))
```

-结果是-
a b c
0 2 4 NaN
1 5 30 NaN
2 6 40 NaN

## 示例 4:使用`DataFrame.mul()`方法乘以数据帧

这里，在这个例子中，我们将通过在`DataFrame.mul()`方法中传递`fill_value=1` 参数来填充任何缺失的值。它将用该默认值替换所有空值。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [None,5,6],'b': [4,6,5],'c': [2,8,7]})
df2 = pd.DataFrame({'a': [None,1,1],'b': [None,5,8]})
print("------------The result is-----------")
print(df1.mul(df2,fill_value=1))
```

-结果为-
a b c
0 NaN 4.0 2.0
1 5.0 30.0 8.0
2 6.0 40.0 7.0

### 结论

在本教程中，我们学习了 Pandas`DataFrame.mul()`方法。我们学习了该方法的语法和参数，并将其应用于数据帧以理解该方法。

* * *

* * *