# Pandas 数据帧`prod()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-prod-method>

在 Pandas 中，要找到数据帧值的乘积，我们可以使用`DataFrame.prod()`方法。当我们将此方法应用于数据帧时，它会返回由所需轴上的值的乘积组成的序列或数据帧。

下面是`DataFrame.prod()`方法的语法。

### 句法

```py
DataFrame.prod(axis=None, skipna=None, level=None, numeric_only=None, min_count=0, **kwargs)
```

### 因素

**轴:**表示索引或列轴，索引为“0”，列为“1”。当`axis=0`方法应用于`index`轴时，以及当`axis=1`方法应用于`column`轴时。

**skipna:** bool(真或假)。默认值为“无”。如果该参数为`True`，则在计算结果时，排除所有 NA/null 值。

**级别:**代表 int 或级别名称，默认值为 None。如果轴是一个多索引(分层)，则与特定级别一起计数，折叠成一个系列。

**仅限数值:**布尔(真或假)，默认值为无。如果此参数为`True`，则仅包括浮点、整数、布尔列。

**min_count:** 表示 int，默认值为 0。它指示执行操作所需的有效值数量。

****kwargs** :要传递给方法的附加关键字参数。

## 示例:在 Pandas 中找到数据帧的产品

这里，我们使用`DataFrame.prod()`方法沿着索引轴寻找数据帧值的乘积。它将返回数据帧所有值的乘积。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df_1=pd.DataFrame({'A':[1,2,3],'B':[4,5,6],'C':[7,8,9]})
print("------The DataFrame is---------")
print(df_1)
print("---------------------------------")
print(df_1.prod(axis=0))
```

-数据帧为-
A B C
0 1 4 7
1 2 5 8
2 3 6 9
-
A 6
B 120
C 504
数据类型:int64

## 示例:在 Pandas 中找到数据帧的产品

这里，我们使用`DataFrame.prod()`方法沿着**列轴**找到数据帧值的乘积。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df_1=pd.DataFrame({'A':[1,2,3],'B':[4,5,6],'C':[7,8,9]})
print("------The DataFrame is---------")
print(df_1)
print("---------------------------------")
print(df_1.prod(axis=1))
```

-数据帧为-
A B C
0 1 4 7
1 2 5 8
2 3 6 9
-
0 28
1 80
2 162
数据类型:int64

## 示例 3:查找空数据帧的乘积

默认情况下，`DataFrame.prod()`方法在执行产品操作时排除空值或缺失值。如果我们在`DataFrame.prod()`方法中设置 **`skipna=False`** ，则在执行产品操作时会包含空值。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#importing numpy as np
import numpy as np
#creating the DataFrame
df_1=pd.DataFrame({'A':[1,2,np.nan],'B':[np.nan,5,6],'C':[7,8,9]})
print("------The DataFrame is---------")
print(df_1)
print("---------------------------------")
print(df_1.prod(axis=1,skipna=False))
```

-数据帧为-
A B C
0 1.0 NAn 7
1 2.0 5.0 8
2 NAn 6.0 9
-
0 NAn
1 80.0
2 NAn
数据类型:float64

### 结论

在本教程中，我们学习了 Pandas`DataFrame.prod()`方法。我们学习了语法、参数，并在数据帧上应用了这种方法。

* * *

* * *