# Pandas 数据帧`radd()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-radd-method>

在本教程中，我们将讨论和学习 Pandas`DataFrame.radd()`的方法。此方法用于获取数据帧和其他元素的添加。它返回一个带有反向加法运算结果的数据帧。

`DataFrame.radd()`方法的语法如下所示。

### 句法

```py
DataFrame.radd(other, axis='columns', level=None, fill_value=None)
```

### 因素

**其他:**可以是标量、序列、序列或数据帧。它可以是单个或多个元素数据结构，或者类似列表的对象。

**轴:**表示索引或列轴，索引为“0”，列为“1”。当`axis=0`功能应用于`index`轴时，以及当`axis=1`功能应用于`column`轴时。对于输入`Series`，轴要匹配系列索引。

**级别:**代表 int 或标签。它跨级别广播，匹配传递的多索引级别上的索引值。

**fill_value:** 表示浮动或无，默认值为无。它会在计算之前用该值填充现有的缺失值或空值，以及成功的数据帧对齐所需的任何新元素。如果两个相应数据帧位置的数据都丢失，结果也将丢失。

## 示例 1:使用`DataFrame.radd()`方法添加数据帧

这里，我们使用`DataFrame.mul()`方法添加带有`scalar`的数据帧，该方法返回由反向加法操作的输出组成的数据帧。请看下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df = pd.DataFrame({'a': [2,5,7],'b': [1,2,3],'c': [4,5,7]})
print("---------The DataFrame is------")
print(df)
print("----------------------------")
print(df.radd(2))
```

-数据帧为-
a b c
0 2 1 4
1 5 2 5
2 7 3 7
-
a b c
0 4 3 6
1 7 4 7
2 9 5 9

## 示例 2:使用`DataFrame.radd()`方法添加数据帧

这里，我们使用`DataFrame.radd()`方法用`other DataFrame`添加数据帧，该方法返回由反向添加操作的输出组成的数据帧。请看下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [1,5,6],'b': [4,6,5],'c': [2,8,7]})
df2 = pd.DataFrame({'a': [2,1,1],'b': [1,5,8],'c': [7,5,6]})
print("------------The result is-----------")
print(df1.radd(df2))
```

-结果是-
a b c
0 3 5 9
1 6 11 13
2 7 13 13

## 示例 3:使用`DataFrame.radd()`方法添加数据帧

这个例子和上一个相似。如果两个数据帧没有对齐，则结果输出由 NaN 值组成。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [1,5,6],'b': [4,6,5],'c': [2,8,7]})
df2 = pd.DataFrame({'a': [2,1,1],'b': [1,5,8]})
print("------------The result is-----------")
print(df1.radd(df2))
```

-结果是-
a b c
0 3 5 NaN
1 6 11 NaN
2 7 13 NaN

## 示例 4:使用`DataFrame.radd()`方法添加数据帧

这里，在这个例子中，我们将通过在`DataFrame.radd()`方法中传递`fill_value=2` 参数来填充任何缺失的值。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating DataFrame
df1 = pd.DataFrame({'a': [None,2,6],'b': [2,1,4],'c': [2,1,0]})
df2 = pd.DataFrame({'a': [1,1,2],'b': [None,5,0]})
print("------------The result is-----------")
print(df1.radd(df2,fill_value=2))
```

-结果是-
a b c
0 3.0 4.0 4.0
1 3.0 6.0 3.0
2 8.0 4.0 2.0

### 结论

在本教程中，我们学习了 Pandas`DataFrame.radd()`方法。我们通过在 DataFrame 上应用这个函数来学习语法、参数和求解示例，并理解了该方法。

* * *

* * *