# Pandas 数据帧`mode()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-mode-method>

在本教程中，我们将讨论和学习 Pandas`DataFrame.mode()`的方法。使用这种方法，我们可以沿着指定的轴获得每个元素模式。当此方法应用于数据帧时，它返回由每一列或每一行的模式组成的数据帧。

以下是`DataFrame.mode()`方法的语法

### 句法

```py
DataFrame.mode(axis=0, numeric_only=False, dropna=True)
```

### 因素

**轴:**表示索引或列轴，索引为“0”，列为“1”。当`axis=0`方法应用于`index`轴时，以及当`axis=1`方法应用于`column`轴时。

**仅限数值:**代表布尔(真或假)，默认值为假。如果此参数为`True`，则仅包括浮点、整数、布尔列。

**dropna:** 代表 bool，默认值为 True。它不考虑空值。

## 示例:查找 Pandas 中数据帧的模式值

让我们创建一个数据帧，通过在`DataFrame.mode()`方法中指定参数`axis=0` 来获得`index`轴上的**模式**值。见下面的例子。

如我们所见，`DataFrame.mode()`方法返回一个数据帧，该数据帧由沿着`row`轴的数据帧中重复次数最多的值组成。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,2,1],"B":[2,2,1],"C":[5,2,5],"D":[4,5,4]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.mode(axis=0))
```

-数据帧为-
A B C D
0 1 2 5 4
1 2 2 2 5
2 1 5 4
-
A B C D
0 1 2 5 4

## 示例 2:Pandas 中数据帧的查找模式

让我们创建一个数据帧，通过在`DataFrame.mode()`方法中指定一个参数`axis=1` 来获得列轴上的**模式**值。见下面的例子。

如我们所见，`DataFrame.mode()`方法返回一个数据帧，该数据帧由数据帧中沿列轴重复最多的值组成。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,2,1],"B":[2,2,1],"C":[5,2,5],"D":[1,5,4]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.mode(axis=1))
```

-数据帧为-
A B C D
0 1 2 5 1
1 2 2 2 5
2 1 5 4
-
0
0 1
1 2
2 1

## 示例 3:查找 Pandas 中数据帧的模式值

默认情况下，`DataFrame.mode()`方法不考虑空值或缺失值。如果我们在`DataFrame.mode()`方法中设置`dropna=False`，它也会考虑空值，模式可以是空值。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A":[1,2,None],"B":[None,2,None],"C":[5,2,5],"D":[1,5,4]}) 
print("------The DataFrame is------")
print(df)
print("---------------------------")
print(df.mode(axis=1,dropna=False))
```

-数据帧为-
A B C D
0 1.0 NaN 5 1
1 2.0 2.0 2 5
2 NaN 5 4
-
0
0 1.0
1 2.0
2 NaN

### 结论

在本教程中，我们学习了 Pandas`DataFrame.mode()`方法。我们学习了语法、参数，并将其应用于数据帧，我们解决了示例并理解了 `DataFrame.mode()`方法。

* * *

* * *