# Pandas 数据帧`pipe()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-pipe-method>

如果我们想对整个数据帧应用一种方法，我们可以使用 [Python](https://www.studytonight.com/python/getting-started-with-python) pandas `DataFrame.pipe()`方法。此方法以先进先出的方式将指定的方法或多个方法(链)应用于数据帧的所有行和列。应用方法可以是用户定义的方法，也可以是内置方法。

下图显示了`DataFrame.pipe()` 方法的语法。

### 句法

```py
DataFrame.pipe(func, *args, **kwargs)
```

### 因素

**功能:**是应用于指定数据帧的方法。

**args:** 可以迭代，可选。它表示传递到`func`的位置参数。

**夸脱:**表示映射，可选。传递到`func`的关键字参数字典。

## 示例 1:将用户定义的方法应用于数据帧

让我们创建一个数据帧，并对数据帧应用`DataFrame.pipe()` 方法。在这个例子中，我们定义了一个名为`add()` 的方法，它将`'1'`添加到元素中。使用`DataFrame.pipe()` 方法，我们可以将这个`add()` 方法应用到整个数据帧。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
def add(x):
    return x+1
df=pd.DataFrame({'A':[1,2,3],'B':[4,5,6],'C':[7,8,9]})
print("--------The DataFrame is------")
print(df)
print("---------------------")
print(df.pipe(add))
```

-数据帧为-
A B C
0 1 4 7
1 2 5 8
2 3 6 9
-
A B C
0 2 5 8
1 3 6 9
2 4 7 10

## 示例 2:将用户定义的方法应用于数据帧

让我们创建一个数据帧，并对数据帧应用`DataFrame.pipe()` 方法。在本例中，我们使用`DataFrame.pipe()` 方法将`np.add()` 方法应用于整个数据帧。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#importing numpy as np
import numpy as np
df=pd.DataFrame({'A':[1,1,1],'B':[2,2,2],'C':[3,3,3]})
print("--------The DataFrame is------")
print(df)
print("---------------------")
print(df.pipe(np.add,2))
```

-数据帧为-
A B C
0 1 2 3
1 1 2 3
2 1 2 3
-
A B C
0 3 4 5
1 3 4 5
2 3 4 5

## 示例 3:将用户定义的方法应用于数据帧

我们可以使用`DataFrame.pipe()` 方法对数据帧应用多种方法。见下面的例子。

在本例中，我们将值`'2'` 添加到数据帧中，并分别使用`np.add()` 和`np.multiply()` 方法将结果数据帧乘以`'2'` 。

```py
#importing pandas as pd
import pandas as pd
#importing numpy as np
import numpy as np
df=pd.DataFrame({'A':[1,1,1],'B':[2,2,2],'C':[3,3,3]})
print("--------The DataFrame is------")
print(df)
print("---------------------")
print(df.pipe(np.add,2).pipe(np.multiply,2))
```

-数据帧为-
A B C
0 1 2 3
1 1 2 3
2 1 2 3
-
A B C
0 6 8 10
1 6 8 10
2 6 8 10

### 结论

在本教程中，我们学习了 Pandas`DataFrame.pipe()`方法。我们学习了语法、参数，并在数据帧上应用了这种方法。

* * *

* * *