# Pandas 数据帧`rename()`方法

> 原文：<https://www.studytonight.com/pandas/pandas-dataframe-rename-method>

在本教程中，我们将讨论和学习 Pandas`DataFrame.rename()` 方法。通过使用这种方法，我们可以改变或改变轴标签。当此方法应用于数据帧时，如果`inplace=True`为，则返回数据帧或无。如果在选定的轴中找不到指定的标签，它会发出`KeyError` 。

下图显示了`DataFrame.rename()` 方法的语法。

### 句法

```py
DataFrame.rename(mapper=None, index=None, columns=None, axis=None, copy=True, inplace=False, level=None, errors='ignore')
```

### 因素

**映射器:**可以是类似字典的函数或函数。类似 Dict 或函数的转换应用于该轴的值。使用`mapper`和`axis`中的任意一个指定要以`mapper`为目标的轴，或者使用`index`和`columns`为目标的轴。

**索引:**可以是字典状或函数。这是指定轴的替代方法。

**列:**可以是类似字典的或函数。这是指定轴的替代方法。

**轴:**表示索引或列轴，索引为“0”或“索引”，列轴为“1”或“列”。当`axis=0 or index`方法应用于`index`轴时，当`axis=1`或`columns` 方法应用于`column`轴时。

**副本:**代表 bool(真或假)，默认值为 True。它复制底层数据。

**inplace:** 表示 bool(真或假)，默认值为 False。它指示是否返回新的数据帧。如果参数为真，则忽略副本的值。

**级别:**表示 int 或 level 名称，默认为 None。

**错误:**包括‘忽略’、‘提高’，默认为‘忽略’。

## 示例 1:更改 Pandas 中数据帧的标签

这里，使用`DataFrame.rename()` 方法，我们更改列的名称。见下面的例子。

我们也可以使用轴参数指定我们正在哪个轴上。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A": [1, 2, 3], "B": [4, 5, 6],"C": [7,8,9]})
print("-------The DataFrame is-------")
print(df)
print("----------------------------------")
print(df.rename(columns={"A": "a", "B": "b","C":"c"}))
```

-数据帧为-
A B C
0 1 4 7
1 2 5 8
2 3 6 9
-
A B C
0 1 4 7
1 2 5 8
2 3 6 9

## 示例:使用`DataFrame.rename()` 方法更改标签

这里，使用`DataFrame.rename()` 方法，我们更改索引的名称。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A": [1, 2, 3], "B": [4, 5, 6],"C": [7,8,9]})
print("-------The DataFrame is-------")
print(df)
print("----------------------------------")
print(df.rename(index={0: "index_1", 1: "index_2", 2:"index_3"}))
```

-数据帧为-
A B C
0 1 4 7
1 2 5 8
2 3 6 9
-
A B C
索引 _1 1 4 7
索引 _2 2 5 8
索引 _3 3 6 9

## 示例:在`DataFrame.rename()`方法中设置`errors=raise`

如果在更改行或列的名称时出现任何错误，默认情况下`DataFrame.rename()` 方法会忽略这些错误。如果我们在`DataFrame.rename()` 方法中设置`errors='raise'`，会产生错误。见下面的例子。

在下面的示例中，`DataFrame.rename()` 方法会引发键错误，因为在数据帧中找不到指定的列标签。

```py
#importing pandas as pd
import pandas as pd
#creating the DataFrame
df = pd.DataFrame({"A": [1, 2, 3], "B": [4, 5, 6],"C": [7,8,9]})
print(df.rename(columns={"A": "a", "B": "b","D":"d"},errors="raise"))
```

键错误:“['D']在轴中找不到”

### 结论

在本教程中，我们学习了 Pandas`DataFrame.rename()`方法。我们通过在数据帧上应用这种方法来学习语法、参数和解决示例，并理解了这种方法。

* * *

* * *