# Pandas 序列`at_time()`方法

> 原文：<https://www.studytonight.com/pandas/python-pandas-seriesat_time-method>

在本教程中，我们将讨论和学习 Pandas`Series.at_time()`方法，使用该方法我们可以在一天中的特定时间选择值。如果索引中没有指定的时间，它将返回空序列；如果索引不是日期时间索引，它将引发`TypeError`。

下图显示了`Series.at_time()`方法的语法。

### 句法

```py
Series.at_time(time, asof=False, axis=None)
```

### 因素

**时间:**是 datetime.time 或 str。

**轴:** {0 或'索引'，1 或'列' }，默认为 0。

## 示例:使用`Series.at_time()`方法选择值

让我们创建一系列数据时间索引，并使用`Series.at_time()`方法获取值。如果指定的时间出现在索引中，`Series.at_time()`方法返回这些行。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
Values = pd.date_range('2021-04-01', periods=6, freq='8H')
series = pd.Series([1, 2, 3, 4, 5, 6], index=Values)
print(series)
print("-----Selecting values---------")
print(series.at_time('8:00'))
```

2021-04-01 00:00:00 1
2021-04-01 08:00:00 2
2021-04-01 16:00:00 3
2021-04-02 00:00 4
2021-04-02 08:00:00 5
2021-04-02 16

## 示例:使用`Series.at_time()`方法选择值

这个例子类似于上一个改变周期，频率和获取值的例子。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
Values = pd.date_range('2021-04-01', periods=4, freq='10T')
series = pd.Series([1, 2, 3, 4], index=Values)
print(series)
print("-----Selecting values---------")
print(series.at_time('00:10:00'))
```

2021-04-01 00:00:00 1
2021-04-01 00:10:00 2
2021-04-01 00:20:00 3
2021-04-01 00:30:00 4
Freq:10T，dtype: int64
-选择值-
2021-04-01 00

## 示例:`Series.at_time()`方法返回空序列

这里，在这个例子中，`Series.at_time()`方法返回空序列，因为指定的时间`'10:00'` 不在索引中。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
Values = pd.date_range('2021-04-01', periods=4, freq='10T')
series = pd.Series([1, 2, 3, 4], index=Values)
print(series)
print("-----Selecting values---------")
print(series.at_time('10:00'))
```

2021-04-01 00:00:00 1
2021-04-01 00:10:00 2
2021-04-01 00:20:00 3
2021-04-01 00:30:00 4
频率:10T，数据类型:int64
-选择值-
系列([]，频率:10T，数据类型

## 示例:`Series.at_time()`方法引发类型错误

序列的索引必须是日期时间索引，否则`Series.at_time()`方法在选择值时会引发`TypeError`。见下面的例子。

```py
#importing pandas as pd
import pandas as pd
series = pd.Series([1, 2, 3, 4])
print(series.at_time('10:00'))
```

类型错误：索引必须是日期时间索引

### 结论

在本教程中，我们学习了 Pandas`Series.at_time()`方法。我们理解了函数的语法和参数，并通过在数据帧上应用`Series.at_time()`方法来获得指定时间的值来解决示例。

* * *

* * *