# Spring IOC 容器

> 原文：<https://www.studytonight.com/spring-framework/spring-ioc-container>

Spring IoC 容器是 Spring 框架的核心部分，用于管理应用 bean。它在创建 bean 时注入依赖项，并在执行过程中**管理 bean 的生命周期**。

SpringIOC 的基本任务是:

*   例示

*   配置和

*   组装 Bean

IOC 容器从 Spring 配置文件中获取配置相关信息。可以是 **XML** 或者 **Java** 文件。

容器使用[](https://www.studytonight.com/spring-framework/spring-constructorbased-dependency-injection)**依赖注入来管理组成应用的组件。**

 **Spring 提供了两种 IOC 容器:

*   豆工厂

*   应用上下文

## Spring 豆工厂界面

它是一个 IoC 容器，负责维护 beans 及其依赖关系。它基本上是一个提供基本功能的接口。

### 豆工厂接口方法:

以下是豆工厂接口方法:

| 

方法名

 | 

描述

 |
| `boolean containsBean(String name)` | 它检查这个 bean 工厂是否包含具有给定名称的 bean 定义或外部注册的单例实例。 |
| `String[] getAliases(String name)` | 它返回给定 bean 名称的别名(如果有)。 |
| `<T> T getBean(Class<T> requiredType)` | 它返回唯一匹配给定对象类型(如果有)的 bean 实例。 |
| `<T> T getBean(Class<T> requiredType, Object... args)` | 它返回指定 bean 的一个实例，该实例可以是共享的，也可以是独立的。 |
| `Object getBean(String name)` | 它返回指定 bean 的一个实例，该实例可以是共享的，也可以是独立的。 |
| `<T> T getBean(String name, Class<T> requiredType)` | 它返回指定 bean 的一个实例，该实例可以是共享的，也可以是独立的。 |
| `Object getBean(String name, Object... args)` | 它返回指定 bean 的一个实例，该实例可以是共享的，也可以是独立的。 |
| `<T> ObjectProvider<T> getBeanProvider(Class<T> requiredType)` | 它返回指定 bean 的提供者，允许实例的延迟按需检索，包括可用性和唯一性选项。 |
| `<T> ObjectProvider<T> getBeanProvider(ResolvableType requiredType)` | 它返回指定 bean 的提供者，允许实例的延迟按需检索，包括可用性和唯一性选项。 |
| `Class<?> getType(String name)` | 它确定具有给定名称的 bean 的类型。 |
| `Class<?> getType(String name, boolean allowFactoryBeanInit)` | 它确定具有给定名称的 bean 的类型。 |
| `boolean isPrototype(String name)` | 它检查这个 bean 是否是原型。 |
| `boolean isSingleton(String name)` | 它检查这个 bean 是否是共享的单例。 |
| `boolean isTypeMatch(String name, Class<?> typeToMatch)` | 它检查具有给定名称的 bean 是否与指定的类型匹配。 |
| `boolean isTypeMatch(String name, ResolvableType typeToMatch)` | 它检查具有给定名称的 bean 是否与指定的类型匹配。 |

## Spring 应用上下文子接口

`ApplicationContext`是`BeanFactory`的子界面，提供更多类似企业的功能。它添加了特定于应用层的上下文，例如网络应用的`WebApplicationContext`。

此应用上下文界面有几种实现，例如:

*   ClassPathXmlApplicationContext

*   XmlWebApplicationContext

*   filestystemxmlaplicationcontext

### 应用上下文方法:

以下是应用上下文接口中的方法。

| 

方法名

 | 

描述

 |
| `String getApplicationName()` | 它返回此上下文所属的已部署应用的名称。 |
| `AutowireCapableBeanFactory getAutowireCapableBeanFactory()` | 它为这个上下文公开了 AutowireCapableBeanFactory 功能。 |
| `String getDisplayName()` | 它返回该上下文的友好名称。 |
| `String getId()` | 它返回此应用上下文的唯一 id。 |
| `ApplicationContext getParent()` | 它返回父上下文，如果没有父上下文，则返回 null，这是上下文层次结构的根。 |
| `long getStartupDate()` | 它返回首次加载该上下文时的时间戳。 |

## BeanFactory 和应用上下文之间的区别

两个接口(BeansFactory 和 ApplicationsContext)都充当 IoC 容器。BeanFactory 接口是一个基础接口，提供了创建和运行 IoC 容器的所有基本功能，而 ApplicationContext 接口是 BeanFactory 接口的一个子接口，它增加了一些额外的功能，如与 Spring 的 AOP 的简单集成、消息资源处理(对于 I18N)、应用层特定的上下文等。因此，我们可以使用 ApplicationContext 来获得更好的特性。

## 如何配置 IoC 容器？

这是基于 XML 的配置元数据的基本结构。

```java
<?xml version="1.0" encoding="UTF-8"?>
<beans 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://www.springframework.org/schema/beans
        https://www.springframework.org/schema/beans/spring-beans.xsd">

    <bean id="..." class="...">  
        <!-- collaborators and configuration for this bean go here -->
    </bean>

    <!-- more bean definitions go here -->

</beans>
```

主要有三种方法可以配置我们的 IoC 容器。

*   基于 XML 的

*   基于注释

*   基于 Java 的

在下一节中，我们将讨论如何以所有可能的方式配置 IoC 容器。

* * *

* * ***