# Spring Bean

> 原文：<https://www.studytonight.com/spring-framework/spring-bean>

Bean 是 Spring 中的一个对象，由 Spring IoC 容器管理。Spring 使用我们在 XML 文件的 **< bean >** 标签中提供的配置元数据创建 bean。我们通过使用 XML 文件或 Java 注释向 IoC 容器提供元数据。

在元数据配置期间，我们为 bean 定义提供了一些可选属性，例如:

*   Bean 类名的完全限定名。比如**com study south . community . reader**。

*   Bean 行为，如 Bean 作用域、生命周期回调等。

*   Bean 所需的 bean 依赖项(对其他 bean 的引用)。

### <bean>标签结构</bean>

```java
<bean id="demoBean" class="com.examples.DemoBean" /> 
```

**id** 属性为由**类**属性指定的类设置唯一的 id。

## Bean 定义属性

下表包含用于在配置文件中配置 bean 的<bean>标签属性。</bean>

| 

Bean 属性

 | 

描述

 |
| --- | --- |
| 班级 | 此属性用于指定为其创建对象的类。 |
| 名字 | 此属性用于为 bean 指定唯一的标识符。 |
| 作用域 | 它指定了 beans 的作用域，如 singleton 或 prototype。 |
| 构造器参数 | 它用于基于构造器的依赖注入。 |
| 性能 | 此属性用于基于属性的依赖注入。 |
| 自动装配模式 | 用于设置 bean 自动装配。 |
| 协作者和惰性初始化模式 | 它用于设置惰性 bean 初始化。 |
| 初始化方法 | 它用于设置在 bean 初始化时执行的初始化方法。 |
| 销毁方法 | 它用于设置在销毁 bean 对象之前执行的破坏性方法。 |

## 1.命名 Bean

为了在基于 XML 的配置中设置 bean 的名称，我们使用 **id、** **名称**属性，或者两者都使用。 **id** 属性让我们可以精确地指定一个 id。

在设置 bean 名称时，我们需要遵循命名约定，这意味着 bean 名称以小写字母开头，并且是骆驼大小写。

```java
<bean id="..." class="..."> 
    <!-- Configuration for this bean go here --> 
</bean>
```

## 惰性初始化

默认情况下，`ApplicationContext`实现急切地创建和配置所有单例 beans，作为初始化过程的一部分。

延迟初始化的 bean 告诉 IoC 容器在第一次请求时创建一个 bean 实例，而不是在启动时。

```java
<bean id = "..." class = "..." lazy-init = "true">
      <!-- Configuration for this bean go here -->
</bean>
```

### 初始化方法

此属性用于指定在 bean 初始化时执行的方法。bean 标记和属性的语法如下。

```java
<bean id = "..." class = "..." init-method = "...">
      <!-- Configuration for this bean go here -->
</bean>
```

### 销毁方法

此属性用于指定在 bean 销毁时执行的方法。bean 标记和属性的语法如下。

```java
<bean id = "..." class = "..." destroy-method = "...">
      <!-- Configuration for this bean go here -->
</bean>
```

## 简单的 Bean 示例

让我们创建一个示例来创建一个 bean，并从 bean 和属性标签中访问它的属性。以下是我们在项目中创建的 Java 和 XML 文件。

**//Employee.java**

这是一个简单的 Java POJO bean 类，它有设置器和获取器方法来处理数据。

```java
package com.studytonight.community;
public class Employee {

	int id;
	String name;

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}
}
```

### // SpringApp.java

该文件读取 XML 文件，并获取 XML 文件中的 bean 数据集。我们使用获取器方法来获取 bean 数据。

```java
package com.studytonight.community;

import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

public class SpringApp {

	private static ApplicationContext context;
	public static void main(String[] args) {

		context = new ClassPathXmlApplicationContext("applicationContext.xml");
		Employee e = (Employee) context.getBean("employee");
		System.out.println("Id: "+e.getId());
		System.out.println("Name: "+e.getName());
	}
}
```

### //application context . XML

这是一个上下文文件，通过使用属性标记来配置 bean 标记及其属性。

```java
<?xml version="1.0" encoding="UTF-8"?>
<beans 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:context="http://www.springframework.org/schema/context"
	xsi:schemaLocation="http://www.springframework.org/schema/beans 
                           http://www.springframework.org/schema/beans/spring-beans.xsd
                           http://www.springframework.org/schema/context 
                           http://www.springframework.org/schema/context/spring-context.xsd">

	<bean id="employee" class="com.studytonight.community.Employee">
		<property name="id" value="0501"></property>
		<property name="name" value="Rahul"></property>
	</bean>
</beans>
```

### //POM . XML

这是一个 maven 依赖文件，用于配置所有项目设置和依赖关系。

```java
<project 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 https://maven.apache.org/xsd/maven-4.0.0.xsd">
	<modelVersion>4.0.0</modelVersion>
	<groupId>com.studytonight</groupId>
	<artifactId>SpringApp</artifactId>
	<version>0.0.1-SNAPSHOT</version>
	<dependencies>
		<!-- https://mvnrepository.com/artifact/org.springframework/spring-web -->
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-core</artifactId>
			<version>${spring.version}</version>
		</dependency>
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-context</artifactId>
			<version>${spring.version}</version>
		</dependency>
	</dependencies>
	<properties>
		<spring.version>5.2.8.RELEASE</spring.version>
	</properties>
	<build>
		<sourceDirectory>src</sourceDirectory>
		<plugins>
			<plugin>
				<artifactId>maven-compiler-plugin</artifactId>
				<version>3.8.1</version>
				<configuration>
					<source>1.8</source>
					<target>1.8</target>
				</configuration>
			</plugin>
		</plugins>
	</build>
</project>
```

### 运行应用

成功完成项目并添加依赖项后，运行应用，您将获得如下输出。

Id: 501
姓名:拉胡尔

* * *

* * *