# Spring 自动装配

> 原文：<https://www.studytonight.com/spring-framework/spring-autowiring>

自动装配是 Spring 中用来实现自动依赖注入的一种技术。通过使用它，Spring 容器可以自动连接协作 beans 之间的关系。它被称为 Spring 自动装配。

Spring 提供@Autowired 注释，使您能够隐式地注入对象依赖关系。它在内部使用设置器或构造器注入。

**注意:**我们不能使用@Autowired 注解来注入原语和字符串值。它的工作方式仅供参考。

## 启用 Spring 自动装配

Spring 框架支持自动依赖注入。换句话说，通过在 Spring 配置文件中声明所有的 bean 依赖关系，Spring 容器可以自动连接协作 bean 之间的关系。这叫做 Spring bean 自动装配。

在基于 Java 的配置中，我们可以通过使用@componentScan 注释来启用它。

```java
@Configuration
@ComponentScan("com.studytonight")
public class AppConfig{
}
```

而在 XML 配置的情况下，我们可以在 applicationcontext 文件内部使用<annotation-config>标签。</annotation-config>

自动连接也可以用于字段、方法和构造器。让我们看一些例子

启用注释注入后，**我们可以在属性、设置器和构造器上使用自动连接**。

## 示例:现场自动装配

Spring 允许使用带有字段的@Autowired 注释来注入依赖关系，就像我们在下面的例子中所做的那样。完整的例子，请参考我们的详细文章[@带字段自动装配](https://www.studytonight.com/spring-framework/spring-field-injection)。

```java
@Service
@Component
public class UserServices {	 

	@Autowired
	private SessionFactory sessionFactory;

	public void setSessionFactory(SessionFactory sessionFactory) {
        this.sessionFactory = sessionFactory;
    }
}
```

## 示例:方法自动装配

Spring 允许使用@Autowired 注释和方法来注入依赖关系，就像我们在下面的例子中所做的那样。完整的例子可以参考我们详细的文章[@用方法](https://www.studytonight.com/spring-framework/spring-method-injection)自动装配。

```java
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class FictionWriter implements Writer {

	private Award award;

	@Autowired
	public void awardInstance(Award award) {
		this.award = award;
	}
}
```

## 示例:构造器自动装配

Spring 允许使用带有构造器的@Autowired 注释来注入依赖项，就像我们在下面的例子中所做的那样。完整的例子可以参考我们详细的文章[@带构造器的自动装配](https://www.studytonight.com/spring-framework/spring-qualifier-with-constructors)。

```java
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

@Component
public class TechnicalWriter implements Writer{

	private Award award;

	@Autowired
	public TechnicalWriter(@Qualifier("pulitzerAward") Award award) {
		this.award = award;
	}
}
```

我们也可以将它与字段、构造器和方法混合使用。

```java
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

@Component
public class TechnicalWriter implements Writer{

	@Autowired
	private Award award;  // Field Autowired

	@Autowired            // Constructor Autowired
	public TechnicalWriter(Writer writer) {
		TechnicalWriter tWriter =  writer
	}
}
```

之后，我们将讨论使用*@限定符*注释、以及潜在的异常场景来解决 bean 冲突。

* * *

* * *