# Spring `@Bean`注解

> 原文：<https://www.studytonight.com/spring-framework/spring-bean-annotation>

Spring ``@Bean`` 注解用于显式声明单个 bean，而不是 Spring 自动创建的。它将 bean 的声明从类定义中分离出来，让我们按照自己的选择创建和配置 bean。

配置文件(用@configuration 注解标记的文件)用于声明 bean，然后由 Spring 容器获取该 bean。我们举个例子来理解一下。在 **AppConfig** 文件中，我们使用@bean 注解创建了一个名为 manager 的 Bean。我们没有使用任何 XML 文件和`<bean>`标签来创建一个 bean，因为@Bean 注解本身就可以完成所有的工作。我们的项目包含以下文件。

*   银行应用.java
*   AppConfig.java
*   Manager.java
*   Employee.java
*   pom.xml 文件

//app config . Java

这是一个 Java 配置文件，它是我们为基于 xml 的配置示例创建的 **applicationContext.xml** 文件的替代文件。`@Configuration`注解表示这不是一个简单的类，而是一个配置类，`@ComponentScan`注解用于表示我们 spring 项目中的组件位置。

```java
package com.studytonight.community;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class AppConfig {

	@Bean
	public Manager manager() {
		return new Manager();
	}
}
```

**银行应用.java**

该文件包含为我们的应用创建 IOC 容器的代码。AnnotationConfigApplicationContext 类用于为应用上下文创建对象。

```java
package com.studytonight.community;

import org.springframework.context.annotation.AnnotationConfigApplicationContext;

public class BankApp {

	public static void main(String[] args) {

		AnnotationConfigApplicationContext context = new AnnotationConfigApplicationContext(AppConfig.class);
		Employee employee = context.getBean("manager",Employee.class);
		employee.work();
		context.close();
	}
}
```

**//Manager.java**

这是另一个使用`@Component`注解标记并实现`Employee`接口的组件类。在这个类中，我们实现了一个**设置器依赖注入**。请参见，管理器类通过使用在设置器方法中实例化的 account 类对象来调用 account 类的方法。请看下面的例子。

```java
package com.studytonight.community;

import org.springframework.stereotype.Component;

public class Manager implements Employee{

	public void work() {
		System.out.println("Manage the branch office");

	}
}
```

**//Employee.java**

这是一个包含`doWork()`抽象方法的界面`Employee`。每个实现这个接口的类都必须覆盖`doWork()`方法。

```java
package com.studytonight.community;

public interface Employee {

	void work();

} 
```

//POM . XML

这个文件包含这个项目的所有依赖项，比如 spring jars、servlet jars 等。将这些依赖项放入项目中以运行应用。

```java
<project  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 https://maven.apache.org/xsd/maven-4.0.0.xsd">
  <modelVersion>4.0.0</modelVersion>
  <groupId>com.studytonight</groupId>
  <artifactId>springApp</artifactId>
  <version>0.0.1-SNAPSHOT</version>
  <dependencies>
		<!-- https://mvnrepository.com/artifact/org.springframework/spring-web -->
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-core</artifactId>
			<version>${spring.version}</version>
		</dependency>
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-context</artifactId>
			<version>${spring.version}</version>
		</dependency>
		<dependency>
			<groupId>javax.annotation</groupId>
			<artifactId>javax.annotation-api</artifactId>
			<version>1.3.2</version>
		</dependency>
	</dependencies>
	<properties>
		<spring.version>5.2.8.RELEASE</spring.version>
	</properties>
	<build>
		<sourceDirectory>src</sourceDirectory>
		<plugins>
			<plugin>
				<artifactId>maven-compiler-plugin</artifactId>
				<version>3.8.1</version>
				<configuration>
					<source>1.8</source>
					<target>1.8</target>
				</configuration>
			</plugin>
		</plugins>

	</build>
</project>
```

### 运行应用

成功完成项目并添加依赖项后，运行应用，您将获得如下输出。

管理分公司

* * *

* * *