# Spring 读取属性文件

> 原文：<https://www.studytonight.com/spring-framework/spring-read-property-file>

如果我们在一个文件中有一些值(数据)，并且想使用 bean 的获取器方法读取它们，那么就使用属性文件。属性文件用于包含 Spring 应用的属性值。

我们可以用它来保存 bean 的字段值。它使用**。属性**扩展名创建一个文件作为属性文件。

### 如何将属性文件加载到 Spring 应用中

为了加载属性文件，Spring 提供了`@PropertySource`注释和`<context:property-placeholder>`标记。如果您正在使用 XML，那么您可以使用<内容:属性-占位符>标记，否则使用注释来加载属性文件。例如，

### XML 标记示例

使用这个标签进入 **applicationContext.xml** 加载属性文件。

```java
content:property-placeholder location="classpath:filename.properties" />
```

### 注释示例

将此注释与配置类一起使用，以加载属性文件。

```java
@PropertySource("classpath:manager.properties")
```

### 如何从属性文件中读取属性

要读取属性，使用`@Value()`注释或`<property/>`标记。Spring 允许使用 XML 和非 XML 配置。让我们看看语法

### XML 标记示例

使用这个标签进入 **applicationContext.xml** 读取属性。

```java
<property name="propertyName" value="${propertyValue}"> </property>

```

### 注释示例

将此注释用于类字段，并创建一个获取器方法。

```java
@Value("{propertyName}")
```

## 用 Java 读取属性文件的示例

让我们创建一个示例来读取属性文件的属性。这个项目有以下几个 java 文件。

**// 银行应用.java**

该文件包含为我们的应用创建 IOC 容器的代码。AnnotationConfigApplicationContext 类用于为应用上下文创建对象。

在这里，我们使用获取器来读取管理器 bean 的属性。

```java
package com.studytonight.community;
import org.springframework.context.annotation.AnnotationConfigApplicationContext;
public class BankApp {

	public static void main(String[] args) {

		AnnotationConfigApplicationContext context = new AnnotationConfigApplicationContext(AppConfig.class);
		Manager employee = context.getBean(Manager.class);
		employee.work();
		System.out.println("Email: " + employee.getEmail());
		System.out.println("Id: " + employee.getId());
		context.close();
	}
}
```

![](img/4765334125b448ec4c4bdf8285a1da72.png)![](img/4765334125b448ec4c4bdf8285a1da72.png "Click and drag to move")

//app config . Java

这是一个 Java 配置文件，它是我们为基于 xml 的配置示例创建的 **applicationContext.xml** 文件的替代文件。`@Configuration`注释表示这不是一个简单的类，而是一个配置类，`@PropertySource`注释用于表示属性文件在我们的 spring 项目中的位置。

```java
package com.studytonight.community;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.context.annotation.PropertySource;

@Configuration
@PropertySource("classpath:manager.properties")
public class AppConfig {

	@Bean
	public Manager manager() {
		return new Manager();
	}
}
```

![](img/4765334125b448ec4c4bdf8285a1da72.png)![](img/4765334125b448ec4c4bdf8285a1da72.png "Click and drag to move")

**//Manager.java**

这是一个使用`@Component`注释标记的组件类，实现了`Employee`接口。在这个类中，我们使用@Value 注释将字段映射到属性文件。看，我们创建了获取器来从属性文件中读取属性。请看下面的例子。

```java
package com.studytonight.community;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class Manager implements Employee{

	@Value("${id}")
	private int id;
	@Value("${email}")
	private String email;

	public void work() {
		System.out.println("Manage the branch office");

	}
	public int getId() {
		return id;
	}
	public String getEmail() {
		return email;
	}
}
```

**// manager.properties**

这是我们的属性文件，包含两个带值的属性。

```java
email=manager@studytonight.com
id=1025
```

**//Employee.java**

这是一个包含`Work()`抽象方法的界面`Employee`。实现此接口的每个类都必须重写此方法。

```java
package com.studytonight.community;
public interface Employee {

	void work();
} 
```

//POM . XML

这个文件包含这个项目的所有依赖项，比如 spring jars、servlet jars 等。将这些依赖项放入项目中以运行应用。

```java
<project  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 https://maven.apache.org/xsd/maven-4.0.0.xsd">
  <modelVersion>4.0.0</modelVersion>
  <groupId>com.studytonight</groupId>
  <artifactId>springApp</artifactId>
  <version>0.0.1-SNAPSHOT</version>
  <dependencies>
		<!-- https://mvnrepository.com/artifact/org.springframework/spring-web -->
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-core</artifactId>
			<version>${spring.version}</version>
		</dependency>
		<dependency>
			<groupId>org.springframework</groupId>
			<artifactId>spring-context</artifactId>
			<version>${spring.version}</version>
		</dependency>
		<dependency>
			<groupId>javax.annotation</groupId>
			<artifactId>javax.annotation-api</artifactId>
			<version>1.3.2</version>
		</dependency>
	</dependencies>
	<properties>
		<spring.version>5.2.8.RELEASE</spring.version>
	</properties>
	<build>
		<sourceDirectory>src</sourceDirectory>
		<plugins>
			<plugin>
				<artifactId>maven-compiler-plugin</artifactId>
				<version>3.8.1</version>
				<configuration>
					<source>1.8</source>
					<target>1.8</target>
				</configuration>
			</plugin>
		</plugins>

	</build>
</project>
```

### 运行应用

成功完成项目并添加依赖项后，运行应用，您将获得如下输出。

![](img/4765334125b448ec4c4bdf8285a1da72.png)

管理分公司
manager@studytonight.com
1025

* * *

* * *