# Spring Boot 简介

> 原文：<https://www.studytonight.com/spring-boot/introduction-to-spring-boot>

应用开发非常重要，因为它有助于我们的日常工作。例如，支持在线订购的食品订购应用必须使用前端用户界面、后端(服务器端编程)和数据库来保存数据。自 90 年代中期以来，Java 一直是许多程序员设计软件的流行选择，因此，许多框架的开发都是为了使用 Java 来简化软件开发。

为了使开发变得简单有效，引入了几个框架，如 *Struts* 、 *Spring* 和 ORM 工具，如 *Hibernate* 、 *Toplink* 等。用于数据库操作。

近年来，Spring 有了很大的发展，出现了许多新模块，如**Spring 靴**、**Spring Security**、**Spring 云**等。在这一系列教程中，我们将学习 spring-boot 框架及其提供的各种特性，使其成为应用开发的流行选择。Spring 靴由 **PIVOTAL** 团队开发。

## 先决条件:

*   java 编程知识。
*   动手 REST 网络服务
*   依赖管理工具，如 Maven 或 Gradle，将是一个额外的优势。

## Spring Boot 的优势:

1.  SpringBoot 的主要优势是为项目启用**自动配置。这减轻了程序员的负担，节省了大量时间。**

2.  它使**使用非常简单的注释**，并取代了 spring MVC 中典型的基于 XML 的配置设置。

3.  提供一个**嵌入式 servlet 容器**，并帮助轻松引导(快速运行)准备好生产的应用。

4.  它支持为 spring 应用创建胖 Jar，其中包含所有的依赖项，因此您可以直接运行它。

5.  微服务架构可以通过 spring-boot 框架有效地构建，它还为依赖关系管理提供了 **spring-boot-starter 等概念。**

## 类路径依赖关系:

建立一个项目需要大量的外部库(核心 Java 和其他相关框架)。如前所述，spring-boot 支持自动配置，这取决于类路径中可用的 jar。我们将在开始设置项目时查看自动配置。

**spring-boot-starter** 有助于有效地管理所有依赖关系，不像 spring-MVC 那样没有 starter 的概念。

## 什么是 SpringBoot 装置？

Starters 为基于 spring 的项目提供了有效的依赖管理。例如，如果我们想使用 hibernate 作为 ORM 工具，我们需要 hibernate maven 脚本(要包含在项目的 [pom.xml 文件中)，如下所示。](https://www.studytonight.com/maven/pom-in-maven)

```java
<dependency>
    <groupId>org.hibernate</groupId>
    <artifactId>hibernate-core</artifactId>
    <version>5.4.2.Final</version>
</dependency>
```

Spring-boot 提供了诸如**spring-boot-starter-data-JPA**这样的启动器，当包含在 maven 项目中时，它提供了上面提到的 **hibernate 依赖关系**以及 **spring-data-jpa 依赖关系**。

简而言之，**启动器是多个依赖项**的组合，通过在您的 *pom.xml* (适用于 maven 项目)或 *ivy.xml* (适用于 IVY/ANT 项目)或 *build.gradle* 文件(适用于 gradle 项目)中指定它们的名称，可以轻松解决并减少手动包含每个依赖项的任务。一些例子是:

```java
<dependency>
    <groupId>org.springframework.boot</groupId>
    <artifactId>spring-boot-starter-data-jpa</artifactId>
</dependency>

<dependency>
    <groupId>org.springframework.boot</groupId>
    <artifactId>spring-boot-starter-hateoas</artifactId>
</dependency>
```

请注意，与上面的代码不同，上面的启动脚本没有提到版本，因为版本是从**spring-boot-starter-parent**导入的，这将在后面进一步讨论。

## 什么是应用属性？

这个文件帮助我们使用简单的属性来管理应用的配置。根据所提供的配置，spring-boot 会自动配置一些 beans(由 spring 直接管理并在应用启动时初始化的对象)。

它还有助于启用用户提供的其他配置。比如嵌入式 tomcat 的**默认端口为 8080** ，可以通过**应用.属性文件**中提到的 **server.port** 属性进行更改。下面的属性在端口 9000 上运行 tomcat。

```java
server.port=9000
```

以上属性文件可以替换为 **yml 文件(application.yml)** 。Spring-boot 使我们能够为不同的环境维护多个属性文件。我们可以在应用启动时选择所需的配置。当我们开始开发应用时，我们将详细讨论这个主题。

**结论:**在本教程中，我们了解了 spring-boot，并看到了它的重要性以及它为更容易开发提供的优势。

* * *

* * *