# 在 tomcat servlet 容器上运行 SpringBoot 应用

> 原文：<https://www.studytonight.com/spring-boot/running-springboot-application-on-tomcat-servlet-container>

在本教程中，我们将在 tomcat servlet 容器上部署 SpringBoot 应用。

## 部署程序

我们需要在 **pom.xml** 文件中添加一个属性，将项目打包为 **WAR** 。生成的 WAR 将部署在 tomcat 中。

![](img/335893a0bb5c94484656ebc006107aa0.png)

观察上面 pom.xml 文件中`<packaging>war</packaging>`的属性，该属性允许我们在目标文件夹下生成 WAR 文件。Application.java 需要扩展类`SpringBootServletInitializer`
右键点击项目，点击**运行为**，然后 **Maven 安装**即可在 WAR 中获取项目构建。

![](img/85f209826ecac8d0a369262e2f797711.png)

在上面的图中我们可以看到，WAR 生成了并将部署在 tomcat 安装的 webapps 文件夹下。如前所述，Spring 应用 beans 通常由 `ApplicationContext`管理，但是为了在 Tomcat 中部署 spring 应用时初始化 `ServletContext` ，需要扩展`SpringBootServletInitializer.`

```java
@SpringBootApplication
public class Application extends SpringBootServletInitializer{

        //main method body

}
```

如果机器上没有安装 tomcat，从`https://tomcat.apache.org/download-80.cgi`下载。解压缩 zip 文件夹后，安装目录将如下所示

![](img/f980432083b09df0a38c949f4f58520e.png)

将 WAR(在目标文件夹中生成)放置在 web 应用中(注意上面的图 7.3)。现在导航到 bin 文件夹并打开 cmd。为了启动 Tomcat，必须确保环境变量设置正确，我们在前面的教程中讨论过这一点。

![](img/50e1f62a31cc0a5244991d61a68d21df.png)

环境变量是根据 JAVA 的安装路径设置的。在 Tomcat 安装的 web 应用目录中部署 WAR 文件。运行以下命令启动服务器。Tomcat 将在单独提示后启动，如图 7.6 所示。

![](img/6a1dfd0a495fc523457b59cb1ab1f20b.png)
![](img/ef882180ff3e3441102d42174785a101.png)
我们可以使用 postman 如下测试部署在 tomcat 上的应用。
![](img/a73f20478249766ab22d87251c871c62.png)

在上图中，请注意在 tomcat 中部署了具有 WAR 名称的 URL，并且返回的状态是 200 OK。这是 tomcat 中 WAR 部署的整个过程。到目前为止，我们一直在使用嵌入式 tomcat 从 IDE 启动应用。让我们再次回顾一下集成开发环境中的应用启动，因为它与这个主题相关。

右键单击**项目** - > **运行方式** - > **Java 应用**

![](img/389908cd2a6c97ff0b2be79aa019a3a2.png)

上图显示了应用控制台，并且是从 IDE 启动的。

**结论:**在本教程中，我们讨论了将 spring-boot 应用 WAR 部署到 servlet 容器，以及从 IDE 启动。

* * *

* * *