# 操作系统中的虚拟内存

> 原文：<https://www.studytonight.com/operating-system/virtual-memory-in-operating-systems>

在本教程中，我们将介绍操作系统中虚拟内存的概念。

虚拟内存是一个空间，大型程序可以在执行时以页面的形式存储自己，并且只有所需的页面或进程部分被加载到主内存中。这种技术非常有用，因为当用户程序只有很小的物理内存时，它会提供很大的虚拟内存。因此，虚拟内存是一种允许完全不在物理内存中的进程执行的技术。

虚拟内存主要是在按需分页的帮助下，给人一种物理内存比实际内存多的错觉。

在实际场景中，大多数进程从来不需要同时拥有所有页面，原因如下:

*   除非出现特定的错误，否则不需要错误处理代码，有些错误非常罕见。

*   在最坏的情况下，数组的规模往往过大，实际上只有一小部分数组被使用。

*   某些程序的某些功能很少使用。

在操作系统中，内存通常以称为**页**的单元形式存储。基本上，这些是用于存储大型程序的原子单元。

虚拟内存可以通过以下方式实现

1.  请求页面调度

2.  需求分段

## 虚拟内存的需求

以下是需要虚拟内存的原因:

*   在这种情况下，如果运行 Windows 操作系统的计算机需要比系统中安装的内存更多的内存或内存，那么它会为此使用一小部分硬盘。

*   假设有一种情况，当您的计算机在物理内存中没有空间时，它会将需要记住的内容写入硬盘的交换文件中，并将其作为虚拟内存。

## 拥有虚拟内存的好处

1.  可以编写大型程序，因为与物理内存相比，可用的虚拟空间非常大。

2.  所需的输入/输出越少，进程交换就越快越容易。

3.  更多的物理内存可用，因为程序存储在虚拟内存中，所以它们在实际物理内存中占据的空间非常小。

4.  因此，逻辑地址空间可以比物理地址空间大得多。

5.  虚拟内存允许多个进程共享地址空间。

6.  在创建过程中，虚拟内存允许:**写时复制**和**内存映射文件**

## 程序在虚拟内存中的执行

在操作系统的帮助下，程序的一些部分被带入主存储器:

*   进入主存储器的进程的一部分称为驻留集。

每当需要一个不在主存储器中的地址时，它就会产生一个中断。操作系统将进程置于阻止状态。包含逻辑地址的进程片段被带入主存储器。

## 请求页面调度

需求分页背后的基本思想是，当一个进程被换入时，它的页面不会同时被换入。相反，只有当进程需要它们时，它们才会被交换进来(按需)。最初，只加载进程立即需要的那些页面。

未移入内存的页面在页面表中标记为无效。对于无效条目，表的其余部分为空。对于加载到内存中的页面，它们会被标记为有效，同时还会显示在哪里可以找到换出的页面。

## 页面替换

正如在需求分页中所研究的，只有进程的某些页面最初被加载到内存中。这允许我们同时将更多的进程放入内存。但是，当一个进程请求更多的页面，而没有可用的空闲内存来容纳它们时，会发生什么呢？可以采取以下步骤来解决这个问题:

1.  将进程放入等待队列，直到任何其他进程完成其执行，从而释放帧。

2.  或者，从内存中完全移除一些其他进程来释放帧。

3.  或者，找到一些目前没有使用的页面，将它们移动到磁盘上以获取空闲帧。这种技术被称为**页面替换**，是最常用的。我们有一些很好的算法来有效地进行页面替换。

## 痛打

花在分页上的时间比执行时间多的进程被称为抖动。换句话说，这意味着进程没有足够的框架来保存所有的页面以供执行，所以它频繁地交换页面以保持执行。有时，不久的将来需要的页面必须被换出。

最初，当 CPU 利用率低时，进程调度机制为了提高多道程序设计的水平，会同时将多个进程加载到内存中，为每个进程分配有限数量的帧。当内存填满时，进程开始花费大量时间换入所需的页面，这再次导致 CPU 利用率低，因为大多数进程都在等待页面。因此，调度程序会加载更多的进程来提高 CPU 利用率，因为这种情况会持续到整个系统停止的时间点。

## 虚拟内存的优势

下面给出了使用虚拟内存的优势:

*   虚拟内存允许您一次运行更多的应用程序。

*   在虚拟内存的帮助下，您可以轻松地将许多大型程序装入较小的程序中。

*   借助虚拟内存，可以轻松实现多道程序环境。

*   因为应该在主存储器中维护更多的进程，这导致了 CPU 的有效利用。

*   数据应该在需要时从磁盘中读取。

*   公共数据可以在内存之间轻松共享。

*   在虚拟内存的帮助下，当程序的执行只需要程序的一个特定段时，速度就提高了。

*   该进程甚至可能变得比所有物理内存都大。

## 虚拟内存的缺点

下面给出了使用虚拟内存的缺点:

*   虚拟内存降低了系统的稳定性。

*   虚拟内存的性能不如内存。

*   如果系统使用虚拟内存，则应用程序可能运行较慢。

*   虚拟内存会对系统的整体性能产生负面影响。

*   虚拟内存占用了存储空间，否则可能会用于长期数据存储。

*   为了在应用程序之间切换，内存需要更多的时间。



* * *

* * *