# HTML `<a>`标签

> 原文：<https://www.studytonight.com/html5-references/html-a-tag>

HTML `<a>`标签是一个**锚点**，用来**创建一个超链接**。超链接用于将当前网页与其他网页或互联网上可用的任何其他网络资源互连。它使用`href`属性来指定网络资源的**网址。**

网络资源可以是通过网络呈现的网页、文件、图像、视频等。

默认情况下，`<a>`标签在浏览器中显示如下:

*   如果链接未显示，它会带有下划线和蓝色。

*   如果链接被访问，它会被加上下划线和紫色。

*   如果链接是活动的，它会带有下划线和红色。

## HTML `<a>`标签-语法和用法

`<a>`标签需要**开始(开始)标签和结束(结束)标签**。

另外，这是一个**内联元素**。以下是在 HTML 代码中使用锚标记的语法:

```html
<a href="SOME-URL">
    <!-- Some content -->
</a>
```

虽然`href`属性不是强制性的，但是没有它，HTML `<a>`标签是没有意义的，因此我们将它作为基本语法的一部分。

### HTML 

下面我们有一个展示如何使用 HTML 锚标签的基本例子，提供了`href`属性和`target`属性。

## HTML `<a>`标签属性

HTML `<a>`标签支持 [**全局**属性](https://www.studytonight.com/html5-references/html-global-attributes) 和 [**事件**属性](https://www.studytonight.com/html5-references/html-event-attributes)以及一些常见属性如下:

| **属性** | **描述** |
| `target` | 该属性用于指定链接网址的显示位置-在**新浏览器选项卡**中，在**新浏览器窗口**中，等等。可以使用该属性进行控制。 |
| `href` | 此属性用于指定当单击超链接时用户应该重定向到的 web 资源/文档的 URL。 |
| `rel` | 该属性用于指定目标文档与链接文档的**关系。例如，如果目标文档有关于作者的详细信息，我们可以指定**作者**，或者如果目标文档是包含有用信息的网页，我们可以指定**帮助**。**因此，我们可以用它来指定用户应该期望从目标文档中得到什么。这是用来**只是给超链接添加更多的信息**，对浏览器上的超链接视图没有**效果。** |
| `type` | 该属性用于指定链接网址的**媒体类型**。 |
| `hreflang` | 用于表示链接资源的人类**语言**。 |
| `id` | 该属性用于**在文档中创建片段标识符**。 |

### 1.HTML 

`href`属性中的术语 **href** 代表**超文本引用**。`href`属性用于设置目标资源的**网址。**

HTML `<a>`元素使用`href`属性来指定当用户单击超链接时要打开的目标源或文档。

在上面介绍 HTML `<a>`标签基本用法的例子中，我们使用了`href`属性。

```html
<p>Click on <a href="https://www.studytonight.com/"> this link </a> to go to the home page of Studytonight</p>
```

### 2.HTML 

`<a>`元素使用`target`属性来指定一个窗口，当单击超链接时，您希望在该窗口中打开 HTML 文档。

例如，您可以使用`target`属性在同一个窗口或另一个窗口中打开文档**。**

下表给出了`target`属性的五个值:

| **值** | **描述** |
| `_blank` | 在**新的未命名浏览器选项卡**中打开链接文档。 |
| `_self` | 在**当前浏览器选项卡**中打开链接的文档，(`_self`为默认值) |
| `_parent` | 它在父窗口中打开链接的文档 |
| `_top` | 在最顶端的窗口中打开链接的文档 |
| `framename` | 它以给定的框架名称打开链接的文档，这意味着在一个 [iframe](https://www.studytonight.com/html-5-references/html5-iframe-tag) 内。 |

让我们看看`<a>`标签和`target`属性的一些用法示例。

### 3.HTML 

该属性被`<a>`标签用来在文档中创建一个**片段标识符。**

一个**片段标识符指定了一个文档**中的一个特定位置 **，比如一个标题或者网页的任何特定部分。您可以使用`id`属性导航到网页内的不同位置。**

`id`属性以字符串为值，该值在同一文档中必须是唯一的，但是可以在不同的文档中重用。

例如，

```html
<h1 id="top">Page Title</h1> <!-- first define the location within the document -->

<!-- If you have this hyperlink at bottom of a webpage, when clicked it will take you to the h1 tag. -->
<a href="#top">Scroll to Top</a> 
```

<u>**注意:**</u> 哈希(`#`)符号表示该值是一个片段标识符。因此，它的结论是，如果在另一个网页的网址后面添加了`#`符号，则跟随`#`(散列符号)以及定义的位置(片段标识符)的网址用于重定向到同一网页内或不同网页上的特定命名超链接，在这种情况下，我们将被重定向到新网页，并且浏览器将自动滚动到与片段标识符的值匹配的网页的指定部分。

让我们举一个代码例子，

### 4.HTML 

HTML `<a>`标签中的`hreflang`属性用于指定点击超链接时用户将被带到的目标 HTML 文档的语言。

```html
<html>
<body>

  <h1>The a hreflang attribute</h1>

  <p><a hreflang="en" href="https://www.studytonight.com/">StudyTonight.com</a></p>

</body>
</html> 
```

## HTML `<a>`标签的默认 CSS 样式

下面给出了大多数浏览器对 HTML `<a>`标签使用的默认 CSS 设置:

```html
a:link, a:visited {
  color: (internal value);
  text-decoration: underline;
  cursor: auto;
}

a:link:active, a:visited:active {
  color: (internal value);
}
```

## 对 HTML `<a>`标签的浏览器支持

以下浏览器支持此属性:

*   Firefox 1+

*   谷歌 Chrome 1+

*   Internet Explorer 2+

*   Apple Safari 1+

*   Opera 4+

* * *

* * *