# HTML `<canvas>`标签

> 原文：<https://www.studytonight.com/html5-references/html-canvas-tag>

HTML5 **中引入了 HTML `<canvas>`标签，使用 JavaScript 在网页[上显示 2D 形状和图形](https://www.studytonight.com/javascript)**。该标签允许您在网页上创建**图形**、**游戏**、**图像**和**其他视觉效果**。

默认情况下，HTML 中的

<canvas>标签的**宽度为**300 像素**，高度为**150 像素**，没有任何边框或内容。我们可以使用 JavaScript 在 HTML 画布中填充一些图形、绘图或图像等视觉效果。**</canvas>

`<canvas>`标签可用于在图像上应用**各种变换，如旋转和模糊**。

在开始和结束`<canvas>`标签之间定义的**内容仅在浏览器不支持`<canvas>`标签时显示**。****

**最大**尺寸的`<canvas>`标签是**非常大**，但它的确切尺寸只取决于浏览器。

还有，这是一个**块级元素**。

## HTML `<canvas>`标签-语法和用法

`<canvas>`元素需要**开始(开始)标签**和**结束(结束)标签。**

```html
<canvas>
    ...
</canvas>
```

## HTML `<canvas>`标签属性

`<canvas>`标签支持[全局属性](https://www.studytonight.com/html5-references/html-global-attributes)和[事件属性](https://www.studytonight.com/html5-references/html-event-attributes)。下面给出了与该标签一起使用的一些常见属性:

| **属性** | **描述** |
| `height` | 该属性用于以像素为单位指定画布的高度。 |
| `width` | 该属性用于以像素为单位指定画布的宽度。 |
| `moz-opaque` | 该属性用于管理画布的半透明性 |
| `id` | `id`属性用于指定元素的唯一名称。画布元素的`id`属性用于获取 Javascript 中画布的引用，为其添加图形。 |
| `style` | `style`属性用于指定 CSS 样式代码。 |

## HTML `<canvas>`标签基本示例

在本节中，我们将介绍一些`<canvas>`标签的例子，以帮助您理解我们如何使用它。

### 1.简单`<canvas>`标签

在下面的 HTML 代码中，我们刚刚在我们的 HTML 中使用了一个

<canvas>标签，这将对网页没有视觉效果，除了`<canvas>`标签将占用的额外空间。</canvas>

```html
<!DOCTYPE html>
    <head>
        <title>Simple Canvas</title>
    </head>
    <body>
        <canvas id="myCanvas"></canvas>
    </body>
</html> 
```

默认宽度为**300 像素**，高度为**150 像素**。

我们可以使用`style`属性为这个标签添加样式，就像添加一个边框来知道画布的边界一样。请参见下面的代码示例:

```html
<!DOCTYPE html>
    <head>
        <title>Simple Canvas</title>
    </head>
    <body>
        <canvas id="myCanvas" style="border: solid 1px #000;"></canvas>
    </body>
</html> 
```

如果你运行上面的代码，你会看到一个矩形，有一个**黑色边框**，默认宽度为**300 像素**，高度为**150 像素**。

### 2.带有图形的`<canvas>`标签(使用 JavaScript)

在本例中，我们将在画布内填充**创建一个矩形**，并使用`fillstyle`属性和`fill()`方法为其提供背景色，使用`lineWidth`和`strokeStyle`属性和`stroke()`方法添加边框。

在 JavaScript 中，我们可以使用`id`属性访问`<canvas>`标签，并向其中添加图形，我们使用`canvas.getContext("2d")`方法来控制画布上下文。getContext()方法可以取 **2d** 、 **webgl** 、 **webgl2** 等值。

### 3.带文本的`<canvas>`标签(使用 JavaScript)

在本例中，我们将学习如何在画布元素上绘制文本。

## 

在上面的例子中，我们使用`fillText()`方法来提供文本，使用`font`属性来为文本添加一些样式。

## HTML `<canvas>`标签的默认 CSS 样式

默认情况下，以下 CSS 样式应用于`<canvas>`标签。

```html
canvas {
  height: 150px;
  width: 300px;
}
```

## 对 HTML `<canvas>`标签的浏览器支持

以下浏览器支持此属性:

*   Firefox 2+

*   谷歌 Chrome 4+

*   Internet Explorer 9+

*   Apple Safari 3.1+

*   Opera 9+

* * *

* * *