# HTML `<form>`标签

> 原文：<https://www.studytonight.com/html5-references/html-form-tag>

表单由多种不同类型的元素组成，用于接受用户输入，例如文本输入、复选框、文本区域(用于长文本)等。如果我们想在网页中创建一个表单，我们必须使用 HTML `<form>`标签。

*   在表单中，纯文本和 **HTML 元素**用于构建表单。

*   表单内部使用了各种不同的 HTML 元素，如输入文本、复选框、单选按钮，通过允许任何**用户输入信息**，使表单具有交互性。

*   开始和结束`<form>`标签指示浏览器关于表单的开始和结束点。

*   此外，这是一个**块级元素**。

## HTML `<form>`标签-语法和用法

`<form>`标签需要**开始(开启)标签**和**结束(关闭)标签**。

下面我们有相同的基本语法:

```html
<form>
    ...content
</form>
```

## HTML `<form>`标签属性

`<form>`标签支持[全局属性](https://www.studytonight.com/html5-references/html-global-attributes)和[事件属性](https://www.studytonight.com/html5-references/html-event-attributes)。下面给出了一些常见属性:

| **属性** | **描述** |
| `autocomplete` | 此属性用于启用表单中的自动完成功能。 |
| `novalidate` | 此属性指定提交时不应验证表单。 |
| `name` | 该属性用于引用表单的名称 |
| `action` | 它指的是服务器中用于处理表单的程序的 URL(统一资源定位符)。 |
| `enctype` | 它用于指定信息在发送到服务器之前应该如何在表单中编码。 |
| `method` | 此属性用于指定信息如何从浏览器发送到服务器。 |
| `target` | 该属性用于指定提交表单后显示结果的目的地。 |

## HTML `<form>`标签基本示例

下面我们有一个`<form>`标签的基本例子:

```html
<!doctype html>
<html>
    <head>
        <title>
            Example of Form tag
        </title>
    </head>
    <body>
        <p>Starting of Form</p>
        <form>
            This is our First Form
        </form>
        <p>Ending of Form</p>
    </body>
</html>
```

形态的开始
这是我们的第一形态
形态的结束

在上面的代码中，我们简单地使用了开始和结束`<form>`标签，并且添加了纯文本。这只是为了说明 HTML `<form>`标签也可以和简单的纯文本一起使用。但这不是它的目的。因此，让我们在表单中添加一些表单元素，以便为用户输入做好准备。

### 使用`action`和`method`属性:

在 HTML `<form>`标签中，`action`和`method`是两个最重要、最常用的属性。

```html
<form action="somefile.php" method="GET">
    <label for="name">Name:</label>
    <input id="name" type="text" name="name"/>
    <input type="submit" value="Submit">
</form>
```

在上面的代码示例中，您可以看到我们添加了`action`属性，其值为文件名。该文件将根据您的选择接收**获取**或**发布**请求中的表单值。根据您用来处理表单值的后端编程语言，您可以接收 **GET** 和 **POST** 值，然后对这些值执行任何操作，可能会将它们保存在数据库中或更新数据库中的一些现有值。

如果将`action`属性留空，则表单值将被提交到当前页面(在该页面上有表单)，因此`action`属性的**空值**被解释为 **SELF URL** 。

## HTML `<form>`示例:

让我们制作另一个表单，表单中有几个字段接受用户输入。

## 带有字段集、图例和标签的 HTML 表单:

在本例中，我们将向表单中添加一些元素。您可以学习更多关于使用这些标签的知识: [HTML `<fieldset>`标签](https://www.studytonight.com/html5-references/html-fieldset-tag)、 [HTML 图例标签](https://www.studytonight.com/html5-references/html-legend-tag)和 [HTML `<label>`标签](https://www.studytonight.com/html5-references/html-label-tag)。

```html
<form action="" method="POST">
    <fieldset>
        <legend>Gender</legend>
        <input type="radio" name="gender" value="male"> Male
        <input type="radio" name="gender" value="male"> Female
        <input type="radio" name="gender" value="male"> Others
    </fieldset>
</form>
```

## 对 HTML `<form>`标签的浏览器支持

以下浏览器支持此属性:

*   Firefox 1+

*   谷歌 Chrome 1+

*   Internet Explorer 2+

*   Apple Safari 1+

*   Opera 4+

* * *

* * *