# HTML `<input>`标签

> 原文：<https://www.studytonight.com/html5-references/html-input-tag>

在 HTML 中，`<input>`标签用于创建不同类型的输入字段，当我们必须在网页上接受用户输入时，这些字段以 HTML 形式使用。

在网页上创建表单的主要目的是获取用户输入的详细信息，为了帮助用户，我们可以使用多种不同的格式进行用户输入，如文本框、单选按钮、复选框、下拉列表等。

这些不同类型的 HTML 形式的输入字段可以使用`<input>`标签来创建。

对于使用不同类型的输入字段，需要设置`<input>`标签的`type`属性。

## 超文本标记语言输入类型:

`type`属性用于在 HTML 表单中创建不同类型的输入字段。HTML5 中新引入了一些类型的输入标签。我们在下面介绍了其中的大部分内容:

1.  `hidden`:可以使用输入元素并将其类型设置为“隐藏”来创建隐藏字段。隐藏字段可用于将信息从一个表单传递到另一个表单，而无需强制用户重新输入信息，浏览器也不会显示该信息。

2.  `tel`:输入控件的`tel`类型用于以表格的形式输入**电话号码**。默认情况下，这种类型的输入字段只接受数字作为输入，而不接受字母。

3.  `URL`:输入控件的`URL`类型用于输入网页的**有效路径。任何有效的网址都应该有:**协议、域名和路径名**。无论何时提交表单，都会自动验证网址的值。**

4.  `datetime-local`:用于以网页形式从用户处获取日期和时间的输入。用户可以根据您的时区选择日期和时间。

5.  `number`和`range`:输入控件的`number`类型只允许用户输入数字。如果任何用户试图输入任何字母，那么它不会接受，并且还会给用户一条只输入数字的信息。当我们希望用户输入指定范围内的值时，使用`range` 类型的输入控件。

6.  `file`:`file`类型的输入允许您选择存储在本地计算机中的文件，并在提交表单时将其发送到服务器。`size`、`maxlength`和`accept`是该输入类型使用的少数属性。

7.  `checkbox`:复选框用于选择或取消选择表单上显示的一个或多个项目。可以通过将输入类型设置为`checkbox`来创建复选框。

8.  `radio`:一种`radio`类型用于为多个选项创建单选按钮，允许用户一次选择任意一个项目。单选按钮被称为包含多个项目的列表，用户必须从中选择一个项目。

9.  `submit`:只要用户点击提交按钮，表单所有字段中输入的信息就会被发送到`<form>`标签的`action`属性中指定的网址。

10.  `reset`:当任何用户点击重置按钮时，所有字段的信息都会被清除并设置为默认值或空白值。可以通过将`type`属性设置为“**重置**来创建。

11.  `datetime`、`date`、`month`、`week`、`time`:以日期时间、日期、月份、星期和时间的形式进行输入，可以分别使用这些带有`type`属性的值。

12.  `email`:此类型用于从最终用户处输入有效的电子邮件地址，该地址应包含一个 **@符号**和一个(**)。**)圆点。电子邮件的价值会在提交表单时自动验证。使用电子邮件的`multiple`属性，可以在一个字段中输入多个电子邮件地址。

13.  `password`:这个表单控件是用来保护用户不想与他人分享的秘密信息的。它类似于文本框，但输入的文本不是可读形式，因为星号符号或点以字符形式显示。

14.  `text`:这是最简单的输入字段形式，在其中使用可以输入纯文本。

## HTML `<input>`标签-语法和用法

`<input>`元素是一个空标签。

此外，这是一个**内联元素**。其基本语法如下:

```html
<input type=""/>
```

这里`type`属性可以具有上面列表中指定的任何值。除了类型属性之外，还有许多其他属性，我们将在下一节中列出。

## HTML `<input>`标签属性

HTML `<input>`标签支持[全局属性](https://www.studytonight.com/html5-references/html-global-attributes)和[事件属性](https://www.studytonight.com/html5-references/html-event-attributes)，一些常见属性如下:

| **属性** | **描述** |
| `size` | 该属性用于定义输入字段中可见文本的宽度。更简单地说，该属性将根据输入字段中预期的文本长度来设置输入字段的宽度。例如，如果我们将`size`属性设置为 **4** ，那么输入字段的宽度将被设置为只能容纳 4 个字符。 |
| `readonly` | 该属性用于指示特定字段是只读的。 |
| `type` | 该属性用于指示要显示的`<input>`字段的类型，我们已经介绍过了。 |
| `value` | 该属性用于指示`<input>`元素的值。使用这个，我们也可以设置一个默认值。 |
| `name` | 该属性用于指定`<input>`元素的名称。 |
| `maxlength` | 该属性指定在`<input>`元素中可以输入的最大字符数。 |
| `src` | 此属性用于为“提交”按钮指定图像。`src`属性仅用于图像。 |
| `alt` | `alt`属性用于为图像提供替代文本，在网络浏览器无法渲染图像的情况下很有帮助。 |
| `autocomplete` | `autocomplete`属性用于指定输入元素是否应该启用自动完成，其中，当用户在输入字段中输入任何内容时，浏览器将显示建议。 |
| `placeholder` | `placeholder`属性用于在输入`type` **文本**字段中提供占位符文本。 |

## HTML `<input>`标签基本示例

在这个例子中，有三个输入字段，即用户名、密码和文件输入。

在上面的例子中，我们在输入字段中使用了三种不同的类型，以及三个属性，即`autocomplete`、`maxlength`和`size`。我们建议您使用更多类型的输入字段和属性，看看它们如何影响输入字段。

### 使用复选框输入字段:

现在我们将创建一个带有多个选项的简单表单，供用户以复选框的形式选择。

在上面的例子中，我们已经创建了多个复选框以及一个文本字段和一个提交按钮。

## 对 HTML `<input>`标签的浏览器支持

以下浏览器支持此属性:

*   Firefox 1+

*   谷歌 Chrome 1+

*   Internet Explorer 2+

*   Apple Safari 1+

*   Opera 2.1+

* * *

* * *