# HTML 全局属性

> 原文：<https://www.studytonight.com/html5-references/html-global-attributes>

HTML **全局属性**是所有 HTML 标签/元素共有的属性。

任何 HTML 标签的**属性只是它的一部分，可以用来给任何 HTML 标签添加更多的信息，例如，在[`<a>`标签](https://www.studytonight.com/html5-references/html-a-anchor-tag)中，`href` 是用来提供文本将被超链接到的网址的属性。同样，HTML 标签可以有**全局属性**提供**附加标识**，像 **CSS 样式类**这样的信息，或者一些标准属性**隐藏**(隐藏 HTML 元素)**语言**等。**

![HTML global attributes example](img/36613ffdf4d20b5ebe3f52108c7b5e40.png)

任何 HTML 标记都可以有多个属性。

*   **全局属性**可以和所有标签一起使用；尽管在一些 HTML 标签上，它们没有任何效果。

*   在这些属性不相关的地方也有一些例外，一些不支持全局属性的例外标签有 [`<base>`标签](https://www.studytonight.com/html5-references/html-base-tag)、 [`<script>`标签](https://www.studytonight.com/html5-references/html-script-tag)、 [`<title>`标签](https://www.studytonight.com/html5-references/html-title-tag)等。

*   **全局属性**甚至可以与**未指定**为 **HTML 标准标签**的标签一起使用；即**非标准**标签也允许**全局属性**。在文档中使用这些非标准元素表示文档不再符合**html 5**。

下面是一个在非标准标签中使用全局属性`hidden`的例子。

```html
<foo hidden>....</foo>
```

这个`<foo>`不是 **HTML5 标准标签**，仍然支持`hidden`属性。

## HTML 全局属性

有许多全局属性，下面列出了它们的描述:

### 1\. 访问密钥

该属性用于提供一个访问键，它是一个键盘键，用作聚焦任何 HTML 元素的**快捷键**。

该属性由一系列以空格分隔的**字符组成。**

例如:

```html
<a href="https://www.studytonight.com/code/" accesskey="h">HTML Interactive Course</a>
<a href="https://www.studytonight.com/cascading-style-sheet/" accesskey="c">CSS Tutorial</a>
```

现在对于不同的浏览器，有不同的使用 accesskey 属性的方式，例如在 **Chrome、Safari 等中我们可以使用 ALT + accesskey** 来关注 HTML 元素，在 **Firefox 中我们可以使用 ALT + SHIFT + accesskey** 。

对于上面的 HTML 代码，如果您按下 **ALT + h** ，第一个超链接文本 **HTML 互动课程也会被聚焦并点击**。

### 2.自动沉淀

该属性与`input` HTML 标签一起使用，以控制用户输入或编辑的文本是否自动大写以及如何大写，或者应该对输入文本应用何种形式的大写。

它还具有一些**预定义值**，可用于设置其行为，如下所示:

*   **关或无:**表示不大写。

*   **字符:**表示所有字符默认为大写。

*   **单词:**表示每个单词的首字母默认为大写，其他全部为小写。

*   **on 或句子:**表示一个句子的第一个字母默认为大写，其余全部为小写。

太多浏览器尚不支持此属性。

让我们举个例子:

```html
<input type="text" autocapitalize="word" id="mytext"/>
```

### 3.班级

它表示元素类的**空格分隔的**列表。这是最广泛使用的全局属性之一，用于指定使用 CSS 样式类的类选择器，并使用类属性处理 JavaScript 事件。

这里有一个在 HTML 标签中使用`class`属性的例子:

```html
<div class="somestyle">This is a div element.</div>
<p class="pstyle">This is a paragraph.</p>
```

### 4.内容可编辑

这用于指示内容是否应该是用户可编辑的**，即使 HTML 元素不是输入类型。如果是，那么浏览器会修改它的小部件，并允许编辑 HTML 元素。**

 **它有两个值:`True`和`false`

**true:** 表示内容可编辑

**false:** 表示内容不可编辑

例如:

```html
<p contenteditable="true">This is a paragraph.</p>
```

### 5.数据还是数据-*

该属性用于创建一个名为**自定义数据属性**的自定义属性，可以用来指定 HTML 标签中任何有用的数据。

让我们举个例子来理解它:

```html
<p>Choose Vehicle:</p>
<select>
    <option data-vehicle-type="hatchback" value="Polo">VW Polo</option>
    <option data-vehicle-type="motorcycle" value="R15">Yamaha R15</option>
    <option data-vehicle-type="SUV" value="Polo">Hyundai Creta</option>
</select>
```

就像我们使用`data-vehicle-type`属性定义车辆类型一样，类似地，youc an 也创建任何自定义`<data>`标签，以**前缀数据-** 开始，因此它也被称为**数据-*** 属性。

### 6.目录

该属性用于指示 HTML 元素中文本的方向，如`div`、`span`、`p`等。

它也有一些值，如下所示:

1.  **ltr: ltr** 代表从左到右的**，该属性用于表示像**英语那样从左到右书写的语言。****

***   **rtl: rtl** 代表从右到左的**，这个属性用来表示像**阿拉伯语那样从右到左书写的语言。****

    ***   **auto:** 哪个让用户代理(浏览器)决定。它使用一种基本算法，解析元素中的字符，直到找到一个具有强方向性的字符，然后将该方向性应用于整个元素。**** 

 ****让我们举个例子:

```html
<p dir="rtl">This text will appear right to left on browser.</p>
```

### 7.可拖动的

此属性用于指示是否可以拖动元素。

它可以采用以下值:

1.  **true:** 表示元素可能被拖动。

2.  **false:** 表示元素不能拖动。

### 8\. dropzone

它用于指示在拖动后放下可拖动元素时要执行的操作。

该属性的允许值如下所示:

1.  **复制**:该值表示拖放将创建被拖动元素的副本。

2.  **移动**:该值表示被拖动的元素将被移动到这个新位置。

3.  **链接**:该值将创建到被拖动元素的链接。

### 9.隐藏的

`hidden`属性用于指示特定元素不应显示在浏览器中。这个属性可以用来隐藏任何 HTML 元素，这些元素对应用程序有一些有用的价值，但是不应该像表单的 CSRF 令牌那样显示给用户。

### 10.编号

`id`属性用于定义唯一标识符，该标识符对于整个 HTML 文档必须是唯一的。

主要目的是在链接、脚本或样式化过程中识别元素。这是最广泛使用的全局属性之一，就像`class`全局属性一样。

### 11 .输入模式

该属性用于为虚拟键盘配置的类型提供提示，虚拟键盘配置用于编辑元素的内容。

主要用于`<input>`标签，当标签处于`contenteditable`模式时使用。

### 12.存在

该属性用于指定标准元素应该如何像在 Javascript 中定义的注册自定义内置元素一样工作。

### 13.itemid

此属性用作项目的唯一全局标识符。

### 14 .项目属性

使用`itemprop`属性将**属性**添加到元素中。几乎每个 HTML 元素都指定了`itemprop`属性；其中`itemprop`存在于**名称-值对中。**

它用于构造 HTML 文档信息，并随内容指定附加元信息。

例如，

```html
<div itemscope itemtype="http://schema.org/Student">
    <h1 itemprop="name">John Wick</h1>
    <span>Class:
        <span itemprop="section">Comp. Sci.</span>
    </span>
    <span itemprop="sex">Male</span>
    <span itemprop="rollno">CS-547-2K7</span>
</div>
```

### 15.itemref

该属性用于在文档的其他地方提供带有一些附加属性的元素 id 列表(不是`itemid`)，例如在一些其他的 HTML 元素中引用一些元素。

### 16.项目范围

该属性与`itemtype`属性一起工作，以指定块中包含的 HTML 是关于特定项目的。该`itemscope`属性创建项目，并定义与之关联的`itemtype`的范围；其中`itemtype`是描述带有属性上下文的项目的有效 URL 的形式。

### 17.itemtype(项目类型)

此属性用于指定词汇的 URL，该词汇将用于定义数据结构中的项属性。因此`itemscope`用于设置数据结构的范围，其中`itemtype`设置的词汇将被激活。

### 18.语言

该属性用于定义可编辑和不可编辑的 HTML 元素的语言。为任何 HTML 元素定义语言时，该值由两个组件组成，第一个组件用于定义语言，第二个组件用于定义子语言，例如 en-GB 用于英国英语，en-US 用于美国英语。

这里有一个例子，

```html
<p lang="en-GB">This is British English.</p>
```

### 19.狭槽

此属性用于将阴影树中的槽分配给元素。通过创建名称属性值与插槽属性值匹配的`<slot>`元素，将具有`slot`属性的元素分配给插槽。

### 20.拼写检查

这用于定义可以检查元素的拼写错误。

其值如下:

1.  **true:** 用于表示元素要检查拼写错误。

2.  **false:** 用于表示不应对元素进行拼写错误检查。

### 21.风格

该属性包含隐式 CSS 样式代码，用于声明任何元素的样式规则。

虽然建议在单独的 CSS 文件中定义样式属性，但是我们可以使用`style`属性在 HTML 元素中指定样式规则。

`style`属性和`<style>`标签允许分别在一个 HTML 元素或一个 HTML 文档中定义 CSS 样式规则。

让我们举个例子:

```html
<p style="color:green;">This text will be shown in green color.</p>
```

### 第 22 个定位点索引

它用于指示一个元素是否可以获得输入焦点，如果可以，它是否应该参与顺序键盘导航，如果可以，那么在哪个位置。

它具有以下值:

1.  **否定**:表示元素是可聚焦的，但不能通过顺序键盘导航到达。

2.  **0:** 该值表示元素可聚焦，也可通过顺序键盘导航到达。

3.  **正:**表示元素应该是可聚焦的，并且可以通过连续的键盘导航到达，并且元素聚焦的顺序与 **tabindex** 的递增值相同

### 23.标题

该属性包含一个文本，该文本表示与其所属的 HTML 元素相关的任何附加信息。如果您为任何 HTML 元素指定了标题属性，当鼠标悬停在该 HTML 元素上时，您将看到该标题文本。这是一个工具提示，用于显示 HTML 页面中显示的任何信息的附加信息。

例如，

```html
<p title="This is John Wick">Keep mouse on me to see who am I!</p>
```

### 24.翻译

它用于指示元素的属性值及其文本值是否可以翻译

它有两个值:

*   **空字符串**和**是**，表示元素将被翻译。

*   **否**值表示该元素将不被转换。

有了这个，我们已经列出了所有的全局属性，你可以使用你的 HTML 标签。去我们的[网络游乐场](https://www.studytonight.com/code/playground/web/)试试吧。

* * *

* * *******