# CSS 选择器

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-selectors>

好吧。所以现在你已经很好地掌握了 CSS 的语法，让我们进入**选择器**。选择器帮助我们识别需要应用特定样式的 HTML 元素。

选择器有三种类型，即，

1.  **元素**选择器
2.  **id** 选择器
3.  **级**选择器

本模块将帮助您理解选择器的含义以及这三种选择器的工作原理，这反过来又可以在设计大型网页时节省大量时间和精力。

为了构建一个样式表，我们需要定义选择 HTML 元素的规则，并向它们应用各种样式属性。我们已经知道**元素选择器**(回想一下我们给`<h1>`标签分配的样式)，如果你不记得了，不要担心，我们会在本教程中再次讨论它。除了元素选择器，最常见的两种选择器形式是 **id** 和 **class** 选择器。

在下面的**视频**中，我们已经详细解释了所有三种类型的 CSS 选择器。

* * *

### 元素(标签)选择器

元素选择器或标签选择器，在 HTML 标签级别工作。当我们在 CSS 文件中直接为 HTML 标签添加样式时，它被称为元素选择器。

例如:

**HTML 代码**

```html
<h1>Welcome to Studytonight</h1>
```

CSS 代码

```html
h1 { 
    color: red; 
}
```

在上面的 CSS 代码中，我们已经直接给`h1`标签/元素分配了样式，这种标签选择和样式的方式被称为元素选择器，因为我们直接给元素分配样式。

上面的 CSS 代码，将把 HTML 文件中所有`h1`标签里面的文字字体颜色，改成`red`。当您想要对任何元素/标签应用基本样式时，应该使用这种选择模式，例如如果您想要所有段落文本都使用 **calibri** 字体，您可以编写以下 CSS 规则:

```html
p { 
    font-family: calibri; 
}
```

[现场示例→](/code/playground/web?file=css-element_selectors)

* * *

### id 选择器

如果在所有字体设置为`calibri`的段落标签中，你想让一个段落在你的网页上脱颖而出，并且你想让它有不同的风格，会怎么样。你会怎么做？

HTML 中的元素可以通过在标签内部使用 **id** 属性来命名，以便更好地引用。考虑以下示例:

```html
<p id="unique">CSS is fun!</p>
```

既然标签已经命名，我们只需要使用标签的`#unique` ( `#`后跟 **id 值**)就可以为其指定样式规则。

```html
#unique {
    color: green; 
    text-align: center;
}
```

[现场示例→](/code/playground/web?file=css-id_selector_1)

`#id`当您想要为特定的标签/元素设置样式时，会使用选择器。你所要做的就是，给 HTML 标签分配一个`id`属性，并在 CSS 文件中为它提供样式。

我们也可以通过在 CSS 文件中的`#id`选择器前添加标签来制作一个 **id 选择器**，标签/元素特定。

考虑以下风格:

```html
p#star {
    font-family: Arial;
}
```

[现场示例→](/code/playground/web?file=css-id_selector_2)

这将只选择其`id`属性设置为`star`的段落元素。把这个规则和我们之前看到的进行比较，

```html
#star {
    font-family: Arial;
}
```

这将匹配任何带有`id = "star"`的元素/标签，无论是标题的段落。这可能会回答您的疑问，即多个标签是否可以具有相同的 id？是的，他们可以！但是作为标准实践，`id`属性应该用于设置单个元素的样式。

虽然 CSS 为您提供了一种选择*元素特定 id 规则*的方式，就像`p#star`一样，但是始终将相同的标签名与 **id** 选择器一起使用，然后根据元素过滤掉是不合适的。但是，如果您有一个在整个站点范围内使用的样式表，并且您在不同的文档中有不同的 id `star`元素，那么这样的规则确实是有意义的。为了安全起见并避免混淆，最好对元素使用唯一的 id。

* * *

### 类别选择器

`class`选择器的规则定义为`.class-name`，如下所示:

**HTML 代码**

```html
<p class="fancy">I am fancy paragraph</p>
<h1 class="fancy">I am fancy heading</h1>
<h2 class="fancy">Mee too!</h2>
```

CSS 代码

```html
.class {
    background-color: black; 
    color: white; 
    font-style: italic;
}
```

[现场示例→](/code/playground/web?file=css-class_selector_1)

`class`属性用于定义特定标签或一组标签所属的类的名称。与`id`值不同，类值不必是唯一的，因为许多元素可以是同一类样式的成员。事实上，不同类型的元素也可以属于同一个样式类。

类规则也有一些变化。例如，将类`css_demo`的所有`h1`元素设置为黄色背景色，

```html
h1.css_demo { background-color: yellow; }
```

可以使用。

要显式选择类`css_demo`的*所有元素*，也可以使用`*`。

```html
*.css_demo{ background-color: yellow; }
```

与相同，

```html
.css_demo{ background-color: yellow; }
```

虽然`class`和`id`属性为创建样式规则提供了很大的灵活性，但是还存在许多其他同等价值的标签。例如，您可能希望区别对待`<p>`内的所有`<strong>`标签，而不是出现在`<p>`标签外的`<strong>`标签。为此，您必须使用**上下文选择**。

这种选择是通过为要应用的规则指定标签必须嵌套的顺序来完成的，用`>`隔开。例如，

```html
p > strong{
    background-color: yellow;
}
```

[现场示例→](/code/playground/web?file=css-class_selector_2)

上述规则将应用于所有`<strong>`标签，在一个`<p>`标签内。

在一个`p`元素中所有出现的`strong`元素都将有一个 *Helvetica* 字体。不包含在`p`标签中的`strong`标签的其他事件将不会应用相同的规则。

> ***注意:**使用上下文选择器要小心。不需要的逗号可能会将上下文选择变成分组，反之亦然。*

既然你已经习惯了选择器，让我们继续讨论 CSS 中的背景样式吧！

* * *

* * *