# CSS 背景

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-backgrounds>

好了，你现在已经看到了 CSS 的语法，现在已经习惯了使用`class`和`id`选择器来编写 CSS 规则。接下来，我们现在在 CSS 中潜入背景，是时候抛弃旧的黑白主题，拥有美丽、明亮的设计了。

背景属性是最有用的属性之一，玩起来非常有趣。正如我们将很快看到的，它被用来操纵页面背景。

* * *

### 背景色- `background-color`

`color`在 CSS 世界中，可以通过以下三种方式指定:

*   使用有效的颜色名称，如`red`
*   使用一个 RGB 值，如`rgb(255, 255, 255)`
*   或者，通过使用颜色的 hexa 代码，如`#F9F9F9`(有很多网站检查颜色的 Hexa 代码，如 [ColorHexa](http://www.colorhexa.com/) )

回到`background-color`，该属性设置元素的背景颜色。默认值透明允许任何底层内容通过。值`inherit`应用包含父元素的属性值。

```html
background-color: color | transparent | inherit
```

例如，

```html
h1 { background-color: red; }

p { background-color: orange; }
```

[现场示例→](/code/playground/web?file=css-background_color)

上例中，将所有`h1`标题的背景颜色设置为`red`，所有段落的背景颜色设置为`orange`。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 4+
*   Safari 1+

* * *

### 背景图像- `background-image`

顾名思义，**背景图像**将图像与元素相关联。背景图像需要使用`url()`语法指定的源图像的网址。默认值为**无**。

```html
background-image: url(image-file) | none | inherit
```

考虑下面的例子，这将为整个网页设置一个背景图像。

```html
body { 
    background-image: url(tile.png) 
}
```

要设置背景图像，对于任何特定的元素/标签，使用`class`或`id`进行设置，

```html
#hello { 
    background-image: url(http://www.example.com/images/hello.gif); 
}
```

[现场示例→](/code/playground/web?file=css-background_image_1)

`url`的值可以是完整的网址，也可以是相对网址。例如，如果图片存在于同一目录中，您可以简单地指定图片的名称。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 4+
*   Safari 1+

**注意:**设置背景时要记住的一点是，一定要选择与上面文字相得益彰的背景，这样文字才会清晰可见。

* * *

### 重复背景- `background-repeat`

有时，您为网页选择的背景图像可能会小于页面上其他元素使用的画布空间。在这种情况下，您可能需要重复图像。此属性的值可以如下所示:

*   `repeat` -垂直和水平重复图像。这是`background-repeat`属性的默认值。
*   `repeat-x` -仅水平重复
*   `repeat-y` -垂直重复
*   `no-repeat` -不重复背景图像。

**示例:**

```html
body{ 
    background-image: url(studytonight.png); 
    **background-repeat**: *no-repeat*; 
}
```

[现场示例→](/code/playground/web?file=css-background_image_2)

上面的代码将使图像**studytonight.png**作为网页背景，但是如果图像的大小较小，它不会完全填充网页，并且由于`background-repeat`属性被设置为`no-repeat`，因此它不会重复，留下一些没有背景的区域。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 4+
*   Safari 1+

* * *

### 背景位置- `background-position`

默认情况下，背景图像位于网页左上角**处，但我们可以更改这一点。**

 **此属性确定背景图像的位置。左上角背景图像的位置可以用绝对距离(以像素为单位)来指定，也可以用百分比值来指定。

在确定位置时，也可以使用命名值。横轴名称为*中心*、*左*和*右*。纵轴，你可能已经猜到了，*顶部*，*中心*和*底部*。请考虑以下示例:

```html
body { 
    background-image: url(hello.png); 
    background-position: 100px 150px; 
}
body { 
    background-image: url(hello.png); 
    background-position: 10% 55%;
}
body { 
    background-image: url(hello.png); 
    background-position: top center; 
}
```

> 在最后一个实时示例中，通过在`#study`样式中添加`background-position: top right;`来尝试这一点。

当我们在**像素**或**百分比**中指定`background-position`时，我们指定 2 个值，第一个值指定距左侧的距离，第二个值指定距顶部的距离。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 4+
*   Safari 1+

* * *

### 背景行为- `background-attachment`

此属性设置背景图像是否滚动。默认值为`scroll`，设置背景滚动相关内容，通常是文本。当相关内容在背景上滚动时，替代值`fixed`使背景静止。

值`inherit`应用包含父元素的属性值。

```html
background-attachment: scroll | fixed | inherit
```

考虑下面的例子，

```html
body{ 
    background-image: url (hello.png); 
    background-repeat: no-repeat;
    background-position: right top;
    background-attachment: fixed; }
```

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 4+
*   Safari 1+

> ***注意:**这个属性经常用来创建水印效果，类似于微软推出的标签的专有属性 bgproperties。*

* * *

### 背景属性在一起

如果我们愿意，我们可以将上述所有背景属性组合在一个属性中。

属性的顺序应该无关紧要，您没有定义的任何属性都使用它们自己的默认值。请考虑以下示例:

```html
body { background: white url(picture.gif) repeat-y center; }
```

* * *

* * ***