# CSS 样式化文本

> 原文：<https://www.studytonight.com/cascading-style-sheet/styling-the-text>

网站最重要的部分是文本，因为这是 HTML 的构建目的，标记要在互联网上共享的文本。文本是每个网页不可分割的一部分。一个设计优秀但不可读、难看、无格式文本的网页是非常不合适的。

现在，您已经了解了 CSS 背景属性的基本知识，让我们努力在网页上拥有美观、格式良好的文本。

在本模块中，我们将不讨论字体，但我们将讨论文本的表示。

文本属性是有趣的实验，并肯定会添加到您的网页动态边缘。让我们从任何文本最基本的属性开始，颜色！

* * *

### 文本颜色

`color`属性定义文本的颜色。在 **CSS1** 中引入，几乎所有的网页浏览器都支持。为文本选择颜色时，一定要记住背景的颜色。

就像在`background-color`中一样，在这个属性中，颜色可以用以下三种形式中的任何一种来指定:

*   有效的颜色名称，如**红色**、**蓝色**等
*   HEXA 代码，和白色一样，是 **#FFFFFF** ，黑色是 **#000000**
*   一个 RGB 值

**语法:**

```html
selector { 
    color: red;
}
```

[现场示例→](/code/playground/web?file=css-text_color)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

### 文本方向

文本的 direction 属性可用于支持多种语言和同一文档。默认值为`ltr`，即**从左到右**。一些语言，如阿拉伯语、波斯语、乌尔都语等，需要从右向左的文本方向。

*例如*

```html
body { 
    direction: rtl;
}
```

[现场示例→](/code/playground/web?file=css-text_direction)

上面的 CSS 代码会将网页上每个文本的方向从右向左改变。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 5.5+版
*   Firefox 1+
*   Opera 9.2+
*   Safari 1.3+
*   铬 2+

* * *

### 字母间距

此属性定义文本中单词字母之间的间距。

**语法:**

```html
letter-spacing: normal | length | initial | inherit; 
```

长度可以是正值或负值。最初，属性设置为默认值，即`normal`。

```html
h1{ 
    letter-spacing: 2px; 
}
h2{ 
    letter-spacing: -3px; 
}
```

[现场示例→](/code/playground/web?file=css-letter_spacing)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

### 文本对齐

啊，越熟悉`text-align`！此属性指定元素中文本的水平对齐方式。默认值取决于方向属性。如果方向设置为`rtl`，对准是正确的；如果方向设置为`ltr`，对准是向左的。

**语法:**

```html
text-align: left | right | center | justify | inherit;
```

*例如*

```html
#text-center { 
    text-align: center;
}
```

[现场示例→](/code/playground/web?file=css-text_alignment)

这与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

### 文本缩进

此属性指定文本从保持块的第一行(左上角)开始的缩进(间距)。您可以为此属性指定负值。正如您可能猜到的那样，对于负值，文本将向左缩进，对于正值，文本将远离左侧缩进。长度可在`pixel`、`cm`、`pt`等中指定。您也可以为此属性指定一个百分比值。

**语法:**

```html
text-indent: length;
```

*例如*

```html
#little_towards_right { 
    text-indent: 10px;
}
```

[现场示例→](/code/playground/web?file=css-text_indent)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

### 文本装饰

`text-decoration`属性指定添加到文本中的装饰。

> ***注意:**在 CSS3 中，`text-decoration`属性是`text-decoration-line`、`text-decoration-color`和`text-decoration-style`的简写属性，但目前这在任何主要浏览器中都不受支持。*

**语法:**

```html
text-decoration: none | underline | overline | line-through;
```

*例如*

```html
#underlined { 
    text-decoration: underline;
}
```

[现场示例→](/code/playground/web?file=css-text_decoration)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

### 文本阴影

`text-shadow`属性为文本添加阴影。

**语法:**

```html
text-shadow: h-shadow v-shadow blur-radius color | none;
```

`h-shadow`和`v-shadow`为强制参数。`h-shadow`指定实际文本与其阴影之间的水平距离，`h-shadow`指定文本与其阴影之间的垂直距离。

如果我们没有为`blur-radius`指定任何值，那么阴影是实际文本的精确副本，由于 h 形阴影和 v 形阴影而稍微移位。`blur-radius`让它模糊，更看重马克斯这个影子更模糊。

*例如*

```html
h1{ text-shadow: 2px 2px 5px #ff0000; }
```

 `[现场示例→](/code/playground/web?file=css-text_shadow)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 10+
*   Firefox 3.5+
*   Opera 9.6+
*   Safari 4+
*   Chrome 4+

> ***注意:**要给文本添加多个阴影，请添加逗号分隔的阴影列表。*

您可以使用更多的文本属性。上面提到的属性是最常用的！接下来，字体！

* * *

* * *`