# 使用 CSS 更改文本字体

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-fonts>

在上一个模块中，我们讨论了文本格式。现在，你已经知道如何在 CSS 中处理**背景**和**文本格式**。让我们从字体开始。

**字体**为你的网页设置一个主题。字体也有助于你与你的听众建立联系。在正式网页上使用*漫画无*没有任何意义，可能会立即导致负面印象，而在儿童网站上，相同的字体可能看起来很有趣。

您可以使用 font 属性在一个规则中指定所有字体属性。

**语法:**

```html
font: font-style font-variant font-weight font-size font-family;
```

您不需要包含所有属性，考虑一个例子:

```html
p { 
    font: normal small-caps bold 18pt/22pt "Times New Roman", Courier;
}
```

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 6+
*   Safari 1+
*   Chrome 1+

* * *

### 字体系列- `font-family`

该属性定义了用于文本的字体。

语法:

```html
font-family: font 1[, font2, ... ,fontN]
```

字体可以专门命名，也可以使用通用字体系列名称。当使用逗号指定多个字体名称时，将按降序读取它们，寻找第一个匹配项。并非所有的浏览器和设备都支持所有的字体，因此我们应该提供逗号分隔的字体，以便覆盖大多数设备/浏览器。五种通用字体名称是:

*   衬线
*   无衬线字体
*   草书
*   幻想
*   单一间隔

> **注意:**它们可能不会在所有浏览器中以相同的方式呈现。

*示例:*

```html
p{ 
    font-family: Serif; 
}
```

[现场示例→](/code/playground/web?file=css-font_family)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 4+
*   Safari 1+
*   Chrome 1+

这个属性相当于一个`<font>`标签的脸属性。由于`<font>`标签在 HTML5 中被弃用，建议不要使用。

* * *

### 字体大小- `font-size`

这用于设置字体的大小。

**语法:**

```html
font-size: length | percentage | Size in Words | inherit;
```

Here Size in Words referes to → larger | smaller | xx-small | x-small | small | medium | large | x-large | xx-larger

默认为**中**。长度通常在**点**、**像素**、 **em** 等中指定。

**百分比**值将字体大小设置为当前继承字体大小的百分比。

`px`像素值取决于设备，一般相当于 1/96 英寸。但是对于不同屏幕分辨率的设备，这个值是不同的。

另一个广泛使用的单位是`em`。我们试着理解一下，借助一个例子:如果把正文的`font-size`设置为`1em`，把`h1`标题文本的`font-size`设置为`3em`。然后无论是哪种设备，浏览器都会确保标题文本的大小始终是正文文本的 3 倍。

*示例:*

```html
#fontastic{ 
    font-size: *12px*;
}
#fontastic-1{
    font-size: *1em*
}
```

[现场示例→](/code/playground/web?file=css-font_size)

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 4+
*   Safari 1+
*   Chrome 1+

* * *

### 字体样式和字体粗细

`font-style`设置字体的表现风格，而`font-weight`设置文本的粗细或相对粗细。

**语法:**

```html
font-style: italic | normal | oblique | inherit;
font-weight: normal | bold | bolder | lighter | 100 to 900 | inherit;
```

[现场示例→](/code/playground/web?file=css-font_style)

大多数浏览器会将 **100-500** 解释为普通文本， **600-900** 解释为粗体。相对值如*较浅*或*较粗*会根据父元素的字体粗细增加或减少。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 4+
*   Safari 1+
*   Chrome 1+

* * *

### 字体变体

此属性设置指定或默认字体系列的变体。

**语法:**

```html
font-variant: normal | small-caps | inherit;
```

[现场示例→](/code/playground/web?file=css-font_variant)

小写值将小写文本设置为大写。小型大写形式的应用是法律或许可文件。

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 3+
*   Firefox 1+
*   Opera 4+
*   Safari 1+
*   Chrome 1+

* * *

* * *