# CSS 边框

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-borders>

`border`属性是所有边框属性的简写。它定义了元素边框所有四条边的颜色、宽度和样式。

**语法:**

```html
border: border-width border-style border-color
```

上面提到的是最常用的`border`属性格式来给你的 HTML 元素添加边框。就像我们对这一段做的那样。

*示例:*

```html
#red-border {
    border: 1px solid red;
}
```

但是 border 也可以单独使用属性来实现。让我们了解这 3 个边框属性以及如何使用它们。

* * *

### 边框样式`border-style`

此属性用于设置元素周围的边框。支持多种边框样式，例如:

*   虚线
*   有点的
*   两倍
*   律动
*   隐藏的
*   插入物
*   没有人
*   开始
*   山脉
*   固体

这是**虚线**边框

这是**虚线**边框

这是**槽**边框

*示例:*

```html
#dashed-border {
    border-style: dashed;
}
#dotted-border {
    border-style: dotted;
}
#groove-border {
    border-style: groove;
}
```

[现场示例→](/code/playground/web?file=css-border_style)

* * *

### 边框宽度`border-width`

该属性以数值或命名值设置边框宽度，命名值为**细**、**中**或**粗**。边框的宽度也可以使用独立属性`border-width`进行调整

这是一个**粗虚线**边框

*例*

```html
#dashed-border {
    border-style: *dashed*;
    border-width: *6px*;
}
```

[现场示例→](/code/playground/web?file=css-border_width)

* * *

### 边框颜色`border-color:`

此属性使用颜色值设置边框的颜色。颜色值可以是六进制代码、RGB 值或有效的颜色名称。

这是一个**粗的红色虚线**边框

*例*

```html
#dashed-border {
    border-style: dashed;
    border-width: 6px;
    border-color: red;
}
```

[现场示例→](/code/playground/web?file=css-border_color)

我们还可以在一个`border-color`规则中提供 4 种不同的颜色，为边框的所有 4 条边设置不同的颜色。

这是一个**粗虚线的彩色**边框

*例*

```html
#dashed-border {
    border-style: dashed;
    border-width: 6px;
    border-color: red blue green yellow;
}
```

[现场示例→](/code/playground/web?file=css-border_multi_color)

4 种不同的颜色值，用于顶部、右侧、底部和左侧，顺序相同。如果您提供两种不同的颜色名称，那么第一种颜色将设置为顶部和底部边框，第二种颜色将设置为左侧和右侧。去试试吧！

与 **CSS1** 、 **CSS2** 、 **CSS3** 以及以下网页浏览器兼容，

*   IE 4+
*   Firefox 1+
*   Opera 3.5+
*   Safari 1+
*   Chrome 1+

* * *

#### 边界崩溃

此属性确定表格单元格是连接的还是分开的。

**语法:**

```html
border-collapse: collapse | separate | inherit
```

默认值为`separate`，每个单元格都有一个带有一定间距的边框。如果设置为`collapse`，整个元素只有一个边框。

该属性主要用于样式`<table>`。

* * *

* * *

#### 边框间距

此属性定义表格中单元格之间的间距。同样，该属性也用于 HTML 中的表。

**语法:**

```html
border-spacing: non-negative length | inherit
```

如果提到一个长度，它会给出水平和垂直间距。如果明确定义了两个值，第一个值给出*水平*间距，而第二个值给出*垂直*间距。

* * *

### 在一侧设置边框

如上所述，我们可以使用`border-style`属性轻松设置元素周围的边框，使用`border-width`属性更改边框的厚度，并使用`border-color`属性为其赋予颜色。

现在，我们也可以使用这三个属性在任意一侧设置边框。我们所要做的就是在中间加上边的名字:

例如:要在底部添加边框，请使用属性`border-bottom-style`、`border-bottom-width`、`border-bottom-color`

我在底部有一个虚线边框

*例*

```html
#dashed-border {
    border-bottom-style: dotted;
    border-bottom-width: 4px;
    border-bottom-color: blue;
}
```

[现场示例→](/code/playground/web?file=css-border_on_side)

同样可以用速记的方式写如下:

```html
border-bottom: dotted 4px blue
```

与`border-bottom`类似，边框属性可以分别设置为顶部、右侧和左侧。要设置上边框，您可以使用

*   顶部边框(简写)
*   边框顶部宽度
*   边框-顶部样式
*   边框-顶部颜色

要设置右边框，您可以使用

*   右边框(简写)
*   边框-右宽度
*   右边框样式
*   右边框颜色

要设置左边框，您可以使用

*   左边框(速记)
*   边框-左宽度
*   左边框样式
*   左边框颜色

唷！那是很多属性。但是熟能生巧。接下来是桌子！祝你好运！

* * *

* * *