# CSS 样式化表格

> 原文：<https://www.studytonight.com/cascading-style-sheet/styling-tables>

你对 HTML 中的表格相当熟悉(回想一下`<table>`标签？).表格本质上是由行和列组成的电子表格。你在网站上使用表格的频率会比你想象的要高，所以让我们了解更多关于如何用 CSS 让它们看起来漂亮的知识。在本模块中，我们将同时关注 CSS 和 HTML 部分。

大多数表的实际第一行不包含数据，它只包含列的*标题*。所以我们明确提到这一点不是更好吗？这可以通过使用`<thead>`元素来实现，这样查看器就可以正确区分列名和列数据。它可以包含多行标题信息。

> ***注意:**使用`<thead>`时，一定不能有`<tr>`是`<table>`元素的直接子元素。所有`<tr>`必须出现在`<thead>`、`<tbody>`或`<tfoot>`元素内。*

有些表格也有**页脚**。考虑一家超市的打印收据，其中**表格**的底部用大粗体字母显示了总金额(好像你还不知道杂货有多贵！)反正`<tfoot>`元素是用来展示表尾信息的。现在你可能期望这个元素出现在`<thead>` & `<body>`元素之后。然而事实并非如此。`<tfoot>`必须在`<thead>`之后&之后`<tbody>`之前。`<tfoot>`用于包装指示表格页脚的表格行。

尽管标签放置异常，`<tfoot>`实际上在表格的底部呈现。网站上看到的大多数表格都使用颜色和线条来区分元素。**边境**在这种情况下至关重要。默认情况下，所有表格元素的边框默认为`2px`。

| 第 1 栏标题 | 第 2 栏标题 |
| --- | --- |
| 足音 1 | 足音 2 |
| 你好，第一栏 | 你好第二栏 |

下面是上表的 HTML 代码:

```html
<table id="table-style-1">
    <thead>
        <tr>
            <th>Column 1 Heading</th>
            <th>Column 2 Heading</th>
        </tr>
    </thead>
    <tfoot>
        <tr>
            <td>Foot Note 1</td>
            <td>Foot Note 2</td>
        </tr>
    </tfoot>
    <tbody>
        <tr>
            <td>Hello column 1</td>
            <td>Hello column 2</td>
        </tr>
    </tbody>
</table>
```

要指定表格边框，我们使用表格的`border`属性。

```html
#table-style-1{ 
    border: 0.5px solid black; 
}
```

[现场示例→](/code/playground/web?file=css-table_style_1)

就像我们在上一个教程中学习的一样，**边框宽度**、**边框样式**和**边框颜色**。

以上示例将所述表格元素的边框修改为纯黑的`0.5px`。但是考虑下面的例子，

```html
table, th, td{ border: 1px solid black; }
```

在上例中，由于`<th>`和`<td>`的边框不同，表格将有双边框。如果要显示单个边框，请使用`border-collapse`属性，如下所示。

```html
table{ 
    border-collapse: *collapse*; 
}
table, th, td { 
    border: 1px solid black; 
}
```

[现场示例→](/code/playground/web?file=css-table_style_2)

继续尝试这个，看看有没有属性`border-collapse`的表是什么样子的。

> ***注:**若<！未指定 DOCTYPE >，边框折叠属性会在 IE8 及更早版本中产生意外结果。*

* * *

### 文本对齐以及宽度和高度

您还可以更改表格列中的水平文本对齐方式。这是由我们已经熟悉的`text-align`属性完成的。

`<th>`元素中的数据默认为*居中对齐*，`<td>`中的数据默认为*左对齐*。但我们可以随时改变它们。

```html
th{ text-align: left; }
```

桌子的**高度**和**宽度**也可以自定义。以下示例将表格的宽度设置为`100%`(覆盖整个页面宽度)，标题行的高度设置为`80px`。

```html
table { 
    width: *100%*; 
}
th, td { 
    height: *40px*; 
}
```

[现场示例→](/code/playground/web?file=css-table_style_3)

| 第 1 栏标题 | 第 2 栏标题 |
| --- | --- |
| 足音 1 | 足音 2 |
| 你好，第一栏 | 你好第二栏 |

* * *

### 垂直文本对齐

`vertical-align`属性用于定义表格中文本的顶部、底部或中间对齐方式。默认情况下，这被设置为**中间的**。

```html
table { 
    width: 100%; 
}
td { 
    height: 40px; 
}
th{ 
    height: 40px;
    vertical-align: bottom; 
}
```

| 第 1 栏标题 | 第 2 栏标题 |
| --- | --- |
| 足音 1 | 足音 2 |
| 你好，第一栏 | 你好第二栏 |

* * *

### 文本颜色和背景颜色

您可以使用属性`color`和*背景色*设置表格的文本颜色和背景颜色。也可以使用`border`属性指定边框颜色。

```html
td{ 
    background-color: #EEEEEE; 
    color: blue; 
    border: 1px solid red;
}
```

[现场示例→](/code/playground/web?file=css-table_style_4)

| 第 1 栏标题 | 第 2 栏标题 |
| --- | --- |
| 足音 1 | 足音 2 |
| 你好，第一栏 | 你好第二栏 |

* * *

* * *