# CSS 元素定位

> 原文：<https://www.studytonight.com/cascading-style-sheet/positioning-of-elements>

元素的定位极其重要。考虑化学元素周期表(啊！)所有的元素都按照适当的顺序排列，这使得我们更容易找到这些元素，这些元素按照它们的属性和原子序数分组在一起。

好了，化学已经够了。讨论周期表的重点是位置很重要。从可用性的角度来看，你如何定位你的网页元素是非常重要的，也就是说，用户使用你的网站感觉有多舒服。

CSS 可以帮助你在网站上定位东西。position 属性用于指定元素的位置。有四种类型的位置值:

*   `static`
*   `relative`
*   `absolute`
*   `fixed`

一旦设置了`position`属性，则可以使用顶部、底部、左侧和右侧属性将元素定位在网页上，但是除非设置了`position`值，否则它们不起作用。此外，对于上面提到的每一个`position`值，这些值的行为也会有所不同。

* * *

### 静止姿势

任何页面元素的默认值都是`static`。静态意味着元素会像正常情况下一样适合页面。显式指定 static 是非常罕见的，并且可以用来去掉任何继承的位置值。

静态定位元素不受*顶部*、*底部*、*左侧*和*右侧*属性的影响。

```html
div{ 
    position: static;
    border: 15px solid #6699CC;
}
```

[现场示例→](/code/playground/web?file=css-static_position)

* * *

### 相对位置

这个位置意味着相对于自身。将元素的位置设置为相对，但不指定任何其他属性，如*顶部*、*底部*、*左侧*或*右侧*，对元素的位置没有特别的影响。但是指定一个*底部*属性为，`bottom: 20px;`将使元素**相对于其**正常**位置向上移动**。

将位置设置为`relative`会使元素出现在其区域中的任何其他静态元素之上。其他内容不会被调整以适合元素留下的任何间隙。

```html
div{ 
    position: relative; 
    border: 4px solid #6699CC; 
}
```

[现场示例→](/code/playground/web?file=css-relative_position)

* * *

### 绝对位置

该值允许您将元素精确地放置在您想要的位置。定位属性*顶部*、*底部*、*左侧*和*右侧*用于确定准确位置。这些元素相对于最后一个**父元素**放置。如果没有父元素，这些元素将被设置为相对于页面本身，即它在滚动时随页面一起移动。

```html
div{ 
    position: absolute;
    border: 15px solid #6699CC;
}
```

[现场示例→](/code/playground/web?file=css-absolute_position)

* * *

### 定位

这种类型的定位很少，但肯定有它的用途。固定位置元素相对于**视口**或浏览器窗口本身定位，而不是相对于*父*元素或其*兄弟*元素定位。当窗口滚动时，视口不会改变，所以当页面滚动时，一个固定位置的元素会停留在原来的位置。

> *这个效果其实挺酷的，但是需要好好测试一下。*

```html
div{ 
    position: fixed;
    border: 15px solid #6699CC;
}
```

[现场示例→](/code/playground/web?file=css-fixed_position)

你可以在浏览器屏幕的左侧看到一个固定的橙色元素，带有一个类似脸书的按钮，它是使用`position:fixed`属性制作的。

你好！我被固定在这里。

* * *

### 重叠元素

当我们如此玩转定位时，就会出现元素相互重叠的情况。那么，在重叠的情况下，哪个元素会出现在另一个元素的顶部呢？

`z-index`定义元素的堆叠顺序。具有较大`z-index`的元素将始终位于具有较低`z-index`的元素之上。一个元素可以有正或负的`z-index`值。

```html
h1{ 
    position: absolute;
    left: 0px;
    top: 0px;
    z-index: -1;
}
```

[现场示例→](/code/playground/web?file=css-overlapping)

> ***注意:**如果两个定位的元素重叠而没有指定`z-index`，则 HTML 代码中最后定位的元素将显示在顶部。*

* * *

* * *