# CSS 二维变换

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-2D>

你好！今天，我们从这里开始我们的旅程，进入一些高级的 CSS 主题，比如 CSS 变换，它包含在 CSS3 规范中。

我们将从 2D 变换开始，它允许你**变换**、**缩放**和**扭曲**元素。我们已经在下面详细解释了这些术语的含义。

一个**变换**是一个让元素改变形状、大小或位置的效果。CSS3 支持 2D 变换和三维变换。

让我们从列出支持 2D 变换的浏览器开始。

*   IE 10+
*   谷歌 Chrome 36+
*   Mozilla Firefox 16+
*   Safari 9+
*   Opera 23+

> **注意:** *这些浏览器的一些旧版本也支持 2D 变换，但是要使您的 CSS 工作，您需要在变换属性上附加一个前缀(例如`-ms-`或`–webkit-`)。*

在本教程中，您将学习以下变换函数，而不是属性。

*   翻译()
*   旋转()
*   比例()
*   skewX()
*   skewY()

* * *

### `translate()`

此函数使用作为函数参数提供的值，将元素从其正常位置移动到不同位置。

以下示例将把

# 元素`50`像素向右移动，而`100`像素从其原始位置向下移动。请注意附加的前缀以支持旧版本。

```html
h1{
    -ms-transform: translate(50px,100px);   /* IE 9 */
    -webkit-transform: translate(50px,100px);   /* Safari */
    transform: translate(50px,100px);
}
```

[现场示例→](/code/playground/web?file=css-2d_transformation_translate)

* * *

### `rotate()`

通过为该功能提供`degree`值，可以顺时针或逆时针旋转特定元素**。**

```html
h1{ 
    transform: rotate(20deg);
}
```

[现场示例→](/code/playground/web?file=css-2d_transformation_rotate)

* * *

### `scale()`

缩放会增加或减少元素的大小。

```html
div{ 
    transform: scale(2, 3);
}
```

上面的例子将

元素的大小增加到原来宽度的两倍，原来高度的三倍。

[现场示例→](/code/playground/web?file=css-2d_transformation_scale)

尝试在`scale()`方法中使用负值，看看元素内部文本的镜像是如何显示的。

* * *

### `skew()`

您也可以分别使用`skewX()`或`skewY()`功能将元素沿 X 轴或 Y 轴**倾斜任意给定的角度。**

```html
div{ 
    transform: skewX(20deg); 
}

div{ 
    transform: skewY(30deg); 
}
```

或者，您可以为`skew()`方法提供两个参数，如下所示:

```html
div{ 
    transform: skew(20deg, 30deg);
}
```

第一个参数对应 **X 轴**，第二个对应 **Y 轴**。如果没有指定第二个参数，默认情况下它将取零值。

[现场示例→](/code/playground/web?file=css-2d_transformation_skew)

* * *

### 变换原点性质

`transform-origin`属性允许您更改已经变换的元素的位置。元素的 x 轴和 y 轴可以在 2D 变换中改变，而元素的 **z 轴**也可以在三维变换中随 x 轴和 y 轴一起改变。

> **注意:** *这个属性必须和 transform 属性一起使用。*

**语法:**

```html
transform-origin: x-axis y-axis[z-axis] | initial | inherit;
```

*   x 轴参数的可能值为**右侧**、**左侧**、**中心**、**长度**或**百分比**。
*   y 轴参数的可能值为**顶部**、**底部**、**中心**、**长度**或**百分比**。
*   z 轴的可能值是**长度**。

好了，这就是 CSS3 中 2D 变换的全部内容。

* * *

* * *