# CSS 渐变

> 原文：<https://www.studytonight.com/cascading-style-sheet/css-gradients>

在前面的课程中，我们了解了`background`属性以及`background-image`和`background-color`属性。您也可以使用渐变，而不是为背景设置图像。不使用实际的图像文件，而是使用渐变背景，可以获得更好的网页性能和对设计的更好控制。

那么什么是**梯度**？渐变是一种颜色渐变为另一种颜色。在 CSS 中，您可以控制颜色和渐变的变化模式，以您想要的方式修改它们。

记得我们之前用`background-color`设置背景颜色。然而对于渐变，我们使用`background-image`

```html
.gradient{ 
    background-image: linear-gradient(red, orange);
}
```

* * *

### 线性梯度

这是最常见和最有用的渐变类型。渐变`axis`可以从左到右，从上到下，也可以选择任何角度。如果不声明角度，则假设轴是从上到下的。您可以使用六进制代码或命名颜色或 RGB 值来指定颜色。

```html
.gradient {
 	background-image: linear-gradient(to right, red, #f06d06 );	
}
```

为了使它从左到右，我们在`linear-gradient()`函数参数的开头传递一个附加参数，使用单词**到**，指示方向，例如**“向右”**。这种语法也适用于拐角。

例如，如果你想让渐变的轴从左下角开始，到右上角，你可以说**“到右上角”**。

您可以使用任意多的颜色来制作渐变。

```html
.gradient {
    background-image:linear-gradient(to right, red, #3366ff, rgb(255, 255, 0), green);	
}
```

[现场示例→](/code/playground/web?file=css-gradient_linear)

* * *

### 径向梯度

径向梯度不同于线性梯度，因为它从一个点开始，向外扩展。渐变通常用于模拟灯光效果，因此它们有助于使渐变看起来更加自然。

默认设置是，第一种颜色从元素的(中心)开始，向元素的边缘渐变到结束颜色。无论是哪个方向，衰落都以相同的速度发生。淡入淡出的默认样式是**椭圆**，但也可以强制为圆形样式。

**示例:**

```html
/* default ellipse */
.gradient {
  	background-image:radial-gradient(yellow, #3366ff );	
}

/* changing the fading to circle form */
.gradient {
  	background-image:radial-gradient(circle, yellow, #3366ff );	
}
```

[现场示例→](/code/playground/web?file=css-gradient_radial)

以下浏览器支持线性和径向渐变:

*   Chrome 26+
*   Firefox 16+
*   IE 10+
*   Opera 15+
*   Safari 6.1+

还有第三种梯度，即`repeating gradient`。然而，到目前为止，支持这种类型的浏览器并不多。

使用渐变可以获得很多乐趣。与`background-image`相比，它们在性能方面是更好的选择，而且它们看起来更自然。

* * *

* * *