# SCSS 语法

> 原文：<https://www.studytonight.com/sass/sass-scss-syntax>

正如我们在[Sass 介绍](https://www.studytonight.com/sass/introduction-to-sass-or-scss)教程中学到的，Sass 与 CSS 有何不同，它带来了哪些好处。在本教程中，我们将学习 Sass 的语法，并了解它如何优于传统的 CSS 语法。

## 文件扩展名

Sass 支持两种不同的文件扩展名，即**。SASS**和**。scss** ，一个是针对 SASS 代码，一个是针对 scss 语法。正如我们在介绍教程中已经提到的，从版本 3 开始，Sass 就变成了 Scss，其语法与 css 非常相似，而 Sass 的语法则非常不同。

如果您有一些按照 Sass 语法编写的代码，并且想要将其转换为 Scss 语法，您可以使用 sass-convert 命令来实现。例如，如果我们在 *sass-style.sass* 文件中有 sass 代码，而对于 scss 代码我们有 *scss-style.scss* ，我们可以使用以下命令将 Sass 代码转换为 scss 代码，

```sass
sass-convert sass-style.sass scss-style.scss
```

我们也可以用它来将 Scss 代码转换成 Sass 代码。

## SCSS 语法

Scss 的语法类似于 css，只是在语法上做了一些改变，这进一步简化了编写复杂 HTML 结构的代码。Scss 还为我们提供了变量、运算符用法、许多现成函数等功能，我们将在接下来的教程中了解它们。在本教程中，我们将只关注在 Scs 中引入的一些重要的语法变化，这些变化在 css 中是不可用的。

### 1.SCSS 的评论

**Scss** 支持单行和多行评论，即`//`和`/* */`。但是一旦 **Scss** 或 **Sass** 文件被编译成 css，那么生成的 CSS 将只保留多行注释而不是单行注释，因为 CSS 不支持单行注释。举个例子吧。

```sass
 // Hello
// This is Sass tutorial

/*  This tutorial will help you to understand sass
    completely so that you can straight away apply sass
    in your project and make your project awesome.
*/

// Thank you

.hello-world
{
    background-color:pink;
} 
```

如果我们将上面的 Scss 代码编译成 css，生成的 CSS 将如下所示:

```sass
 /*  This tutorial will help you to understand sass
    completely so that you can straight away apply sass
    in your project and make your project awesome.
*/
.hello-world
{
    background-color:pink;
} 
```

### 2.嵌套规则

在 HTML 中，我们有嵌套和可视化的层次结构。例如，如果我们创建一个列表，我们使用`<li>`标签在`<ul>`或`<ol>`标签内创建列表项。但是 CSS 不支持这样的嵌套语法。因此，如果我们必须用下面的 HTML 代码来设计网页边栏中的列表及其项目的样式，

```sass
<div id="sidebar">
    <ul>
        <li>Tutorials</li>
        <li>Q & A Forum</li>
        <li>Flashcards</li>
        <li>Tests</li>
        <li>Collaborate</li>
    </ul>
</div>
```

我们将编写如下 CSS 代码:

```sass
#sidebar {
    float:left;
    width:25%;
    background-color:lightblue;
    padding: 30px 10px;
}

#sidebar ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
}

#sidebar li {
    padding: 6px;
    margin-bottom: 10px;
    background-color: #10A2FF;
    color: #ffffff;
}
```

但是在 Scss 中，我们可以使用嵌套规则以更易读的方式实现这一点，

```sass
#sidebar {
    float:left;
    width:25%;
    background-color:lightblue;
    padding: 30px 10px;

    ul {
        list-style-type: none;
        margin: 0;
        padding: 0;
    }

    li {
        padding: 6px;
        margin-bottom: 10px;
        background-color: #10A2FF;
        color: #ffffff;
    }
}
```

看，比 CSS 好。

### 3.父选择器

在 Sass 语法中，我们可以使用`&`符号来表示父类，并定义进一步的嵌套规则。让我们举个例子来理解这一点。考虑下面的 HTML 代码，

```sass
<div id="studytonight">
    <div id="studytonight-body">
        /* Some HTML code */
    </div>
</div>
```

正如我们在上面的嵌套规则示例中所看到的，我们可以使用 Sass 嵌套规则来定义`#studytonight`和`#studytonight-body`的样式，但是 Sass 使使用父选择器语法更加容易。

```sass
#studytonight {
    // styling for #studytonight div
    &-body {
        // styling for #studytonight-body div
    }
}
```

当 Sass 代码转换为 CSS 代码时，`&`符号被编译为父选择器值。当我们必须在主元素中使用类似`:hover`、`:selected`等伪选择器时，这就派上了用场。因此，如果您有一个`<a>`标签，并且想要为鼠标悬停定义样式，您可以在 Sass 中这样做，

```sass
a {
    text-decoration: none;
    color:black;
    // using parent selector
    &:hover {
        color:red;
    }
}
```

这相当于下面的 CSS 代码，

```sass
a{ 
    text-decoration: none;
    color:black;
}
a:hover
{
    color:red;
}
```

### 4.嵌套属性

在 CSS 中，有许多属性具有与`font-weight`、`font-size`、`font-family`等相同的前缀。在 CSS 中，我们必须键入完整的属性名，以使用它们来设计我们的 HTML 元素。但是 Sass 语法允许我们用这样只声明一次的前缀来定义嵌套属性，

```sass
font: {
    family: calibri;
    size: 12px;
    weight: 500;
} 
```

这个 Sass 代码被编译成下面的 CSS，

```sass
font-family: calibri;
font-family: 12px;
font-weight: 500;
```

因此为您节省了一些代码输入。

### 5.占位符选择器

Scss/Sass 中的占位符选择器或占位符类用于定义样式规则，这些规则本身没有任何意义，但为继承这些规则的类提供了意义。正如我们在入门教程中已经指定的 [Sass 支持继承](https://www.studytonight.com/sass/inheritance-in-sass)，这就是继承在 Sass 中的工作方式。我们使用%符号定义一个占位符选择器，在其中提供一些样式规则，然后我们可以将这个类继承到其他类中。当我们有一些想要包含在多个样式类中的通用样式代码时，这非常有帮助。

让我们举个例子来理解 Sass 的这个特殊特性。

```sass
%card {
    box-sizing: border-box;
    border-top: 1px rgba(#000, .12) solid;
    width: 100%;

    &:hover { border: 2px rgba(#000, .5) solid; }
}

.card-light {
    // inheriting card styling rules
    @extend %card; 
    background-color: #FFFFFF;
    color: #000000;
}

.card-dark {
    // inheriting card styling rules 
    @extend %card; 
    background-color: #000000;
    color: #FFFFFF;
}

```

上面的代码将被编译成下面的 CSS 代码，

```sass
.card-light, .card-dark {
    box-sizing: border-box;
    border-top: 1px rgba(#000, .12) solid;
    width: 100%;

}

.card-light:hover, .card-dark:hover {
    border: 2px rgba(#000, .5) solid;
}

.card-light {
    background-color: #FFFFFF;
    color: #000000;
}

.card-dark {
    background-color: #000000;
    color: #FFFFFF;
}
```

如果我们不在 Sass 代码中扩展/继承占位符选择器，那么它们将从编译后的 CSS 代码中被省略。

## 结论:

正如您在上面看到的，Sass 被如此好地定义，以专门减少编写大量 CSS 代码的痛苦，因此通过首先在 Sass 中编写样式代码，然后将其编译成 CSS 代码，开发人员可以非常容易地为他们的网站编写 CSS。这种惊人的语法可以为您节省数百行代码。

在接下来的教程中，我们将学习更多关于 Sass 的内容。

* * *

* * *