# SASS 变量

> 原文：<https://www.studytonight.com/sass/sass-variables>

Sass/Scss Variable 是 **Scss** 的特性之一，使得编写 CSS 样式更加动态。在 Scss 中，我们可以使用`$`符号声明和定义变量，命名变量，然后为变量提供值。

让我们看一下在 Scss 中定义变量的语法:

```sass
$variable-name: variable value
```

变量声明以`$`开始，随后是**变量名**，然后是一个**冒号** ( `:`)符号，最后是变量的**值。就像任何其他脚本或编程语言中的变量一样，在 Scss 中也是如此，变量保存的值可以在整个样式表中使用。**

## 定义默认值的变量

我们可以使用 SASS 变量来定义默认值。

例如，在 Studytonight 的网站上，我们对一些特殊的文本、按钮和一些背景使用紫色和橙色。当我们使用 CSS 时，我们必须在任何地方使用 Hexa 代码来表示颜色，但是使用 Sass，我们可以定义一个变量，然后在任何我们想要的地方使用变量名。让我们举个例子，

```sass
// define the variable
$purple: #6A67CE;

.purple-btn
{
	text-align: center;
	background-color: $purple;
}
.purple-text
{
	color: $purple;
}
```

在 Sass/Scss 中定义和使用变量的一个更重要的点是，如果你定义了一个名字带有**连字符**或**下划线**的变量，可以互换使用。例如，

```sass
// define the variable
$purple-color: #6A67CE; 
.purple-btn 
{ 
    text-align: center; 
    background-color: $purple-color; 
} 
.purple-text 
{ 
    color: $purple_color;
}
```

在上面的代码中`$purple-color`和`$purple_color`将返回相同的值 **#6A67CE** ，因此连字符和下划线在变量名中被视为相同。

## 在 Scss 变量中存储什么？为什么？

好吧，随便你。它就像一个正态变量。无论你经常使用什么，比如颜色的 Hexa 代码或者某种特定的字体样式等等，都可以在一个地方定义为变量，然后在样式表中反复使用。

此外，使用变量的另一个好处是，如果您想要更改某些 Hexa 颜色的值，您不必处处更改该值，您只需要在一个地方更改该值。

Rest，这是你的选择，你可以定义任意多个变量，并在你的 Scss 代码中使用它们。

## Scss 变量的范围(隐藏)

就像其他编程/脚本语言一样，Scs 中的变量也有作用域。为了理解 scope 是如何工作的，让我们举个例子，

```sass
// define the variable
$purple: #6A67CE;

.purple-btn 
{ 
    text-align: center; 
    // re-defining the variable
    $purple: red;
    background-color: $purple; 
} 
.purple-text 
{ 
    color: $purple; 
}
```

上面的代码将编译成下面的 CSS 代码，

```sass
.purple-btn
{
    text-align: center;
    background-color: red;
}
.purple-text
{
    color: #6A67CE;
}
```

可以看到`.purple-btn`样式类里面的变量`$purple`的值是**红色**而不是 **#6A67CE** ，这是变量范围的结果。

### `!global`开关

您可以使用`!global`开关在范围内定义全局变量。但是不建议这样做，因为使用！从任何选择器中定义全局变量的全局开关将改变整个样式表的变量值。让我们举个例子。

```sass
// define the variable
$purple: #6A67CE;

.purple-btn 
{ 
    text-align: center; 
    // re-defining the variable
    $purple: red !global;
    background-color: $purple; 
} 
.purple-text 
{ 
    color: $purple; 
}
```

上面的代码将编译成下面的 CSS 代码，

```sass
.purple-btn
{
    text-align: center;
    background-color: red;
}
.purple-text
{
    color: red;
}
```

正如您在上面的代码中看到的，使用`!global`开关，我们可以更改整个样式表的变量值。

* * *

* * *