# SASS 支持的值类型

> 原文：<https://www.studytonight.com/sass/sass-supported-value-types>

SASS 支持在样式表中定义样式规则时使用的不同值类型。SASS/SCSS 中支持的大多数值类型都直接来自 CSS。

理解值类型非常重要，因为所有变量都保存值，所有表达式都计算值，所有运算符都对值进行操作，因此在本教程中，我们将介绍 SASS/SCSS 支持的所有值类型。

以下是 SASS/SCSS 支持的值类型:

1.  民数记

2.  用线串

3.  彩色

4.  布尔值

5.  空值

6.  值列表

7.  地图

让我们为每种值类型举几个例子，以了解它们在何时何地被使用。

## SASS 号码

SASS 数字是有或没有单位的数值。SASS 支持 CSS 中支持的所有单元。

这里有几个例子，

```sass
@debug 100; /* 100 */
@debug 0.8; /* 0.8 */
@debug 16px; /* 16px */
```

### 安全系统编号:单位

SASS 在对相似单元执行任何操作时，会自动对它们执行转换。此外，如果我们对不同单位或相同单位的两个数字进行乘法或除法运算，也会对它们的单位进行运算，因此`px * px`变成 **px 平方**。

让我们举个例子:

```sass
@debug 4px * 6px; /* 24px*px (read "square pixels") */
@debug 5px / 2s; /* 2.5px/s (read "pixels per second") */
```

另外，如上所述**在兼容单元上执行操作时，SASS 会自动将其覆盖**，对于不兼容版本**，SASS 会给出错误**。

```sass
/* CSS defines one inch as 96 pixels. */
@debug 1in + 6px; /* 102px or 1.0625in */

@debug 1in + 1s;

/*     ^^^^^^^^
* Error: Incompatible units s and in.
*/
```

## SASS 字符串

SASS 字符串只不过是一个字符序列。SASS 支持**带引号的字符串**，它只不过是用单引号或双引号括起来的字符序列，以及**不带引号的字符串**，它们是 CSS 标识符，如**粗体**等。

让我们举几个例子，

```sass
@debug "Helvetica Neue"; /* "Helvetica Neue" */
@debug bold; /* bold */
```

要逃离任何字符串，我们可以使用`\` **符号**。例如，

```sass
@debug "\""; /* '"' */
@debug \.widget; /* \.widget - dot symbol escaped */
```

## 色彩

就像 CSS 一样，在 SASS/SCSS 的样式表中也有很多不同的颜色表示方式。Sass 颜色可以写成十六进制代码(`#f2ece4`或`#b37399aa`)、 [CSS 颜色名称](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords) ( `midnightblue`、`transparent`)或函数`rgb()`、`rgba()`、`hsl()`和`hsla()`。

让我们举几个例子，

```sass
@debug #f2ece4; /* #f2ece4 */
@debug #b37399aa; /* rgba(179, 115, 153, 67%) */
@debug midnightblue; /* #191970 */
@debug rgb(204, 102, 153); /* #c69 */
@debug rgba(107, 113, 127, 0.8); /* rgba(107, 113, 127, 0.8) */
@debug hsl(228, 7%, 86%); /* #dadbdf */
@debug hsla(20, 20%, 85%, 0.7); /* rgb(225, 215, 210, 0.7) */
```

## SASS 布尔:`true`和`false`

SASS 布尔值是逻辑值`true`和`false`。这些通常是使用**等式或关系运算符**的结果。让我们举几个例子，

```sass
@debug 1px == 2px; /* false */
@debug 1px == 1px; /* true */
@debug 10px < 3px; /* false */
```

SASS 布尔值在编写用于 [`@if`和`@else` AT 规则 s](https://www.studytonight.com/sass/sass-if-else-and-else-if-atrule) 的表达式时非常有用，用于根据条件控制控制流。

## SASS `null`

值`null`是其类型的唯一值。它表示缺少一个值，通常由[函数](https://www.studytonight.com/sass/sass-function-atrule)返回，表示缺少一个结果。例如，

```sass
@debug &; /* null */
```

## SASS 列表

是的，SASS 支持列表，也提供了遍历这些列表的 AT 规则，比如[`@for``@each`和`@while` AT 规则 s](https://www.studytonight.com/sass/sass-for-each-and-while-atrule) 。存储在列表中的值应该是由逗号或空格隔开的**只要它们是一致的。**

您可以通过将值括在方括号甚至不带方括号的**中来定义列表。**

一个 SASS 列表可以有零个值、一个值或多个值。此外，SASS 中的列表是**不可变的**，这意味着一旦定义它们就永远不会改变值，每次您改变任何值，都会创建一个新的列表。

定义[混合](https://www.studytonight.com/sass/sass-mixins-and-include)或[函数](https://www.studytonight.com/sass/sass-function-atrule)时，可以定义列表是参数。

让我们举个例子:

```sass
$listvar: 1, 2, 3;

/* using square barackets */

$sides: ["left", "right", "top", "bottom"]; 
```

## SASS 地图

SASS 映射保存**键值对**，在这里可以使用键访问值。以下是在 SASS 中创建地图的**语法:**

```sass
(<expression>: <expression>, <expression>: <expression>)
```

`:`之前的表达式是**键**，之后的表达式是与该键关联的**值**。**键必须是唯一的**，但是**值可以是重复的**。

此外，定义地图需要括号`()`。要定义一个空地图，我们使用`()`。

SASS 地图也是**不可变的**。

让我们举个例子，

```sass
$font-weights: ("regular": 400, "medium": 500, "bold": 700);
```

这些是 SASS/SCSS 支持的各种不同的值类型，您可以在编写带有 mixins、函数、流控制和循环的动态样式表时使用它们。用 SASS 可以做的事情太多了。

* * *

* * *