# SASS/SCSS 运算符

> 原文：<https://www.studytonight.com/sass/sassscss-operators>

**SASS** 为我们提供了一组运算符，范围从`+`(加法)、`-`(减法)、`/`(除法)等数学运算，以及各种其他类型的运算符，如`==`(相等)、`!=`(不相等)、`and`运算符、`or`运算符等。SASS 有一个相当标准的操作顺序，从最紧到最松。

通过为我们提供对 SASS 操作符的访问，SASS 使编写 CSS 规则变得很有趣，使用这些操作符，我们可以生成一个动态样式规则。如上所述，这些操作符的执行顺序是标准的，但是让我们举几个例子来理解同样的顺序。

```sass
@debug 1 + 2 * 3 == 1 + (2 * 3)  // true
@debug true or false and false == true or (false and false)  // true
```

不要担心`@debug`规则，它只是用来查看任何表达式的最终值，以便在没有获得所需输出的情况下进行调试。

如你所见，在表达式中使用数学运算符时，遵循了 BODMAS 的简单规则。在 SASS 中使用运算符时，我们也可以使用括号来构造任何表达式。括号内定义的操作总是在外部操作之前计算，例如:

```sass
@debug (1 + 2) * 3  // 6
@debug ((1 + 2) * 3 + 4) * 5  // 65
```

现在我们已经了解了运算符是如何评估的，让我们深入了解一下 SASS 中可用的各种不同类型的运算符。

## SASS 操作员

以下是 SASS 中可用的运算符类型。

1.  数学运算符

2.  等式运算符

3.  关系运算符

4.  字符串运算符

5.  布尔运算符

我们将逐一介绍它们，列出所有操作符以及一些示例。

## 数学算子

SASS 支持执行基本数学运算所需的所有数学运算符。

| 经营者 | 用法和说明 |
| --- | --- |
| `+` | `<expression> + <expression>`，将第一个表达式的值与第二个表达式相加。 |
| `-` | `<expression> - <expression>`，从第一个表达式中减去第二个表达式的值。 |
| `/` | `<expression> / <expression>`，第一个表达式的值除以第二个表达式的值。 |
| `*` | `<expression> * <expression>`，将第一个表达式的值乘以第二个表达式的值。 |
| `%` | 这是**模**运算符。`<expression> % <expression>`，返回第一个表达式的值除以第二个表达式的值的余数。 |

让我们举几个例子:

```sass
@debug 10s + 15s  // 25s
@debug 1in - 10px  // 0.8958333333in
@debug 5px * 3px  // 15px*px
@debug (12px/4px)  // 3
@debug 1in % 9px  // 0.0625in
```

我们也可以用**普通数字和任意单位的数字**像这样:

```sass
@debug 50px + 50  // 100px
@debug 12px * 10  // 120px
```

> 在 SASS 中，数学运算符用于**对 SASS 中使用的所有数据单元**执行运算，如 **px** 、中的**等，以及**颜色 Hexa 代码**，因此如果您对两个颜色 Hexa 代码执行任何数学运算，它将产生一些其他 Hexa 代码。此外，我们也可以使用`-`运算符来定义负值**，如 **-5px** 等(确保**`-`运算符和数字之间没有空格，如果代表负值。)**

此外，除了基本操作之外，`+`、`-`和`/`运算符也用于 SASS 中的字符串连接。

### 数学运算符示例:

让我们看几个例子来了解这些**运算符**的用法。以下示例使用加法、减法、乘法和除法运算符。

```sass
.main-division{
    margin: 100px + 200px;
    padding: 1000px / 100px - 10px;
    height: 5px * 3px;
    width: 1in % 9px;
} 
```

同样的，**加法**也可以用于 Hexa 色码，

```sass
.main-division{
    background-color: #111100+#001111;
}
```

在**编译**之后，结果 CSS 将是，

```sass
.main-division{
    background-color: #112211;
}
```

## 2.等式运算符

SASS 支持两个相等运算符，即**等于和不等于**。在下表中，我们列出了 SASS 中可用的两个等式运算符:

| 经营者 | 用法和说明 |
| --- | --- |
| `==` | 等于。`<expression> == <expression>`，返回第一个表达式的值是否等于第二个表达式的值。 |
| `!=` | 不等于。`<expression> != <expression>`，返回第一个表达式的值是否不等于第二个表达式的值。 |

运算符**对于不同类型的值**有不同的行为。所以要谨慎使用。

*   如果你在比较两个数字，那么如果它们具有相同的**值和相同的单位**或数据类型，那么它们是相等的。对于不同的单位，如果可能，SASS 会自动执行转换。

*   **如果颜色**具有相同的**红、绿、蓝和阿尔法值**，则它们是相等的。

*   `true`、`false`、`null`数据单元只等于自己。

*   类似的规则也适用于复杂类型，如列表和地图。所有存在于其中的值都被一个接一个地与值和单位进行比较。

让我们举个例子来看看 SASS 等式运算符的用法:

```sass
@debug 1px == 1px  // true
@debug 1px != 1em  // true
@debug 1 != 1px  // true
@debug 96px == 1in  // true. SASS performs automatic conversion
```

## 3.关系运算符

SASS 支持以下关系运算符:

| 经营者 | 用法和说明 |
| --- | --- |
| `<` | `<expression> < <expression>`，返回第一个表达式的值是否小于第二个表达式的值。 |
| `>` | `<expression> > <expression>`，返回第一个表达式的值是否大于第二个表达式的值。 |
| `<=` | `<expression> <= <expression>`，返回第一个表达式的值是否小于等于第二个表达式的值。 |
| `>=` | `<expression> >= <expression>`，返回第一个表达式的值是否大于等于第二个表达式的值。 |

让我们看几个使用 SASS 关系运算符的例子:

```sass
@debug 10 > 5  // true
@debug 11px < 21px  // true
@debug 96px >= 1in  // true
@debug 10px < 17  // true
```

## 4.字符串运算符-字符串连接

SASS 中没有执行字符串操作的特殊运算符。当与字符串一起使用时，数学运算符`+`、`-`和`/`执行字符串运算。

*   `<expression> + <expression>`返回包含两个表达式值的字符串。如果其中一个值是带引号的字符串，则结果将被加上引号；否则，它将被取消引用。

*   `<expression> / <expression>`返回包含两个表达式值的不带引号的字符串，用`/`分隔。

*   `<expression> - <expression>`返回包含两个表达式值的不带引号的字符串，用`-`分隔。这是一个遗留操作符，但仍然有效。

让我们举几个例子，

```sass
font-family: "Arial" + " Helvetica" + " sans-serif";  // output will be Arial, Helvetica, sans-serif

font-size: 10px / 5px;   // output will be 10px/5px and not 2 px

font-family: sans-+serif;   // output will be sans-serif

font-family: sans - serif;   // output will be sans-serif
```

## 5.逻辑运算符

逻辑运算符如`and`、`or`、`not`在 SASS 中也有。

*   `not <expression>`返回所提供表达式的否定或相反值。
*   如果**左表达式和右表达式的值都是`true`，则`<expression> and <expression>`返回`true`，如果其中一个是`false`，则返回`false`。**
***   如果**表达式的值为`true`，则`<expression> or <expression>`返回`true`，如果两者都为`false`，则返回`false`****

 ****下面给出的示例显示了这些运算符的用法:

```sass
@debug not true; // false

@debug not false; // true

@debug true and true; // true

@debug true and false; // false

@debug true or false; // true

@debug false or false; // false
```

因此，在本教程中，我们了解了各种 SASS 运算符。您可以使用不同的 SASS 操作符来编写动态 CSS 规则，并使您的样式规则更加实用。

* * *

* * *****