# SASS `@use`规则

> 原文：<https://www.studytonight.com/sass/sass-use-atrule>

SASS `@use` AT 规则用于在样式表中加载其他样式表中定义的混合、函数和变量。在引入`@use` AT 规则之前，SASS `@import` AT 规则是用于此目的的。使用 SASS`@use`at-规则使我们能够将样式表分成多个有意义的小样式表，然后使用 SASS`@use`at-规则在彼此中使用它们。

我们可以在单独的样式表文件中定义 SASS 混合和函数，在单独的样式表文件中定义带有默认值的变量，然后在主样式表中，我们可以使用 SASS `@use` AT 规则来使用其他样式表中定义的混合、函数和变量等。

包含的样式表被称为**模块**

## SASS `@use`:语法

以下是使用`@use` AT 规则的语法:

```sass
@use '<URL for other stylesheet>'
```

例如，如果我们有一个名为的样式表，那么我们可以使用下面的语句将它包含在我们的样式表中，

```sass
@use 'mixinstyle.sass'
```

这里需要注意几点:

1.  当我们使用`@use` AT 规则在另一个样式表中包含一个样式表时，样式规则将在编译后的 CSS 中只包含一次。

2.  `@use`语句应该是样式表中的第一条语句。在`@use`语句之前可以有`@forward` AT 规则或变量声明。但在此之前不应指定任何样式规则。

让我们举个例子，

```sass
// style/columns.sass
row
  margin: 0 auto
  line-height: 0

col-12
  width: 100%
```

```sass
// styles/textstyle.sass

h1
  font-size: 36px

p 
  font-size: 14px
```

```sass
// main.sass
@use 'style/columns'
@use 'style/textstyle'
```

## SASS `@use`:命名空间

当我们使用`@use`at-规则将一些样式表包含到样式表中时，包含的样式表的**名称(文件名)作为没有扩展名的名称空间**。

要使用`@use` AT 规则从样式表中包含的另一个样式表(模块)访问变量、混合和函数，我们必须遵循以下语法:

```sass
<namespace>.<variable> 
/* or  */
<namespace>.<function>()
/* or  */
@include <namespace>.<mixin>()
```

其中 **<命名空间>** 是命名空间，也就是包含的样式表的文件名。

例如，如果我们有以下名称为 **round.sass** 的样式表，

```sass
/* css/round.sass   */
$radius: 3px

@mixin rounded
  border-radius: $radius
```

我们可以在主样式表中包含上面的样式表，

```sass
/* style.sass */
@use "css/round"

.button
  @include round.rounded
  padding: 5px + round.$radius
```

上述代码将被编译成以下 CSS 代码:

```sass
.button {
  border-radius: 3px;
  padding: 8px;
} 
```

在下一节中，我们将学习如何为包含的样式表提供自定义命名空间。

### 提供自定义命名空间

当使用`@use` AT 规则将任何外部样式表包含到样式表中时，我们也可以提供一个自定义名称空间。以下是提供自定义命名空间的语法:

```sass
@use "<url>" as <namespace>
```

如果我们必须在 round.sass 样式表中包含一些自定义名称空间，我们可以按如下方式进行:

```sass
/* style.sass */
@use "css/round" as r

.button
  @include r.rounded
  padding: 5px + r.$radius
```

## 什么是偏分？

如果我们定义一个名称以**下划线** ( `_`)开头的样式表，那么在 SASS 中这样的文件被称为 **Partials** ，这意味着这些文件本身没有任何意义，不应该被编译。Partials 仅用于包含在使用`@use` AT 规则的其他样式表中。

让我们举个例子，试着理解这一点。

例如，如果我们有以下名称为 **_round.sass** 的样式表，那么这个样式表将不会被编译，只能包含在其他样式表中。

```sass
/* css/_round.sass   */
$radius: 3px

@mixin rounded
  border-radius: $radius
```

我们可以在主样式表中包含上面的样式表，

```sass
/* style.sass */
@use "css/_round"

.button
  @include round.rounded
  padding: 5px + round.$radius
```

## 使用:索引文件

如果我们将样式表命名为 index.sass 或 _index.sass(在 Partials 的情况下)，那么只需用@use AT 规则指定文件夹的名称，就可以包含 index.sass 或 _index.sass 样式表。这是 SASS 的默认行为。如果只提供文件夹名称，它会将文件夹中的 index.sass 或 _index.sass 文件作为默认样式表。

例如，如果我们在 **css** 文件夹中有以下名称为 **_index.sass** 的样式表。

```sass
/* css/_round.sass   */
$radius: 3px

@mixin rounded
  border-radius: $radius
```

我们可以将上面的样式表包含在我们的主样式表中，甚至不需要提供样式表的名称，只需提供文件夹名称就足够了，

```sass
/* style.sass */
@use "css"

.button
  @include round.rounded
  padding: 5px + round.$radius
```

这是来自于野蛮行为规则。

* * *

* * *