# SASS `@forward`规则

> 原文：<https://www.studytonight.com/sass/sass-forward-atrule>

SASS @forward AT 规则用于在样式表包含在另一个样式表中时，使用@use AT 规则公开样式表中包含的模块(样式表)的成员。

让我们举个例子来理解这一点。如果我们有一个样式表 **_padding.sass** ，它包含了用于填充的所有样式规则(混合、变量等)，并且我们使用`@use`at-规则将它包含在我们的样式表 **style.sass** 中。现在，如果我们必须创建另一个样式表，比如说 **newstyle.sass** ，我们使用`@use`at-规则在这个样式表中包含 **style.sass** ，那么我们将无法访问 **newstyle.sass** 样式表中的 **_padding.sass** 样式表的成员。

![SASS @forward AT 规则](img/fc41ab665ad5433319742100465849e0.png)

因此，如果我们希望样式表 **_padding.sass** 的成员可以在 **newstyle.sass** 文件中访问，我们应该使用 SASS`@forward`at-规则来导入 **style.sass** 文件中的 **_padding.sass** 样式表。

`@forward`at-规则将使 **_padding.sass** 文件的成员在 style.sass 文件中可用，就像它们是在 **style.sass** 文件中定义的一样，因此如果任何其他样式表将包含 **style.sass** 文件，使用`@use`at-规则，也将能够访问 **_padding.sass** 文件的成员。

## SASS `@forward`:语法

`@forward`at-规则的语法与`@use`at-规则相同。

```sass
@forward 'URL-OF-STYLESHEET'
```

如果我们使用`@forward`at-规则，我们可以跳过使用`@use`at-规则。我们也可以同时使用`@use`和`@forward` AT 规则来包含一个样式表，因为 SASS 引擎只会包含它一次。

## 工作

SASS `@forward` AT 规则也像`@use` AT 规则一样工作，将一个样式表的成员包含到另一个样式表中。但是`@use` AT 规则隐藏了包含样式表的成员，不允许进一步导入，但是`@forward` AT 规则通过使您能够形成样式表导入的层次结构，使包含样式表也可用于进一步导入。

如果你同时写了`@forward`和`@use` AT 规则，你应该先写`@forward` AT 规则，然后写`@use` AT 规则。

让我们举个例子，看看这是如何在 SASS 中使用的:

```sass
/* style/_list.sass */

@mixin list-style
  margin: 0
  padding: 0
  list-style: none
```

```sass
/* main.sass */

@forward "src/list"
```

```sass
/* styles.sass */
@use "main"

li
  @include main.list-style
```

这将被编译成以下 CSS:

```sass
li {
  margin: 0;
  padding: 0;
  list-style: none;
}
```

要检查`@forward`和`@use` AT 规则之间的区别，请尝试将 **main.sass** 文件中的`@forward "src/list"`语句更改为`@use "src/list"`，然后编译 CSS，您将看到样式规则不会被导入。

## SASS `@forward`:命名空间和添加前缀

我们知道，当一个样式表包含在另一个样式表中时，SASS 会创建一个名称空间，即样式表的文件名，我们已经在 SASS `@use` AT 规则中详细介绍了这一点。现在，我想到了几个问题:

1.  *使用`@forward`at-规则包含的模块(样式表)的名称空间是什么？*

2.  *它是否与包含它的样式表的命名空间相同？*

3.  *我们对此有什么控制吗？*

正如我们在上面的例子中看到的，是的，使用`@forward`模块包含的文件将使用与包含它的样式表相同的名称空间来访问，因为`@forward`at-规则使正在导入的模块的成员成为导入它的样式表的成员。

在上面的代码示例中，我们在 main.sass 中导入了 **_list.sass** 文件，该文件随后被导入到**style . sass**中，其中我们使用主命名空间访问了 **_list.sass** 文件的成员，因为 **_list.sass** 文件是使用`@forward` AT 规则导入到 **main.sass** 文件中的。

但是，我们可以使用`@forward`at-规则为导入的模块的所有成员名称添加前缀。以下是添加前缀的语法:

```sass
@forward "<url>" as <prefix>-*
```

让我们修改上面的例子，在导入 **_list.sass** 文件时使用前缀。

```sass
/* style/_list.sass */

@mixin stylish
  margin: 0
  padding: 0
  list-style: none
```

```sass
/* main.sass */

@forward "src/list" as list-*
```

这会将前缀**列表-** 添加到样式表 **_list.sass** 的所有成员(所有混合、变量、函数等)的名称中。

```sass
/* styles.sass */
@use "main"

/* name of mixin is stylish but now we will call it as list-stylish */
li
  @include main.list-stylish
```

这将被编译成以下 CSS:

```sass
li {
  margin: 0;
  padding: 0;
  list-style: none;
}
```

## 向前:控制可见性

在将一个模块(样式表)导入到另一个样式表中时，我们可以使用`@forward` AT 规则语句中的`hide`和`show`关键字以及成员名称来控制在连续导入中所有成员应该进一步可用的内容。

以下是它的语法:

```sass
@forward "<url>" hide <members...> 
/*  or  */ 
@forward "<url>" show <members...>
```

下面我们有一个样式表 **_button.sass** ，

```sass
/* css/_button.sass */ 

$btn-font: sans-serif

@mixin btn
    padding: 10px
    border-radius: 5px
    text-decoration: none

@mixin btn-success
    @include btn
    background-color: green 
```

为了从上面的样式表中隐藏一些混合和变量，

```sass
/* main.sass */

@forward "css/button" hide btn, $btn-font
```

所以，这就是 SASS `@forward` AT 规则。

* * *

* * *