# SASS `@function`规则

> 原文：<https://www.studytonight.com/sass/sass-function-atrule>

SASS `@function` AT 规则用于定义具有复杂操作****的函数，接受参数并返回结果**。SASS 函数用于声明复杂的公式和行为，然后可以在整个样式表中使用。**

 **## SASS `@function`:语法和`@return`at-规则

SASS 函数是使用@函数 AT 规则定义的。以下是语法，

```sass
@function <name>(<arguments...>) { ... }
```

与 [SASS mixins](https://www.studytonight.com/sass/sass-mixins-and-include) 不同，SASS 函数必须有一个**返回语句**，该语句是使用`@return`at-规则指定的，用于返回函数调用的结果。

所以整个语法是这样的，

```sass
@function <name>(<arguments...>) {
    // function definition
    @return <somevalue>
}
```

`@return` AT 规则只能在函数定义中使用，**函数的执行在遇到`@return`语句**时结束，用`@return` AT 规则指定的函数结果返回给调用语句。

## 带参数的函数

就像我们可以在 [SASS mixins](http://www.studytonight.com/sass/sass-mixins-and-include) 中提供参数一样，我们也可以在定义 SASS 函数时这样做。

让我们定义一个简单的函数，将提供给它的两个参数相加，并返回相加的结果。

```sass
@function add($var1, $var2) {
    $var3 : $var1 + $var2;
    @return $var3;
}
```

这个函数可以在样式表中使用正常的 CSS 函数语法，如下所示，

```sass
div{
    height: add(300, 400) * 1px;
}
```

正如您在上面的 CSS 代码中看到的，我们必须在调用函数时为参数指定值。

### 函数-带默认值的参数

我们还可以在定义函数时设置参数的默认值，这样如果用户没有传递任何值，就会使用参数的默认值。让我们修改上面使用的同一个例子:

```sass
@function add($var1, $var2: 400) {
    $var3 : $var1 + $var2;
    @return $var3;
} 
```

在调用函数时，我们可以传递一个或两个参数。如果传递了一个参数，则**其他参数将采用默认值**。如果在调用函数时传递了这两个参数，那么函数调用时提供的值将覆盖 defualt 值。

```sass
div {
    height: add(300) * 1px;
} 
```

### 关键字参数

在调用函数时，我们可以提供参数的值以及函数定义中指定的参数名称。因此，除了按顺序或数量传递参数，还可以按名称传递参数。

让我们看看如何调用上面定义的`add`函数，方法是在调用函数时提供关键字参数。

```sass
div {
    height: add($var2: 300, $var1: 400) * 1px;
}
```

### SASS 函数-接受任意参数

有时我们需要在不同的场景中向一个函数传递不同数量的参数。对于这种情况，我们可以**定义我们的函数接受任意数量的参数**，这可以用我们在 mixins 中看到的相同方式来完成，即当**最后一个参数以三个点** `(ex: $abc...)`结束时，这被称为**参数列表**。因此，当调用这个函数时，在函数调用时提供的所有参数都可以在函数参数中作为值列表使用，然后可以在函数中使用。

让我们举个例子，

```sass
@function min($numbers...) {
    $min: null;
    @each $number in $numbers {
        @if $min == null or $number < $min {
            $min: $number;
        }
    }
    @return $min;
}

.micro {
    width: min(50px, 30px, 100px);
} 
```

因此，在本教程中，我们了解了 SASS 函数，并涵盖了各种不同的示例，在这些示例中，我们传递了参数、带有默认值的参数以及任意数量的参数。

* * *

* * ***