# SASS `@extend`规则的继承

> 原文：<https://www.studytonight.com/sass/sass-extend-atrule-sass-inheritance>

SASS `@extend` AT 规则**允许在样式表中继承样式规则**。如果您希望在样式表中用另一个类的所有样式规则以及它自己特定的样式规则来定义一个类，我们可以使用 SASS `@extend` AT 规则。

SASS `@extend` AT 规则将让你在另一个选择器中使用一个选择器的 CSS 属性。

## SASS `@extend`:语法

要使用@extend AT 规则，我们应该遵循以下语法:

```sass
@extend <selector>
```

让我们举一个简单的 SASS 例子，试着理解它的用法。

让我们为*错误*、*警告*和*成功*消息编写一些样式规则。下面写的课。`message-shared`保存基本的样式规则，然后是。消息，。成功。错误和。警告

```sass
.message-shared 
{
	border: 1px solid #ccc
	padding: 10px
	color: #333
} 
```

现在让我们将**扩展到其他类。**

```sass
.message 
{
	@extend .message-shared
}
.success 
{
	@extend .message-shared
	border-color: green
}
.error 
{
	@extend .message-shared
	border-color: red
}
.warning 
{
	@extend .message-shared
	border-color: yellow
} 
```

## SASS `@extend`和占位符选择器

占位符选择器的名称前面有一个`%`符号。当我们定义占位符选择器时，我们不能在我们的 HTML 中使用它，但它只能用于继承，这意味着其他选择器可以使用`@extend` AT 规则继承它的样式。

让我们举一个简单的例子:

```sass
%btn 
{
	border: 1px solid #ccc
	padding: 10px
	color: #333
}
.btn-success 
{
	@extend %btn
    background-color: green
}
.btn-error 
{
	@extend %btn
	background-color: red
}
```

编译后的 CSS 代码看起来像，

```sass
.btn-success 
{
	border: 1px solid #ccc;
	padding: 10px;
	color: #333;
    background-color: green;
}
.btn-error 
{
	border: 1px solid #ccc;
	padding: 10px;
	color: #333;
	background-color: red;
}
```

正如您所看到的，在编译后的 CSS 中，我们没有占位符选择器，只有它在扩展了它的样式类中的样式规则。

### 个人占位符:

我们甚至可以在 SASS 中通过添加一个`-`**连字符或一个**下划线** `_`作为选择器名称的前缀来定义私有占位符。这种占位符选择器变成私有的，只能通过在同一个样式表中编写样式类来扩展。**

 **## SASS `@extend`:可选扩展

如果您使用`@extend`at-规则来扩展任何选择器，并且如果它不存在于样式表中，那么 SASS 将给出错误。因此，在使用@extend AT 规则时应该小心，因为如果更改被扩展的选择器的名称，那么可能会导致错误。

为了解决这个问题，如果您希望样式表代码不会出错，您可以使用！@extend 语句末尾的可选。这将使样式规则的继承成为可选的，如果被扩展的选择器不可用，SASS 仍然不会给出错误。

## SASS `@extend`与`@mixin` AT 规则

SASS mixins 也是用来定义 SASS 中的可重用样式，就像 SASS 扩展一样，那么什么时候应该使用`@mixin` AT 规则，什么时候应该使用`@extend` AT 规则呢？

答案是，当我们想要使用参数配置样式规则时，在这种情况下，我们应该使用 SASS mixins，而如果我们的需求是重用静态样式规则(只是一大块样式)，那么在这种情况下，我们可以在样式表中使用 SASS 扩展。

* * *

* * ***