# SASS `@if`，`@else`和`@else if`规则

> 原文：<https://www.studytonight.com/sass/sass-if-else-and-else-if-atrule>

SASS 还通过提供`@if`、`@else`和`@else if` AT 规则来支持流控制，这些规则可以在 SASS 中通过在样式表中实现条件来编写复杂的代码。

在编写 [SASS 函数](https://www.studytonight.com/sass/sass-function-atrule)或 [SASS 混合函数](https://www.studytonight.com/sass/sass-mixins-and-include)时，我们可以根据包含混合函数或调用函数时提供的参数值定义不同的样式规则。这可以使用 SASS `@if`和`@else`AT 规则 s**来完成，这使得编写更动态的样式规则**变得容易。

## 自动规则

SASS `@if` AT 规则可用于根据条件控制样式块的执行。

### SASS `@if`:语法

使用`@if` AT 规则的语法非常简单，

```sass
@if <expression> { 

    /* statements */ 

}
```

这里，如果表达式评估为**真**，则评估与`@if`at-规则相关联的块，编译成 CSS 样式规则，如果表达式评估为**假**，则跳过**块**。

### SASS `@if`:示例

让我们举个例子来看看`@if` AT 规则的作用。

```sass
@mixin borderstyle($color, $round: false) {
  border-color: $color;
}

  @if $round {
    border-radius: 5px;
  }

.blue-border {
  @include borderstyle(blue, $round: false);
}
.red-border-round {
  @include borderstyle(red, $round: true);
}
```

这将被编译成以下 CSS:

```sass
.blue-border {
  border-color: blue;
}

.red-border-round {
  border-color: red;
  border-radius: 5px;
}
```

## 自动规则

SASS `@else` AT 规则与`@if` AT 规则一起用于**提供替代块**，如果`@if`表达式返回 false ，则执行**。`@else` AT 规则是可选的，其**不是强制的**与`@if` AT 规则一起使用。**

### SASS `@else`:语法

使用`@else` AT 规则的语法非常简单，

```sass
@else { 

    /* statements */ 

}
```

<u>**注意:**</u> 如果没有`@if` AT 规则，就不能使用 SASS `@else` AT 规则。它应该始终遵循`@if`的 AT 规则。

### SASS `@else`:示例

让我们举个例子来看看`@else` AT 规则的作用。

```sass
$light-background: #fefefe;
$light-text: #000000;
$dark-background: #000000;
$dark-text: #fefefe;

@mixin theme-colors($light-theme: true) {
  @if $light-theme {
    background-color: $light-background;
    color: $light-text;
  } @else {
    background-color: $dark-background;
    color: $dark-text;
  }
}

.banner {
  @include theme-colors($light-theme: true);
}
```

这将被编译成以下 CSS:

```sass
.banner {
  background-color: #fefefe;
  color: #000000;
}
```

## 自动规则

要定义多个条件流，我们可以使用`@else if` AT 规则和`@if` AT 规则。可以在@if AT 规则和@else AT 规则之间使用 SASS @else if AT 规则来包含多个条件样式块。

### SASS `@else if`:语法

@ else if-AT 规则的语法类似于@ if-AT 规则的语法:

```sass
@else if <expression> { 

    /* statements */ 

}
```

就像`@if` AT 规则一样，`@else if` AT 规则也取一个表达式作为条件，如果`@if` AT 规则的表达式求值为 **false** ，而`@else if`表达式求值为 **true** ，则编译`@else if`样式块。

此外，`@else if`应该始终与`@if` AT 规则一起使用，就像`@else` AT 规则一样。

### SASS `@else if`:示例

让我们举个例子来看看`@else if` AT 规则的作用。

```sass
@mixin text-effect($val) 
{
   @if $val == danger 
      {
         color: red;
      }
   @else if $val == alert 
      {
         color: yellow;
      }
   @else if $val == success 
      {
         color: green;
      }
   @else 
      {
         color: black;
      }
}
```

在上面的例子中，我们使用`$val`作为参数来确定**的颜色是否应该是危险、警告等**。

下面我们再举一个例子，这里我们用了一个 [**SASS mixin**](https://www.studytonight.com/sass/sass-mixins-and-include) **为不同的边框样式**:

```sass
$light: 1px solid black;
$medium: 3px solid black;
$heavy: 6px solid black;
$none: none;

@mixin border-stroke($val) 
{
  @if $val == light 
  {
     border: $light;
  }
  @else if $val == medium 
  {
     border: $medium;
  }
  @else if $val == heavy 
  {
     border: $heavy;
  }
  @else 
  { 
     border: $none;
  }
}

#box 
{
  width: 150px;
  height: 150px;
  background-color: red;
  /* calling the mixin */
  @include border-stroke(heavy);
}
```

上面的 SASS 代码将被编译成下面的 CSS 代码:

```sass
#box 
{
  width: 150px;
  height: 150px;
  background-color: red;
  border: 6px solid black;
}
```

因此，在本教程中，我们学习了如何在 SASS 中使用样式表中的`@if`、`@else`和`@else if`at-规则来实现流控制，以使样式表更加动态。

* * *

* * *