# SASS `@for`、`@each`和`@while`规则

> 原文：<https://www.studytonight.com/sass/sass-for-each-and-while-atrule>

SASS 提供了像`@for`、`@each`和`@while`这样的 AT 规则，用于在样式表中实现循环。如果你想为 HTML 列表等定义重复的样式规则，那么我们可以使用 SASS 循环。

正如本教程的标题所表明的，在 SASS 中有 3 个 AT 规则可用于设置重复的样式规则创建:

1.  反制规则

2.  反制规则

3.  反制规则

让我们一个接一个地介绍它们，包括它们的语法和一些例子。

## 在规则:

SASS `@for` AT 规则的工作方式与任何编程/脚本语言中的循环的工作方式相同。它用于迭代和编译每次具有不同值的样式块。

### SASS `@for`:语法

以下是在 SASS SASS 中使用`@for` AT 规则的语法:

```sass
@for <variable> from <expression> to <expression> { ... } 
/* or */ 
@for <variable> from <expression> through <expression> { ... }
```

正如您在上面的语法中看到的，在 SCSS/SASS 中有两种使用@for AT 规则的方式:

1.  如果我们指定`from <exp> to <exp>`，那么从第一个表达式的**结果到第二个表达式的**结果的每个数字都被分配给变量，但是**最终数字被排除在外**。

2.  如果我们指定`from <exp> through <exp>`，那么从第一个表达式的结果开始到第二个表达式的结果的每个数字都被分配给变量，但是**的最终数字包括**。

### SASS `@for`:示例

让我们举一个简单的例子来理解如何使用它。下面我们有一个简单的带有段落标签的 HTML 代码。

```sass
<p class="paragraph-1">Sassy way</p>
<p class="paragraph-2">Sassy way</p>
<p class="paragraph-3">Sassy way</p>
<p class="paragraph-4">Sassy way</p>
<p class="paragraph-5">Sassy way</p> 
```

现在如果需要为段落标签中使用的几乎相同的样式类编写一些样式，那么**总共应该编写 5 个样式块**。

在这种情况下，如果使用用于循环的**，则该任务需要较少的努力。另外，在样式规则中，我们需要**通过将 10px** 乘以段落编号来增加每个段落的字体大小。**

 **查看以下 **SCSS 代码:**

```sass
@for $i from 1 to 6 
{
  .paragraph-#{$i} 
  {
    font-size: 10px*$i;
  }
}
```

上面的例子使用了**开始到结束方法**，所以变量`$i`从 **1 到 5** 。如果相同的`@for` AT 规则以**开始到**结束的形式编写，那么变量`$i`将从 **1 到 6** 取值。

从上面的 **SCSS** 代码生成的 **CSS** 看起来像:

```sass
.paragraph-1
{
   font-size: 10px;
}
.paragraph-2
{
   font-size: 20px;
}
.paragraph-3
{
   font-size: 30px;
}
.paragraph-4
{
   font-size: 40px;
}
.paragraph-5
{
   font-size: 50px;
}
```

## 在规则:

SASS SASS`@each` AT 规则也类似于`@for` AT 规则，唯一的区别在于它是**用来迭代一个列表的值并映射**。

### SASS `@each`:语法

以下是使用`@each` AT 规则的语法:

```sass
@each <variable> in <expression> { ... }
```

表达式返回一个列表，并为列表中的每个元素计算样式块，这些元素被一个接一个地分配给给定的变量名。

### SASS `@each`:示例

让我们借助一个例子来理解这一点。考虑**三个 div 元素**，其中每个 div 的背景颜色需要借助`@each` AT 规则来设置。

```sass
<div class="blue-background"></div>
<div class="black-background"></div>
<div class="yellow-background"></div>
```

首先，让我们通过使用一个列表来完成这个任务:

```sass
@each $color in blue, black, yellow 
{
  .#{$color}-background 
    {
       background-color: $color;
    }
}
```

映射方式与列表有点不同，如下所示:

```sass
/* $colors is a map here */
$colors: (color1: blue, color2: black, color3: yellow);
@each $key, $value in $colors 
{
  .#{$color}-background 
  {
    background-color: $value;
  }
}
```

这两种情况的编译后的 **CSS** 如下所示:

```sass
.blue-background
{
  background-color: blue;
}
.black-background
{
  background-color: black;
}
.yellow-background
{
  background-color: yellow;
}
```

## 在规则:

SASS `@while`类似于任何其他编程/脚本语言中的 **while 循环**。它一直执行到指定的表达式计算结果为真。

### SASS `@while`:语法

以下是`@while` AT 规则的语法:

```sass
@while <expression> { ... }
```

用`@while` AT 规则定义的样式块将被求值，直到表达式求值为 **true** 。在使用@ while-AT 规则进行循环时，我们应该小心，因为这很容易导致无限循环。

### SASS `@while`:示例

让我们考虑在`@for`中使用的具有五个段落标签的 HTML 的同一个例子。

```sass
<p class="paragraph-1">Sassy way</p>
<p class="paragraph-2">Sassy way</p>
<p class="paragraph-3">Sassy way</p>
<p class="paragraph-4">Sassy way</p>
<p class="paragraph-5">Sassy way</p> 
```

现在每个段落的字体大小需要根据段落编号来增加。这可以使用**@同时使用**来完成，如下图所示:

```sass
$x: 1;
@while $x < 6 
{
    .paragraph-#{$x} 
    {
        font-size: 10px*$x;
    }
    $x: $x + 1;
}
```

生成的 **CSS** 会是这样的:

```sass
.paragraph-1
{
   font-size: 10px;
}
.paragraph-2
{
   font-size: 20px;
}
.paragraph-3
{
   font-size: 30px;
}
.paragraph-4
{
   font-size: 40px;
}
.paragraph-5
{
   font-size: 50px;
}
```

因此，在本教程中，我们在 SASS/SCSS 中学习了 3 种不同的循环技术来迭代生成样式规则。如果你有一种情况，你必须定义几乎相似的样式类，在样式上做一些改变，比如 **h1、h2、h3、**等等，你可以使用这些类。标签或者在 bootstrap CSS 的情况下，我们有列 **col-1、col-2、col-3** 等。有许多用例可以使用它们。

* * *

* * ***