# SASS `@error`、`@warn`和`@debug`规则

> 原文：<https://www.studytonight.com/sass/sass-error-warn-and-debug-atrule>

当我们在 SASS/SCSS 中编写可以接受参数的 mixins 和函数时，参数类型不匹配的几率会增加，我们必须以某种方式处理这种情况。我们可以使用 SASS/SCSS `@error`、`@warn`和`@debug` AT 规则向用户显示消息，指出提供的参数类型不正确。

在本教程中，我们将介绍以下 AT 规则:

1.  `@error`at-规则

2.  `@warn`at-规则

3.  `@debug`at-规则

让我们从@error AT 规则开始。

## 自动规则

SASS/SCSS `@error`在**混搭**和**功能**中都有帮助。假设我们需要确保在函数或 mixins 中传递的参数是正确的，为此，我们可以使用`@error` at-rul 来显示错误消息，以防证明了错误的数据类型，并且**停止代码的编译**。

使用@error AT 规则的语法是:

```sass
@error <expression>
```

让我们看一个例子，我们需要传递一个参数来决定 float 属性应该是**左**还是**右**。

```sass
mixin setcssfloat($floatvalue) {
    @if $floatvalue !=left or $floatvalue !=right {
        @error "Property #{$property} must be either left or right.";
    }
}

$top: top;

@include setcssfloat($top);
```

显示的错误消息如下所示:

错误:“属性顶部必须是左侧或右侧。”
？
3？@错误“属性#{$property}必须是左侧或右侧。”；
？^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
？
示例. scss 3:5 setcssfoard()
示例. scss 19:3 根样式表

## 自动规则

SASS `@warn` AT 规则用于向用户显示警告，如果用户正在发送一些不正确的值，或者可能是一些不再被 mixin 或函数接受的值。`@warn` AT 规则并没有完全停止 SASS 样式表的编译。

使用@warn AT 规则的语法与@error 的语法相同。

让我们举个例子来看看这是如何实现的。以下是带有 mixin 和@warn AT 规则的 SCSS 代码:

```sass
$known-prefixes: webkit, moz, ms, o;

@mixin prefix($property, $value, $prefixes) {
  @each $prefix in $prefixes {
    @if not index($known-prefixes, $prefix) {
      @warn "Unknown prefix #{$prefix}.";
    }

    -#{$prefix}-#{$property}: $value;
  }
  #{$property}: $value;
}

.tilt {
  // Oops, we typo'd "webkit" as "wekbit"!
  @include prefix(transform, rotate(15deg), wekbit ms);
}
```

这将被编译成以下 CSS:

```sass
.tilt {
  -wekbit-transform: rotate(15deg);
  -ms-transform: rotate(15deg);
  transform: rotate(15deg);
}
```

除显示以下警告消息外:

警告:未知前缀 wekbit。
示例. scss 6:7 前缀()
示例. scss 16:3 根样式表

## 自动规则

在某些情况下，在编写 **SCSS** 代码时检查变量的值是有用的，这样可以调试您正在编写的代码，并查看它在不同输入值下的表现。

SASS SASS 规则帮助我们解决了这个问题。`@debug` AT 规则的语法也类似于`@error` AT 规则。

要了解用法，最好看一个例子。假设一个**混合将两个数字**相加，并将其设置为**填充到一个 div** :

```sass
@mixin div-padding($x, $y) {
    $z : $x + $y;
    padding: $z * 1px;
    @debug "width is: #{$z}";
}

@include div-padding(100,200);
```

调试消息如下所示:

test.scss:3 调试:宽度为:300px

在本教程中，我们介绍了 SASS/SCSS 中的`@error`、`@warn`和`@debug` AT 规则。您必须使用它们来使您的样式表更加详细，以便任何使用它们的人都可以在它们使用任何 mixin 或功能不正确时看到消息。

* * *

* * *