# SASS 嵌套规则和嵌套属性

> 原文：<https://www.studytonight.com/sass/sass-nested-rules-and-nested-properties>

SASS 嵌套规则使我们能够编写嵌套规则**，使用花括号来包围嵌套元素**的样式规则，就像在 HTML 中一样。

嵌套规则使编写 CSS 代码更容易，并使**样式规则更易读**。

在 HTML 中，我们有嵌套和可视化的层次结构。例如，如果我们创建一个列表，我们使用`<li>`标签在`<ul>`或`<ol>`标签内创建列表项。但是 CSS 不支持这样的嵌套语法。因此，如果我们必须用下面的 HTML 代码来设计网页边栏中的列表及其项目的样式，

```sass
<div id="sidebar">
    <ul>
        <li>Tutorials</li>
        <li>Q & A Forum</li>
        <li>Flashcards</li>
        <li>Tests</li>
        <li>Collaborate</li>
    </ul>
</div>
```

我们将编写如下 CSS 代码:

```sass
#sidebar {
    float:left;
    width:25%;
    background-color:lightblue;
    padding: 30px 10px;
}

#sidebar ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
}

#sidebar li {
    padding: 6px;
    margin-bottom: 10px;
    background-color: #10A2FF;
    color: #ffffff;
}
```

但是在 SASS/SCSS 中，我们可以使用嵌套规则以一种更易读的方式做到这一点，

```sass
#sidebar {
    float:left;
    width:25%;
    background-color:lightblue;
    padding: 30px 10px;

    ul {
        list-style-type: none;
        margin: 0;
        padding: 0;
    }

    li {
        padding: 6px;
        margin-bottom: 10px;
        background-color: #10A2FF;
        color: #ffffff;
    }
}
```

看，比 CSS 好。

## 嵌套属性

每当有 **CSS** 属性属于相同的名称空间时，就会使用这种方法。考虑**背景**命名空间，我们在其中具有如下属性:

*   背景色

*   背景图像

*   背景-重复

*   背景-附件

*   背景位置

在 **CSS** 的情况下，如果我们想使用它们，我们需要分别键入所有这些属性。但是 **SCSS** 为我们提供了**的速记嵌套方式**，这使得我们编写名称空间后跟所有属性的工作变得更加容易，即以嵌套的方式。

让我们看一个例子，

```sass
body 
{
  background: 
   {
     color: yellow;
     attachment: fixed;
     repeat: no-repeat;
   }
} 
```

这将被编译为:

```sass
body 
{
  background-color: yellow;
  background-attachment: fixed;
  background-repeat: no-repeat;
} 
```

类似地，在字体命名空间的情况下，

```sass
.funky 
{
  font: 
    {
      family: fantasy;
      size: 30em;
      weight: bold;
    }
}
```

这将被编译成下面的 CSS 代码，

```sass
.funky 
{
  font-family: fantasy;
  font-size: 30em;
  font-weight: bold; 
}
```

## 结论:

在本教程中，我们详细介绍了嵌套规则和嵌套属性的概念，因为这是您在编写 SCSS 风格代码时必须使用的一个很好的特性，因为这将使您的工作变得更容易，也将使您的**样式表更易读，体积更小**。

* * *

* * *