# SASS 父选择器——使用`&`符号

> 原文：<https://www.studytonight.com/sass/sass-parent-selector-using-ampersand>

在 SASS/SCSS 语法中，我们可以使用`&`符号(和符号)来表示父类，并定义进一步的嵌套规则。SASS 中的这个&符号(&)代表父选择器，我们可以用它轻松编写嵌套属性。

## SASS 父选择器语法:

在样式表的嵌套选择器中使用父选择器的语法非常简单。你所要做的就是使用&(和符号)作为前缀，后跟一些文本，当你将 SCSS 代码编译成 CSS 代码时，和符号将被父选择器的名称替换。

```sass
#someclass {
    /* nested property using parent selector */
    &-body {
        /* this will be compiled as #someclass-body */
    }
}
```

`&`符号应该在复合选择器的开头，但是它后面可以跟一个后缀，这个后缀将被添加到父选择器中。

## 使用 SASS/SCSS 父级选择器

让我们举个例子来理解这一点。考虑下面的 HTML 代码，

```sass
<div id="studytonight">
    <div id="studytonight-body">
        /* Some HTML code */
    </div>
</div>
```

正如我们在上面的嵌套规则示例中所看到的，我们可以使用 Sass 嵌套规则来定义`#studytonight`和`#studytonight-body`的样式，但是 Sass 使使用父选择器语法更加容易。

```sass
#studytonight {
    /* styling for #studytonight div */
    &-body {
        /* styling for #studytonight-body div */
    }
}
```

当 SCSS 代码转换为 CSS 代码时，`&`符号被编译为父选择器值。当我们必须在主元素中使用类似`:hover`、`:selected`等伪选择器时，这就派上了用场。因此，如果您有一个`<a>`标签，并且想要为鼠标悬停定义样式，您可以在 Sass 中这样做，

```sass
a {
    text-decoration: none;
    color:black;
    // using parent selector
    &:hover {
        color:red;
    }
}
```

这相当于下面的 CSS 代码，

```sass
a{ 
    text-decoration: none;
    color:black;
}
a:hover
{
    color:red;
}
```

## 结论:

父选择器是 SASS/SCSS 的一个小特性，但它为我们提供了进一步简化的方法，在这种方法中，我们必须编写更少的代码来表达更多的意思。当我们为嵌套的 HTML 组件编写样式代码时，这种方法非常有用，比如使用列表或导航条的菜单等。

* * *

* * *