# SASS 内置模块

> 原文：<https://www.studytonight.com/sass/sass-buildin-modules>

SASS 附带了许多内置模块，就像预定义的样式表一样，可以直接包含/导入到样式表中并使用。我们可以使用 [`@use` AT 规则导入 SASS 内置模块](https://www.studytonight.com/sass/sass-use-atrule)，然后可以访问其成员。

所有内置 SASS 模块的 URL 都以`sass:`开头，因此如果您想要**导入颜色内置模块**，您必须在样式表中添加以下语句:

```sass
@use "sass:color"
```

一旦我们导入任何内置模块，我们就可以使用它的成员混合、变量、函数等。使用**模块名称，后跟点运算符，然后是成员的名称**。

让我们举个例子，

```sass
@use "sass:color";

.button {
  $primary-color: #6b717f;
  color: $primary-color;
  /* using the funciton scale */
  border: 1px solid color.scale($primary-color, $lightness: 20%);
}
```

该 SCSS 代码将被编译为以下内容:

```sass
.button {
  color: #6b717f;
  border: 1px solid #878d9a;
}
```

## SASS/SCSS 内置模块

默认情况下，SASS/SCSS 提供以下内置模块:

**sass:数学**模块，为我们提供对`ciel`、`clamp`、`floor`、`max`、`min`等数字进行各种操作的功能。

**sass:color** 模块，提供各种功能对颜色执行各种操作，比如基于现有颜色创建新颜色，例如创建现有颜色的更浅色调，因此该模块在设计主题时非常有用。这个预装了`scale`、`lighten`、`saturation`、`opacity`、`alpha`等功能。

**sass:string** 模块提供拆分、合并或搜索字符串的功能。它预装了`quote`、`unquote`、`index`、`insert`、`length`、`slice`等功能。

**sass:列表**模块用于对[列表值类型](https://www.studytonight.com/sass/sass-supported-value-types)进行不同的操作。这个有`append`、`join`、`length`等功能。

**sass:map** 模块为我们提供了使用`get`、`keys`、`has-key`、`merge`等函数对 SASS map 值类型进行操作的功能。

**sass:选择器**模块让我们可以访问用于检查和操作选择器的 sass 的选择器引擎。

**sass:meta** 模块公开了 sass 的内部工作方式。

## 结论:

借助内置模块，SASS/SCSS 的开发人员朝着让网页设计师的生活变得更加轻松的方向又迈进了一步，因为有了所有这些预定义的模块和功能，开发人员所要做的就是阅读这些模块及其功能，并在样式表中简单地使用它们。

* * *

* * *