# JavaScript 简介

> 原文：<https://www.studytonight.com/javascript/introduction-to-javascript>

JavaScript 是一种**客户端**、**基于对象的脚本语言**，用于处理和验证客户端数据。JavaScript 还用于使网页的用户界面更加动态，使其对诸如鼠标移动、鼠标点击某个 HTML 元素、按钮点击等事件做出响应，使用它我们可以改善用户体验。

JavaScript 是基于 **ECMAScript 标准**的**轻量级脚本语言**。它在浏览器上执行，因此减少了服务器上的负载。JavaScript 还可以用来创建跨平台应用程序或 SaaS 应用程序，或者通过使用**节点来创建后端服务器端应用程序。**

它是一种**解释语言**，意思是在 Javascript 里面写的脚本是一行一行处理的，处理之前不编译。这些脚本由 **JavaScript 解释器**解释，这是网络浏览器的内置组件。虽然最近这种情况有所改变，但是随着 Chrome 和 NodeJS 中 **V8 引擎的引入，现在**及时编译**也用于 JavaScript。**

JavaScript 是 P **latform Independent** ，也就是说你只需要写一次脚本，就可以在任何平台或者浏览器上运行，而不影响 Script 的输出。

JavaScript，以前被称为 LiveScript，由网景和太阳微系统公司开发。它也被称为 ECMAScript，因为它是由欧洲计算机制造商协会(ECMA)标准化的。最近的升级是 **ECMAScript6** 、 **ES7** 、 **ES8** 、 **ES9** 、 **ES10** 以及今年年初最新的 **ECMAScript2020** 。尽管您应该用所有新功能来更新自己，但 ECMAScript6 是最重要的变化，我们将在本教程系列的最后介绍更多内容。

浏览器使用自己的 JavaScript 引擎来执行 JavaScript 代码。下面列出了一些常用的浏览器:

*   Chrome 采用的是 V8 发动机。

*   火狐使用蜘蛛猴引擎。

*   微软边缘使用查克拉核心引擎。

*   Safari 使用 SquirrelFish 引擎。

## 网络发展路线图:

如果你是初学者，我们建议你先[学 HTML](https://www.studytonight.com/code/html/)[学 CSS](https://www.studytonight.com/cascading-style-sheet/) 然后你会更容易理解 JavaScript。在 web 开发中，HTML 是可以用来开发基本网页的基本构件，基本网页可以有超链接、图像、表单等。然后是 CSS，它用于设计各种 HTML 元素的样式，使它们看起来很好。CSS 是为你的 HTML 元素提供样式的标准，现在没有一个网站是没有它的。

[学习 SASS/SCSS](https://www.studytonight.com/sass) 这是一种新的语言，它使我们能够像任何其他编程语言一样编写动态样式规则，这些规则可以转换成 CSS 代码，然后在 HTML 页面中使用。

然后是 JavaScript，正如我们提到的，它是一种脚本语言，用于处理和验证客户端数据，基于事件使网页动态化，启用 cookies、本地存储等功能，等等。

让我们看看 JavaScript 的一些特性。

## JavaScript 特性

以下是 JavaScript 最有用的一些特性:

*   轻量

*   动态类型

*   基于对象的

*   功能的

*   独立于平台

*   基于原型的

*   解释

*   异步的

让我们看看所有这些特性意味着什么:

**轻量级:** JavaScript 是一种轻量级脚本语言，因为它仅用于浏览器级别的数据处理。因为它不是一种通用语言，所以它有一组有限的库。

**动态类型化:** JavaScript 支持动态类型化，这意味着**变量的类型是基于存储值**定义的。例如，如果您声明了一个变量`x`，那么您可以存储一个字符串或一个数字类型的值。这就是所谓的**动态打字**。

**基于对象的语言:**JavaScript 是一种基于对象的脚本语言，提供字符串、数学、日期等内置对象。

**Functional Style:** 这意味着 JavaScript 使用了一种函数方法，甚至对象都是从构造器中创建的，每个构造器代表一个唯一的对象类型。

**平台无关:**这意味着 JavaScript 是平台无关的或者我们可以说是可移植的；这意味着您只需编写一次脚本，就可以随时随地运行它。一般来说，您可以编写您的 JavaScript 应用程序，并在任何平台或任何浏览器上运行它们，而不会影响脚本的输出。

**基于原型:** JavaScript 是一种基于原型的脚本语言。这意味着 javascript 使用原型而不是类。在 JavaScript 中，每个构造器都与一个原型对象相关联。这是一个有点混乱的概念，但是这样考虑，就像我们在 Java 中有一个类，它就像一个蓝图，然后我们为这个类创建对象([理解类、对象和 OOP](https://www.youtube.com/watch?v=xoL6WvCARJY) 的概念)，在 JavaScript 中，我们定义对象原型，它用于创建其他对象。不要担心，如果你现在不明白这一点，你会明白这一点，因为你会随着教程的进展。

**explored**:javascript 是一种解释语言，意思是在 JavaScript 里面写的脚本是一行一行处理的，在执行之前是不会编译的(虽然这个变化比较慢，不同的浏览器会创建不同的 JavaScript 引擎)。这些脚本由 JavaScript 解释器解释，该解释器是网络浏览器的内置组件。

**异步:**可以用 JavaScript 异步做复杂的处理，这意味着整个页面都不用等待 JavaScript 的处理，一旦脚本处理完成，我们就可以轻松修改 HTML 代码来显示或隐藏数据。此外，我们还可以使用 JavaScript 向服务器发送异步 HTTP 请求，供服务器端处理。

## JavaScript 的优点

作为一种脚本语言，JavaScript 具有各种优势，非常有用，下面列出了一些优势:

1.  JavaScript 使网页更具交互性和动态性。

2.  通过使用 JavaScript，您可以让您的网页立即向用户提供反馈，这样他们就不必重新加载页面。

3.  您可以使用 JavaScript 根据用户如何与您的网页交互来执行动作，使用鼠标点击、表单提交、按钮点击等生成的事件。

4.  JavaScript 甚至可以在向服务器发送数据之前，通过**验证用户输入**来节省服务器流量。

5.  JavaScript 可以用来**存储客户端 cookie**在客户端存储数据，然后读取或删除。

6.  JavaScript 可以用来**进行异步 HTTP 调用**从服务器加载数据。

## JavaScript 的局限性

JavaScript 也有一些限制，如下所示:

1.  像 Java 和其他通用编程语言一样，JavaScript 不能编写**多线程或多处理器代码**。

2.  核心 JavaScript 不能用于开发网络应用程序，尽管有一些像 NodeJS 这样的框架可以用于此。

3.  JavaScript 只能在客户端使用**，即用于前端开发。**

4.  JavaScript 在浏览器中处理，**如果有人在自己的浏览器中禁用了 JavaScript，则不会处理任何 JavaScript 代码**。因此，如果您正在使用 JavaScript 验证表单值，并且您的网站的任何用户在他/她的浏览器中关闭了 JavaScript，那么您的表单验证将停止工作。

5.  JavaScript 为安全研究人员和黑客打开了许多门窗，让他们可以随意摆弄网页。

## 结论:

至此，您已经对 JavaScript 有了一个简单的介绍。在接下来的教程中，我们将涵盖 JavaScript 的所有基础知识，然后我们将继续讨论它的更复杂的部分。

* * *

* * *