# 在 HTML 中包含 JavaScript

> 原文：<https://www.studytonight.com/javascript/include-javascript-in-html>

可以使用 HTML `<script>`标签将 JavaScript 代码插入到 HTML 文件中。当网页浏览器中加载了带有`<script>`标签的 HTML 文档时，浏览器会将包含在`<script>` 标签中的内容作为 JavaScript 代码进行处理。

`<script>` 标签可以包含脚本语句，也可以引用外部 JavaScript 文件。`<script>` 标签提供了一个 **src** 属性，允许我们添加对外部脚本文件的引用。

JavaScript 是大多数浏览器的默认脚本语言。

## `<script>` 标签属性及其用途

以下是使用`<script>`标签的基本语法:

```js
<script src="JS_FILE_URL" type="..."></script>
```

同样，我们也可以使用`<script>`标签直接添加 JavaScript 代码，如下所示:

```js
<script type="text/javascript">
    // JS code here
</script>
```

**脚本**标签有五个属性，如下表所示:

| **属性** | **值** | **描述** |
| `async` | 

*   True

*   Wrong

 | 它指定脚本是否应该异步执行。 |
| `type` | 

*   ā412/ecmascript

*   ā412/JavaScript

*   王路/ecmascript

*   王路/JavaScript

*   ā381/VBScript

 | 它指定脚本的多用途互联网邮件扩展(MIME)类型。一般使用**文本/javascript** 值。 |
| `charset` | 字符集 | 它指定脚本中使用的字符编码类型 |
| `defer` | 

*   True

*   Wrong

 | 它指定浏览器是否继续解析网页。 |
| `src` | 统一资源定位器 | 它指定包含脚本的文件的统一资源定位符。 |

现在我们已经知道了用于在网页中包含 JavaScript 代码的

## 网页中的 JavaScript

您可以在 HTML 网页中使用脚本标记，以下列方式添加 JavaScript 代码:

*   在**头**元素(`<head>`...`</head>`)

*   在**体内**元素(`<body>`...`</body>`)

*   包含外部 JavaScript 文件

让我们一个接一个地介绍所有这些，并附上代码示例来帮助您理解它们。

## 1.在`<head>`元素中用 JavaScript 代码编写`<script>` 标签

让我们把**脚本**标签放在 HTML **头**元素里面。放置在**头**元素中的脚本会加载到网页中，并在任何定义的事件发生时执行。

下面给出的代码展示了如何使用 HTML 文档的`<head>`元素中的`<script>`标签来添加一些 JavaScript 代码。

## 1.在`<body>`元素中用 JavaScript 代码编写`<script>` 标签

您也可以在 HTML 文档的**正文**元素中放置一个**脚本**标签。当网页开始在 web 浏览器中加载时，body 元素中的脚本标记会运行。下面是展示如何在 HTML 文档的`<body>`元素中放置`<script>`元素的代码:

## 3.外部文件中的 JavaScript 代码

每当我们在 HTML 文档中放入冗长的 JavaScript 代码时，都会影响 HTML 文档的可读性和可维护性。此外，有时需要在几个网页中使用相同的 JavaScript 代码。在这种情况下，我们可以将 JavaScript 代码存储在一个外部文件中，并用**保存该文件。js** 分机。所有的 JavaScript 代码文件都应该有一个扩展名**。JS** 别的都没有。

要链接外部文件，我们可以在`<script>` 标签的 **src 属性**中提供它的位置(URL)。

### 包括外部 JavaScript 语法:

我们可以通过这种方式将外部 JavaScript 文件添加到我们的 HTML 文件中:

```js
<script src="jsfile.js" type="text/javascript"></script> 
```

在上面的代码示例中，`type`属性是可选的。

### 外部 JavaScript 文件的优势:

使用外部 JavaScript 文件有它自己的优点。

1.  它将 HTML 和 JavaScript 代码分开，使代码看起来干净易懂。

2.  外部 JavaScript 代码可以在多个 HTML 网页中重用。

3.  外部 JavaScript 代码可以缓存在浏览器中。一旦被缓存，浏览器就不会一次又一次地加载 JavaScript 文件，而是会使用它的缓存版本。这将使您的网页加载速度更快。

## 外部文件中的 JavaScript 代码示例:

下面给出的代码向您展示了如何将外部 JavaScript 文件与 HTML 文档链接起来。

```js
<html>
    <head> 
        <title>my first JavaScript</title> 
        <script src="jsfile.js"></script> 
    </head> 
    <body> 
        <p id="script">this is the old text</p> 
        <button type="button" onclick="text()">Click this button to use JavaScript</button> 
    </body> 
</html>
```

存储在名为 **jsfile.js** 的文件中的 JavaScript 代码

```js
function text() 
{
    document.getElementById("script").innerHTML = "This text has been written inside the JavaScript.";
}
```

在上面的代码中，我们已经在 JavaScript 中定义了一个简单的函数，我们将在接下来的教程中了解 JavaScript 函数。

## 在网页中包含 JavaScript:最佳实践

在大型项目中，JavaScript 代码可能非常庞大，每个 HTML 页面中可以包含多个使用多个`<script>`标签的外部 JavaScript 文件。是的，我们可以使用多个`<script>`标签来包含任意多的外部 JavaScript 文件。

例如，如果我们有 3 个 JavaScript 文件，名称分别是 **one.js** 、 **two.js** 和 **three.js** ，我们必须将所有这些都包含在我们的 HTML 页面中。在这种情况下，我们将使用 3 个`<script>`标签，

```js
<script src="one.js" type="text/javascript"></script>
<script src="two.js" type="text/javascript"></script>
<script src="three.js" type="text/javascript"></script>
```

现在的问题是，我们应该把上面的代码放在我们的 HTML 页面的什么地方。**是应该放在 HTML 代码的 HEAD 部分，还是应该放在 HTML 页面的 BODY 部分？**

嗯，如果我们把它放在 HEAD 部分，那么当我们的网页加载的时候，所有的 JavaScript 文件都会先加载，这样会减慢我们的网页加载，这是不好的。

所以，**我们应该加载一个网页中使用的外部 JavaScript 文件，最后**的意思是要么**就在关闭** `</body>` **标签**之前，要么**就在关闭** `</body>` **标签**之后，这样首先加载我们完整的网页，然后加载外部 JavaScript 文件。这样，即使我们有大的 JavaScript 文件，我们的网页也不会因此而变慢。

```js
<html>
    <head>
        ...
    </head>
    <body>
        <!-- body of HTML page -->
    </body>
    <script src="one.js" type="text/javascript"></script>
    <script src="two.js" type="text/javascript"></script>
    <script src="three.js" type="text/javascript"></script>
</html>
```

## 结论:

因此，本教程涵盖了将 JavaScript 代码包含到 HTML 网页中的所有方法以及最佳实践。在下一个教程中，我们将学习如何**从 JavaScript 代码**中获得输出，这样我们就可以开始进行一些编码，并看到 JavaScript 代码正在运行。

* * *

* * *