# JavaScript `let`关键字

> 原文：<https://www.studytonight.com/javascript/javascript-let-keyword>

在 JavaScript 中，`let`是一个关键字，用于声明一个具有块作用域的局部变量。与 [`var`关键字声明全局范围变量](https://www.studytonight.com/javascript/javascript-variables)不同的是， **ECMAScript2016** (ES6)引入`let`关键字来定义局部范围变量，因为定义全局范围内的所有变量会导致在编写大型 JavaScript 应用程序时出现很多问题。

它允许您声明**有限范围变量**，这些变量不能在范围之外访问。

让我们举个例子来理解`let`关键字在 JavaScript 中已经有`var`关键字创建变量时的需求。假设您正在编写一个包含多个循环、函数和变量的大型 JavaScript 代码，像往常一样，在所有循环中，您为计数器使用了相同的变量名`i`，并且您使用了`var`关键字来定义变量`i`，现在将发生的是，变量 I 将在整个脚本中携带其更改的值，因为它是一个全局变量，如果您忘记在任何地方将其重新初始化为零，它将导致错误，并且您的代码将会中断。你将不得不付出额外的努力来寻找错误。

然而，如果您使用`let`关键字定义计数器变量`i`，其范围将仅限于循环，并且当第一个循环结束时，计数器变量也将结束。这样，使用 let 关键字更有意义，因为我们在一般编程实践中使用很少的全局变量和许多局部变量。

**让**在全局声明时不创建窗口对象的属性。

## JavaScript `let`关键词:语法

使用`let`关键字定义变量的语法与`var`关键字相同。

```js
let var1 [= value1] [, var2 [= value2]] [, ..., varN [= valueN];
```

如上面的语法所示，是的，我们可以使用单个`let`关键字**来定义多个变量**，但是这并不新鲜，我们也可以使用`var`关键字来定义。

我们来看几个例子，看看这个`let`关键词是怎么用的，怎么用的。

### 在代码块中使用`let`:

如果我们已经使用`let`关键字定义了变量，那么在**块** `{ }`内部声明的 JavaScript 变量不能从块外部访问。请参见下面的示例:

```js
{
    let x = 2;
}

alert(x)  // not accessible
```

未捕获的引用错误:x 未定义

在上面的例子中，变量只能在块内部访问。请看下面的例子，可以看到:

```js
{
    let x = 2;
    alert(x)  // accessible
}
```

Two

### 在循环中使用`let`:

它更适合于循环，在循环中，我们声明局部变量用作计数器。因此，变量不会与在循环外编写的代码冲突。请参见下面的示例:

```js
let i = 5;

for(let i = 0; i < 10; i++) {
  	// code
}

alert(i);  // print 5
```

5

正如您在输出中看到的，它显示了 **5** ，即使循环将`i`变量的值增加到了 **10** ，这是因为`for`循环中的局部变量`i`的范围以循环本身结束，因此在循环之外是不可访问的。

### 在函数中使用`let`:

我们知道，`let`关键字声明了局部范围变量。所以在函数内部声明的变量将保留在函数范围内。如果我们试图从函数外部访问这样的变量，我们会得到一个错误。请参见下面的示例:

```js
function show() {
    let amount = 2500;   // Function Scope
}
alert(amount) // not accessible
```

未捕获参考错误:金额未定义

## JavaScript `let` vs `var`关键词

我们已经在介绍中介绍了两者的区别，但是让我们看一些代码示例来看看两者之间的区别。

`let`和`var`，这两个关键词都是用来声明变量的，但主要区别是声明变量的范围。

使用`var`在块内声明的变量可以在块外访问，因为它具有全局范围，但是使用`let`关键字声明的变量具有局部范围。让我们看一个例子:

```js
{
    let amount = 2500;   // block Scope
    var withdraw = 2000;    // global scope
}
document.write(withdraw)   // accessible
document.write(amount)   // not accessible
```

2000
未记录参考错误:金额未定义

## JavaScrip `let`关键词示例:

让我们再举一个例子，在这个例子中，我们将编译上面的所有例子，看看使用`let`关键字定义的变量是如何工作的。

如您所见，在顶部定义的变量`x`具有全局范围，并且在脚本结束之前将保持可访问，而在代码块和函数内部定义的变量`x`具有范围，直到代码块或函数结束。

### 结论

在本教程中，我们已经介绍了用于在 JavaScript 中定义变量的 let 关键字。它是在 ECMAScript2016 中引入的，建议用于定义变量，而不是使用 var 关键字创建 [JavaScript 变量](https://www.studytonight.com/javascript/javascript-variables)。

* * *

* * *