# JavaScript 字面值和关键字

> 原文：<https://www.studytonight.com/javascript/javascript-literals-and-keywords>

JavaScript 字面值是不可更改的固定值，您不需要指定任何类型的关键字来编写字面值。在编程中常使用字面值来初始化变量，变量的名称是字符串字面值。

JavaScript 字面值可以是数字、字符串、浮点值、布尔值甚至是对象。简单来说，任何值都是字面值，如果你写一个字符串**“study now”**就是字面值，任何像 **7007** 这样的数字都是字面值，等等。

JavaScript 支持下面列出的各种字面值:

*   数值字面值

*   浮点字面值

*   布尔字面值

*   字符串字面值

*   数组字面值

*   正则表达式字面值

*   对象字面值

## 数字字面值

*   它可以用十进制(以 10 为基数)、十六进制(以 16 为基数)或八进制(以 8 为基数)格式表示。

*   十进制数值由一系列数字(0-9)组成，没有前导 0(零)。

*   十六进制数字字面值包括数字(0-9)、字母(a-f)或(A-F)。

*   八进制数字字面值包括数字(0-7)。数字字面值中的前导 0(零)表示八进制格式。

### 数值字面值示例

```js
120 // decimal literal

021434 // octal literal

0x4567 // hexadecimal literal
```

## 浮点字面值

*   它包含一个小数点(。)

*   分数是浮点字面值

*   它可能包含一个指数。

### JavaScript 浮点字面值示例

```js
6.99689 // floating-point literal

-167.39894 // negative floating-point literal 
```

## JavaScript 布尔字面值

布尔字面值仅支持两个值，即**真**或**假**。

### JavaScript 布尔字面值示例

```js
true // Boolean literal

false // Boolean literal
```

## JavaScript 字符串字面值

字符串字面值是包含在单引号(`'`)或双引号(`"`)中的零个或多个字符的组合。

### JavaScript 字符串字面值示例

```js
"Study" // String literal

'tonight' // String literal 
```

字符串字面值也可以有一些特殊的字符，如下表所示。

**字符串特殊字符:**

| **字符** | **描述** |
| --- | --- |
| `\b` | 它代表退格。 |
| `\f` | 它代表一个表单源。 |
| `\n` | 它代表一条新的线。 |
| `\r` | 它代表回车。 |
| `\t` | 它代表一个标签。 |
| `\v` | 它代表一个垂直标签。 |
| `\'` | 它代表撇号或单引号。 |
| `\"` | 它代表一个双引号。 |
| `\\` | 它表示反斜杠字符。 |
| `\uXXXX` | 它表示由四位十六进制数指定的 Unicode 字符。 |

## JavaScript 数组字面值

*   数组字面值是一个由零个或多个表达式组成的列表，这些表达式表示括在方括号(`[]`)中的数组元素。

*   每当您使用数组文本创建数组时，它都会使用方括号中指定的元素进行初始化。

### JavaScript 数组字面值示例

```js
var emp = ["aman","anu","charita"];  // Array literal
```

## JavaScript 正则表达式文本

正则表达式是一种模式，用于匹配某些文本中的字符或字符串。它是通过将正则表达式字符串括在正斜杠之间来创建的。

### JavaScript 正则表达式示例

```js
var myregexp = /ab+c/; // Regular Expression literal

var myregexp = new RegExp("abc"); // Regular Expression literal
```

## JavaScript 对象字面值

它是用花括号(`{}`)括起来的键值对的集合。键值对由逗号分隔。

### JavaScript 对象字面值示例

```js
var games = {cricket :11, chess :2, carom: 4}  // Object literal
```

## JavaScript 关键字

每种编程语言都有自己的**关键词和保留词**。创建每个关键字是为了执行特定的任务，编译器或解释器已经知道内置关键字和保留字。JavaScript 支持下表中列出的一组丰富的关键字。

| **关键词** | **描述** |
| --- | --- |
| 为 | for 关键字用于创建 for 循环。 |
| 做/当 | do 和 while 这两个关键字都用于在 JavaScript 中创建循环。 |
| 如果/否则 | if 和 else 关键字用于创建条件语句。 |
| 继续 | continue 关键字用于恢复循环。 |
| 破裂 | 它用来打破循环。 |
| 功能 | function 关键字用于声明函数。 |
| 调试器 | 它用于调用调试器函数 |
| 班级 | class 关键字用于声明类。 |
| 返回 | Return 关键字用于从函数中返回函数。 |
| 漂浮物 | 它用于声明浮点类型变量。 |
| （同 Internationalorganizations）国际组织 | 它用于声明 int 类型变量。 |
| 私人的 | 它是一个访问修饰符。 |
| 公众的 | Public 是一个访问修饰符，它赋予类公共访问权。 |
| 定义变量 | Var 用于声明变量。 |
| 转换 | 开关创建各种语句块，并根据条件或情况只在块上执行。 |
| 尝试/捕捉 | 它为语句的错误处理创建一个块。 |

<u>**注意:**</u> 在定义任何函数或变量的名称时，不应使用任何关键字或保留字。

在本教程中，我们学习了 JavaScript 字面值、不同类型的字面值以及示例。我们还介绍了 JavaScript 关键字和保留字。

* * *

* * *