# JavaScript 数据类型

> 原文：<https://www.studytonight.com/javascript/javascript-data-types>

JavaScript 数据类型用于标识脚本执行期间存储在变量中的数据类型。因为我们已经指定了动态类型 [JavaScript 特性](https://www.studytonight.com/javascript/javascript-features)，所以我们在声明变量时不必指定它的数据类型。

所以 JavaScript 数据类型基本上是为了识别目的，知道变量中存储了什么，什么时候存储的，而不是之前。

动态类型语言是**在运行时**推断数据类型的语言。它允许在编程过程中为变量存储不同类型的值。

下面我们有一个基本的例子，我们用一个数值定义了一个变量，然后更新它来存储一个字符串值。所以 JavaScript 允许这样做。

```js
var x = 5;    // x is a number
x = "studytonight";    // x is string here.
```

JavaScript 广泛支持三种类型的数据类型，它们是:

*   原语类型

*   参考类型

*   特殊数据类型

让我们一个接一个地讨论每一个，同时看看哪个类别有所有的数据类型。

## 原始数据类型

JavaScript 原语数据类型可以进一步分为以下类型:

1.  字符串数据类型

2.  布尔数据类型

3.  数字数据类型

这些是最常见的数据类型，分别用于存储字符序列、真/假和数值。让我们用例子一个接一个地讲述它们。

### 1.字符串数据类型

每当我们在单引号或双引号内写一个字符或字符序列时，它就变成了字符串。比如“**今晚学习**”。

我们可以使用单引号或双引号来创建字符串类型值。

```js
var str = "Ferari F60";  // string using double quotes

var str1 = 'Volvo S60';  // string using single quotes.
```

要将单引号作为字符串的一部分，我们应该使用双引号将字符串值括起来，反之亦然。如果您想在字符串中包含单引号，而该字符串是通过仅用单引号括起来定义的，在这种情况下，我们必须使用反斜杠来转义单引号，同样，我们也可以在字符串值中转义双引号。

让我们看一个例子:

```js
var str1 = "Ferari's F60";    // Output: Ferari's F60

var str2 = 'Volvo "S60"';   // Output: Volvo "S60"

var str3 = 'Ferari\'s F60';    // Output: Ferari's F60
```

我们已经详细介绍了 [JavaScript 字符串](https://www.studytonight.com/javascript/javascript-strings)，也介绍了 JavaScript 中的各种[字符串方法。](https://www.studytonight.com/javascript/javascript-string-methods)

### 2.布尔数据类型

布尔数据类型用于基于条件的编程。它可以有两个值，或者**真**或者**假**。

```js
var isOn = true;  // bulb is on

var isOn = false;  // bulb is off
```

我们在比较两个数字时会得到布尔值，例如:

```js
doument.write(4 < 2)  // false
doument.write(4 > 2)  // true
```

我们将在 [JavaScript If else](https://www.studytonight.com/javascript/javascript-ifelse) 流控制教程中看到这一点。

### 3.数字数据类型

数字数据类型可以有小数点，也可以没有小数点，可以有负值和正值。

```js
var x = 45; // Number without decimal point

var y = 45.90; // Number with decimal point - floating point

var z = -10; // Number with negative value
```

JavaScript Number 数据类型还表示一些特殊的值，如`Infinity`、`-Infinity`和`Nan`。当正数被零除时(这是运行时错误的一种常见情况)，在 JavaScript 中它被表示为`Infinity`。同样，当负数被零除时，我们会得到`-Infinity`。

```js
var a = 100;
var b = -100;
var c = 0;

alert(a/c);  // Infinity 
alert(b/c);  // -Infinity
```

而`Nan`的意思是**不是一个数字**，如果我们试图在一个数值和一个非数值之间执行任何操作，比如字符串，我们会得到这个作为输出。

```js
var a = "Studytonight";
var b = 7;

alert(a/b);    // Nan
```

## 复合数据类型

这些数据类型可以保存值和更复杂实体的集合。它进一步分为对象、数组和函数。

1.  对象数据类型

2.  数组数据类型

3.  函数数据类型

### 1.对象数据类型

在 JavaScript 中，对象数据类型用于存储数据集合。对象的属性被写成**键:值**对，用逗号和**隔开，用花括号** `{}`括起来。

**键(名称)必须始终是字符串**，但是**值可以是任何数据类型**。这非常类似于许多编程语言中的映射数据结构，它也像这样存储键值对。

```js
var name = { };   // It will create an empty object.

var emp = {firstname="ram", lastname="singh", salary=20000};
```

我们已经在单独的教程中用例子介绍了 [JavaScript 对象](https://www.studytonight.com/javascript/javascript-objects)。

### 2.JavaScript 数组类型

JavaScript Array 数据类型写在一对方括号`[]`内，用于存储相同数据类型的多个值，如字符串、数字等。JavaScript 数组中的项目也是以逗号分隔的方式编写的。

数组中的每个元素都有一个数字位置，称为其**索引**。数组索引从 **0** 开始，或者我们可以说**数组索引是从零开始的**，所以第一个数组元素是`arr[0]`而不是`arr[1]`。

让我们举一个 JavaScript 数组的例子:

```js
// Creating an Array
var cars = ["Ferrari", "Volvo", "BMW", "Maseratti"];
```

我们已经在单独的教程中用例子介绍了 [JavaScript 数组](https://www.studytonight.com/javascript/javascript-arrays)。

### 3.JavaScript 函数类型

你一定在想，函数怎么可能是数据类型。但是在 JavaScript 中**函数作为一种数据类型，可以分配给一个变量**。JavaScript 函数只不过是**代码块**中的一组语句，用于执行特定的操作**这个数据类型本质上是可调用的**。因此，您可以随时在程序中的任何地方调用它。

因为函数是对象，所以可以将它们赋给一个变量。

函数可以存储在变量、对象和数组中。函数也可以作为参数传递给其他函数，也可以从其他函数返回。

```js
var welcome = function() {
                  return "Welcome to StudyTonight!";
              }
```

我们已经在单独的教程中用例子介绍了 [JavaScript 函数](https://www.studytonight.com/javascript/javascript-functions)。

## 特殊数据类型

JavaScript 也有一些特殊的数据类型，尽管将被调用的函数视为数据类型对您来说已经很特殊了。但是还有两个。

1.  未定义的数据类型

2.  空数据类型

让我们一个接一个地讨论它们。

### 1.未定义的数据类型

当一个变量刚刚被声明并且没有被赋予任何值时，它的值为**未定义**。是的，未定义在 JavaScript 中是一个有效的数据类型，它只能有一个值**未定义**。

我们甚至可以在做一些比较时使用这个值。让我们举个例子:

```js
var a;   // Undefined

alert(a == undefined);   // returns true
```

### 2.空数据类型

JavaScript Null 数据类型用于表示无值。它不类似于未定义，也不类似于空值或零值。空数据类型意味着变量已经定义，但它不包含任何值。

Null 数据类型只能有一个值，即 **null** 。让我们举一个例子:

```js
var a = null;

alert(a);    // Output will be null
```

## JavaScript `typeOf`运算符

JavaScript 中的`typeOf`运算符可以用来检查任何变量的数据类型。虽然它是一个运算符，但我们在这里提到它，因为它通常用于检查任何变量的数据类型。

让我们举几个例子来看看这是如何工作的:

```js
// Function datatype
var welcome = function() {
                  return "Welcome to StudyTonight!";
              }

typeOf welcome;    // function

var a = null;

typeOf a;   // null

// Array datatype
var cars = ["Ferrari", "Volvo", "BMW", "Maseratti"];

typeOf cars;    // array
```

您也可以尝试其他数据类型。

## 结论:

在本主题中，我们解释了 javascript 中使用的变量的数据类型。所有的主题和副主题都用实例来解释，这样我们可以更好地理解主题。

* * *

* * *