# JavaScript 运算符

> 原文：<https://www.studytonight.com/javascript/javascript-operators>

在本教程中，我们将学习 JavaScript 运算符，JavaScript 中各种不同类型的运算符，并将有几个例子来看看它们的工作原理。

## 什么是操作员？

运算符是为特殊任务或操作保留的符号。运算符用于对操作数执行操作。操作数可以是变量或[数值或字符串](https://www.studytonight.com/javascript/javascript-literals-and-keywords)。一个运算符可以处理一个或多个操作数。

运算符对于通过操作相应的变量来修改或更改数据非常有用。例如，有两个变量`a`和`b`，我们希望**将这两个变量**的值相加，为此，我们可以使用算术运算符`+`来执行这两个变量的相加。

JavaScript 支持一组丰富的运算符。这些操作符执行特定的任务，每个操作符都有不同的属性。操作员列表如下:

*   算术运算符

*   关系运算符

*   按位运算符

*   逻辑运算符

*   赋值运算符

*   字符串运算符

让我们逐一介绍上述每一种运算符类型，并看看 JavaScript 中支持的不同运算符。

## 算术运算符

JavaScript 算术运算符用于执行算术运算，如**加法**、**减法**、**乘法、**等。下表列出了所有的算术运算符。

| **操作员** | **描述** | **例** |
| --- | --- | --- |
| `+` | 

*   Add two numbers

*   to connect two strings

 | 

```js
45+20 // output 65

"My"+"Name" // MyName
```

(也可用于字符串连接) |
| `**-**` | 

*   minus two numbers

*   means negative number

 | 

```js
45-20 // output 25
```

 |
| `*` | 将两个数字相乘 | 

```js
20*5 // output 100
```

 |
| `/` | 将两个数相除 | 

```js
45/10 // output 4.5
```

 |
| `%` | 将两个数相除，然后返回余数 | 

```js
45%10 // output 5
```

 |
| `++` | 将该值增加 1 | 

```js
a = 10
a++; // output will be 11
```

 |
| `--` | 将该值减 1 | 

```js
x = 9
x--; // output will be 8
```

 |

## 关系运算符

这些运算符用于在两个操作数之间进行比较。我们将在介绍[JavaScript if else Flow Control](https://www.studytonight.com/javascript/javascript-ifelse)时使用这些操作符。

| **操作员** | **描述** | **例** |
| --- | --- | --- |
| `==` | 如果两个操作数相等，则返回**真**，否则返回**假**。 | 

```js
45==10  // output false
```

 |
| `!=` | 如果两者不相等，则返回**真**，否则返回**假**。 | 

```js
45!=10  // output true
```

 |
| `===` | 是一个**严格相等的算子**。如果类型转换时操作数严格相等(相同的值和相同的数据类型)，则返回**真**否则返回**假**。 | 

```js
3===3  // output true
```

 |
| `!==` | 如果该运算符两侧的操作数不相等/不是同一类型，则返回 **true** 。 | 

```js
3!=='3'   // output false
```

 |
| `>` | 如果左侧操作数大于右侧操作数，则返回**真**，否则返回**假**。 | 

```js
45>10   // output true
```

 |
| `>=` | 如果左侧操作数大于或等于右侧操作数，则返回**真**，否则返回**假**。 | 

```js
45>=10   // output true
```

 |
| `<` | 如果左侧操作数小于右侧操作数，则返回**真**，否则返回**假**。 | 

```js
10<45   // output true
```

 |
| `<=` | 如果左侧操作数小于或等于右侧，则返回**真**，否则返回**假**。 | 

```js
45<=10   // output false
```

 |

## JavaScript 逐位运算符

JavaScript 支持以下对操作数执行按位运算的按位运算符。

| 操作员 | 描述 | 例子 |
| --- | --- | --- |
| `&`(与) | 如果两位都为 1，则将每个位设置为 1 | 

```js
5&1  // returns 1

0101&0001   // returns 1
```

 |
| `&#124;`(或) | 如果两个位中的一个为 1，则将每个位设置为 1 | 

```js
5&#124;1   // returns 5

0101 &#124; 0001   // returns 5 in decimal or 65 in octal
```

 |
| `^`(异或) | 如果两位中只有一位为 1，则将每个位设置为 1。 | 

```js
5^1    // returns 4

0101^0001    // returns 4 in decimal or 64 in octal
```

 |
| `~`(否) | 反转所有位 | 

```js
~5  // output 6

~0101  // output 66 in octal
```

 |
| `<<`(零填充左移位) | 通过从右边压入零向左移动，让最左边的位脱落 | 

```js
5<<1   // returns 10

0101<<1   // returns 10 in decimal and 130 in octal
```

 |
| `>>`(带符号填充右移) | 通过从左边推入最左边位的副本来向右移动，并让最右边的位脱落。 | 

```js
5>>1  // returns 2

0101>>1  // returns 2
```

 |
| `>>>`(零填充右移) | 通过从左边压入零向右移动，并让最右边的位脱落 | 

```js
5>>>1  // returns 2

0101>>>1  // returns 2
```

 |

## 逻辑运算符

逻辑门的功能在 JavaScript 中用作逻辑运算符。这些运算符也用于控制流。

| **操作员** | **描述** | **例** |
| --- | --- | --- |
| `&&` | 只有当两个操作数都为真时，它才返回**真**，否则返回**假** | 

```js
true&&false   // returns false
```

 |
| `&#124;&#124;` | 如果任一操作数为真，则返回**真**。当两个操作数都为假时，它返回**假** | 

```js
true&#124;&#124;false   // returns true
```

 |
| `!` | **否定**操作数，如果操作数为假则返回真，反之亦然 | 

```js
!true   // returns false
```

 |

## JavaScript 赋值运算符

这些是在给变量赋值时使用的运算符。

| **操作员** | **描述** | **例** |
| --- | --- | --- |
| `=` | 它将值赋给左侧变量。 | 

```js
x = 90;
```

 |
| `+=` | 它将右侧操作数与左侧操作数相加，然后将结果赋给左侧操作数。 | 

```js
x = 45;

x += 20;  // x = 65
```

 |
| `-=` | 它从左侧操作数中减去右侧操作数，然后将结果分配给左侧操作数。 | 

```js
x = 45;

x -= 10;  // x = 35
```

 |
| `*=` | 它将右侧操作数乘以左侧操作数，然后将结果赋给左侧操作数。 | 

```js
x = 45;

x *= 10;  // x = 450
```

 |
| `/=` | 它将左侧操作数除以右侧操作数，并将结果赋给左侧操作数。 | 

```js
x = 45;

x /= 10;   // x = 4.5
```

 |
| `%=` | 它将左侧操作数除以右侧操作数，然后将余数赋给左侧操作数。 | 

```js
x = 45;

x% = 10;   // x = 5
```

 |

## JavaScript 运算符优先级和结合性

运算符优先级决定运算符的求值顺序。具有较高优先级的运算符首先被求值。例如，表达式`(3+4*5)`返回 **23** ，因为乘法运算符(`*`)的**优先级高于加法运算符(`+`)。因此`*`必须先评估。**

运算符关联性决定了处理具有相同优先级的运算符的顺序。比如**赋值运算符是右关联**，可以写`a=b=5`，用这个语句，给`a`和`b`赋值 **5** 。

下表显示了运算符的优先级和关联性。在这个表格中，优先级是从下到上的，也就是说，位于底部的项目优先级较低，当我们移动到表格顶部时，优先级会增加。

| **操作员类型** | **操作员(符号)** | **关联性** |
| --- | --- | --- |
| 成员 | 。[] | 从左向右 |
| 新的 | 新的 | 从右向左 |
| 函数调用 | () | 从左向右 |
| 增量 | ++ |  |
| 减量 | - |  |
| 逻辑非 | ！ | 从右向左 |
| 按位非 | ~ | 从右向左 |
| 一元+ | + | 从右向左 |
| 一元否定 | - | 从右向左 |
| 类型 | 类型 | 从右向左 |
| 空的 | 空的 | 从右向左 |
| 删除 | 删除 | 从右向左 |
| 增加 | * | 从左到右 |
| 分开 | / | 从左到右 |
| 系数 | % | 从左到右 |
| 添加 | + | 从左到右 |
| 减法 | - | 从左到右 |
| 逐位移位 | <<>>>>> | 从左到右 |
| 有关系的 | <<=>>= | 从左到右 |
| 在 | 在 | 从左到右 |
| 实例 | 实例 | 从左到右 |
| 平等 | ==！====！== | 从左到右 |
| 按位“与” | & | 从左到右 |
| 按位异或 | ^ | 从左到右 |
| 按位或 | &#124; | 从左到右 |
| 逻辑与 | && | 从左到右 |
| 逻辑或 | &#124;&#124; | 从左到右 |
| 有条件的 | ？： | 从右向左 |
| 作业 | =+=-=*=/=%=<<=>>=>>>=&==&#124;= | 从右向左 |
| 逗号 | , | 从左到右 |

## JavaScript 运算符示例:

下面我们有一个真实的例子，其中我们使用了上面指定的一些操作符。

在本主题中，我们解释了 JavaScript 运算符及其在 JavaScript 中的用法。运算符是任何编程语言的一个非常重要的组成部分，因为它们是执行操作所必需的，用于条件、比较等。

* * *

* * *