# JavaScript 常量——`const`关键字

> 原文：<https://www.studytonight.com/javascript/javascript-constant-const-keyword>

JavaScript `const`关键字用于定义一旦设置值就不能改变的常量值。常量的值不能通过重新赋值来改变，也不能重新声明。

**常量**的范围是块范围的，这意味着它不能从块外部访问。就范围而言，它很像使用 **let** 语句定义的变量。

常数可以是全局的，也可以是声明它的块的局部的。与 var 变量不同，全局常量不会成为窗口对象的属性。

## JavaScript `const`关键词:语法

下面我们有在 JavaScript 中定义常量值的语法。

```js
const name1 = value1 [, name2 = value2 [, ... [, nameN = valueN]]]
```

在使用`const`关键字时，我们不必使用`var`或`let`关键字。此外，我们可以将列表或简单值或字符串等定义为常量。

## JavaScript `const`关键词示例

让我们了解一下，如何在 JavaScript 程序中创建常量。请参见下面的示例:

```js
{
	const Pi = 3.14;
	alert(Pi);
}
```

3.14

让我们尝试另一个例子，我们将尝试改变常量的值，看看我们是否允许重新分配值。

```js
{
	const Pi = 3.14;
	alert(Pi);

	// Reassign value
	Pi = 3.143;
	alert(Pi);
}
```

3.14
未捕获类型错误:常量变量赋值。

## JavaScript `const`:作用域

使用`const`关键字定义的变量的范围与使用`let`关键字声明的变量的范围相同。所以，**常量在一个块内声明，在该块外**将无法访问。让我们举个例子看看:

```js
{
	const Pi = 3.14;
	alert(Pi);
}

// outside block
alert(Pi);  // error
```

3.14
未捕获的引用错误:未定义 Pi

## JavaScript `const`关键词用法示例

在下面的实时示例中，我们添加了多个代码语句，在这些语句中，我们声明了常量值，并赋予它不同的范围，还尝试更改常量的值。

要查看错误，您可以打开浏览器开发工具(如果您使用的是 Chrome 或 Firefox 浏览器)，您将在控制台中看到*未捕获类型错误:常量变量赋值*错误消息。

这就是我们如何在 JavaScript 中定义一个常量的方法，它可以用在你想要定义一些常量值的情况下，比如域名，任何固定的前缀值，或者任何整数值，或者可能是你的 JavaScript 代码中的一个 zipcode。

**另请阅读:-** [如何用 JavaScript 构建一个动画计数器](https://www.studytonight.com/post/how-to-build-an-animated-counter-with-javascript)

* * *

* * *