# JavaScript 字符串

> 原文：<https://www.studytonight.com/javascript/javascript-strings>

在 JavaScript 中，字符串是一系列字符，可以是字母、数字或特殊字符，可以简单地用引号括起来，也可以使用`String`全局对象创建。字符串的例子有“*今晚学习*”、“*今晚学习*”、“ *1234* ”、“ *@#@#* ”等。

我们将介绍在 JavaScript 中创建字符串的各种不同方式，以及我们可以对 JavaScript 字符串执行的各种操作，同时介绍一些最常见和最有用的`String`内置函数。

`String`对象是包装器类，也是全局对象的成员。`String`是 JavaScript 中用于文本处理的主要全局 obejct。

## 创建 JavaScript 字符串的方法

在 JavaScript 中，基本的**字符串字面值**也被视为字符串，我们可以将 string 全局对象的属性和方法用于字符串字面值。因此，我们可以说 JavaScript 为我们提供了创建字符串的不同方式，它们是:

1.  使用基本字符串或使用`String`构造器

2.  使用字符串全局对象-使用`new`关键字。

JavaScript 将**字符串字面值视为原始字符串类型**，使用字符串字面值或`String`构造器创建，而使用`new`关键字创建的字符串被视为`String`对象。但是 **JavaScript 会自动将原始字符串类型转换为** `String` **对象**，这样我们就可以将 string 全局对象的属性和方法一起使用了。

### 使用字符串字面值

为了创建一个字符串，我们可以使用一个**单引号或者一个双引号**来封闭字符序列。请参见下面的示例:

```js
let str = "Studytonight";   // double quote
let newstr = 'JavaScript';   // single quote
```

我们还可以使用**连接**，即使用`+`运算符，或者使用反斜杠字符来定义多行字符串。让我们看看两者的例子。

**使用字符串连接:**

```js
let longStr = "This is a long string" +
              " which is easy to define" +
              " using string concatenation" +
              " or in simple words - joining strings";
```

**使用反斜杠字符:**

```js
let longStr = "This is a long string \
which is easy to define \
using backslash character \
like this";
```

**字符串字面值作为模板字面值:**

同样，在 **ECMAScript2015** 中，字符串字面值被称为**模板字面值**，这意味着**我们可以使用`${ }`语法嵌入表达式**。让我们举个例子来看看这个:

```js
let str = 'world!';

// using backticks not single quotes
document.write(`hello ${str}`);
```

你好世界！

这些是创建字符串字面值的各种方法。

### 使用字符串构造器创建字符串

如果我们在 JavaScript 中有一个字符序列或任何其他数据类型(甚至是数组)，并且我们想将其转换为字符串基元类型，我们可以使用字符串构造器。以下是它的语法:

```js
String(anything);
```

让我们举个例子来理解这一点:

在上面的例子中，我们定义了一个数组，然后使用`String`构造器将其转换为字符串基元类型。我们还使用了`typeof`运算符来验证数据类型。

### 使用字符串对象

要创建一个新的字符串对象，我们使用`new`关键字。

```js
let obj = new String("studytonight");
document.write(typeof obj);
```

对象

在上面的代码示例中，我们创建了一个新的字符串对象。

## 字符串作为字符数组

JavaScript String 被视为一个字符数组，我们可以使用索引值访问它的字符，就像我们访问存储在数组中的数据一样。是的，每个字符串都有一个从 0 开始的索引值。

```js
let str = "StudyTonight"; 

let ch1 = str[0];   // Accessing using index
console.log(ch1);   // Output: S
```

S

同样，我们也可以遍历存储在字符串中的字符序列。

## JavaScript 字符串:迭代

由于字符串是字符序列，每个字符都有一个索引，所以我们可以使用 JavaScript 中的[循环来迭代它的字符。](https://www.studytonight.com/javascript/javascript-for-loop)

```js
let str = "hello"; 

for(let ch of str)
    document.write("<br>" + ch);
```

h
e
l
l
o

## JavaScript 字符串比较

在 JavaScript 中，我们可以通过使用比较运算符来**比较字符串值。是的，不需要函数，我们可以**使用小于或大于或等于运算符**来比较 JavaScript 中的两个字符串。**

```js
let str1 = "abc";
let str2 = "abc1";

let isEqual = (str1==str2);

document.write("Are the given two strings equal: " + isEqual);
```

给定的两个字符串是否相等:假

## 特殊字符

JavaScript Strings 支持在字符串内部使用引号，只要它们与字符串周围的引号不匹配，例如:*“这是一个字符串‘这是字符串内部的引号’”*这个字符串是有效的，因为字符串是使用双引号创建的，内部我们使用了单引号，但是在这种情况下，如果我们想要在字符串内部添加双引号，我们将不得不使用转义字符。

如果在字符串内部和周围使用相同的引号，那么字符串将被切成两半，因为它将把字符串内部使用的引号视为结束引号，为了避免这种情况，反斜杠转义字符(`\`)被用作**转义字符**。

JavaScript 中有各种转义符号:

1.  `\'` -避开单引号

2.  `\"` -避开双引号

3.  `\\` -转义反斜杠本身

还有一些特殊的字符:

1.  `\b` -退格

2.  `\f` -表单馈送

3.  `\n` -纽琳

4.  `\r` -回车

5.  `\t` -水平制表器

6.  `\v` -垂直制表器

## 字符串字面值和字符串对象之间的区别

虽然我们在开头就已经解释了这一点，但让我们举几个例子来看看两者之间的区别。当我们定义字符串字面值或字符串对象时，如上所述，我们可以使用`typeof`运算符来查找给定变量存储的是基元类型字符串还是字符串对象。

```js
let str = "This is a string";
let strObj = new String("This is also a string");

console.log(typeof str);
console.log(typeof strObj);
```

弦
物体

此外，当我们使用 eval()函数时，基元类型被视为源代码，其中一个字符串对象被视为另一个对象。让我们看一个例子:

```js
let str1 = '2 + 2'              // creates a string primitive
let str2 = new String('2 + 2')  // creates a String object
console.log(eval(str1))         
console.log(eval(str2))
```

4
2 + 2

如您所见，第一个字符串被计算为表达式，而 string 对象只是按原样打印。

至此，我们已经完成了对 JavaScript 字符串的基本介绍，涵盖了基本字符串类型和字符串对象以及一些常见的操作，如迭代等。在下一个教程中，我们将介绍 JavaScript 字符串类型的最常见方法。

* * *

* * *