# JavaScript 字符串方法

> 原文：<https://www.studytonight.com/javascript/javascript-string-methods>

JavaScript String 全局对象原型提供了预定义的方法和属性来处理与字符串相关的操作，使开发人员更容易执行文本处理。在本教程中，我们将通过代码示例讨论一些最有用的字符串方法。

## JavaScript 字符串`concat(str)`方法

该方法的语法为`str1.concat(str2)`，用于连接两个字符串`str1`和`str2`，并返回连接后的字符串作为结果。

### 字符串`concat()`方法示例:

下面我们有一个简单的代码示例来查看`concat()`函数的运行情况:

```js
let a = "Welcome to Studytonight";

let b = " to learn JavaScript";

let c = a.concat(b);

console.log(c);   // writes "Welcome to Studytonight to learn JavaScript"
```

这个函数就像串联运算符`+`一样，也用于连接两个字符串。

## JavaScript 字符串`toLowerCase()`方法

此方法用于将字符串转换为小写字母。这是一个简单的函数，一次对一个字符串进行操作，并将其所有字母字符转换成小写。让我们举个例子，

```js
let a = "WELCOME";

let b = a.toLowerCase();

console.log(b);   // Logs: welcome
```

欢迎

## JavaScript `toUpperCase()`方法

此方法将字符串转换为大写字母，并以大写形式返回结果。让我们举一个例子:

```js
let x = "studytonight";

let y = x.toUpperCase();

console.log(y);
```

今晚学习

## JavaScript 字符串`search()`方法

此方法搜索给定字符串值中的字符串或字符串的一部分(子字符串)，并返回要搜索的子字符串第一次出现的位置。

使用`search()`函数的语法是`str1.search(searchStr);`，其中`str1`是我们要在其中搜索`searchStr`字符串的字符串。

```js
let str =  "Please locate where locate occurs!";

console.log(str.search("locate"));    // Logs: 7
```

7

## JavaScript 字符串`slice()`方法

JavaScript String `slice()`方法用于提取字符串的一部分(一个子字符串)，它将提取的部分作为新字符串返回。该方法采用两个参数，**起始指标位置**和**结束指标位置**(其中结束指标不包含在输出中)。

如果参数为负，则从字符串末尾开始计算位置。

让我们举个例子来理解:

```js
let a = "Orange Banana Mango";

let subA = a.slice(7,14);   //result of subA will be Banana 

console.log(subA)
```

香蕉

在上面的例子中，我们使用了`slice()`方法来提取字符串的一部分，从**第 7 个索引开始，也就是 B 字符**，直到**第 14 个索引，也就是直到香蕉**之后的空格。

现在让我们尝试负指数:

```js
let a = "Orange Banana Mango";

let subA = a.slice(-7,19);   //result of subA will be "a Mango"

console.log(subA)
```

芒果

在上面的代码示例中，我们将**第一个索引指定为-7，因此它将从末尾**开始计数，将**第二个索引指定为正数，因此它将从前面**开始计数。您也可以同时使用两个负值。

## JavaScript 字符串`split()`方法

它用于根据给定的分隔符(如空格、连字符等)拆分字符串，并返回一个包含字符串断开部分的数组。让我们举个例子来理解它是如何工作的:

```js
let str = "x,y,z,u,v";   // this is a string

let arr = str.split(",");   //split based on commas

console.log(arr[0]);   // Logs: x
console.log(arr[1]);   // Logs: y 
```

x
y

## JavaScript 字符串`charAt()`方法

此方法返回字符串中指定索引(位置)处的字符。它**以索引值**为自变量。

让我们举个例子看看:

```js
let str = "Hello Studytonight";

let s = str.charAt(0);   //returns H
console.log(s);
```

H

## JavaScript 字符串`trim()`方法

`trim()`方法从字符串的开头和结尾移除多余的空格。让我们举个例子来理解它是如何工作的。

```js
let str = "          Hello StudyTonight JavaScript!                         ";

console.log(str.trim());
```

你好今晚学习 JavaScript！

在上面的例子中，我们有一个字符串，在前面和末尾有额外的空格。所以我们用`trim()`的方法去除它们。这个方法应该是**用来验证和修改用户在表单中的输入**来删除用户在任何表单值中添加的不必要的空格。

## JavaScript 字符串`replace()`方法

JavaScript 字符串`replace()`方法用给定字符串中的另一个值替换字符串的指定部分(子字符串或字符)。默认情况下，该方法仅**替换子串**的第一次出现，这意味着如果要替换的子串在主串中出现两次，则仅替换第一次出现的子串，并且**该方法区分大小写**。

让我们举个例子来理解它是如何工作的:

```js
let txt = "please visit google";

console.log(txt.replace("google", "StudyTonight"));

let newTxt = "Try to Google 'Google'";

console.log(newTxt.replace("Google", "Bing")); 
```

请访问今晚的学习
尝试搜索“谷歌”

如上例所示，只有第一个出现的子串*“Google”*被替换，而第二个保持不变。

## JavaScript 字符串`substring()`方法

这个方法类似于`slice()`方法。唯一不同的是`substring()`方法不接受负指数。在这个方法中，我们可以通过提供开始和结束索引来提取出主字符串的一部分。让我们举个例子:

```js
let str = "C,JAVA,PYTHON";

let res = str.substring(2,6);  

console.log(res)   // Logs: JAVA
```

JAVA

## JavaScript 字符串`substr()`方法

`substr()`方法与`slice()`方法相似，因为它也采用负值作为索引，但有一点不同。substr()方法将要提取的字符串长度作为第二个参数。例如，您可以指定从索引 2 开始，选择长度为 7 的字符串，这意味着直到索引 9。

让我们举个例子来理解这一点:

```js
let fruits = "Apple, Banana, Kiwi, Orange";

let substr = fruits.substr(6,6);
console.log(substr);
```

香蕉

## JavaScript 字符串内置方法:

下面是内置的字符串全局对象方法，我们可以使用 JavaScript 字符串。

| **方法** | **描述** |
| --- | --- |
| 夏拉特() | 

&#124; 返回指定索引(位置) &#124;

处的字符 |
| charCodeAt() | 

&#124; 返回指定索引处字符的 Unicode &#124;

 |
| 代码点 At() | codePointAt()方法返回一个非负整数，即 Unicode 代码点值。 |
| concat() | 

&#124; 它加入两个或多个字符串，并返回一个新加入的字符串 &#124;

 |
| endsWith（） | 

&#124; 检查字符串是否以指定的字符串/字符结束 &#124;

 |
| 包括() | 

&#124; 它检查一个字符串是否包含指定的字符串/字符 &#124;

 |
| 索引（） | 

&#124; 它返回字符串中第一个发现的指定值出现的位置 &#124;

 |
| lastIndexOf() | 

&#124; 它返回字符串中指定值最后一次出现的位置 &#124;

 |
| localeCompare() | 

&#124; 它比较当前地区的两个字符串 &#124;

 |
| 匹配() | 

&#124; 在字符串中搜索正则表达式匹配项，返回匹配项 &#124;

 |
| 重复() | 

&#124; 它返回一个新字符串，该字符串具有一个现有字符串的指定数量的副本 &#124;

 |
| 替换() | 它在字符串中搜索指定的值或正则表达式，并返回替换指定值的新字符串 |
| 搜索() | 它在字符串中搜索指定的值或正则表达式，并返回匹配的位置 |
| 切片() | 

&#124; 它提取一个字符串的一部分并返回一个新的字符串 &#124;

 |
| 拆分() | 

&#124; 它将一个字符串拆分成一个子字符串数组 &#124;

 |
| 开始开关() | 

&#124; 它检查字符串是否以指定字符开始 &#124;

 |
| 子字符串() | 它从字符串中提取字符，从指定的开始位置开始，通过指定数量的字符 |
| toLocaleLowerCase（） | 

&#124; 它把一个字符串转换成小写字母，根据宿主的语言环境 &#124;

 |
| toLocaleUpperCase() | 

&#124; 它把一个字符串转换成大写字母，根据宿主的语言环境 &#124;

 |
| toLowerCase() | 

&#124; 它把一个字符串转换成小写字母 &#124;

 |
| toString() | 

&#124; 它返回一个 String 对象的值 &#124;

 |
| toUpperCase() | 

&#124; 它把一个字符串转换成大写字母 &#124;

 |
| 修剪() | 

&#124; 它删除字符串两端的空白 &#124;

 |
| valueOf() | 

&#124; 它返回一个 String 对象的原始值 &#124;

 |

在本教程中，我们介绍了开发中最常用的重要字符串方法。

* * *

* * *