# JavaScript 数组

> 原文：<https://www.studytonight.com/javascript/javascript-array>

JavaScript Array 也类似于[数据类型](https://www.studytonight.com/javascript/javascript-data-types)，用于将**一个或多个相似类型或不同类型的值存储在一起**。它就像一个容器，用于在单个变量中存储值。我们可以使用数组来存储字符串类型、整数类型、对象或 JavaScript 中的任何其他有效数据类型的值，或者所有这些值。

JavaScript 中的数组是**“非”提供的连续内存位置**来存储其值。在 JavaScript 中，我们在声明数组时不必提供数组的长度，是的，我们可以简单地声明一个空数组，然后在其中添加任意多的元素。数组是**类似列表的对象**，在其原型中定义了许多内置函数，用于访问元素、添加元素、数组遍历等。

**JavaScript 没有定义数组的特定数组数据类型**。但是，有一个预定义的`Array`对象及其处理数组的方法。**数组在 JavaScript 中也有类似`length`的属性**，它不是函数而是属性。

我们可以通过使用`new`关键字或者使用**数组字面值符号**即`[]`(方括号)来创建 JavaScript 数组。

## 使用字面值符号的 JavaScript 数组

我们也可以使用数组字面值符号创建一个数组。数组字面值符号是括在方括号内的逗号分隔的项目列表。

### 使用数组字面值符号创建数组的语法:

使用数组字面值符号创建数组比使用`new`关键字创建数组简单。

```js
var arr = [ ];  // empty array

var fruits = ["mango","apple","orange","guava"];  // Array having elements
```

让我们举个例子，看看如何使用数组字面值符号创建一个简单的数组。

```js
<script>
    var arr = ["Yamaha","Honda","KTM"];
    console.log(arr.length)
</script> 
```

3

正如您在上面的代码示例中看到的，我们使用了数组的`length`属性来打印其中存在的元素的计数。数组的`length`属性在遍历数组时使用非常频繁。

## 使用`new`的 JavaScript 数组

*   每当我们不知道要插入数组中的元素的确切数量时，我们就创建一个空数组。

*   可以使用`new`关键字创建一个空数组。

*   然后我们可以使用`push()`方法在数组的末尾添加元素，或者使用`unshift()`方法添加到数组的前面。在 JavaScript 中，有许多不同的方法可以将数据添加到数组中。

### 创建数组的语法:

以下是使用`new`关键字创建数组的语法。

```js
let arr = new Array(); // empty array

let arr = new Array(10); // array of 10 elements size

let arr = new Array("Java","C","C++"); // array with 3 values
```

现在，让我们举一个简单的例子来看看这是如何实现的。

```js
<script>
    let fruits = new Array("mango","apple","banana","guava");
    console.log(fruits);
</script>
```

[“芒果”、“苹果”、“香蕉”、“番石榴”]

## JavaScript 数组:访问元素

我们可以通过使用存储数据元素的**索引**值来访问数组元素。存储在数组中的任何数据元素都存储在索引处。数组索引从 0 开始，一直到值(`Array.length` - 1)。因此，第一个元素将存储在索引值 0 处，最后一个元素存储在索引值(`Array.length` - 1)处

```js
let fruits = ["mango","apple","orange","guava"];   // Array having elements

console.log(fruits[0]);   // Accessing element
console.log(fruits[1]);   // Accessing element
console.log(fruits[fruits.length-1]);   // Accessing element
```

芒果
苹果
番石榴

## JavaScript 数组:遍历还是迭代

由于数组是一个对象，我们可以使用`for`循环迭代它的元素。在我们之前的教程中，我们已经介绍了循环 T2 的 JavaScript。我们在下面的例子中使用了 **for-of 循环**，但是您也可以使用简单的 **for 循环**。

```js
let fruits = ["mango", "apple", "orange", "guava"];  // Array having elements
for(f of fruits)    // Traversing array 
	document.wrtie(f + " ");
```

芒果苹果橘子番石榴

对于初学者，让我们看看一个使用基本的**进行循环**的数组遍历的例子，

```js
let fruits = ["mango", "apple", "orange", "guava"];  // Array having elements
// Traversing array 
for(let i=0; i < fruits.length; i++)    
{
	document.write(fruits[i] + " ");
}
```

### 阵列`forEach`功能:

要在数组上循环，我们也可以使用数组函数`forEach`，它是在其原型定义中定义的。让我们看一个例子，

```js
let bikes = ["Honda", "KTM", "Yamaha"];
// using forEach function
bikes.forEach(function(item, index, array) {
    document.write(item, index);
})
```

本田 0
【ktm 1】
雅马哈 2

## JavaScript 数组对象方法

下面我们已经指定了一些流行的方法，用于在 JavaScript 中对数组执行各种操作，比如添加新元素、移除元素、搜索元素的索引等。

1.`concat()`:连接两个或多个数组，并返回连接的数组。

2.`join()`:将数组的所有元素连接成一个字符串。

3.`pop()`:移除数组的最后一个元素并返回该元素。

4.`reverse()`:反转数组中元素列表的顺序。

5.`shift()`:移除数组的第一个元素并返回该元素。

6.`slice()`:选择数组的一部分，并将该部分作为新数组返回。

7.`sort()`:对数组的元素进行排序。

8.`push()`:添加新元素作为最后一个元素，返回新数组的长度。

9.`unshift()`:向数组中添加新元素并返回新长度。

10.`splice()`:添加或移除数组的元素。

11.`fill()`:用静态值将元素填充到数组中。

12.`every()`:判断一个数组的所有元素是否满足提供的函数条件。

13.`isArray()`:检查值是否为数组。

14.`indexOf()`:求数组中某个元素的索引。

15.`forEach()`:循环数组值。

除此之外，还有更多可用的阵列原型功能。让我们来看看其中的一些功能:

### 1.添加一个元素作为数组的最后一个元素

```js
let bikes = ["Honda", "KTM", "Yamaha"];
bikes.push("Triumph");
console.log(bikes);
```

【本田" " KTM " "雅马哈" "凯旋】

### 2.添加一个元素作为数组的第一个元素

```js
let bikes = ["Honda", "KTM", "Yamaha"];
bikes.unshift("Triumph");
console.log(bikes);
```

【凯旋】【本田】【KTM】【雅马哈】

### 3.查找数组元素的索引

```js
let bikes = ["Honda", "KTM", "Yamaha"];
// use console.log or document.write for output
console.log(bikes.indexOf("KTM"); 
```

1

### 4.反转数组

```js
let bikes = ["Honda", "KTM", "Yamaha"];
console.log(bikes.reverse());
```

【山河】、【KTM】、【本田】

同样，你可以在下面给出的直播终端中尝试各种功能。

## JavaScript 数组实时示例:

现在让我们来看看一些 JavaScript Array 代码的实际应用。在下面的终端中，我们已经声明了一个数组，并实现了一个遍历数组的循环。现在，请尝试使用上述功能，看看它们是如何工作的。练习代码将帮助您更快地掌握概念。

在本主题中，我们解释了 JavaScript Array 及其功能，以及通常在 Array 上执行的各种操作。我们已经介绍了多个代码示例来帮助您理解这个概念。

* * *

* * *