# JavaScript 正则表达式

> 原文：<https://www.studytonight.com/javascript/javascript-regular-expression>

在 JavaScript 中，正则表达式也称为正则表达式，是用于匹配、替换、比较字符串中的字符组合的模式。

当我们在文本中搜索一些特定的数据时，我们可以使用正则表达式作为搜索模式来描述您正在搜索的内容。

正则表达式可以是单个字符，也可以是更复杂的模式。

我们可以使用正则表达式执行任何类型的**文本搜索**和**文本替换**操作。

在 JavaScript 中使用正则表达式有两种不同的方式，它们是:

1.  使用正则表达式对象的构造器

2.  使用正则表达式字面值

在本教程中，我们将涵盖正则表达式字面值，并在涵盖 [JavaScript 对象](https://www.studytonight.com/javascript/javascript-objects)时详细涵盖 [`RegExp`对象](https://www.studytonight.com/javascript/the-regexp-object)。

## JavaScript 正则表达式文本:语法

我们可以使用正则表达式字面值，它由括在**斜线**之间的模式组成，如下所示:

```js
/*pattern*/*modifiers*;
```

正则表达式文本在脚本加载时编译。

在上面的语法中，模式可以是任何文本或字符串组合，其中修饰符/标志由 Javascript 提供。下面给出了一些标志。

| 

**【标志】t1㎡**

 | 

**描述**

 |
| --- | --- |
| `i` | 它用于执行不区分大小写的搜索。 |
| `g` | 它用于搜索所有匹配项，如果没有它，则只返回第一个匹配项。 |
| `m` | 搜索多行模式。 |
| `s` | 启用允许点的“点全”模式。匹配换行符\n。 |
| `u` | 启用完全 unicode 支持。 |
| `y` | 在文本中的准确位置搜索。 |

通常，正则表达式用于根据模式验证字符串，或者从字符串中提取特定的子字符串，或者检查字符串是否包含特定的子字符串，为了检查这一点，我们使用`RegExp.test()`函数。

### JavaScript 字符串`test()`、`replace()`和`match()`功能:

`test()`函数与提供字符串作为参数的正则表达式模式一起使用。使用`test()`函数的语法是:

```js
let re = "/SOME-EXPRESSION/";
let str = "some string";
// using test() function
let result = re.test(str);    // returns true on match else false
```

就像我们在上面的例子中使用`test()`函数来检查特定的字符串模式是否存在于给定的字符串中一样，当我们必须用其他字符串值替换字符串模式时，我们使用`replace()`函数和`match()`函数来匹配并返回匹配字符串。

让我们看几个例子来理解如何在 JavaScript 中使用正则表达式。

### 使用正则表达式字面值搜索

让我们在任何给定的字符串中使用正则表达式来搜索字符串**“hello”**。请参见下面的代码示例:

```js
<script>
	let re = /hello/;
	let str = "Hello Studytonight";
    // test() function is used with regular expression
	let result = re.test(str);
	document.write(result)
</script>
```

假

在上面的例子中，我们执行了一个搜索，在给定的字符串中寻找一个子字符串模式。在这里，我们没有使用任何标志，所以**默认情况下执行区分大小写的搜索**，这就是为什么我们得到的结果是 f **也是**。

### 使用正则表达式字面值搜索-忽略大小写

我们可以在忽略字符串大小写的情况下执行搜索，如果我们想搜索一个可能的模式，但我们并不是在寻找一个完全匹配的模式。对于使用正则表达式在字符串中执行不区分大小写的搜索，我们将使用 **`i`** 标志来启用忽略大小写的搜索。请参见下面的示例:

```js
<script>
	let re = "/hello/i";
	let str = "Hello Studytonight";
	let result = re.test(str);
    // use console.log or document.write
	document.write(result);
</script>
```

真

### 使用正则表达式替换字符串

在本例中，我们将用另一个字符串替换一个字符串模式。要替换字符串，我们将使用字符串对象的`replace()`方法，而不是`test()`方法。

```js
<script>
		// Creating regex literal
	    let re = "/(\w+)\s(\w+)/"
        let str = 'Delhi Noida';
        // Replacing string
        let newstr = str.replace(re, '$2, $1');
        document.write(newstr);
</script>
```

订婚，德里

### 在字符串中搜索模式

这里，我们使用`match()`方法进行搜索。如果匹配，此方法返回匹配的字符串。请参见下面的示例:

```js
<script>
		// Creating regex literal
		var regex = "/India/g";
        var str = "We live in India.";
        // search for india
        var matches = str.match(regex);
        document.write(matches)
</script>
```

印度

### JavaScript 正则表达式文本:验证电子邮件

JavaScript 中的正则表达式用于验证输入表单值，如电子邮件地址、密码、zipcode 或任何其他值。

让我们创建一个正则表达式来验证电子邮件地址，并使用它来检查给定的电子邮件地址是否有效。您可以很容易地在互联网上找到正则表达式来验证各种类型的输入。

```js
let str = "abc@gmail.com";
// regex pattern to match valid email
let re = /^\w+@[a-zA-Z_]+?\.[a-zA-Z]{2,3}$/
// test the 
let result = re.test(str);
if(result)
    document.write("Email is valid")
else
    document.write("Email is not valid")
```

邮件有效

在本教程中，我们学习了正则表达式，以及如何在 JavaScript 中使用它们来匹配字符串模式、替换字符串、验证用户输入等。我们在这里学到的是创建正则表达式的字面方法(就像在 array 中有两种方法一样)，我们也可以使用 JavaScript 中的正则表达式原型创建正则表达式对象。我们将在讨论 JavaScript 对象时了解它。

* * *

* * *