# JavaScript 默认参数

> 原文：<https://www.studytonight.com/javascript/javascript-default-parameters>

在 JavaScript 中，默认的函数参数是**参数，在声明 [JavaScript 函数](https://www.studytonight.com/javascript/javascript-functions)时提供一个默认值**。这很有用，因为我们可以为参数提供默认值，如果在调用函数时没有提供值，则可以使用默认值。

因此，如果在函数调用期间没有值或传递了`undefined`**，则默认函数参数用于用默认值**初始化命名参数。****

 **例如，如果您定义了一个函数，其中如果您提供了两个变量，它将第一个参数与第二个参数相除，并返回除法运算符的结果。现在，如果用户只提供一个参数，那么函数调用将失败。为了避免这种情况，您可以为第二个参数提供一个 defualt 值作为 1，这将把函数调用期间传递的单个参数除以默认值 1，而不是给出一个错误。

默认情况下，如果函数参数在函数调用期间没有被提供值，则在其中设置`undefined`。

## JavaScript 默认参数语法:

以下是默认函数参数的语法:

```js
function function_name([param1[ = defaultValue1][, ..., paramN[ = defaultValueN ]]]) 
{
    statements
}
```

这里需要注意的一点是，如果一个函数中有多个参数，比如说 2，你为第一个参数提供了默认值，而第二个参数没有默认值，那么在调用过程中，如果用单个参数调用该函数，它将被分配给第一个参数(有默认参数值的参数)，第二个参数将获得未定义的值，这是因为，参数分配是从左到右进行的。所以**在默认参数**之后不应该有没有默认值的参数。

例如，

```js
function printValue(a=1, b) {
    console.log("a = " + a + " and b = " + b);
}

printValue();    // Logs: a = 1 and b = undefined
printValue(7);    // Logs: a = 7 and b = undefined
printValue(7, 3);    // Logs: a = 7 and b = 3
```

在上面的代码中，当我们在调用函数时没有提供参数时，`a`使用了它的默认值，而`b`没有定义。然后，我们在调用函数的时候提供了一个参数，这个参数被赋值给了第一个参数`a`，因为参数的参数赋值是按顺序进行的，所以`b`又一次被欠训练了。

因此，一般来说，如果您不想为其他参数提供默认值，我们建议不要为第一个参数提供默认值，因为这会使您的代码变得混乱。

### JavaScript 默认参数示例

在这个例子中，我们正在为参数设置**默认值，并在没有参数**的情况下调用它。

```js
// default function parameters

function add(a=10, b=20)
{
	return a+b;
}

console.log(" Sum is : " + add());   // No argument
console.log(" Sum is : " + add(1));   // with one argument
console.log(" Sum is : " + add(5,6));   // with both argument
```

总和为:30
总和为:21
总和为:11

### 带有`null`或空参数的 JavaScript 默认参数

如果我们没有为函数参数提供任何值，那么就使用默认值，但是如果有人提供 null 或空字符串作为值呢。在这种情况下`null`和空值**被认为是有效的**，并且不使用默认参数值。

让我们举个例子来看看这个:

```js
function test(a = 1)
{
    console.log(typeof a);
    console.log("Value of a: " + a);
}

test();    // Logs: number Value of a: 1
test(undefined);    // Logs: number Value of a: 1

test('');    // Logs: string Value of a: 
test(null);    // Logs: object Value of a: null
```

正如我们在上面的例子中所看到的，不为参数提供任何值并且提供`undefined`作为值，两者都将导致函数使用默认参数值，但是当我们提供一个空字符串作为参数时，或者如果我们提供`null`作为参数，那么两者都被认为是**有效值，并且被用作参数值**而不是使用默认值。

### 默认参数在调用时计算

这是要考虑的默认参数的另一个重要特性。每次调用函数时都会创建 JavaScript 默认参数，这些参数不会被重用。让我们举个例子来理解这一点:

```js
function append(value, array = []) {
    array.push(value)
    return array
}

append(1)  // [1]
append(2)  // [2], not [1, 2]
```

## JavaScript 默认参数实时示例

让我们再举一个例子来看看缺省参数在 JavaScript 函数中的用法:

因此，在本教程中，我们学习了默认参数的概念。这是一个有用的概念，可以帮助您更好地发挥功能。在下一个教程中，我们将学习什么是休息参数，这是另一个重要的概念。

* * *

* * ***