# JavaScript 箭头函数

> 原文：<https://www.studytonight.com/javascript/javascript-arrow-function>

JavaScript Arrow 函数或 Arrow 函数表达式是常规 JavaScript 函数定义语法的一个更短的替代。它是在 ECMAScript2016 中引入的，它使得定义函数就像编写简单的表达式一样。

箭头函数可以有可选参数和一个返回语句，以及包含在大括号`{ }`中的函数定义。箭头函数表达式提供了紧凑的语法，但是这会使代码可读性降低。同样，由于它们不太像是函数，而更像是表达式，它们不太适合用于定义方法。**它们不能用作构造器**。

## JavaScript 箭头函数:语法

arrow 函数表达式支持多种不同的语法，我们将看到其中的一些。

```js
(param1, param2, …, paramN) => { statements } 

/* or for a single parameter */

(param1) => { statements } 

/* in case of no parameter */

() => { statements }
```

在**我们有单个参数**的情况下，使用参数`()`是可选的，我们也可以这样定义箭头函数表达式:

```js
param1 => { statements }
```

而**如果我们有一个单独的表达式来返回一些输出**，我们甚至可以跳过大括号`{}`如下:

```js
param1 => { return expression; }
/* can be written as*/
param1 => expression
```

上述语法也适用于多个参数。

### 换行符:

箭头函数的参数和箭头之间不能有换行符，但是我们可以在箭头之后有换行符。例如:

```js
var someFunc = (a, b, c)
  => 1;
// SyntaxError: expected expression, got '=>'

var someFunc = (a, b, c) => 
  1;
// No Sytax Error

var someFunc = (a, b, c) => (
  1
);
// No Sytax Error
```

让我们看一些代码示例。

### JavaScript 箭头函数示例:

查看普通 JavaScript 函数和箭头函数表达式之间的区别。让我们从创建一个常规函数开始，然后我们将定义它的箭头函数。

```js
// Example of a regular function
let add = function(a,b) {
    return a+b;
}

let sum = add(10,20);
console.log(sum);
```

30

现在让我们将上面的函数改为箭头函数表达式:

```js
// Arrow function
let add = (a,b) => { return a+b; }

let sum = add(10,20);

console.log(sum);
```

30

正如我们在上面的语法中所讨论的，我们可以进一步分解上面的箭头函数表达式，去掉大括号，因为这个表达式只有一个语句代码。

```js
// Arrow function
let add = (a,b) => a+b;

let sum = add(10,20);

console.log(sum);
```

现在，让我们再举几个涵盖不同场景的例子。

### 不带参数的 JavaScript 箭头函数:

就像常规函数一样，箭头函数也可以是非参数化的。让我们举个例子来看看如何实现它。

```js
// Arrow function - without parameter
show = () => { return "Hello from arrow function"; }

// Calling function
let msg = show();

console.log(msg);
```

箭头功能您好

同样，在这个例子中，我们甚至可以删除花括号`{}`和`return`关键字，就像我们在上面这个例子中所做的那样。

### 带默认参数的 JavaScript 箭头函数:

在 JavaScript 箭头函数中，我们还可以在定义箭头函数表达式时指定参数的默认值。让我们举个例子来理解这个概念。

```js
// Arrow function - with default parameters

let sum = (a,b=1) => a+b;

// Calling function
let result = sum(10);
console.log(result);
```

11

请记住，您不能只为第一个参数提供默认值，也不能为第二个参数提供默认值。要么为两者都提供默认值，要么只为第二个提供默认值。

### 不带括号的 JavaScript 箭头函数:

在这种情况下，如果函数中只有一个参数，那么可以省略参数周围的括号。让我们举个例子:

```js
// Arrow function without parenthesis
let show = a => "You entered: " + a

console.log(show(10));
```

你进入:10

## JavaScript 箭头函数:实时示例

现在让我们来看一个理解箭头函数的实例。请随意修改代码并更改下面定义的箭头函数以进行实践。

因此，在本教程中，我们学习了如何在 JavaScript 中使用 arrow 函数表达式以简写格式编写函数，这种简写格式易于定义和使用，但有时会导致您的代码变得难以理解。

* * *

* * *