# JavaScript 错误

> 原文：<https://www.studytonight.com/javascript/javascript-errors>

JavaScript Errors 被 JavaScript 用来通知开发人员正在执行的脚本中的各种问题。这些问题可能是语法错误，开发人员/程序员使用了错误的语法，也可能是由于一些错误的用户输入或其他问题。

JavaScript 以错误的形式报告这些问题，当您运行 JavaScript 代码时，可以在浏览器控制台中看到这些错误。

例如，如果我运行下面的 JavaScript 代码，

```js
/* 
    try to use variables a and b,
    without defining them
*/
let result = a + b;
```

未捕获的引用错误:未定义

在输出中可以看到， **JavaScript 抛出了一个 ReferenceError** ，这意味着没有找到变量`a`的引用。因为，要使用任何 [JavaScript 变量](https://www.studytonight.com/javascript/javascript-variables)，我们应该首先声明和定义它。

## JavaScript 错误类型

现在我们知道了什么是错误，它们可能由于许多不同的原因而发生。让我们看看 JavaScript 中有哪些不同类型的错误，以及几个例子。

每当发生运行时错误时，JavaScript 都会创建一个`Error`对象并抛出它。`Error`对象是其他特定错误类型所基于的基础对象。我们还可以在 JavaScript 中定义自定义用户定义的错误类型。

JavaScript `Error`对象有两个字段:

| 财产 | 描述 |
| --- | --- |
| `name` | 用于设置或获取错误的名称 |
| `message` | 用于设置或获取错误信息 |

以下是 JavaScript 根据错误类型可以抛出的 **6 类**`Error`对象:

| 错误对象 | 描述 |
| --- | --- |
| `EvalError` | 当`eval()`函数出现任何错误时，JavaScript 都会抛出这个错误。 |
| `RangeError` | 当一个数字或任何其他参数出现超出范围时，JavaScript 会抛出这个错误。 |
| `ReferenceError` | 当您试图使用一些没有声明或定义的变量或对象时，JavaScript 会抛出这个错误。 |
| `SyntaxError` | 当 JavaScript 代码的语法有问题时，JavaScript 会抛出这个错误。 |
| `TypeError` | 当代码中存在类型不匹配时，JavaScript 会抛出此错误。如果 JavaScript 需要某个其他类型的值，并且在代码中得到不同的类型。 |
| `URIError` | 当`encodeURI()`或`decodeURI()`函数出现任何错误时，JavaScript 都会抛出这个错误。 |

## JavaScript 抛出错误

每当在 JavaScript 代码执行过程中出现错误，代码执行就会停止，JavaScript 会在控制台中打印一个错误。这也叫**抛出错误**。这是所有编程语言中使用的标准术语。

JavaScript 在内部捕获错误，然后抛出它，这中断了代码的执行。

如果您想自己在代码中做同样的事情，您想中断代码执行并抛出错误，您可以使用`throw`语句来完成。

### JavaScript `throw`语句

我们可以在 JavaScript 代码中使用 throw 语句来抛出一个自定义的错误/异常，我们可以在抛出错误时提供一条消息。该消息可以是字符串消息、数字或任何布尔类型(**真**或**假**)。让我们举个例子来看看这个:

```js
throw "Some error message";
throw 404;
throw false;
```

未发现某些错误消息

当遇到`throw`语句时，代码执行中断，因此只有第一个`throw`语句被执行。为了处理由 JavaScript 或使用 throw 语句引发的错误，我们有`try`和`catch`块，我们将在下一个教程中介绍它们。

## JavaScript 自定义错误(用户定义的错误):

在 JavaScript 中，我们也可以定义我们的自定义`Error`对象。这里我们讨论了 ECMAScript2015 的方式，这是定义用户定义的错误类型的原型方式。

当您运行上述代码示例时，您将在浏览器的控制台中收到一条错误消息。要打开浏览器的开发者工具，请在窗口中按 **F12** ，在 Mac OSX 中按**命令+选项+ I** 。以下是输出:

MyError { name:“MyError”，消息:“这是自定义错误”，堆栈:“新 MyError 处的错误(<匿名> :6:31)

在 ECMAScript2016 中，我们可以定义自定义错误类，这将在后面的教程中介绍。

因此，在本教程中，我们获得了 JavaScript errors 的基本介绍，它的各种不同类型，如何使用 throw 语句抛出错误，以及如何编写自定义的 Error 类型。在下一个教程中，我们将学习如何在 JavaScript 中处理错误和异常。

* * *

* * *