# JavaScript 错误处理-`try`、`catch`、`finally`和`onerror`事件

> 原文：<https://www.studytonight.com/javascript/javascript-error-handling-try-catch-finally-and-onerror-event>

异常是当程序在语法上是正确的**时，由于非法操作而在执行时(运行时)发生的错误。例如，每当您试图引用未定义的变量或调用不存在的方法时；将出现异常。**

 **我们已经介绍了 [JavaScript 错误](https://www.studytonight.com/javascript/javascript-errors)，在本教程中，我们将介绍如何处理 JavaScript 代码中的错误和运行时异常，以避免代码执行突然结束。

因此，异常或错误处理从识别代码开始，我们认为当我们运行它时，代码可能会给出一些错误/异常。这样的代码块可以包含在一个特殊的`try`块中，这是一个特殊的代码块，如果出现任何运行时异常，那么我们可以在`catch`块中处理该异常。

要监控异常的语句包含在`try`块中。如果在`try`块内发生异常，那么它将被抛出。

您可以通过使用处理异常的`catch`块来捕获这个抛出的异常。

## JavaScript 中处理错误/异常的方法:

在 JavaScript 中处理异常主要有两种方式:

1.使用`try`、`catch`和`finally`语句

2.使用`onerror`事件

让我们逐一讨论上面给出的处理异常的方法。

## JavaScript `try`和`catch`语句

在 JavaScript 中，您必须编写这样的代码，如果在运行时生成错误/异常，则该代码位于`try`块内部，以便可以优雅地处理异常/错误。紧接着，在`try`块之后，应该有一个`catch`块，指定您想要**捕捉**的异常类型。

简单地说，我们要执行的代码语句被保存在 try 块中，后面是 catch 块。这就通知 JavaScript 去**尝试执行给定的代码语句**，如果有异常发生，**抛出，catch 块将捕获异常**，然后 catch 块内部的代码被执行。

### JavaScript `try`和`catch`语法:

让我们看看 try 和 catch 块的语法:

```js
try
{
    // code that can cause an error
}
catch(err)
{
    // what to do when an error occurs
}
```

在上面的语法中，有两个块`try`和`catch`。其中`try`块包含可能产生错误的可疑代码。如果发生错误，那么`try`块抛出由`catch`块捕获的异常，在该异常中我们可以按照自己的意愿处理它。我们可以显示用户可读的信息，也可以在[警告框](https://www.studytonight.com/javascript/javascript-popup-boxes)中显示错误信息。

### JavaScript `try`和`catch`示例:

让我们举个例子来看看 JavaScript `try`和`catch`块的作用:

在上面的代码中，我们创建了一个网页，展示了如何使用 try-catch 语句处理异常。它包含两个代码块- `try`和`catch`。

在`try`块中，我们试图打印未定义变量`n`的值，因此，`try`块抛出一个被`catch`块捕获的异常。然后`catch`块使用`err`参考显示存储在错误对象中的信息。

注意在`try`块中，还有一个包含 **Hello World 的`document.write()`函数调用！**字符串，该字符串从不执行，因为一旦抛出异常，程序会将控制从`try`块转移到`catch`块。

## JavaScript `finally`语句

我们还有一个称为`finally`语句的可选语句，它与`try`和`catch`语句相关联。它用于在执行 try 和 catch 代码块后执行一些代码。JavaScript `finally`语句确保`finally`块中的代码语句被执行，无论是什么。

### JavaScript `finally`语句:语法

`finally`语句用在`try`和`catch`语句之后，

```js
try
{
    // code that can cause an error
}
catch(err)
{
    // what to do when an error occurs
}
finally
{
    //code that execute in all the cases
}
```

不管是否抛出异常，try-catch 语句的可选`finally`块总是运行其代码。可能有两种情况:

*   如果`try`块**中的代码运行成功，没有任何异常**，那么`catch`块将不会被执行，但是`finally`块将被执行。

*   如果`try`块有错误，则执行`catch`块，之后执行`finally`块

每当控件通过显式的`return`语句从`try`或`catch`块返回调用方方法时，`finally`块就在控件返回之前执行。

简而言之，无论发生什么，如果你定义了一个`finally`块，它都会被执行。

### JavaScript `try`、`catch`和`finally`示例:

这里我们有另一个在 JavaScript 代码中处理运行时异常并使用`finally`语句的例子。

在上面的代码中，我们创建了一个显示 finally 块如何工作的网页。上面的代码包含三个块:try、catch 和 finally。try 块生成一个未定义的变量异常，该异常被 catch 块捕获。然后`finally`块执行并显示 Hello 世界字符串，即使异常已经发生。

## 处理异常的 JavaScript `onerror`事件

try-catch 语句未处理的任何错误都会导致在[窗口对象](https://www.studytonight.com/javascript/window-object)上触发`onerror`事件。`onerror`事件不创建事件对象，由有错误的窗口调用。

它接受三个论点:

1.  错误消息

2.  发生错误的页面的统一资源定位符

3.  包含错误的行号。

当`onerror`事件触发时，显示错误信息。网页的 URL，发生错误的行号。

### JavaScript `onerror`事件语法:

以下是使用`onerror`事件的语法:

```js
window.onerror = function(errmessage, url, line)
{
    alert(errmessage);
}
```

在上面的代码中，我们使用了 window 对象来调用`onerror`事件，我们可以为其指定一个事件处理函数。

### JavaScript `onerror`事件示例:

在本例中，我们使用`onerror`事件处理错误:

至此，我们已经完成了 JavaScript 异常处理教程。在本教程中，我们学习了用于在 JavaScript 代码中处理运行时异常的`try`、`catch`和`finally`语句，并介绍了使用`onerror`事件处理异常的另一种方式。

* * *

* * ***