# JavaScript Cookies

> 原文：<https://www.studytonight.com/javascript/javascript-cookies>

**JavaScript Cookie** 用于在客户端浏览器上存储一些有用的信息，这些信息可以在连续的 HTTP 请求中访问。

cookie 是一个包含信息的小文件，存储在客户端的计算机上，或者更具体地说，存储在客户端的浏览器中。每次当客户端请求网页时，服务器在显示所请求的网页之前参考所创建的 cookie 以获取信息。

让我们举一个简单的例子来理解 cookies 的概念，为什么需要它，以及我们如何使用它。嗯，如果你有一个网站，它没有用户登录系统，在你的网站上你有很多文章。您想在您的网站上添加一个新功能，其中用户已经阅读的文章将在网站上标记为已读。但是由于您没有用户登录系统，因此您无法在服务器(数据库)上保存此用户相关数据。在这种情况下，可以使用 cookies。我们可以创建一个 cookie，并存储在客户端的浏览器中，我们可以在 cookie 中添加用户已经阅读过的文章的网址(或其他标识)。当用户再次访问任何文章时，我们可以首先检查 cookie，如果我们在 cookie 中找到当前文章的网址，我们可以通知用户您已经阅读了它。

嗯，这就是我们如何使用饼干。存储有用的信息，我们可以在进一步的请求中检索这些信息来了解用户。

cookie 的**大小取决于浏览器，但一般不应超过 **1K** (1，024 字节)。所以我们应该小心我们储存在饼干里的东西。**

cookie 通常用于在计算机上存储用户信息，以便每当用户再次访问网站时，您可以知道该用户是您的旧用户。

一个 **cookie 有几个属性**，这些属性包含关于 cookie 的重要信息，例如它的**名称**、它所属的**域名**以及域内有效路径的**地址。**

下面给出了一些常用属性:

### 1.Cookie 名称属性

它表示要存储在 cookie 中的变量名和相应的值。

### 2.Cookie 过期属性

它指定 cookie 将被删除的时间。它被表示为一个 Unix 时间戳。一般来说，cookie 不会从浏览器中删除，它会过期。

### 3.Cookie 域属性

它表示 cookie 所属的域名(部分或完整)。

例如，如果有效域属性的值为*www.studytonight.com*，则每次用户访问*www.studytonight.com*网站时，客户端(浏览器)都会将 cookie 信息作为 HTTP 请求的一部分发送给网络服务器。

<u>**注意:**</u> 浏览器只会提供与 HTTP 请求中当前 URL 域属性值相同的 cookie。

### 4.Cookie 路径属性

此属性用于为同一域名创建路径特定的 cookies。例如，如果我们想为**studytonight.com 根路径(/**)创建一个 cookie，为**studytonight.com/code/playground**创建另一个 cookie，用于实时编码部分，那么我们可以使用 cookie 路径属性来区分这些 cookie。

它根据同一个域中的不同路径来识别网站。将该属性设置为**服务器根(/)允许整个域访问存储在 cookie 中的信息**。

### 5.Cookie 安全属性

它限制浏览器通过不安全的连接发送 cookie 信息。如果没有设置，它允许通过任何类型的超文本传输协议(HTTP)连接发送 cookie。

安全标志属性的默认值为 **0** 。将该值设置为 **1** 仅允许通过**安全 HTTP 连接**发送 cookie。

## 创建和存储 Cookies

在 JavaScript 中，您可以创建自己的 cookies 来存储用户信息或任何您想要的信息。

要创建 cookie，请使用`document.cookie`属性。设置 cookie **值**、**路径**指定存储 cookie 的位置，**过期日期**设置 cookie 的有效期。

以下是创建 cookie 的语法:

```js
document.cookie = cookieString;
```

其中，`cookieString`是一串形式**键=值**，将保存在 cookie 中。除了这些信息，我们还可以提供诸如 cookie 的最大年龄、cookie 的到期时间、cookie 的路径属性(它是自动提取的)等信息。用分号(`;`)分隔每个**键=值**对。

以下是每个附加可选属性的语法，您可以将其附加到 cookie 字符串中，以便在创建 cookie 时提供更多信息。

| Cookie 属性 | 描述 |
| --- | --- |
| ；路径= *某个路径* | 默认情况下，cookie 是为当前网址创建的，但是我们可以在创建 cookie 时通过为此属性提供值来更改它。例如:

```js
document.write = "username=John Wick;path=/profile";
```

该 cookie 将为当前域名的路径**/配置文件**创建。 |
| ；域名= *域名* | 默认情况下，这将再次作为当前域名。此外，如果您试图提供一个不同于当前加载 JavaScript 代码的域名，浏览器将忽略您的请求。 |
| ；最大年龄= *最大年龄(秒)* | 指定 cookie 应该存在或不应该过期的时间。它的价值可以是`60*60*24*365`或 31536000 一年，或 3600 一天。 |
| ；过期=*GMTString 格式的日期* | 此属性用于指定 cookie 过期的确切时间。如果我们不提供该属性或`max-age`属性，那么 cookie 将在为其创建 cookie 的当前会话结束时过期。 |
| ；安全的 | 指定只能通过安全的 HTTP 连接提供 cookie。例如:

```js
document.write = "username=John Wick;secure";
```

 |
| ；同一地点 | 此属性用于防止浏览器发送跨站点请求的 cookie 数据。 |

### 示例创建 Cookies

在下面的代码示例中，我们创建了一个带有一些附加信息的 cookie，

```js
document.cookie = "username=johnwick; expires=Thu, 17 May 2020 10:30:00 IST; path=/"; 
```

在上面的代码中，我们创建了一个 cookie 来存储网站访问者的**名称。正如您在上面的代码示例中看到的，cookie 只不过是一个附加了所有信息的字符串，用分号(`;`)隔开。**

## JavaScript 读取 Cookies

要读取 cookie，我们可以使用`document.cookie`属性。它将返回当前位置路径中存储的所有 cookie。

```js
var x = document.cookie;
```

让我们举一个简单的例子来理解这一点:

```js
<html>
    <head>
        <title>
            Using onerror Event
        </title>
        <script type="text/javascript">
        document.cookie = "name=johnwick";
        document.cookie = "favorite_car=1969FordMustang";
        function alertCookie() {
            alert(document.cookie);
        }
        </script>
    </head>
    <body>
        <!-- HTML body -->
        <button onclick="alertCookie()">Show cookies</button>
    </body>
</html>
```

名称= johnwick 最喜欢的 _ 汽车= 1969 福特野马

当您点击按钮时，您将在警报框中获得上述输出。所以，储存饼干然后读回来非常容易。

## JavaScript 更新 Cookie 值

要更新 cookie，只需为它设置一个新值，并确保路径应该相同，这样它将更新 cookie，而不是创建一个新的 cookie。

```js
document.cookie = "username=BruceWayne; expires=Sat, 15 Aug 2020 12:00:00 UTC; path=/"; 
```

它将覆盖旧的 cookie 值。

## 删除 Cookie

要删除一个 cookie，我们需要**为该 cookie 设置一个过去的过期日期**来立即删除它，或者我们可以在创建 cookie 时设置一个过期日期来指定该 cookie 应该被删除的时间。

```js
document.cookie = "username=BruceWayne; expires=Thu, 10 Jan 2020 00:00:00 UTC; path=/;"; 
```

您应该定义 cookie 路径，以确保删除正确的 cookie。

* * *

* * *