# JavaScript 对象

> 原文：<https://www.studytonight.com/javascript/javascript-objects>

在 JavaScript 中，我们可以将一个对象定义为属性的集合，这些属性被定义为键值对，其中键是可以赋值的对象特征的通用名。不要把这个对象和类对象混淆，在类对象中，我们定义一个类，然后为它创建一个对象。

在 JavaScript 中，对象是一个独立的实体，对象的属性定义了对象的特征。

例如，如果我们将一部**手机**视为一个对象，那么它的属性就是它的颜色、屏幕大小、品牌名称、操作系统、内存、内存等。所有这些属性定义了手机的特性。

对象的属性是一个**键:值**对，其中**键**指的是一个变量，**值**指的是与该键关联的任何类型的值。该值可以是任何类型，如数字、字符串，甚至是数组或其他对象。

我们可以使用**构造器**或者对象**字面值**在 JavaScript 中创建一个对象。

## 创建一个 JavaScript 对象

我们可以通过使用`Object`构造器或者使用对象字面值语法来创建一个 JavaScript 对象。下面我们有一个创建对象的基本语法，它是使用两种方式的 JavaScript:

```js
/* Using Object constructor */
let obj1 = new Object();
/* Using the object literal syntax - empty object */
let obj2 = {};
/* Using the object literal syntax - with properties */
let obj3 = { key1:value1, key2:value2, ...};
```

当我们使用对象构造器创建一个对象时，我们首先创建一个空对象，然后为其分配属性，而在对象字面值语法的情况下，我们可以创建一个**空对象**或者在创建对象时在**大括号**内指定属性。

不需要混淆，JavaScript 为创建对象提供了多种不同的方法。让我们举几个例子来介绍用 JavaScript 创建对象的不同方法。

### 使用对象构造器的 JavaScript 对象

我们可以使用`new`关键字创建一个对象的直接实例:

```js
let mobile = new Object();
```

然后可以使用点运算符(`.`)为其分配属性，如下所示:

```js
mobile.name = 'Blackberry';
mobile.color = 'Black';
mobile.price = 40000;
```

我们还可以像这样一次创建对象并为其分配属性，

```js
let mobile = new Object(),
             color = 'Black',
             price = 40000,
             specifications = new Object();
```

正如您在上面的代码示例中看到的，我们的对象有一个属性，它也是一个对象。

### 使用对象字面值语法的 JavaScript 对象

使用对象字面值语法创建对象，我们使用花括号`{ }`。这也是首选的方式，也是比较简单的方式，但是和`Object`构造器一样。我们可以在花括号内定义这个对象的属性。

让我们创建一个对象，**手机**，其属性为*颜色*、*名称*、*价格*。

```js
let mobile = {         
    name: "Apple iPhone",
    color: "Black",
    price: 100000      
}; 
```

在**移动**对象中，有三个属性:

1.  第一个属性有键**名称**和值“**苹果 iPhone** ”。

2.  第二个有键**色**，值“B **缺**”。

3.  第三套房产有钥匙**价格**和价值 **10 万**。

## 访问 JavaScript 对象属性

要获取对象的属性，我们可以使用点(`.`)运算符，后跟**属性**名称或键。见下面的例子，

无论如何创建对象，访问属性的方式都将保持不变。

### 使用方括号符号:

我们还可以使用方括号符号来访问使用属性名称或键的任何属性。JavaScript 对象类似于**关联数组**，因为关联数组也有命名索引值，不同于简单数组中的数值索引值。

让我们举个例子来看看如何使用方括号符号来访问对象属性:

```js
/* JS comes here */
let mobile = {         
    name: "Samsung",
    color: "black",
    price: 40000      
};

// Accessing property using square brackets
document.write(mobile['name']);
document.write("<br>"+mobile['color']);
```

就像我们访问属性值一样，我们也可以向对象添加新属性。

## 向 JavaScript 对象添加新属性

JavaScript 允许我们向现有对象添加新属性。请参见下面的示例:

```js
let mobile = {         // an object
  name: "BlackBerry",  // property
  color: "black",
  price: 40000      
};

// Adding New Property
mobile.weight = "100gm"

// Accessing newly added property
document.write(mobile.weight) 
```

100 克

### 使用方括号符号:

我们还可以使用方括号符号来设置使用属性名称或键的任何属性。

让我们举个例子来看看如何使用方括号符号来访问对象属性:

```js
/* JS comes here */
let mobile = {         
    name: "Samsung",
    color: "black",
    price: 40000      
};

// setting property using square brackets
mobile['screen'] = "5 in";
```

## 移除 JavaScript 对象的属性

如果我们想从对象中移除任何属性，那么我们可以通过使用`delete` 运算符轻松完成。请参见下面的示例:

```js
let mobile = {         // an object
  name: "BlackBerry",  // property
  color: "black",
  price: 40000      
};

// Deleting Property
delete mobile.price;

// Trying to access deleted property
document.write(mobile.price);   // Undefined 
```

未定义

## 更新 JavaScript 对象的属性

允许用新的 JavaScript 对象属性值更新该对象属性值。要更新任何属性，只需为其分配一个新值。请参见下面的示例:

```js
let mobile = {         // an object
  name: "BlackBerry",  // property
  color: "black",
  price: 40000 
};

// Updating property 
mobile.color = "Pearl White";

// Accessing Property
document.write(mobile.color); 
```

珍珠白

## 对象:处理多字属性

JavaScript 允许我们创建多字属性，但是很少注意，因为使用点(`.`)操作符访问多字属性会产生**语法错误**。所以，为了避免这个错误，我们应该使用**方括号(** `[]` **)** 。

让我们举个例子来看看这个:

```js
let mobile = {         // an object
  name: "BlackBerry",  // property
  color: "black",
  "latest price": 40000      // multiword should enclose with double quotes
};

// setting multiword property key-value with square brackets
mobile["screen size"] = "5 in";

// Accessing Property using square brackets
document.write(mobile["latest price"]); 
```

4 万

如果我们试图使用点运算符(`.`)来访问多字键属性，我们将会得到一个语法错误。

## 遍历 JavaScript 对象

我们可以使用 [**在**循环](https://www.studytonight.com/javascript/javascript-for-loop)中遍历对象的属性。它返回与对象相关联的键，这些键还可以用来获取值。请参见下面的示例:

```js
let mobile = {         // an object
  name: "BlackBerry",  // property
  color: "black",
  price: 40000
};

// Traversing object
for (key in mobile) {
	document.write(mobile[key]+"<br>")
} 
```

黑莓
黑色
4 万

## JavaScript 对象中的创建方法

我们也可以在对象中定义方法。一个**方法**是一个与对象相关联的函数。方法被定义为正常的 [JavaScript 函数](https://www.studytonight.com/javascript/javascript-functions)被定义，除了它们必须作为属性被分配给一个对象。

### 定义 JavaScript 对象方法:

这里，我们定义了一个方法`showInfo` ，它将显示关于对象的信息，即所有对象属性。

```js
let mobile = {         // an object
    name: "BlackBerry",  // property
    color: "black",
    price: 40000

    // defining method
    showInfo: function() {
        document.write(this.name+" "this.color+" "+this.price);
    }
};
```

### 访问 JavaScript 对象方法:

访问或调用一个方法非常容易，只需在对象名中使用点(`.`)运算符:

```js
var mobile = {         // an object
    name: "BlackBerry",  // property
    color: "black",
    price: 40000,

    // method
    showInfo: function() {
        document.write(this.name+" "+this.color+" "+this.price)
    },
};

// Calling method
mobile.showInfo();
```

黑莓黑 4 万

## JavaScript 内置对象

JavaScript 有丰富的内置对象集，可以用来处理各种类型的集合。下面列出了一些常用的内置类型。

1.  线

2.  正则表达式

3.  布尔代数学体系的

4.  数字

5.  排列

6.  数学

7.  日期

在接下来的几个教程中，我们将介绍内置的 JavaScript 对象，还将学习如何在 JaavaScript 中创建自定义的用户定义对象。

* * *

* * *