# JavaScript 用户定义的对象类型

> 原文：<https://www.studytonight.com/javascript/javascript-userdefined-object-type>

本教程涵盖了 JavaScript 中用户定义对象类型的概念。我们已经介绍了 [JavaScript 对象](https://www.studytonight.com/javascript/javascript-objects)，它是使用**对象初始化器语法**或**对象构造器**语法创建的，并且创建了一个`Object`类型的实例。

就像默认的对象类型一样，使用它我们可以在 JavaScript 中创建对象，我们可以定义自定义类型，使用它我们可以在 JavaScript 中创建自定义对象。

## 创建用户定义的 JavaScript 对象类型

我们可以通过编写构造器来定义自定义对象类型，其中函数的名称应该以大写字母开头，例如 *Car* 、 *Cup* 、 *Human* 等。

构造器的定义就像我们定义任何其他用户定义的 [JavaScript 函数](https://www.studytonight.com/javascript/javascript-functions)一样。

以下是定义构造器的**语法:**

```js
function Xyz(param1, param2, ... , paramN)
{
    this.param1 = param1;
    this.param2 = param2;
    ...
    this.paramN = paramN;    
}
```

一旦我们定义了构造器，我们就可以用它来创建一个使用`new`关键字的对象，如下所示:

```js
let customObj = new Xyz(paramValue1, paramValue2, paramValue3, ... , paramValueN);
```

### 使用`this`关键词

在 JavaScript 中，我们使用`this`关键字来引用当前对象，因此在构造器中，我们创建新的属性(*参数 1* 、*参数 2* ，...)为对象类型，我们使用`new`关键字设置对象创建时提供的参数值。

### 需要记住的几点:

1.  我们可以根据需要多次更新构造器，添加更多属性或从中移除属性。

2.  我们也可以在使用`new`关键字创建对象时，在对象的属性中存储另一个对象。

3.  在定义用户定义的对象类型的构造器时，我们可以使用[默认参数](https://www.studytonight.com/javascript/javascript-default-parameters)来指定默认值和[剩余参数](https://www.studytonight.com/javascript/javascript-rest-parameters)。

现在让我们举几个例子来看看如何定义一个自定义的对象类型，并使用`new`关键字创建一个对象。

## 用户定义的 JavaScript 对象类型示例

在下面的代码示例中，我们为对象类型**自行车**创建了一个新的构造器，然后使用`new`关键字创建了一个对象。

一旦我们为自行车定义了构造器，我们就可以创建任意多的自行车类型的对象。我们可以在创建对象时设置不同的属性值。例如，

```js
let myBike = new Bike("KTM", "Duke", 2020);
let yourBike = new Bike("Royal Enfield", "Classis", 2020);
```

我们可以使用 JavaScript 操作符比较这些对象，也可以执行许多其他操作。

### 使用用户定义的对象作为另一个对象的属性

让我们再定义一个对象类型，然后将其用作我们的**自行车**对象类型中的一个值。

我们在下面定义了一个新的对象类型**人**，并且在**自行车**对象类型中增加了一个新的属性**车主**，我们将在其中存储**人**对象。

我们可以用 JavaScript 中用户定义的对象类型做任何事情。

## 使用`Object.create`方法

如果您不想麻烦定义一个构造器方法来定义一个用户定义的对象类型，您可以使用 Object.create()方法来创建任何已经定义的原型对象的对象。

让我们举个例子来理解这一点。

```js
let Bike = {
    company: 'KTM',  // Default value of properties
    model: 'Duke 390',
    show: function() {  // Method to display property type of Bike
        document.write(this.company+" "+this.model);
    }
};

// using Object.create to create a new object
let newBike = Object.create(Bike);
newBike.company = 'Yamaha';
newBike.model = 'R15';
newBike.show();
```

雅马哈 R15

正如您在上面的代码中看到的，我们可以使用`Object.create`方法使用已经定义的对象创建一个新的对象，然后如果需要，我们可以更改属性值并使用对象函数。

本教程到此结束。在下一个教程中，我们将逐一介绍各种内置的 JavaScript 对象。

* * *

* * *