# JavaScript 布尔对象

> 原文：<https://www.studytonight.com/javascript/javascript-boolean-object>

JavaScript 布尔对象是全局对象和包装类的成员。它用于创建一个布尔对象，根据创建布尔对象时使用的值，该对象保存**真**或**假**值。

布尔对象的**真**和**假**值不同于**原始布尔类型的**真值和假值。

如前所述，它有两个值，真和假。在创建布尔对象时，当传递诸如 0、-0、空字符串(`""`)、false、`null`、`undefined`或 Not Number(NaN)等值时，布尔对象返回 **false** 。除了将布尔对象的初始值设置为**假**的所有这些值之外，所有其他值，甚至空数组(`[]`)、空对象(`{}`)或字符串“**假**”，都将布尔对象的初始值设置为**真**。

## 创建 JavaScript 布尔对象

为了创建布尔对象的实例，我们在布尔对象构造器中使用`new`关键字，在创建时提供一个值。

以下是它的语法:

```js
let bool = new Boolean(SOME_VALUE);
```

根据传递的值，初始值被设置为**真**或**假**。

让我们举个例子，

```js
// Creating Boolean Object
let boolObj = new Boolean(true);  
document.write(boolObj);

boolObj = new Boolean(false);  
document.write("<br>"+boolObj); 
```

真
假

## JavaScript 布尔对象假

如果对象创建时提供的值为 **0** 、 **-0** 、`NaN`、`null`、`undefined`，则 JavaScript Boolean Object 的初始值为 false，为 false，为空字符串，或者即使没有提供值，因为默认值也为 false。

```js
let obj1 = new Boolean();
let obj2 = new Boolean(0);
let obj3 = new Boolean(null);
let obj4 = new Boolean('');
let obj5 = new Boolean(false);

document.write(obj1+" "+obj2+" "+obj3+" "+obj4+" "+obj5)
```

假假假假假

## JavaScript 布尔对象真

除了上面指定的布尔对象初始值为假的值之外，所有其他值都将该值设置为真。让我们举几个例子，

```js
let obj1 = new Boolean(true);
let obj2 = new Boolean('true');
let obj3 = new Boolean('false');
let obj4 = new Boolean('hello');
let obj5 = new Boolean([]);
let obj6 = new Boolean({});

document.write(obj1+" "+obj2+" "+obj3+" "+obj4+" "+obj5+" "+obj6)
```

真真真真真真真

## JavaScript 布尔对象与基本布尔类型

正如我们已经提到的，布尔对象和基本布尔类型是不同的。布尔对象是一个 JavaScript 对象，不是一个原语类型，而是一个对象类型，其值可以是**真**或**假**。

让我们举个例子，在这里我们将看到布尔对象和原始布尔类型在 [JavaScript 条件语句](https://www.studytonight.com/javascript/javascript-if-else-and-else-if-statements)表达式中使用时的行为。

```js
// Boolean object
let obj = new Boolean(false);

// using in if condition 
if(obj)
{
	document.write("It is boolean object"); // executes
}

// Primitive value
let bool = false;
if(bool)
{
	document.write("It is primitive boolean"); // does not execute
}
```

是布尔对象

不管布尔对象的**假**值如何，都会执行第一个`if`语句，这是因为当我们在`if`条件中提供一个对象时，它总是被评估为真。

我们可以通过使用布尔对象的`valueOf()`方法来获得布尔对象的值，然后它将被视为正常的原始类型**真**或**假**值。

### 将布尔对象转换为基元

我们可以使用布尔对象的`valueOf()`方法来访问它的值，

```js
// Boolean object
let obj = new Boolean(false);

// using the value of Boolean object in condition 
if(obj.valueOf()){
	document.write("It is boolean object");   // does not execute
}
else{ 
	document.write("boolean value is false");   // executes
}
```

布尔值为假

## 布尔对象的方法

以下是布尔对象的一些常用方法。

1.  `toString():`将布尔值转换为字符串并返回该字符串。

2.  `valueOf():`返回布尔对象的基元值。

## JavaScript 布尔对象示例

让我们看看布尔对象的另一个代码示例:

在本教程中，我们已经介绍了布尔对象、它的方法、它与基本布尔类型的区别以及多个代码示例。

* * *

* * *