# JavaScript 数字对象

> 原文：<https://www.studytonight.com/javascript/javascript-number-object>

JavaScript Number 是一个内置的包装对象，用于处理数值。可以使用`Number()`构造器创建一个数字对象。

所有数字都是 64 位(8 字节)浮点数。不像 C 或 C++，没有像**整数**、**浮点数、**等数据类型可以在 JavaScript 中定义数字(最近有了 ECMAScript2016，JavaScript 已经开始支持整数的`BigInt`类型)。

## 创建 JavaScript 数字对象

如果我们使用带有`new`关键字的`Number()`构造器，我们可以创建 Number 对象。

```js
let num = new Number(SOME_NUMERIC_VALUE);
```

如果我们使用`Number()`函数(在非构造器上下文中)**而不使用**`new`关键字，它将创建一个**原始数字类型**，该类型也可用于类型转换。

让我们举个例子，

```js
let x = new Number(290.78);
document.write(x + "<br/>");
document.write(typeof x + "<br/>");
```

290.78
物体

因为 Number 是一个内置对象，所以它有一些属性和方法可以处理数字类型。

## 数字对象属性

以下是数字对象的属性:

| 财产 | 描述 |
| --- | --- |
| `Number.EPSILON` | 两个可表示数字之间的最小间隔。 |
| `Number.MAX_SAFE_INTEGER` | 返回 JavaScript 中最大可能的安全整数值，即 253 - 1 |
| `Number.MAX_VALUE` | 返回可表示的最大正数 |
| `Number.MIN_SAFE_INTEGER` | 返回 JavaScript 中可能的最小安全整数值，即-(253 - 1) |
| `Number.MIN_VALUE` | 返回在 JavaScript 中可能表示的最小数值。 |
| `Number.NaN` | 它代表特殊的“非数字”值 |
| `Number.NEGATIVE_INFINITY` | 它代表负无穷大的值。 |
| `Number.POSITIVE_INFINITY` | 它代表负无穷大的值。 |
| `Number.prototype` | 这可用于向 Number 对象添加更多属性 |

<u>**注意:**</u> 任何大于`MAX_SAFE_INTEGER`值的值在用 JavaScript 处理时都会被破坏。

让我们举一个例子来看看这些属性的作用。

```js
// Range of Number
document.write(Number.MIN_VALUE+"<br>")
document.write(Number.MAX_VALUE+"<br>")
document.write(Number.NEGATIVE_INFINITY+"<br>")
document.write(Number.POSITIVE_INFINITY+"<br>")
document.write(Number.prototype+"<br>")
document.write(Number.MIN_SAFE_INTEGER+"<br>")
document.write(Number.MAX_SAFE_INTEGER+"<br>") 
```

5e-324
1.7976931348623157 e+308
-Infinity
Infinity
0
-9007199254740991
9007199254740991

## 数字对象方法

JavaScript Number 对象既有**静态方法**(在没有创建任何 Number 对象的情况下使用)也有**实例方法**(在对象上使用)。以下是 Number 对象最常用的方法:

| 方法名 | 描述 |
| --- | --- |
| `Number.isNaN()` | 静态方法；用于检查给定值是否为 NaN。 |
| `Number.isFinite()` | 静态方法；用于检查给定值是否为有限数。 |
| `Number.isInteger()` | 静态方法；用于检查给定值是否为整数。 |
| `Number.isSafeInteger()` | 静态方法；用于检查给定值是否为安全值，即在 253 - 1 到-(253 - 1)之间 |
| `Number.parseFloat(string)` | 静态方法；用于将字符串转换为浮点数。 |
| `Number.parseInt(string, [radix])` | 静态方法；用于将字符串转换为整数。这里基数代表数学数字系统的基数。 |
| `valueOf()` | 返回数字对象的原始值。 |
| `toString()` | 返回数字对象的字符串值。 |
| `toFixed(x)` | 将数字四舍五入到小数点后的 x 位。 |
| `toPrecision(x)` | 将数字向上舍入到 x 位数的长度。 |
| `toExponential(x)` | 将数字转换为指数记数法。 |

让我们举几个例子来看看其中的一些功能。

### 将数字对象转换为基本对象

Number 对象提供了一种方法`valueOf()`，可用于将 Number 对象转换为基本类型。

```js
let x = new Number(290.78);
document.write(typeof x + "<br/>");

// Conversion from object to number
let num = x.valueOf()
document.write(typeof num + "<br/>");
```

对象
号

### 在非构造器上下文中使用数字

正如我们在开头提到的，如果我们使用 **Number** 函数**而没有**这个`new`关键字，我们可以用它来进行类型转换。让我们看几个例子:

```js
// using the Date object
let d = new Date('December 17, 1995 03:24:00');
console.log(Number(d));    // Logs: 819199440000
```

上面的代码将给出输出 819199440000，它是指定日期的 UNIX 时间戳等价物。这样日期就成功转换成了数字。

此外，我们可以使用**数字**功能进行如下更简单的转换:

```js
Number('77');        // 77
Number('70.7');      // 70.7
Number('');          // 0
Number('foo');       // NaN
Number('-Infinity'); // -Infinity
Number(null);        // 0
```

## JavaScript 数字对象示例

在这个例子中，我们使用内置方法来理解它们的用途。

您可以使用 **Number** 对象来检查任何值的类型，例如，如果您必须验证给定的值是否是数字，则可以使用`Number.isNaN`方法。同样，您也可以使用 Number 对象属性在脚本中分配允许的最大值和最小值。

* * *

* * *