# JavaScript 数学对象

> 原文：<https://www.studytonight.com/javascript/javascript-math-object>

在 JavaScript 中，数学是一个内置对象，它包括数学运算的属性和方法。我们可以使用数学对象来执行简单和复杂的算术运算。

<u>**注:**</u> 数学仅适用于 [JavaScript Number](https://www.studytonight.com/javascript/javascript-number-object) 类型。

在数学对象中，所有的属性和方法都是静态的。因此，我们不需要创建它的对象来使用它的属性或方法。同样，即使我们想要，我们也不能创建一个对象，因为**数学不是构造器**函数。

## 使用 JavaScript 数学

假设，我们想在程序中得到用于几何计算的**π**的值或一个数的平方根，那么我们可以使用数学对象。让我们看看如何:

```js
let pi = Math.PI;
document.write(pi + "<br/>");

let sqrt = Math.sqrt(9);
document.write(sqrt);
```

3.141592653589793
3

JavaScript 提供了一组丰富的数学属性，可以用来获取预定义的常量值。

## 数学属性

以下是 JavaScript 数学对象提供的属性:

| **属性** | **描述** |
| --- | --- |
| `E` | 保存欧拉数，其值为 2.718(近似值) |
| `LN2` | 保存值为 0.693(近似值)的自然对数 2。 |
| `LN10` | 保存 10 的自然对数，其值为 2.302(近似值)。 |
| `LOG2E` | 保存 E 的以 2 为底的对数，取值为 1.442(近似值) |
| `LOG10E` | 保存 E 的以 10 为底的对数，其值为 0.434(近似值) |
| `PI` | 保存圆周率的数值，其近似值为 3.142 |
| `SQRT1_2` | 保持 1/2 的平方根，其近似值为 0.707 |
| `SQRT2` | 保持 2 的平方根，大约值为 1.414 |

让我们举个例子来看看如何使用这些属性。

```js
var e  = Math.E
document.write(e +"<br>")

var ln2  = Math.LN2
document.write(ln2 +"<br>")

var ln10  = Math.LN10
document.write(ln10 +"<br>")

var sq = Math.SQRT1_2
document.write(sq +"<br>")
```

2.718281828459045
0.6931471805599453
2.71828929946

### 查找最小和最大数量

假设，我们想从随机数列表中找到最小值和最大值，那么使用数学对象就很容易了。见下面的例子。

```js
// Find minimum number
var min = Math.min(10,25,47,23,18,8,21,30)
document.write(min +"<br>")

// Find maximum number
var max = Math.max(10,25,47,23,18,8,21,30)
document.write(max +"<br>") 
```

8
47

## 数学方法

JavaScript 数学对象提供了一组丰富的方法，用于简化数学计算，并有助于减少面向数学的编程的工作量和时间。这里我们列出了最常用的数学对象方法:

| **方法** | **描述** |
| --- | --- |
| `abs(x)` | 返回 x 的绝对值 |
| `ceil(x)` | 将 x 向上舍入到最接近的最大整数 |
| `cos(x)` | 返回 x 的余弦值 |
| `exp(x)` | 返回指数的值。 |
| `random()` | 返回一个介于 0 和 1 之间的随机数 |
| `tan(x)` | 返回 x 的正切值 |
| `sqrt(x)` | 返回 x 的平方根 |
| `sin(x)` | 返回 x 的正弦值。 |
| `floor(x)` | 将 x 向上舍入到最近的最小整数。 |
| `max(x,y,z,......n)` | 返回 lsit 中最高的数字。 |
| `min(x,y,z,.......n)` | 返回列表中最低的数字。 |
| `pow(x,y)` | 返回 x 的 y 次方 |
| `cos(x)` | 返回 x 的余弦值 |
| `log(x)` | 返回 x 的对数值 |

让我们看一个例子，其中我们使用数学方法来理解这些方法的返回值:

所以要使用 Math 对象属性或方法，我们不需要使用`new`关键字创建对象，我们可以直接使用代码中的属性和方法。

* * *

* * *