# JavaScript 日期对象

> 原文：<https://www.studytonight.com/javascript/javascript-date-object>

日期对象是一个内置的对象，用于处理日期和时间。它存储一个数字，代表 Unix 时间戳的毫秒数(它只不过是自 1970 年 1 月 1 日世界协调时以来经过的毫秒数)。我们可以用它来创建一个新的日期，格式化一个日期，获得两个不同时间值之间经过的时间，等等。

它还有助于使用毫秒数获得日期值，我们还可以根据不同的时区获得日期。

**日期**对象默认使用浏览器的日期时区，并以文本格式显示日期。

可以使用日期构造器创建日期对象。

## 创建 JavaScript 日期对象

让我们看看如何用 JavaScript 创建**日期**对象。虽然有多种方式，但默认方式是将`new`关键字与**日期**构造器一起使用。

```js
let newdate = new Date();
```

上面将创建一个新的日期对象，其中存储了当前日期和时间。存储在该对象中的日期格式将是:

2020 年 05 月 05 日星期二格林尼治时间+0530 时 21:16:17(印度标准时间)

是的，它将是完整的日期和时间以及时区信息。

要获得标准的 UNIX 时间戳值，我们可以使用以下代码:

```js
let newdate = Date.now();
```

1588693792007

在上面的代码中，我们对日期对象使用了静态函数`now()`。这将为我们提供当前日期和时间的 Unix 时间戳，它只不过是自 1970 年 1 月 1 日以来经过的毫秒数。

### 创建 JavaScript 日期的其他方法

除了以上两种语法之外，还有多种其他方法可以在 JavaScript 中创建日期。这里，我们使用不同的语法来创建日期对象。

正如您在上面的示例中看到的，我们可以为自定义日期创建一个日期，该日期可以是过去的日期，也可以是未来的日期。我们甚至可以提供时间值。

## 使用 JavaScript 日期

JavaScript Date 构造器处理不同的格式来创建日期，我们可以传递一个字符串格式的日期或者一个带有毫秒的数字字面值来创建一个 JavaScript 中的日期对象。

### 使用字符串创建 JavaScript 日期

JavaScript 允许以下字符串格式创建日期对象。

```js
let date1 = new Date('February 13, 1991 06:44:00')
document.write(date1 +"<br>");

let date2 = new Date('1991-02-13T06:44:00');
document.write(date2);
```

1991 年 2 月 13 日星期三 06:44:00 GMT+0530(印度标准时间)
1991 年 2 月 13 日星期三 06:44:00 GMT+0530(印度标准时间)

### 使用数字字面值创建 JavaScript 日期

我们可以使用 Date()构造器可以取 7 个参数来创建日期，分别是:**年**、**月**、**日**、**小时**、**分钟**、**秒**、**毫秒**。

我们也可以通过经过**毫秒**来得到日期。参见以下示例:

```js
let date1 = new Date(2018,11,25,12,25,12,0);
document.write(date1 +"<br/>");

// Passing miliseconds
let date2 = new Date(1825356800000);
document.write(date2); 
```

2018 年 12 月 25 日星期二 12:25:12 GMT+0530(印度标准时间)
Fri 2027 年 11 月 05 日 01:03:20 GMT+0530(印度标准时间)

### 从 JavaScript 日期中获取年、月和日

要从日期中获取年、月或日的值，我们可以使用 JavaScript 内置方法。这些方法易于使用，减少了编码的工作量和时间。

```js
// Creating a date
let date1 = new Date(2018,11,25,12,25,12,0);

// Getting year
let year = date1.getFullYear();
document.write("<br> Year: "+  year);

// Getting Month
let month = date1.getMonth();
document.write("<br> Month: "+  month);

// Getting day
let day = date1.getDate();
document.write("<br> Day: "+  day);
```

年:2018
月:11
日:25

## 日期对象方法

JavaScript 提供了一组丰富的内置方法，它们既是**静态方法，也是**实例方法，可以用来从 JavaScript Date 对象中获取不同的信息。

| **方法** | **描述** |
| --- | --- |
| `Date.now()` | 返回当前日期和时间的毫秒数(Unix 时间戳)。 |
| `Date.parse()` | 分析日期的字符串值，并返回自 1970 年 1 月 1 日 00:00:00 世界协调时以来的毫秒数，忽略闰秒。 |
| `Date.UTC()` | 此函数采用 7 个带数值的参数，但以世界协调时时区创建日期。 |
| `setDate()` | 设置从 1 到 31 的月份日期。 |
| `setHours()` | 设置从 0 到 23 的小时数 |
| `getSeconds()` | 返回 0 到 59 之间的秒数 |
| `toDateString()` | 将日期值转换为字符串 |
| `valueOf()` | 返回日期对象的原始值。 |
| `setMinutes()` | 设置 0 到 59 之间的分钟数。 |
| `setMonth()` | 设置从 0 到 11 月的数值等值范围 |
| `setMilliseconds()` | 设置 0 到 999 之间的毫秒数 |
| `toTimeString()` | 将时间转换成字符串。 |
| `getDate()` | 返回 1 - 31 之间的日期 |
| `getDay()` | 从 0 - 6 返回星期几 |
| `getFullYear()` | 返回指定日期的年份(4 位数年份为 4 位数) |
| `getMinutes()` | 返回指定日期的分钟数(`0`–`59`) |
| `getMonth()` | 返回指定日期的月份(`0`–`11`) |
| `getHours()` | 返回 0 到 23 之间的小时数。 |

现在我们将向您展示如何使用一些日期对象方法:

### 寻找 JavaScript 日期和运行时间之间的差异

我们可以简单地减去两个日期，找出任意两个日期之间的差异。让我们举个例子来看看这个:

```js
// Using Date objects
let start = Date.now();

// Do something for some time

// get the end time
let end = Date.now();
// time elapsed
let elapsed = end - start;   // elapsed time in milliseconds
```

但这并不像 Date 对象有日、月、年、小时、分钟和秒的值那么简单，因此我们在查找经过的时间时应该小心。

在本教程中，我们介绍了在许多网络应用程序中使用的 JavaScript 中的日期对象。

* * *

* * *