# JavaScript 正则表达式对象

> 原文：<https://www.studytonight.com/javascript/javascript-regexp-object>

正则表达式或 JavaScript RegExp 是一个帮助您验证字符串中的字符模式或匹配字符串等的对象。您可以使用 JavaScript RegExp 对象来验证表单中输入的电子邮件，或者检查密码是否全是数字，或者密码是否包含字母数字和特殊字符等。

在 JavaScript 中定义正则表达式有两种方式。

1.使用 JavaScript 正则表达式对象的构造器

2.使用[字面语法](https://www.studytonight.com/javascript/javascript-regular-expression)

## 创建 JavaScript 正则表达式对象

让我们看看如何用 JavaScript 创建一个正则表达式对象:

```js
// Object Syntax
let regExp = new RegExp("pattern", "flag");

// Literal Syntax
let regExp = /pattern/flag;
```

其中**模式**是正则表达式的文本，**标志**使正则表达式搜索特定的模式。

**<u>注:</u>** 在本教程中，我们将讨论 RegExp 对象、其属性和方法。所有的例子都将基于正则表达式对象，而不是字面上的正则表达式。我们已经在前面介绍了[正则表达式字面语法](https://www.studytonight.com/javascript/javascript-regular-expression)。

我们将使用以下字符串方法来使用正则表达式对象来测试、匹配和验证 JavaScript 中的各种字符串值:

*   `test()`

*   `match()`

*   `replace()`

*   `exec()`

让我们举几个例子来理解 JavaScript RegExp 对象的使用。

### 创建一个正则表达式来匹配 IP 地址

为了匹配所有看起来像 IP 地址的字符串: **xxx.xxx.xxx.xxx** ，我们可以使用以下正则表达式模式:

```js
let regularexp = /\b\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\b/g;
```

现在让我们创建一个验证 IP 地址的示例。如果给定的 IP 地址有效，下面的代码返回 **true** :

```js
let str = "102.235.251.251";
// regex pattern to match valid ip
let re = new RegExp(/\b\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\b/);
// test the regex
let result = re.test(str);
if(result)
	document.write("Ip address is valid");
else
	document.write("Ip address is not valid");
```

Ip 地址有效

### 如何使用 Regex 替换字符串？

让我们看一个例子，用其他字符串替换字符串的一部分或整个字符串，或者用正则表达式替换字符串的顺序。

```js
// Creating regex object
let re = new RegExp(/(\w+)\s(\w+)/);
let str = 'Mohan Shyam';
// Replacing string
let newstr = str.replace(re, '$2, $1');
document.write(newstr);
```

山药、墨山

### 从域名获取子域值

我们可以使用正则表达式从一个网址中获取子域。RegExp `exec()`方法用于执行正则表达式模式匹配，并返回一个字符串数组。请参见下面的示例:

```js
let url = 'http://linux.studytonight.com';
// Creating regex object
let re = new RegExp(/[^.]+/);
let result = re.exec(url)[0].substr(7);
document.write(result);
```

linux

### 在字符串中查找模式

要在字符串中找到模式，我们可以使用字符串`match()`方法。它返回可以是子串的匹配模式。请参见下面的示例:

```js
// Creating regex object
var regex = new RegExp(/India/g);
var str = "We live in India.";
// search for India
var matches = str.match(regex);
document.write(matches);
```

印度

## JavaScript 正则表达式对象的属性

*   **全局**:指设置了 **g** 修改器。

*   **忽略**:表示设置了 **i** 修改器

*   **lastIndex** :指开始下一场比赛的索引。

*   **多行**:表示设置了 **m** 修改器。

*   **来源**:指 RegExp 模式的文本。

### JavaScript 正则表达式`ignoreCase`属性:

`ignoreCase`属性表示`i`标志是否与正则表达式一起使用。`ignoreCase`是正则表达式对象的只读属性。

```js
var re = new RegExp("/hello/","i");
// ignorecase property
var result = re.ignoreCase;
document.write(result);
```

真

 <caption>## 对象方法

Regex 对象提供了使用正则表达式的各种方法。下表包含其方法:</caption> 
| 

方法

 | 

描述

 |
| --- | --- |
| `exec()` | 在字符串中执行匹配搜索。如果不匹配，它将返回一个信息数组或 null。 |
| `test()` | 测试字符串中的匹配。它返回真或假。 |
| `match()` | 返回包含所有匹配项(包括捕获组)的数组，如果找不到匹配项，则返回 null。 |
| `matchAll()` | 返回包含所有匹配项的迭代器，包括捕获组。 |
| `search()` | 测试字符串中的匹配。它返回匹配的索引，如果搜索失败，则返回-1。 |
| `replace()` | 在字符串中执行匹配搜索，并用替换子字符串替换匹配的子字符串。 |
| `split()` | 使用正则表达式或固定字符串将字符串分解为子字符串数组。 |

### 正则表达式`test()`方法示例

RegExp `test()`方法用于测试正则表达式，如果表达式匹配，则返回 true。

```js
<script>
	var str = "Hello";
	var re = new RegExp("/hello/","i");
	var result = re.test(str);
	document.write(result)

</script>
```

真

### 使用正则表达式验证电子邮件

让我们使用正则表达式来验证电子邮件地址。在下面的示例中，我们正在为用户验证电子邮件，以确保用户只输入有效的电子邮件。

```js
let str = "abc@gmail.com";
// regex pattern to match valid email
let re = new RegExp(/^\w+@[a-zA-Z_]+?\.[a-zA-Z]{2,3}$/);
// test the 
let result = re.test(str);
if(result)
    document.write("Email is valid")
else
    document.write("Email is not valid")
```

邮件有效

* * *

* * *