# JavaScript 窗口对象

> 原文：<https://www.studytonight.com/javascript/javascript-window-object>

JavaScript Window 是**全局接口(对象类型)**，用于**控制浏览器窗口生命周期**并对其进行各种操作。

在我们的 JavaScript 代码中有一个全局变量窗口，代表当前运行代码的浏览器窗口，可以使用`window`字面值直接访问。

它表示一个包含网页的窗口，而网页又由文档对象表示。窗口可以是新窗口、新选项卡、框架集或用 JavaScript 创建的单个框架。

在多标签浏览器的情况下，一个**窗口对象代表一个标签**，但是它的一些属性如`innerHeight`、`innerWidth`和方法如`resizeTo()`会影响整个浏览器窗口。

每当您打开一个新窗口或选项卡时，就会自动创建一个代表该窗口/选项卡的窗口对象。

窗口对象的属性用于检索关于当前打开的窗口的信息，而它的方法用于执行特定的任务，如打开、最大化、最小化窗口等。

为了理解窗口对象，让我们使用它来执行一些操作，并看看它是如何工作的。

## 使用 JavaScript 窗口对象

让我们使用 JavaScript 窗口对象创建一个新窗口，使用`open()`方法。此方法创建一个新窗口，并返回一个对象，该对象可进一步用于管理该窗口。

在上面的代码中，我们已经使用了现有窗口的窗口对象，使用`open()`方法创建了一个新窗口。在`open()`方法中，我们可以提供要在新窗口中打开的网址(我们也可以将其留空)**窗口名称**、要创建的窗口的**宽度**和**高度**。

以下是 window 对象 open()方法的语法:

```js
let newWindow = window.open(url, windowName, [windowFeatures]);
```

在创建新窗口时，我们可以提供任意多的属性。

当执行`open()`方法时，它返回所创建的新窗口的窗口对象的引用，您可以将其分配给一个变量，就像我们在上面的代码中所做的那样。我们已经将`window.open()`方法返回的值赋给了`win`变量。

我们使用了`win`变量来访问新窗口，比如获取窗口的名称，获取打开新窗口的窗口的位置等等。

窗口对象有许多属性和方法，我们在下面列出了它们。

### 查找窗口的尺寸

我们可以通过使用窗口对象的内置属性来获得窗口的高度和宽度。

我们还可以使用一个窗口对象(`window.document`)来访问文档对象，该对象为我们提供了对 HTML 文档的访问，因此我们可以添加新的 HTML 元素，或者向文档中写入任何内容，就像我们在上面的示例中所做的那样。

## JavaScript 窗口对象属性

wondow 对象属性是指在 windows 对象内部创建的变量。

在 JavaScript 中，所有可用的数据都作为属性附加到窗口对象。

我们可以访问窗口对象的属性，如:`window.propertyname` ，其中**属性名称**是属性的名称。

最流行的窗口对象属性表如下所示:

| **属性** | **描述** |
| --- | --- |
| 关闭的 | 返回一个布尔值，该值指定窗口是否已关闭 |
| 文件 | 指定窗口中的文档对象。 |
| 历史 | 指定窗口的历史对象。 |
| 框架 | 指定当前窗口中所有帧的数组 |
| 默认状态 | 指定必须出现在窗口状态栏中的默认消息。 |
| 内部高度 | 指定窗口内容区域的内部高度。 |
| 内宽 | 指定窗口内容区域的内部宽度。 |
| 长度 | 指定窗口中包含的帧数。 |
| 位置 | 指定了窗口的位置对象 |
| 名字 | 指定窗口的名称 |
| 顶端 | 指定最顶层浏览器窗口的引用。 |
| 自己 | 返回当前活动框架或窗口的引用。 |
| 父母 | 返回当前窗口的父框架或窗口。 |
| 状态 | 指定在窗口上执行活动时，窗口状态栏中显示的消息。 |
| 屏幕左 | 指定窗口相对于用户监视器屏幕的 x 坐标 |
| screenTop(屏幕顶部) | 指定窗口相对于用户监视器屏幕的 y 坐标 |
| screenX(屏幕 x) | 指定窗口相对于用户监视器屏幕的 x 坐标 |
| 风景 | 指定窗口相对于用户监视器屏幕的 y 坐标 |

让我们举个例子来看看其中的一些属性:

在上面的例子中，我们创建了一个新窗口，只是为了让您熟悉新窗口的创建，也是为了让您理解当我们创建一个新窗口时，当前窗口有一个不同的窗口对象，而新窗口将有一个单独的窗口对象。

然后，我们尝试访问创建的新窗口的一些属性。

<u>**TASK:**</u> 在上面的代码游乐场中多尝试一些 windows 属性，练习并理解 windows 属性是如何工作的。

## JavaScript 窗口对象方法

窗口对象方法指的是在窗口对象内部创建的函数，这些函数可用于在浏览器窗口上执行各种操作，例如它如何显示消息或从用户那里获取输入。

下面我们列出了一些最常用的窗口对象方法:

| **方法** | **描述** |
| --- | --- |
| `alert()` | 指定一种方法，该方法显示带有消息“确定”按钮的警告框。 |
| `blur()` | 指定从当前窗口中移除焦点的方法。 |
| `clearInterval()` | 指定清除计时器的方法，该方法是通过使用 setInterval()方法设置的。 |
| `close()` | 指定关闭当前窗口的方法。 |
| `confirm()` | 指定显示对话框的方法，该对话框包含一条消息和两个按钮“确定”和“取消” |
| `focus()` | 指定在当前窗口上设置焦点的方法。 |
| `open()` | 指定了打开新浏览器窗口的方法 |
| `moveTo()` | 指定将窗口移动到指定位置的方法 |
| `moveBy()` | 指定相对于当前位置移动窗口的方法。 |
| `prompt()` | 指定提示输入的方法。 |
| `print()` | 指定发送打印命令以打印当前窗口内容的方法。 |
| `setTimeout()` | 指定在指定的毫秒数后计算表达式的方法。 |
| `setInterval()` | 指定以指定的时间间隔(毫秒)计算表达式的方法 |
| `resizeBy()` | 指定窗口大小调整的量 |
| `resizeTo()` | 用于动态调整窗口大小 |
| `scroll()` | 将窗口滚动到文档中的特定位置 |
| `scrollBy()` | 按给定值滚动窗口 |
| `stop()` | 此方法停止加载窗口 |

让我们举个例子，看看上面的一些方法是如何起作用的:

在上面的例子中，我们已经使用了一些窗口方法，您可以尝试更多的方法。在下一个教程中，我们将学习**历史**对象，它是窗口对象的一个属性。

* * *

* * *