# JavaScript 历史对象

> 原文：<https://www.studytonight.com/javascript/javascript-history-object>

JavaScript 历史是一个内置接口(对象类型)，用于访问浏览器窗口会话历史。它包含用户在特定浏览器窗口、选项卡或框架中浏览的网址列表，由窗口对象表示。

历史对象是 [JavaScript 窗口对象](https://www.studytonight.com/javascript/javascript-window-object)的属性，可以通过`window.history`属性进行访问，用于访问该窗口对象的会话历史。

它提供了有用的方法和属性，让我们可以在窗口的会话历史中来回导航。

让我们举个例子来看看这是如何工作的，以便更好地理解它。

## JavaScript 历史对象示例

历史对象的`back()`方法用于返回到历史列表中浏览器窗口中访问的上一个网址。

这和在浏览器中点击**“后退”按钮**是一样的。

```js
<button onclick="goBack()">Go Back</button>

<script>
	function goback(){
	    window.history.back();
	}
</script>
```

同样，我们可以使用历史对象的`forward()`方法来加载历史列表中的下一个 URL。如果下一个网址不存在，它什么也不做。

和在浏览器中点击**“前进”按钮**一样。

```js
<button onclick="goforward()">Go Forward</button>

<script>
	function goforward(){
	    window.history.forward();
	}
</script>
```

除了`back()`和`forward()`之外，JavaScript 历史对象提供了更多类似`go()` 的方法，可以用来**跳转到历史对象中存在的任何特定 URL** 。

要将**移动到任何特定页面**，我们可以使用`go()`方法，它采用一个整数参数作为历史网址列表的**索引值。请参见下面的示例:**

```js
<script>
    // move to one page backward
	window.history.go(-1);

    // move to two page backward
    window.history.go(-2);

    // move to one page forward
    window.history.go(1);

    // move to two page forward
    window.history.go(2);
</script>
```

我们也可以使用历史对象**的`go()`方法刷新当前页面**。在下面的例子中，我们已经调用了`go()`方法两次，它在两个场景中的工作原理是一样的。当我们想要刷新/重新加载当前页面时，我们可以随时调用它。

```js
<script>
// Refresh the page
        window.history.go(0);

        window.history.go();

</script>
```

## JavaScript 历史对象属性

以下是历史对象的属性。`length`属性使用最多。

| **属性** | **描述** |
| --- | --- |
| 长度 | 指定对象中包含的元素数量 |
| 滚动恢复 | 允许 web 应用程序在历史导航中显式设置默认滚动恢复行为 |
| 状态 | 表示历史堆栈顶部的状态 |

让我们举一个例子来获取用户在浏览器窗口中访问的页面数量。我们将使用包含被访问页面信息的`length`属性。请参见下面的示例:

## 历史对象方法

JavaScript 历史对象方法是指在历史对象内部创建的函数。这些方法指定与浏览器窗口当前会话中访问的网址相关的操作。

| 方法 | 描述 |
| --- | --- |
| `back()` | 指定从历史列表中加载上一个网址的方法。 |
| `forward()` | 指定从历史列表中加载下一个网址的方法。 |
| `go()` | 指定从历史列表中加载特定 URL 的方法。 |
| `pushState()` | 用于将给定数据推送到具有指定标题的会话历史堆栈上 |
| `replaceState()` | 用于将历史堆栈上的最新条目更新为指定的数据、标题和 URL(如果提供) |

我们已经在本教程的开头用例子解释了每种方法。

在下一个教程中，我们将了解导航浏览器对象。

* * *

* * *