# JavaScript 文档对象

> 原文：<https://www.studytonight.com/javascript/javascript-document-object>

JavaScript Document 对象是一个提供对文档中所有 HTML 元素的访问的对象。当一个 HTML 文档被加载到浏览器窗口中时，它就变成了一个文档对象。

文档对象将 HTML 文档的元素(如 HTML、HEAD、BODY 和其他 HTML 标记)存储为对象。

文档对象是[窗口对象](https://www.studytonight.com/javascript/javascript-window-object)的子对象，指的是浏览器。

您可以使用`window.document`属性或直接使用对象来访问文档对象。

#### **看，我们能用文档对象做什么:**

*   假设您已经在 HTML 文档中使用 FORM 元素创建了一个表单，并在表单上添加了一些文本字段和按钮。提交表单时，您希望验证输入或在另一页上显示输入。在这种情况下，您可以使用作为窗口对象的子对象的文档对象。使用文档对象，您可以访问表单的元素并验证输入。

*   文档对象提供不同的集合元素，如锚点和链接，这有助于您计算表单上特定元素的数量。

*   文档对象还提供了`URL`、`bgcolor`等多种属性。这将允许您检索文档的详细信息和各种方法，如`open()`、`close()`、`write()`、`etElementById()`、`getElementByName()`等。它允许您执行各种任务，如打开一个 HTML 文档来显示输出和在网页上书写文本。

*   文档对象还允许您通过提供名为 cookie 的属性来为网页创建 cookie。cookie 存储关于用户计算机的信息，这有助于访问访问过的网站。

现在让我们探索文档对象方法和属性。

## JavaScript 文档对象属性

我们知道，一个对象的属性是与该对象相关联的值。使用以下符号访问属性:

```js
objectName.propertyName
```

其中 **objectName** 是对象的名称， **propertyName** 是其属性的名称。

现在，我们将在下表中显示文档对象的属性:

| **属性** | **描述** |
| --- | --- |
| 甜饼干 | 返回包含与文档相关联的所有可见和未过期 cookies 的报告 |
| 领域 | 返回文档来源服务器的域名 |
| 上次修改时间 | 返回文档上次修改的日期 |
| 文档模式 | 返回浏览器处理文档时使用的模式 |
| 就绪状态 | 返回文档的加载状态。 |
| 推荐人 | 返回 HTML 文档中引用的文档的 URL |
| 标题 | 返回在 TITLE 元素的开始和结束标记之间定义的 HTML 文档的名称 |
| 统一资源定位器 | 返回 HTML 文档的完整 URL。 |

让我们举个例子，看看文档对象属性的作用:

## JavaScript 文档对象方法

JavaScript Document 对象还提供了各种访问 HTML 元素的方法。

现在，我们将向您展示文档对象的一些常用方法:

| **方法** | **描述** | **语法** |
| --- | --- | --- |
| `open()` | 打开一个 HTML 文档来显示输出 | 

```js
document.open(mimetype, replace)
```

 |
| `close()` | 关闭一个 HTML 文档 | 

```js
document.close()
```

 |
| `write()` | 将 HTML 表达式或 JavaScript 代码写入 HTML 文档 | 

```js
document.write(exp1, exp2, ...)
```

 |
| `writeln()` | 在每个 HTML 表达式或 JavaScript 代码后写一个新的行字符 | 

```js
document.writeln(exp1, exp2, ...)
```

 |
| `getElementById()` | 返回具有指定 id 的 HTML 文档的第一个元素的引用。 | 

```js
document.getElementById(id)
```

 |
| `getElementByName()` | 返回具有指定名称的元素的引用 | 

```js
document.getElementsByName(name)
```

 |
| `getElementsByTagName()` | 返回具有指定标记名的所有元素 | 

```js
document.getElementsByTagName(tagname)
```

 |

现在我们举个例子，看看像`open()`、`write()`、`getElementById()`这样的文档对象方法，解释它们的用法。请参见下面的示例:

**另请阅读:-** [如何使用 JavaScript 构建不和机器人](https://www.studytonight.com/post/how-to-build-a-discord-bot-using-javascript)

* * *

* * *