# ECMAScript 2020 或 ES11 中的新功能

> 原文：<https://www.studytonight.com/javascript/ecmascript-2020-or-es11>

在本文中，我们将介绍 **ECMAScript 2020** 新增的功能。

**ECMAScript** 是由 **ECMA 国际**根据 [ECMA 262](https://www.ecma-international.org/publications-and-standards/standards/ecma-262/) 文件标准化的通用脚本语言。这是一个 JavaScript 标准，用于跨多个浏览器为网页提供互操作性。

**ECMAScript** 一般用于**万维网(WWW)** 上的**客户端脚本**，也用于**使用 **Node.js** 编写服务器应用程序**和**服务**。

除了 JavaScript，多种语言都遵循 ECMAScript 规范，如 ActionScript、JScript 等。

**ECMAScript** 每年都会进化并发布更新，在新版本中增加新功能。此外，流行的浏览器很快增加了对新功能的支持，发布间隔时间很短。

**ECMAScript 2020** 是 **ECMAScript 语言**的**第 11 版**(也称为 ES11)，发布于**2020 年 6 月**。这是最新版本的 ECMAScript。

## JS ECMA 脚本 2020 的特点

2020 年 ECMA 脚本新增功能如下:

*   string . prototype . matchell()

*   动态导入

*   比吉斯本

*   Promise.allSettled()

*   全局此

*   可选链接

*   看涨合并

让我们了解一下所有这些特性。

## string . prototype . matchell()方法

`matchAll()`是 **ECMAScript 2020** 中提供的**串**的新方法，**配合正则表达式**使用。这个方法返回所有与正则表达式匹配的迭代器。每个匹配项都是一个带有一些附加属性的数组，即**索引**和**输入**。

正则表达式必须有`/g`标志。否则，它将通过一个**类型错误**。

### martchAll()的语法

`matchAll()`方法的语法如下:

```js
string.prototype.matchAll(regexp)
```

### 因素

*   **字符串** -是要找到匹配的参考字符串。

*   **正则表达式** -是一个[正则表达式对象](https://www.studytonight.com/javascript/javascript-regexp-object)。

*   **返回值** -返回值将是一个迭代器

## 动态导入

**动态导入**允许我们**将 JavaScript 文件作为模块**动态导入。当我们在 Javascript 代码中需要时，这个特性使我们能够在代码的任何地方导入任何代码。我们甚至可以在运行时从其他脚本中导入特定的函数。

### 动态导入的语法

**动态导入**的语法很简单，使用`import()`表达式:

```js
import(moduleSpecifier)
```

## 比吉斯本

正如我们所知，JavaScript 只有一个用于数字的**数据类型，这是一个**数字**类型。这种数据类型代表 64 位浮点数。它还表示小于 2^53 的整数。为了表示大于**的数字，引入了 2^53-1** 、 **BigInt** 。**

**BigInt** 是一个**内置** **对象**代表**整数**比 **2^53-1** 更有意义，后者是**最大值****JavaScript**可以在 BigInt 之前表示。对于 BigInt 数可以有多长，没有指定限制。

**BigInt 值**与**数值**相当**类似**，但两者略有不同。我们不能使用内置数学函数的 BigInt 值。

### 如何创建 BigInt 值？

我们可以通过在普通数值后添加`n`或者使用`BigInt()`函数来创建一个 BigInt 值。

```js
let bigNum = 123432n;

// or use BigInt() function
```

## Promise.allSettled()

**ECMAScript 2020** 介绍了`Promise.allSettled()`方法。该方法**接受一个承诺列表**并**返回一个新的承诺**，该承诺在所有输入的承诺已经履行或被拒绝后解决。

**返回的承诺**是用描述每个输入承诺结果的对象数组解析的**。**

当我们有多个不依赖对方成功完成的**异步任务**时，或者当我们想知道每个承诺的结果时，使用这种方法。

### Promise.allSettled()方法的语法

```js
Promise.allSettled(iterable);
```

### 参数

*   **可迭代** -可迭代参数是所有输入承诺的列表。

*   **返回值** -它返回一个待定承诺，当每个输入承诺都已结算时，该承诺将异步履行。

## 全局此

`globalThis`对象由 **ECMAScript 2020** 或 **ES11** 引入。

如今，JavaScript 被用于各种各样的环境中。除了 web 浏览器是 JavaScript 最常见的主机环境类型之外，我们还可以在服务器、手机、机器人硬件等上运行 JS 程序。使用像 NodeJS 这样的运行时。每个环境由它的**对象模型**组成，并且具有不同的**语法**到**来访问全局对象**。可以通过**网页浏览器**中的`window`、`self`或`frame`关键词访问全局对象。在 **Node.js** 中，`global`关键字用于**访问****全局对象**。在 **Web Workers** 中，只有`self`关键字存在。

**访问全局对象**的多种方式使得开发人员很难编写出能够在各种平台上运行的 JavaScript 代码。为了克服所有这些问题，引入了`globalThis`。

该对象为**多个环境**提供了一种标准方式**访问全局对象**。通过使用`globalThis`对象，我们可以创建一个代码，该代码将在窗口(如`window`引用可用的浏览器)和非窗口环境(后端运行 NodeJS)上工作，而无需添加任何额外的检查或测试。

通常，当我们不知道我们的代码将在哪个环境中运行时，或者当我们想要使我们的代码在不同的环境中可执行时，使用`globalThis`。为了在不支持这些功能的旧浏览器中实现这些功能，我们必须使用 polyfill。

## 可选链接(？。)

**可选链接操作符**在 **ECMAScript 2020** 中引入。(`?.`)符号代表**可选链接操作符**。它改变了从**深嵌套对象**访问属性的**方式。它还解决了在 JavaScript 中访问一长串对象属性时必须进行多次空值检查的问题。**

### 可选链接的用例

*   它访问一个对象的可能为空或未定义的属性。

*   它有助于从可能尚不可用的变量中获取结果。

*   它有助于获取默认值。

*   它有助于访问长长的属性链。

### 可选链接的语法

可选链接的语法如下:

```js
obj.val?.prop

obj.val?.[expr]

obj.arr?.[index]

obj.func?.(args)
```

## 看涨合并

**无效合并**是 **ECMAScript 2020** 的新功能。是一个**逻辑运算符**，是**两个问号** ( `??`)所代表的**。该运算符接受两个操作数来执行任何任务:**

```js
leftExpression ?? rightExpression
```

如果**左表达式为空或未定义**，则该运算符返回**右表达式**。

这个**运算符**与逻辑的 **OR 运算符**非常相似**，如果**左侧操作数**是**假的**值，该运算符也**返回**右侧操作数**值，而不仅仅是空值或未定义的值。****

 ****无效合并**运算符的**运算符优先级第五低**，直接低于`||`，现在高于条件(三元)运算符。

### 看涨组合的语法

```js
leftExpression ?? rightExpression
```

## 结论

在本文中，我们已经了解了 ECMAScript 2020。此外，我们还了解到了 ECMAScript 2020 中增加的新功能，如下所示:

*   string . prototype . matchell()

*   动态导入

*   比吉斯本

*   Promise.allSettled()

*   全局此

*   可选链接

*   看涨合并

在接下来的教程页面中，我们已经用代码示例详细介绍了所有这些新特性。单击“下一步”按钮逐一查看所有内容。

* * *

* * ***