# JavaScript 可选的捕获绑定

> 原文：<https://www.studytonight.com/javascript/javascript-optional-catch-binding>

在早期版本的 JavaScript 中，无论是否需要，都需要将异常变量传递给 **catch 语句**。为了避免这种情况，引入了**可选锁扣绑定**。

**可选捕捉绑定**是由 **ECMAScript 2019** (ES10)推出的 JavaScript 新功能。

可选的捕捉绑定允许我们使用**尝试/捕捉**语句**而不通过****错误参数**在**捕捉块**内。您可以选择是否传递错误变量。

让我们借助一个例子来理解它。

### 示例:没有可选的捕获绑定

这里，我们必须在 catch 块中传递一个变量。

```js
//Without optional catch binding

try {
// do something
} catch (error) {
// we have error parameter to handle it
}
```

### 示例:带有可选的捕捉绑定(ES10)

在这里，我们可以跳过在 catch 块中传递变量。

```js
//With optional catch binding

try {
// do something
} catch {
// no binding or parameter to handle it
}
```

正如我们在第一个例子中看到的，一个异常参数**错误**被传递给 **catch 语句**。

该参数用于**识别在**试块**内出现哪种类型的错误**。而在第二个例子中，正如我们已经注意到的，没有**参数传递给 **catch 语句**，因为它在 **ES10 中是**可选的**。****

如果在处理异常的代码中不需要异常对象，这将很有帮助。

### 示例:可选捕获绑定

在这个例子中，我们已经演示了使用**尝试和捕捉块** **与**和**无例外变量**。

```js
<!DOCTYPE html>
<html>
<head>
<title>Optional catch binding</title>
</head>
<body>
	<script type="text/javascript">
	//Wihout optional catch binding
	try {
		throw new Error("Some random error");
	} catch (error) {
		console.log(error)
	}

	//With optional catch binding
	try {
		throw new Error("Hey");
	} catch {
		console.log("No parameter for catch");
	}
	</script>
</body>
</html> 
```

### 输出

![output](img/783df9d5b57c89f3c0efd9500e8e3ba8.png)

## 结论

在本文中，我们学习了 **ECMAScript 2019** 或 **ES10** 中引入的**可选捕捉绑定**。它允许我们在向 catch 语句传递或不传递异常变量的情况下使用 catch 块。

* * *

* * *