# PHP 运算符

> 原文：<https://www.studytonight.com/php/php-operators>

运算符用于对 PHP [变量](variables-in-php)和简单值进行运算。

在 PHP 中，总共有 7 种类型的运算符，它们是:

1.  算术运算符
2.  赋值运算符
3.  比较运算符
4.  递增/递减运算符
5.  逻辑运算符
6.  字符串运算符
7.  数组运算符

还有一些额外的操作符，如类型操作符、位操作符、执行操作符等。

根据这些操作符的使用方式，它们分为三类:

1.  **一元运算符**:处理单个操作数(变量或值)。
2.  **二进制运算符**:处理两个操作数(变量或值)。
3.  **三元运算符**:对三个操作数起作用。

* * *

## PHP 算术运算符

这些运算符用于执行基本的算术运算，如加法、乘法、除法等。

| 名字 | 操作员 | 它是做什么的？ | 例子 |
| 添加 | `+` | 用于执行正常加法。 | $a + $b |
| 减法 | `-` | 它用于执行正常减法。 | $a - $b |
| 增加 | `*` | 它用于执行乘法。 | $a * $b |
| 分开 | `/` | 它用于执行除法。 | $a / $b |
| 指数 | `**` | 它返回第一个操作数与第二个操作数的幂。`$a ** $b = $a<sup>$b</sup>` | $a ** $b |
| 模数(或余数) | `%` | 它返回第一个操作数除以第二个操作数的余数 | $a % $b |

* * *

## PHP 赋值运算符

赋值操作符用于给变量赋值，可以是按原样赋值，也可以是在对变量执行某种算术运算之后赋值。最基本的赋值运算符是**等于** `=`。

| 操作员 | 使用 |
| `=` | `$a = $b`，将变量`$b`的值保存到变量`$a` |
| `+-` | `$a += $b`同`$a + $b` |
| `-=` | `$a -= $b`同`$a - $b` |
| `*=` | `$a *= $b`同`$a * $b` |
| `/=` | `$a /= $b`同`$a / $b` |
| `%=` | `$a %= $b`同`$a % $b` |

所以基本上，赋值运算符为我们提供了执行算术运算的速记技术。

* * *

## PHP 比较运算符

顾名思义，这些用于比较两个值。

| 名字 | 操作员 | 它是做什么的？ | 例子 |
| 平等的 | `==` | 如果左操作数等于右操作数，则返回`true`。 | $a == $b |
| 同一的 | `===` | 如果左操作数等于右操作数，并且它们属于同一类型，则返回`true`。 | $a === $b |
| 不平等 | `!=` | 如果左操作数不等于右操作数，则返回`true`。 | 一美元！= $b |
| 不相同 | `!==` | 如果左操作数不等于右操作数，并且它们的类型不同，则返回`true`。 | 一美元！== $b |
| 大于 | `>` | 如果左操作数大于右操作数，则返回`true`。 | $a > $b |
| 不到 | `<` | 如果左操作数小于右操作数，则返回`true`。 | $a < $b |
| 大于或等于 | `>=` | 如果左操作数大于或等于右操作数，则返回`true`。 | $a >= $b |
| 小于或等于 | `<=` | 如果左操作数小于或等于右操作数，则返回`true`。 | $a <= $b |

* * *

## PHP 递增/递减运算符

这些运算符是**一元运算符**，即它们只需要一个操作数。

| 操作员 | 使用 |
| `++$a` | **预增量**，首先将操作数增加`1`(加一)，然后使用或返回。 |
| `$a++` | **后置递增**，首先返回操作数，然后将操作数递增`1`。 |
| `--$b` | **预减**，首先将操作数减`1`(减一)，然后使用或返回。 |
| `$b--` | **后递减**，首先返回操作数，然后将操作数递减`1`。 |

当使用循环或者当我们在程序/脚本中简单地将任何值递增 1 时，这些操作符非常有用和方便。

* * *

## 逻辑运算符

当任何操作依赖于两个或多个条件时，通常使用逻辑运算符。

| 名字 | 操作员 | 它是做什么的？ | 例子 |
| 和 | `and`或`&&` | 如果两个操作数(或表达式)都返回真，则返回真。 | $ a & $ b |
| 或者 | `or`或`&#124;&#124;` | 如果两个操作数(或表达式)中的任何一个返回真，或者两个都返回真，则返回真。 | $a &#124;&#124; $b |
| Xor | `xor` | 如果两个操作数(或表达式)中的任何一个返回真，则返回真，但当两个都返回真时，则不返回真。 | $a xor $b |
| 不 | `!` | 这是一个**一元运算符**。如果操作数(或表达式)返回 false，则返回 true。 | ！一美元 |

* * *

## 字符串运算符

串操作符用于对[串](php-strings)进行操作。字符串操作符只有两种，一般是用 PHP 内置函数对字符串进行各种操作，我们会在后面的教程中了解到。

| 名字 | 操作员 | 它是做什么的？ | 例子 |
| 串联 | `.`(一个点) | 它用于连接两个字符串。 | $a.$b |
| 串联赋值 | `.=` | 它用于将一个字符串附加到另一个字符串。 | $a .= $b |

这里我们有一个简单的例子来演示这两个字符串操作符的用法。

```php
<?php
    $a = "study";
    $b = "tonight";
    // concatenating $a and $b
    echo $a.$b;

    // appending $b to $a
    $a .= $b
    echo $a;
?>
```

今晚学习今晚学习

* * *

## PHP 数组运算符

这些运算符用于比较[数组](php-arrays)。

| 名字 | 操作员 | 它是做什么的？ | 例子 |
| 平等的 | `==` | 如果两个数组具有相同的键/值对，则返回`true`。 | $a == $b |
| 同一的 | `===` | 如果两个数组具有相同的键/值对，顺序相同，类型相同，则返回`true`。 | $a === $b |
| 不平等 | `!=` | 如果两个数组不相同，则返回`true`。 | 一美元！= $b |
| 不相同 | `!==` | 如果两个数组不相同，则根据值类型等返回`true`。 | 一美元！== $b |
| 工会(加入) | `+` | 它将数组连接在一起 | $a + $b |

* * *

* * *