# PHP 函数

> 原文：<https://www.studytonight.com/php/php-user-defined-functions>

一个**函数**只不过是一个“语句块”，它通常执行一个特定的任务，并且可以在我们的程序中重复使用。这个“语句块”也被赋予了一个**的名字**，所以无论何时我们想在我们的程序/脚本中使用它，我们都可以用它的**名字**来称呼它。

在 PHP 中，有成千上万个内置函数，我们可以直接在程序/脚本中使用。

PHP 还支持**用户自定义函数**，我们可以在这里定义自己的函数。

函数在被定义时不执行，在被调用时执行。

* * *

## 用户定义函数

让我们理解如何在程序中定义自己的函数并使用这些函数。

**语法:**

```php
<?php

function function_name()
{
    // function code statements
}

?>
```

### 命名函数的几个规则

1.  一个**函数名**只能包含字母、数字和下划线。不允许使用其他特殊字符。
2.  名称应该以字母或下划线开头。它不应该以数字开头。
3.  最后但同样重要的是，函数名不区分大小写。
4.  函数名后的左花括号`{`标志着函数代码的开始，右花括号`}`标志着函数代码的结束。

* * *

### 举个例子

让我们写一个非常简单的函数，它将显示一个简单的“圣诞快乐和新年快乐”的信息。这个脚本实际上非常有用，当你必须给你的每个朋友发送节日邮件，并且你必须在所有的邮件中写同样的信息。

```php
<?php
// defining the function
function greetings()
{
    echo "Merry Christmas and a Very Happy New Year";
}

echo "Hey Martha <br/>";
// calling the function
greetings();

// next line
echo "<br/>";

echo "Hey Jon <br/>";
// calling the function again
greetings();

?>
```

嗨，玛莎，圣诞快乐，新年快乐嗨，乔恩，圣诞快乐，新年快乐

* * *

### 用户定义函数的优势

由于我们已经看到了上面使用函数的一个简单例子，您一定已经理解了它对于大型程序来说是多么节省时间。以下是为您使用函数的一些优点:

1.  **可重用代码**:从上面的例子可以清楚的看到，一个函数你写一次就可以在程序中使用一千次。
2.  **少代码重复**:在上面的例子中，我们在函数中只有一行代码，但是如果我们有 10 行代码呢。因此，我们可以为它们创建一个函数，并简单地调用该函数，而不是一遍又一遍地重复所有这些代码行。
3.  **易懂**:在你的程序中使用函数，让代码更易读易懂。

* * *

### PHP 函数参数

我们甚至可以将数据传递给一个函数，这个函数可以在函数块中使用。这是使用参数完成的。一个参数只不过是一个变量。

参数在函数名后面的括号中指定，用逗号分隔。当我们定义一个函数时，我们必须定义它将接受的参数数量，并且在调用该函数时只能传递这么多参数。

**语法:**

```php
<?php
/* 
    we can have as many arguments as we
    want to have in a function
*/
function function_name(argument1, argument2)
{
    // function code statements
}

?>
```

让我们举一个简单的例子:

```php
<?php
// defining the function with argument
function greetings($festival)
{
    echo "Wish you a very Happy $festival";
}

echo "Hey Jai <br/>";
// calling the function
greetings("Diwali");

// next line
echo "<br/>";

echo "Hey Jon <br/>";
// calling the function again
greetings("New Year");

?>
```

嘿杰祝你排灯节快乐嘿乔恩祝你新年快乐

从上面的例子中可以看到，我们是如何改变我们的`greetings()`函数开始接受参数的，现在它可以用于发送不同节日的问候。

* * *

### PHP 默认函数参数

有时函数参数在函数代码执行中起着重要的作用。在这种情况下，如果用户在调用函数时忘记提供参数，可能会导致一些错误。

为了避免这样的错误，我们可以为参数提供一个默认值，当调用函数时没有为参数提供任何值时，就使用这个默认值。

举个例子吧。

```php
<?php

// defining the function with default argument
function greetings($festival = "Life")
{
    echo "Wish you a very Happy $festival";
}

echo "Hey Jai <br/>";
// calling the function with an argument
greetings("Diwali");

// next line
echo "<br/>";

echo "Hey Jon <br/>";
// and without an argument
greetings();

?>
```

嘿杰祝你排灯节快乐嘿乔恩祝你生活愉快

因此，当您在调用函数时忘记提供参数时，为了掩饰，您可以为函数的参数设置默认值。

* * *

### 返回值的函数

是的，函数甚至可以返回结果。当我们有函数被定义来执行一些数学运算时，我们想要输出运算的结果，所以我们返回结果。

`return`语句用于从 PHP 中的函数返回任何变量或值。

我们来看一个例子。

```php
<?php

function add($a, $b)
{
    $sum = $a + $b;
    // returning the result
    return $sum;
}

echo "5 + 10 = " . add(5, 10) . "
";

?>
```

5 + 10 = 15

* * *

## 函数重载

函数重载允许您拥有一个函数的多个不同变体，根据它们所采用的参数的数量和类型来区分。

例如，我们定义了函数`add()`，它接受两个参数，并返回这两个参数的和。如果我们希望为添加 3 个数字提供支持，该怎么办？

为了解决这种情况，我们可以做的是，我们可以定义函数`add()`的两个不同变体，一个接受 2 个参数，另一个接受 3 个参数。这叫做**功能过载**。

让我们举个例子，

```php
<?php
// add function with 2 arguments
function add($a, $b)
{
    $sum = $a + $b;
    // returning the result
    return $sum;
}

// overloaded add function with 3 arguments
function add($a, $b, $c) 
{
    $sum = $a + $b + $c;
    // returning the result
    return $sum;
}

// calling add with 2 arguments
echo "5 + 10 = " . add(5, 10) . "<br/>";

// calling add with 3 arguments
echo "5 + 10 + 15 = " .add(5, 10, 15) . "<br/>";

?>
```

5 + 10 = 15 5 + 10 + 15 = 30

**遗憾的是，PHP 不支持函数重载。**

这只是为了让你了解什么是函数重载。在 PHP 中，函数签名只基于它们的名称，不包括参数列表，因此我们不能有两个同名的函数。

* * *

* * *