# PHP 关联数组

> 原文：<https://www.studytonight.com/php/associative-arrays>

**关联数组**类似于[索引数组](indexed-array)，但不是用数字索引顺序存储数据，而是可以用用户设计的`string`类型的键分配每个值。

* * *

## 创建关联数组

就像索引数组一样，在 PHP 中有两种不同的方法来创建关联数组，

**语法**第一种创建关联数组的方法:

```php
<?php
/* 
    1st - direct array initialization
*/
$lamborghinis = array("suv"=>"Urus", "sports"=>"Huracan", "coupe"=>"Aventador");

?>
```

第二种创建关联数组的方式的**语法**是:

```php
<?php
/* 
    2nd - distributed array initialization
*/
$suzuki["hatch"] = "Swift";
$suzuki["utility"] = "Ertiga";
$suzuki["suv"] = "Vitara";

?>
```

无论我们如何初始化数组，我们都可以按如下方式访问数组，

```php
<?php
/* 
    Accessing array
*/
echo "Accessing the 2nd array...";
echo $suzuki["hatch"], "\n";
echo $suzuki["utility"], "\n";
echo $suzuki["suv"], "\n";

echo "Accessing the 1st array...";
echo $lamborghinis["suv"], "\n";
echo $lamborghinis["sports"], "\n";
echo $lamborghinis["coupe"], "\n";

?>
```

访问第二个阵列...Swift Ertiga Vitara 访问第一个阵列...Urus Huracan Aventador

因此，要访问关联数组，我们必须使用数组名和方括号中元素的索引，唯一的区别是索引将是一个字符串，而不是像索引数组那样的数值。

* * *

## 遍历 PHP 关联数组

遍历数组意味着从数组的第一个索引开始迭代，直到最后一个元素。

我们可以使用`for`循环或`foreach`遍历关联数组。要了解`for`和`foreach`循环的语法和基本用法，可以参考 [PHP for 和 foreach 循环](php-for-and-foreach-loop)教程。

* * *

### 使用`for`循环

使用`for`循环遍历关联数组时，我们必须知道数组的大小/长度，这可以使用`count()`函数找到。

此外，由于关联数组中的索引不是数字，也不是顺序的，因此要查找索引值或**键**(因为保存在关联数组中的数据是键值形式)，我们可以使用函数`array_keys()`来获取关联数组中使用的键的数组。

以下是使用`for`循环遍历数组的语法。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// find size of the array
$size = count($lamborghinis);

// getting the array of keys/index strings
$keys = array_keys($lamborghinis);

// using the for loop
for($i = 0; $i < $size; $i++)
{
    echo $lamborghinis[$keys[$i]] ." is a/an ". $keys[$i] ." car \n";
}

?>
```

Urus 是一辆 suv 汽车 Huracan 是一辆跑车 Aventador 是一辆轿跑车

* * *

### 使用`foreach`循环

如果必须遍历整个数组，使用`foreach`遍历关联数组是一种更好的方法，因为我们不必费心计算数组的大小来循环数组。

下面我们用`foreach`遍历`$lamborghinis`数组。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// using the foreach loop
foreach($lamborghinis as $key => $value)
{
    echo $value ."is a/an ". $key ." car \n";
}

?>
```

Urus 是一辆 suv 汽车 Huracan 是一辆跑车 Aventador 是一辆轿跑车

不要被语法`as $key=>$value`所迷惑，这意味着在`foreach`的每次迭代中，我们都将**数组**表示为**键值对**。

* * *

### 关联数组的优点

以下是在我们的程序/脚本中使用关联数组的一些优点:

1.  我们可以为数组元素提供更有意义的键值或索引值。
2.  我们可以保存更多的数据，因为我们可以有一个字符串作为数组元素的键，我们可以将数据与要存储的值相关联，就像在我们的示例中，我们将汽车的类型存储为键，将汽车的名称存储为值。因此在一个数组元素中存储两种不同的信息。

* * *

* * *