# PHP 多维数组

> 原文：<https://www.studytonight.com/php/multidimensional-arrays>

**多维数组**是在每个索引处存储另一个数组而不是存储单个值的数组。简单来说，多维数组就是数组的数组。

通常情况下，[关联数组](associative-arrays)存储在多维数组中。

* * *

## 创建多维数组

正如我们已经看到的，如何创建一个关联数组，多维数组是数组的数组，将在其中保存关联数组。

**创建多维数组的语法**:

```php
<?php
/* 
    multidimensional array initialization
*/
$cars = array(
    array(
        "name"=>"Urus", 
        "type"=>"SUV", 
        "brand"=>"Lamborghini"
    ),
    array(
        "name"=>"Cayenne", 
        "type"=>"SUV", 
        "brand"=>"Porsche"
    ),
    array(
        "name"=>"Bentayga", 
        "type"=>"SUV", 
        "brand"=>"Bentley"
    ),
);
?>
```

由于我们在这里处理数组内部的数组，因此要访问任何信息，我们首先需要到达该数组，然后从存储在多维数组中的特定数组中获取数据。

例如，如果我们想要显示 **Urus** 汽车的数据，那么，首先我们必须获得我们的多维数组中的第一个数组，可以使用索引 **0** 访问该数组，然后在该数组中，我们可以显示所有数据，就像我们在[关联数组](associative-arrays)中所做的那样。

```php
<?php
/* 
    Accessing multidimensional array
*/
echo "Accessing multidimensional array...";
echo "Urus is an ".$cars[0]["type"]." manufactured by ".$cars[0]["brand"]."\n";
echo "Bentayga is an ".$cars[2]["type"]." manufactured by ".$cars[2]["brand"]."\n";

?>
```

访问多维数组...Urus 是一款由兰博基尼制造的 SUV，Bentayga 是一款由宾利制造的 SUV

* * *

## 遍历 PHP 多维数组

遍历数组意味着从数组的第一个索引开始迭代，直到最后一个元素。

我们可以使用两个`for`循环或两个`foreach`循环或一个`for`循环和一个`foreach`循环遍历多维数组。要了解`for`和`foreach`循环的语法和基本用法，可以参考 [PHP for 和 foreach 循环](php-for-and-foreach-loop)教程。

* * *

### 使用一个`for`循环和一个`foreach`

在多维数组的情况下，我们必须遍历主数组，然后遍历存储在主数组中的数组，因此我们需要两个循环。

当使用`for`循环遍历多维数组时，我们必须知道数组的大小/长度，这可以使用`count()`函数找到。

让我们以上面定义的数组作为遍历多维数组的第一个例子。

```php
<?php
/* 
    multidimensional array initialization
*/
$cars = array(
    array(
        "name"=>"Urus", 
        "type"=>"SUV", 
        "brand"=>"Lamborghini"
    ),
    array(
        "name"=>"Cayenne", 
        "type"=>"SUV", 
        "brand"=>"Porsche"
    ),
    array(
        "name"=>"Bentayga", 
        "type"=>"SUV", 
        "brand"=>"Bentley"
    ),
);

// array traversal
// find size of the array
$size = count($lamborghinis);

// using the for loop
for($i = 0; $i < $size; $i++)
{
    foreach($cars[$i] as $key => $value) {
        echo $key . " : " . $value . "\n";
    }
    echo "\n";
}

?>
```

名称:Urus 类型:SUV 品牌:兰博基尼名称:卡宴类型:SUV 品牌:Prosche 名称:Bentayga 类型:SUV 品牌:宾利

在上面的多维数组中，我们将主数组作为索引数组，并且存储为元素的数组是关联的。

但是主数组也可以是关联的，让我们举个例子。

此外，由于关联数组中的索引不是数字，也不是顺序的，因此要查找索引值或**键**(因为保存在关联数组中的数据是键值形式)，我们可以使用函数`array_keys()`来获取关联数组中使用的键的数组。

```php
<?php
/* 
    multidimensional array initialization
*/
$cars = array(
    "Urus" => array(
            "type"=>"SUV", 
            "brand"=>"Lamborghini"
        ),
    "Cayenne" => array(
            "type"=>"SUV", 
            "brand"=>"Porsche"
        ),
    "Bentayga" => array(
            "type"=>"SUV", 
            "brand"=>"Bentley"
        ),
);

/* 
    array traversal
*/
// find size of the array
$size = count($lamborghinis);

// array keys
$keys = arra_keys($cars);

// using the for loop
for($i = 0; $i < $size; $i++)
{
    echo $keys[$i]. "\n";
    foreach($cars[$keys[$i]] as $key => $value) {
        echo $key . " : " . $value . "\n";
    }
    echo "\n";
}

?>
```

Urus 类型:SUV 品牌:兰博基尼卡宴类型:SUV 品牌:Prosche Bentayga 类型:SUV 品牌:宾利

* * *

### 多维数组的优势

以下是在我们的程序/脚本中使用多维数组的一些优点:

1.  详细信息可以存储在多维数组中。
2.  最重要的是，它可以保持索引或关联，这使得它更加用户友好，因为他们可以根据自己的需求使用它。

* * *

* * *