# PHP 数组函数

> 原文：<https://www.studytonight.com/php/php-array-functions>

我们已经介绍了数组、[索引数组](indexed-array)、[关联数组](associative-arrays)和[多维数组](multidimensional-arrays)的基础知识。现在让我们深入研究数组，了解 PHP 中用于数组处理的内置函数。

一般来说，使用正确的数组函数会节省你很多时间，因为它们是在 PHP 库中预定义的，你所要做的就是调用它们来使用它们。

* * *

## 常用的 PHP5 数组函数

下面我们列出了 PHP 中一些常用的[数组](php-arrays)函数:

### `sizeof($arr)`

此函数返回数组的大小或数组中存储的数据元素的数量。

它就像`count($arr)`方法一样，我们在前面的教程中遍历数组时使用的。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");
echo "Size of the array is: ". sizeof($lamborghinis);

?>
```

数组的大小为:3

* * *

### `is_array($arr)`

要检查提供的数据是否为数组形式，我们可以使用`is_array()`函数。如果变量是数组，则返回`True`，否则返回`False`。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// using ternary operator
echo is_array($lamborghinis) ? 'Array' : 'not an Array';

$mycar = "Urus";

// using ternary operator
echo is_array($mycar) ? 'Array' : 'not an Array';

?>
```

数组不是数组

* * *

### `in_array($var, $arr)`

使用数组时，我们可能经常想要检查数组中是否存在某个值。例如，如果获得某辆车的列表，就像我们在几乎所有示例中所做的那样，要检查某辆车是否被添加到数组中，我们可以使用`in_array`功能。

让我们举个例子看看，

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// new concept car by lamborghini
$concept = "estoque";

echo in_array($concept, $lamborghinis) ? 'Added to the Lineup' : 'Not yet!'

?>
```

还没有！

我们可以看到，与上面的其他函数不同，这个函数采用**两个参数**，一个是数组中要搜索的值，第二个是数组本身。

* * *

### `print_r($arr)`

虽然这不是一个数组函数，但这里值得特别一提，因为我们可以使用这个函数以最具描述性的方式打印数组。该函数打印数组的完整表示，以及所有键和值。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");
print_r($lamborghinis);

?>
```

S7-1200 可编程控制器

* * *

### `array_merge($arr1, $arr2)`

如果您想将两个不同的数组组合成一个数组，可以使用这个函数。要组合的数组是相同类型(索引的、关联的等)还是不同类型并不重要，使用这个函数我们可以将它们组合成一个数组。

让我们举一个例子，我们将合并一个索引数组和一个关联数组。

```php
<?php

$hatchbacks = array(
        "Suzuki" => "Baleno",
        "Skoda" => "Fabia",
        "Hyundai" => "i20",
        "Tata" => "Tigor"
    );

// friends who own the above cars
$friends = array("Vinod", "Javed", "Navjot", "Samuel");

// let's merge the two arrays into one
$merged = array_merge($hatchbacks, $friends);

print_r($merged);

?>
```

array([铃木] = > Baleno[斯柯达]= >法比亚[现代]= > i20[塔塔]= > Tigor[0]= > Vinod[1]= > Javed[2]= > Navjot[3]= > Samuel)

* * *

### `array_values($arr)`

在数组中，数据以键值对的形式存储，其中键可以是数字(在索引数组的情况下)或用户定义的字符串(在关联数组的情况下)和值。

如果我们想从数组中获取所有的值，而不需要键，并将它们存储在一个单独的数组中，那么我们可以使用`array_values()`函数。

我们以上例中形成的数组`$merged`为例，

```php
<?php

$hatchbacks = array(
        "Suzuki" => "Baleno",
        "Skoda" => "Fabia",
        "Hyundai" => "i20",
        "Tata" => "Tigor"
    );

// friends who own the above cars
$friends = array("Vinod", "Javed", "Navjot", "Samuel");

// let's merge the two arrays into one
$merged = array_merge($hatchbacks, $friends);

//getting only the values
$merged = array_values($merged);

print_r($merged);

?>
```

Array ( [0] => Baleno [1] = >法比亚[2]= > i20[3]= > Tigor[4]= > Vinod[5]= > Javed[6]= > Navjot[7]= > Samuel)

* * *

### `array_keys($arr)`

就像值一样，我们也可以只从数组中提取键。让我们用这个函数从数组`$merged`中提取按键。

```php
<?php

//getting only the keys
$keys = array_values($merged);

print_r($keys);

?>
```

Array ( [0] = >铃木[1] = >斯柯达[2] = >现代[3] = >塔塔[4] => 0 [5] => 1 [6] => 2 [7] => 3)

* * *

### `array_pop($arr)`

此函数移除数组的最后一个元素。因此，它可以用来从末端移除一个元素。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// removing the last element
array_pop($lamborghinis);

print_r($lamborghinis);

?>
```

数组([0] => Urus [1] = >飓风)

* * *

### `array_push($arr, $val)`

该功能与`array_pop()`功能相反。这可用于在数组末尾添加新元素。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// adding a new element at the end
array_push($lamborghinis, "Estoque");

print_r($lamborghinis);

?>
```

数组([0] => Urus [1] = >飓风[2] = >复仇者[3] = >库存)

* * *

### `array_shift($arr)`

此函数可用于移除/移动数组中的第一个元素。所以，它就像`array_pop()`功能一样，只是被移除元素的位置不同。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador");

// removing the first element
array_shift($lamborghinis);

print_r($lamborghinis);

?>
```

阵列([0] = >飓风[1] = >袭击者)

与此类似，我们有另一个函数`array_unshift($arr, $val)`在数组的开始处添加一个新值(`$val`)(作为第一个元素)。

* * *

### `sort($arr)`

该函数按升序对数组元素进行排序。在字符串值数组的情况下，值按字母升序排序。

其他一些排序功能有:`asort()`、`arsort()`、`ksort()`、`krsort()`和`rsort()`。

```php
<?php

$lamborghinis = array("Urus", "Huracan", "Aventador", "Estoque");

// sort the array
sort($lamborghinis);

print_r($lamborghinis);

?>
```

数组([0] = >修正者[1] = >库存[2] = >飓风[3] => Urus)

* * *

### `array_map('function_name', $arr)`

如果要对存储在数组中的所有值执行某种操作，可以使用 [`for`循环或`foreach`](php-for-and-foreach-loop) 对数组进行迭代，并对数组的所有值执行所需的操作。

或者，可以使用`array_map()`功能。我们所要做的就是定义一个单独的函数，我们将一个接一个(一次一个)向它提供存储在数组中的值，它将对这些值执行操作。举个例子，

```php
<?php

function addOne($val) {
    // adding 1 to input value
    return ($val + 1);
}

$numbers = array(10, 20, 30, 40, 50);

// using array_map to operate on all the values stored in array
$numbers = array_map('addOne', $numbers);

print_r($numbers)

?>
```

数组([0]= > 11[1]= > 21[2]= > 31[3]= > 41[4]= > 51)

功能`array_walk($arr, 'function_name')`的工作原理与`array_map()`功能一样。

* * *

### `array_flip($arr)`

这个函数交换 PHP 关联数组的键和值。

```php
<?php

$hatchbacks = array(
        "Suzuki" => "Baleno",
        "Skoda" => "Fabia",
        "Hyundai" => "i20",
        "Tata" => "Tigor"
    );

// we can directly print the result of array flipping
print_r(array_flip($hatchbacks));

?>
```

Array ( [Baleno] = >铃木[法比亚] = >斯柯达[i20] = >现代[Tigor] = >塔塔)

* * *

### `array_reverse($arr)`

此函数用于颠倒元素的顺序，使第一个元素成为最后一个元素，最后一个元素成为第一个元素，并类似地重新排列其他数组元素。

```php
<?php

$num = array(10, 20, 30, 40, 50);
// printing the array after reversing it
print_r(array_reverse($num));

?>
```

数组([0]= > 50[1]= > 40[2]= > 30[3]= > 20[4]= > 10)

* * *

### `array_rand($arr)`

如果你想从一个数组中选择随机的数据元素，你可以使用`array_rand()`函数。这个函数从给定的数组中随机选择一个元素并返回它。

如果是索引数组，它将返回元素的索引，如果是关联数组，它将返回所选随机元素的键。

```php
<?php

$colors = array("red", "black", "blue", "green", "white", "yellow");

echo "Color of the day: ". $colors[array_rand($colors)];

?>
```

当天颜色:绿色

每次运行上面的脚本，它都会从数组中返回一个随机的颜色值。

* * *

### `array_slice($arr, $offset, $length)`

此函数用于创建任何数组的子集。使用这个函数，我们定义了起始点(`$offset`，这是子集开始的数组索引)和长度(或者，子集所需的元素数量，从偏移量开始)。

让我们举个例子，

```php
<?php

$colors = array("red", "black", "blue", "green", "white", "yellow");

print_r(array_slice($colors, 2, 3));

?>
```

数组([0] = >蓝色[1] = >绿色[2] = >白色)

* * *

* * *