# PHP 字符串

> 原文：<https://www.studytonight.com/php/php-strings>

就像任何其他编程语言一样，Php 中的字符串也是字母数字字符的集合，对于简单的字符串数据用单引号括起来，对于复杂的字符串数据用双引号括起来。

* * *

## 创建 PHP 5 字符串

有许多不同的方法可以在 Php 中创建字符串。让我们从最简单的方法开始，

```php
<?php

$srt1 = "This is a String";
$str2 = 'This is also a String';

?>
```

我们可以使用双引号和单引号**来定义字符串。**

但是，如果字符串中有单引号或双引号，那会怎样？

```php
<?php

$srt1 = "This is "a" String";
$str2 = 'This is also 'a' String';

?>
```

以上两种字符串定义都会导致**错误**，因为如果字符串是在双引号内定义的，我们不能在字符串中包含双引号。

但是如果字符串包含双引号，但是它是使用单引号定义的，反之亦然，例如，

```php
<?php

// string inside double quotes, with a single quote
$srt1 = "This is 'a' String";

// string inside single quotes, with a double quote
$str2 = 'This is also "a" String';

?>
```

还有一个更简单的技巧来处理引号问题，它被称为**转义特殊字符**，这可以使用**反斜杠**来完成。

让我们举个例子，

```php
<?php

// escaping double quote using backslash
$srt1 = "I\"ll handle this.";

// escaping single quote using backslash
$str2 = 'I\'ll handle this.';

echo $str1;
echo "\n";  // new line
echo $str2;

?>
```

我会处理的。我来处理。

从上面的例子可以明显看出，在 PHP 5 中声明和定义一个字符串变量非常简单。只是要小心引号和其他一些特殊字符，如`$`。我们也举一个`$`特殊字符的例子。

```php
<?php

// string with $
$srt1 = "pas$word";

echo $str1;

?>
```

注意:未定义的变量传递

运行上面的代码，将显示只有在`$`符号之前的字符串部分将被存储在变量中，而`$word`被视为变量，没有被赋予任何值，因此，PHP 打印了一个`NOTICE`。现在让我们试着用反斜杠来转义它，

```php
<?php

// string with escaped $
$srt1 = "pas\$word";

echo $str1;

?>
```

传递$word

* * *

## 使用此文档方法创建字符串

如果我们想定义一个多行字符串，使用这里的**doc**语法是最好也是最简单的技术。

使用这种方法，我们可以创建多行字符串，而不需要字符串连接。

此外，如果我们使用这里的**文档**方法来定义字符串，则不需要转义双引号或单引号。

让我们举个例子:

```php
<?php

$str = <<< EOT
    Take a right from the T point,
    and the go straight to fins the "Shop"
EOT;

echo $str;

?>
```

从 T 点向右拐，然后一直走到“商店”

这里 **EOT** 只是文本结尾的同义词，没有任何意义。这 3 个字符只是用来标记多行字符串的开始和结束。

你可以使用 **EOF** 或者也许 **[SQL](/plsql/overview-of-plsql)** 如果你用这个来定义你的多行 SQL 查询，比如，

```php
<?php

$tablename = "products";

$str = <<< SQL
    Select * from $tablename
    Where product_name = "widgets"
SQL;

echo $str;

?>
```

从产品中选择*产品名称=“小部件”

* * *

## 使用 Nowdoc 方法创建字符串

创建字符串的 **Nowdoc** 方法类似于**赫里多克**方法，只有一个区别，那就是字符串没有被解析，因此如果我们想使用其他变量`，就像我们在上面的 SQL 查询字符串中所做的那样，给我们的字符串添加一个值，我们不能用 **Nowdoc** 来做。

让我们举个例子，

```php
<?php

$hername = "Selena";

$str = <<< 'LOV'
    This is my declaration of love,
    for $hername
LOV;

echo $str;

?>
```

这是我的爱情宣言，价值 100 美元

字符串中的变量不会被转换为其值。

* * *

### 打印字符串变量

打印字符串变量很简单，我们举两个例子，第一个例子中我们只使用`echo`方法打印字符串变量，第二个例子中，我们将在`echo`方法中附加一个字符串变量和一些其他文本，用单引号和双引号括起来。

```php
<?php

$hername = "Selena";

// only the string variable
echo $hername;

// for new line
echo "\n";

// string variable with text and single quote
echo '$hername, I love you!';

echo "\n";

// string variable with text and double quote
echo "$hername, I love you!";

?>
```

赛琳娜，我爱你！赛琳娜，我爱你！

看到区别了吗，单引号不会解析它里面的文本，因此变量不会被翻译成它的值，而在双引号的情况下，它会。

* * *

* * *