# PHP 字符串函数

> 原文：<https://www.studytonight.com/php/php-string-functions>

在上一个教程中，我们已经介绍了什么是字符串以及如何创建它们，现在让我们深入研究字符串，了解 PHP 中用于字符串处理的内置函数。

一般来说，使用正确的字符串函数会节省很多时间，因为它们是在 PHP 库中预定义的，您所要做的就是调用它们来使用它们。

* * *

## 常用的 PHP 5 字符串函数

下面我们列出了 PHP 中一些常用的字符串函数:

### `strlen($str)`

此函数返回字符串的长度或字符串中的字符数，包括空格。

```php
<?php

$str = "Welcome to Studytonight";

// using strlen in echo method
echo "Length of the string is: ". strlen($str);

?>
```

字符串的长度为:23

* * *

### `str_word_count($str)`

此函数返回字符串中的字数。对于一些简单的验证，这个函数在表单域验证中很容易实现。

```php
<?php

$str = "Welcome to Studytonight";

// using str_word_count in echo method
echo "Number of words in the string are: ". str_word_count($str);

?>
```

字符串中的字数是:3

* * *

### `strrev($str)`

此函数用于反转字符串。

让我们举个例子看看，

```php
<?php

$str = "Welcome to Studytonight";

// using strrev in echo method
echo "Reverse: ". strrev($str);

?>
```

反向:thginotyduts ot emoclew

* * *

### `strpos($str, $text)`

该函数用于查找给定字符串中任何文本/单词的位置。就像[数组](php-arrays)一样，字符串也从零开始为存储在其中的字符分配索引值。

```php
<?php

$str = "Welcome to Studytonight";

// using strpos in echo method
echo "Position of 'Studytonight' in string: ". strpos($str, 'Studytonight');

?>
```

“今晚学习”在字符串中的位置:11

* * *

### `str_replace($replacethis, $replacewith, $str)`

此函数用于用一些文本替换字符串的一部分。使用此函数时，第一个参数是要替换的字符串部分，第二个参数是要包含的新文本，最后一个参数是字符串变量本身。

让我们举个例子，

```php
<?php

$str = str_replace("Studytonight", "Studytonight.com", "Welcome to Studytonight");

echo $str;

?>
```

欢迎来到 Studytonight.com

* * *

### `ucwords($str)`

该函数用于格式化字符串。该函数将字符串中每个单词的第一个字母/字符转换为大写。

让我们举个例子看看，

```php
<?php

$str = "welcome to studytonight";

echo ucwords($str);

?>
```

欢迎今晚来学习

* * *

### `strtoupper($str)`

要将字符串中每个单词的每个字母/字符转换为大写，可以使用`strtoupper()`方法。

```php
<?php

$str = "welcome to studytonight";

echo strtoupper($str);

?>
```

欢迎今晚来学习

* * *

### `strtolower($str)`

该函数用于将字符串的每个字母/字符转换为小写。

```php
<?php

$str = "WELCOME TO STUDYTONIGHT";

echo strtolower($str);

?>
```

欢迎今晚来学习

* * *

### `str_repeat($str, $counter)`

该函数用于将字符串重复给定的次数。第一个参数是字符串，第二个参数是字符串应该重复的次数。

```php
<?php

$str = "Studytonight";

echo str_repeat($str, 4);

?>
```

今晚学习

* * *

### `strcmp($str1, $str2)`

该函数用于比较两个字符串。比较是按字母顺序进行的。如果第一个字符串大于第二个字符串，结果将大于`0`，如果第一个字符串等于第二个字符串，结果将等于`0`，如果第二个字符串大于第一个字符串，则结果将小于`0`。

```php
<?php

$str1 = "Studytonight";
$str2 = "Studytonight.com";

// comparing str1 and str2
echo strcmp($str1, $str2);

// comparing str2 and str1
echo strcmp($str2, $str1);

// comparing str1 with str1
echo strcmp($str1, $str1);

?>
```

-4 4 0

* * *

### `substr($str, $start, $length)`

该函数用于从特定位置开始，取出特定长度的字符串(子字符串)的一部分。

第一个参数是字符串本身，第二个参数是要提取的子字符串的起始索引，第三个参数是要提取的子字符串的长度。

```php
<?php

$str = "Welcome to Studytonight";

echo substr($str, 11, 12);

?>
```

今晚学习

* * *

### `trim($str, charlist)`

此函数用于从字符串的开头和结尾移除多余的空格。第二个参数`charlist`是可选的。我们可以提供一个字符列表，就像字符串一样，作为第二个参数，从主字符串中删除这些字符。

```php
<?php

$str1 = "   Hello World   ";

echo trim($str1) . "<br/>";

$str2 = "Hello Hello";

echo trim($str2,"Heo");

?>
```

你好，地狱世界

正如您在输出中看到的，从开始和结束的额外空格被删除，在第二种情况下，指定的字符从字符串的开始和结束被删除。

* * *

### `explode(separator, $str, $limit)`

此函数用于断开字符串，创建字符串断开部分的数组并返回数组。第一个参数**分隔符**定义了从哪里断开字符串。它可以是空格、hiphen(-)或任何其他字符。

这个函数的第二个参数是字符串本身，第三个参数是**限制**，指定要返回的数组元素个数。第三个参数是可选的。

举个例子，

```php
<?php

$str = "Its a beautiful day";

// we can directly print the result of explode
print_r(explode(" ", $str));

?>
```

数组([0] = >它的[1] = >一个[2] = >美丽的[3] = >天)

在上面的例子中，我们提供了**空间**作为分隔符来断开字符串并返回一个数组。

如果我们也提供第三个参数**限制**，我们可以限制返回的数组元素的数量。例如，如果我们提供`2`作为第三个参数，那么我们将只得到数组中的 2 个元素，前两个。

* * *

### `implode(separator, $arr)`

该函数用于使用提供的数组中的数组元素组成字符串，并使用**分隔符**连接它们。

让我们举个例子，

```php
<?php

$arr = array("Its", "a", "beautiful", "day");

// <br> is used to jump to next line
echo implode(" ", $arr) . "<br>";
echo implode("-", $arr) . "<br>";
echo implode("/", $arr) . "<br>";

?>
```

这是美好的一天，这是美好的一天

* * *

### `nl2br($str)`

该功能用于将换行符或`\n`改为换行符的 HTML 标签，即`<br>`。

这个函数对于格式化字符串数据以在 HTML 页面上显示非常有用，因为当提交多行表单数据时，它的 strnig 中包含了`\n`用于换行符，但是当您在 HTML 页面上显示它时，换行符不会被渲染，因为 HTML 不理解`\n`。

```php
<?php

echo nl2br("Its a\nbeautiful day");

?>
```

天气真好

* * *

* * *