# PHP Cookies

> 原文：<https://www.studytonight.com/php/php-cookies>

Cookie 是网络服务器以文件形式存储在用户浏览器中的一小段信息。一旦创建，cookie 将作为每个 HTTP 请求的头信息发送到 web 服务器。

您可以使用 cookie 保存任何数据，但大小不应超过 **1K(1024 字节)**。

在我们继续讨论如何创建、更新和删除 cookie 之前，让我们学习一些 cookie 在现实世界中的用法。

* * *

## 饼干的真实使用

1.  存储用户信息，如他/她何时访问过，网站上访问过哪些页面等，以便下次用户访问您的网站时，您可以提供更好的用户体验。
2.  要存储基本的网站具体信息要知道这不是用户的第一次访问。
3.  您可以使用 cookies 来存储访问次数或查看计数器。

我希望这能让你对如何在你的 web 应用程序中利用 cookies 有一个概念。

* * *

## 饼干的种类

有两种类型的 cookies，它们是:

1.  **会话 Cookie** :这种类型的 Cookie 是临时的，一旦会话结束或浏览器关闭，就会过期。
2.  **持久 Cookie** :要使 Cookie 持久，我们必须为其提供过期时间。那么该 cookie 将仅在给定的过期时间后过期，在此之前它将是有效的 cookie。

* * *

## 用 PHP 创建一个 Cookie

在 PHP 中，我们可以使用`setcookie()`函数创建/设置一个 cookie。

下面是函数的语法，

```php
setcookie(name, value, expire, path, domain, secure)
```

定义 cookie 的**名称**的第一个参数是强制的，其余的都是可选参数。让我们了解一下，我们可以向`setcookie()`函数提供哪些可用的参数来设置 cookie。

| 争吵 | 它是干什么用的？ |
| 名字 | 用于指定 cookie 的名称。这是一个强制性的论点。cookie 的名称必须是字符串。 |
| 价值 | 用于在 cookie 中存储任何值。一般保存为带名称的一对。例如，名称为*用户标识*，值为 *7007* ，任意用户的用户标识。 |
| 期满 | 用于设置 cookie 的过期时间。如果不提供任何值，cookie 将被视为会话 cookie，并在浏览器关闭时过期。 |
| 小路 | 用于在 cookie 中设置网址。如果设置，cookie 将只能从该网址访问。要通过域访问 cookie，请将`'/'`设置为 cookie 路径。 |
| 领域 | 您的 web 应用程序的域。它可以用来限制子域对 cookie 的访问。例如，如果您将域值设置为**wwww.studytonight.com**，则该 cookie 将无法从**blog.studytonight.com**访问 |
| 安全的 | 如果您将此设置为`1`，则 cookie 将可用，并且仅通过 HTTPS 连接发送。 |

因此，如果我们想创建一个 cookie 来存储访问您网站的用户的姓名，并设置一周的过期时间，那么我们可以这样做，

```php
<?php

setcookie("username", "iamabhishek", time()+60*60*24*7);

?>
```

要访问存储的 cookie，我们使用`$_COOKIE`全局变量，并且可以使用`isset()`方法来检查 cookie 是否被设置。

让我们有一个完整的例子，我们将设置一个 cookie，然后检索它以在 HTML 页面中显示它的值。

```php
<?php
// set the cookie
setcookie("username", "iamabhishek", time()+60*60*24*7);
?>
<html>
    <body>

    <?php
    // check if the cookie exists
    if(isset($_COOKIE["username"]))
    {
        echo "Cookie set with value: ".$_COOKIE["username"];
    }
    else
    {
        echo "cookie not set!";
    }
    ?>

    </body>
</html>
```

因此，通过提供带有全局变量`$_COOKIE[]`的方形数据库中的 cookie 名称，我们可以访问该 cookie。

**注意:** `setcookie()`功能应该放在起始 HTML 标记(`<html>`)之前。

* * *

## 用 PHP 更新 Cookie

要更新/修改 cookie，只需再次设置即可。例如，如果我们想更新上面创建的 cookie 中存储的用户名，我们可以再次使用`setcookie()`方法来完成，

```php
<?php
// updating the cookie
setcookie("username", "iamNOTabhishek", time()+60*60*24*7);
?>
<html>
    <body>

    <?php
    // check if the cookie exists
    if(isset($_COOKIE["username"]))
    {
        echo "Cookie set with value: ".$_COOKIE["username"];
    }
    else
    {
        echo "cookie not set!";
    }
    ?>

    </body>
</html>
```

我们只是将**用户名** cookie 的**值**从*iamabishek*更新为*iamanabishek*。

* * *

## 删除 PHP 中的一个 Cookie

要删除/移除 cookie，我们需要使 cookie 过期，这可以通过使用过期日期在过去的`setcookie()`功能更新 cookie 来完成。

```php
<?php
// updating the cookie
setcookie("username", "iamNOTabhishek", time() - 3600);
?>
<html>
    <body>

    <?php

    echo "cookie username is deleted!";

    ?>

    </body>
</html>
```

有了这个，我们现在知道如何创建一个 cookie，如何更新它，以及当我们不再需要它时如何删除它。接下来，会话！

* * *

* * *