# 用于状态管理的 PHP 会话

> 原文：<https://www.studytonight.com/php/php-session-management>

为了存储网页上可访问的信息，我们使用会话。**会话**不像[cookie](php-cookies)那样存储在用户浏览器上，因此它是一个更安全的选项。

我们知道 HTTP 是一个无状态协议，如果用户访问一个网页并执行一些动作，那么当用户导航到下一个网页时，就没有办法记住他做了什么。

让我们举一个实际的例子，当你登录你的 facebook 帐户时，通过提供你的电子邮件地址和密码，直到并且除非你注销，网络应用程序会记住你是谁，并在你的新闻提要上显示你的朋友正在发布和喜欢什么，你可以更新你的个人资料，给某人发消息，加入一个群组等，这是通过 **Session** 完成的。

当用户在任何网络应用程序上登录他们的帐户时，会为他们创建一个会话，并且在该会话中会存储他们的*用户名*或*用户标识*或其他一些唯一的标识符，然后在连续的网页上使用这些标识符来显示该用户的特定信息。注销时，会话将被销毁。

会话不受任何大小限制，您可以在会话中存储任何信息，无论其大小如何。

在我们继续讨论如何在 PHP 中开始、更新和结束一个会话之前，让我们学习会话的一些实际用法。

* * *

## 会话的真实使用

1.  需要用户登录的 Web 应用程序使用会话来存储用户信息，以便在每个网页上向用户显示相关信息。
2.  在电子商务网站中，购物车通常作为会话的一部分保存。

我希望这能让你了解如何在你的 web 应用程序中利用会话。

* * *

* * *

## 用 PHP 启动一个会话

在 PHP 中，我们可以使用`session_start()`函数启动一个会话。并且使用会话变量将数据存储在会话中，可以使用全局变量`$_SESSION`为其分配不同的值

简单来说，使用函数`session_start()`我们初始化会话，其中我们可以使用会话变量`$_SESSION`存储信息。

举个例子，下面我们有一个 Php 文件名为 **first_page.php** 的网页

```php
<?php
// start the session
session_start();

// set the session variable
$_SESSION["username"] = "iamabhishek";
$_SESSION["userid"] = "1";
?>

<html>
    <body>

    <?php
    echo "Session variable is set.";
    ?>

    <a href="second_page.php">Go to Second Page</a>

    </body>
</html>
```

**注意:**函数`session_start()`应该是页面的第一条语句，在任何 HTML 标签之前。

* * *

## 获取 PHP 会话变量值

在上面的代码中，我们已经启动了一个会话并设置了两个会话变量。上述网页还将有一个链接导航到第二页 **second_page.php** 。

下面是 **second_page.php** 的代码，其中我们从 **first_page.php** 中设置的会话变量中获取值。

```php
<?php
// start the session
session_start();

// get the session variable values
$username = $_SESSION["username"];
$userid = $_SESSION["userid"];
?>

<html>
    <body>

    <?php
    echo "Username is: ".$username."<br/>";
    echo "User id is: ".$userid;
    ?>

    </body>
</html>
```

用户名为:iamabhishek 用户 id 为:1

你一定在想，为什么我们在这里使用`session_start()`虽然我们没有在会话变量中设置任何新的值。

`session_start()`函数用于初始化一个新的会话，并获取正在进行的会话(如果已经开始)，然后，使用`$_SESSION`全局变量，我们可以在会话中设置新的值，或者获取保存的值。

如果会话中存储的值太多，并且不知道要获取哪个值，可以使用下面的代码打印所有当前会话变量数据。

```php
<?php
// start the session
session_start();
?>

<html>
    <body>

    <?php
    print_r($_SESSION);
    ?>

    </body>
</html>
```

数组([用户名]= > iamabishek，[用户标识] => 1)

* * *

## 用 PHP 更新会话变量

要更新会话变量中存储的任何值，通过调用`session_start()`函数启动会话，然后简单地覆盖 vakue 来更新会话变量。

```php
<?php
// start the session
session_start();

// update the session variable values
$_SESSION["userid"] = "1111";
?>

<html>
    <body>

    <?php
    echo "Username is: ".$username."<br/>";
    echo "User id is: ".$userid;
    ?>

    </body>
</html>
```

用户名为:iamabhishek 用户 id 为:1111

我们刚刚将会话变量中**用户标识**的**值**从 *1* 更新为 *1111* 。

* * *

## 用 PHP 销毁一个会话

要清除会话变量或从会话变量中移除所有存储的值，我们可以使用函数`session_unset()`，要取消会话，我们可以使用`session_destroy()`函数。

```php
<?php
// start the session
session_start();
?>

<html>
    <body>

    <?php
    // clean the session variable
    session_unset();

    // destroy the session
    session_destroy();
    ?>

    </body>
</html>
```

在电子商务网站的情况下，我们在类似**注销**或**结账**的页面上使用这些功能来清除用户特定数据的会话变量，并最终销毁当前会话。

* * *

* * *