# PHP 中的类

> 原文：<https://www.studytonight.com/php/php-class>

作为一种面向对象的编程语言，PHP 允许在开发任何软件或应用程序时，创建遵循面向对象编程范式的类和对象。

一个**类**是用户定义的数据类型，包括局部变量和局部方法。

而**对象**是类的一个实例，它保存了带有赋值的局部变量，我们可以在其上调用类中定义的局部方法。

在本教程中，我们将学习如何在 PHP 中定义一个类，以及如何创建它的对象。

* * *

## 用 PHP 定义一个类

当我们用 PHP 定义一个类时，就像任何变量一样，我们必须给我们的类命名，在用 PHP 命名我们的类时，我们必须遵循一些规则，它们是:

*   类名应该以字母开头。
*   类名不应是保留的 PHP 关键字。
*   类名不应包含任何空格。

现在我们已经知道了 PHP 中与类命名约定相关的规则，让我们创建一个名为 **Person** 的简单类。

* * *

### 用 PHP 定义类的语法

在 PHP 中定义一个类的语法非常简单，我们使用关键字`class`后跟类的**名称**，然后我们将该类的代码放在**花括号{ }** 中，就像函数/方法一样。

以下是`Person`类的代码:

```php
<?php
    class Person {

        // class variables and methods comes here...

    }
?>
```

虽然这不是强制性的，但是使用类名作为 PHP 文件的文件名是一个很好的做法。此外，PHP 允许在一个文件中定义多个类，但同样不建议这样做。

所以我们将上述类`Person`的代码保存在文件**Person.php**中。

现在我们给我们的类添加一个变量来存储一个人的**名字**。当我们在一个类中创建一个变量时，它被称为**属性**。

```php
<?php
    class Person {
        // to store name of person
        var $name;

    }
?>
```

`var`是定义类内变量/属性的关键字，`$name`是变量的名称。

是时候在我们的类中添加方法/函数了。函数在类内定义时称为**方法**。

在一个类中，方法被定义为要么对类变量(属性)执行一些操作，要么对类执行一些其他操作，比如打印所有变量的值，或者可以将数据存储到数据库等。

当我们定义方法来**获取**类变量的值和**设置**类变量的值时，这些方法被称为 **Getter 和 Setter** 函数。

这些被普遍命名为`get_NAME-OF-VARIABLE()`和`set_NAME-OF-VARIABLE()`。

所以，对于变量`$name`，我们来添加`get_name()`和`set_name()`函数。

```php
<?php
    class Person {
        // to store name of person
        var $name;

        // print name
        function get_name() {
            return $this->name;
        }

        function set_name($new_name) {
            $this->name = $new_name;
        }

    }
?>
```

当我们将学习如何创建类的对象时，我们将更多地讨论为什么我们需要 getter 和 setter 函数。

* * *

### 我们可以定义一个没有变量的类吗？

是的，一个简单的类不需要任何变量。我们可以简单地有一些方法。这样的类通常是助手类，其中包含一些有用的通用方法。

让我们用两种方法创建一个名为**人类**的简单类:

```php
<?php
    class Human {

        // for male
        function male() {
            echo "This human is a male";
        }

        function female() {
            echo "This human is a female";
        }

    }
?>
```

对于上面的类，所有的对象都是相似的，因为没有变量。

当我们在一个类中有变量时，我们可以用类变量的不同值创建该类的多个对象。

所以到目前为止，我们希望你已经理解了什么是类，它只是一个用户定义的数据类型，它有属性/变量和类方法。在下一个教程中，我们将学习如何创建类对象。

* * *

* * *