# PHP 访问修饰符

> 原文：<https://www.studytonight.com/php/php-access-modifiers>

为了设置[类](php-class)方法和变量的访问权限，我们使用的访问修饰符只是 PHP 关键字。我们甚至可以将其中的一些访问修饰符分配给类本身，以使类以一种特殊的方式运行。

下面是 PHP **关键字**，它们被用作访问修饰符，并带有它们的含义:

1.  `public`:当我们将类成员定义为公共的时候，那么它们可以从任何地方访问，甚至可以从类范围之外访问。
2.  `private`:当我们将类成员定义为私有时，只能从类本身内部访问。
3.  `protected`:这个和 private 一样，除了一个例外，定义为 protected 的类成员仍然可以从它的子类访问(我们在了解[继承](php-inheritance)的时候会了解子类)。
4.  [`abstract`](php-abstract-class-and-methods) :此关键字仅用于 PHP 类及其成员函数。
5.  `final`:定义为 final 的类方法不能被任何子类改变或覆盖。

* * *

## 何时使用哪个访问修饰符

我们不能对类、它的变体和方法使用所有可用的访问修饰符。在下表中，我们指定了哪个访问说明符应用于什么:

| 访问修饰符 | 班 | 功能 | 变量 |
| **公共** | 不适用 | 可应用的 | 可应用的 |
| **私人** | 不适用 | 可应用的 | 可应用的 |
| **受保护** | 不适用 | 可应用的 | 可应用的 |
| **摘要** | 可应用的 | 可应用的 | 不适用 |
| **决赛** | 可应用的 | 可应用的 | 不适用 |

现在我们知道了在哪里使用哪个访问修饰符，让我们通过例子详细了解访问修饰符。

* * *

## `public`存取修改子

如果我们不指定任何访问修饰符，默认情况下，所有类及其成员都被视为`public`。

如上表所述，`public`、`private`或`protected`访问修饰符不能用于类。让我们看看如果我们这样做了会发生什么，

```php
<?php
    public class Studytonight {
        ...
    }
?>
```

分析错误:语法错误，中出现意外的“PUBLIC”(T _ PUBLIC)...

我们会得到上面的错误。

但是对于类方法和变量，我们应该指定访问说明符，尽管默认情况下它们被视为公共的。

这是一个简单的 PHP 类的例子:

```php
<?php
    class Studytonight {
        // to store name of person
        var $url = "studytonight.com";

        // simple class method
        function desc() {
            echo "Studytonight helps you learn Coding.";
        }
    }
?>
```

在上面的代码中，我们在类变量之前使用了关键字`var`。如果我们不使用`var`，我们会得到一个解析错误。

但是除了使用`var`之外，我们还可以在类变量的脱序之前使用访问修饰符关键字，例如:

```php
<?php
    class Studytonight {
        // to store name of person
        public $url = "studytonight.com";

        // simple class method
        function desc() {
            echo "Studytonight helps you learn Coding.";
        }
    }
?>
```

这就是我们应该如何创建一个 PHP 类，指定访问修饰符以及类变量和方法是很好的编程实践。

* * *

## `private`存取修改子

我们可以对类变量和方法使用`private`访问修饰符，但不能对 PHP 类使用。当一个类成员——一个变量或一个函数——被声明为`private`时，它就不能直接使用该类的对象来访问。例如:

```php
<?php
    class Person {
        // first name of person
        private $fname;
        // last name of person
        private $lname;

        // public function to set value for fname
        public function setFName($fname) {
            $this->fname = $fname;
        }

        // public function to set value for lname
        public function setLName($lname) {
            $this->lname = $lname;
        }

        // public function to 
        public function showName() {
            echo "My name is: " . $this->fname . " " . $this->lname;
        }
    }

    // creating class object
    $john = new Person();

    // trying to access private class variables
    $john->fname = "John";  // invalid
    $john->lname = "Wick";  // invalid

    // calling the public function to set fname and lname
    $john->setFName("John");
    $john->setLName("Wick");

?>
```

在上面的代码中，`$fname`和`$lname`是私有的类变量，因此我们不能使用类对象直接访问它们。

因此，当我们尝试执行以下代码行时:

```php
<?php
    $john->setFName("John");
?>
```

我们将得到一个致命的 PHP 错误:

致命错误:无法访问私有属性个人::$fname in...

但是我们可以通过在类中定义公共函数来轻松访问类的私有变量。我们可以创建单独的函数来设置私有变量的值并获取它们的值。这些函数称为**获取器和设置器**。

```php
<?php
    class Person {
        // first name of person
        private $name;

        // public function to set value for name (setter method)
        public function setName($name) {
            $this->name = $name;
        }

        // public function to get value of name (getter method)
        public function getName() {
            return $this->name;
        }
    }

    // creating class object
    $john = new Person();

    // calling the public function to set fname
    $john->setName("John Wick");

    // getting the value of the name variable
    echo "My name is " . $john->getName();

?>
```

我叫疾速追杀

对于类中的所有私有变量，我们应该有 getter 和 setter 方法。

* * *

## `protected`存取修改子

就像`private`访问修饰符一样，`protected`访问修饰符也限制类外的类变量和方法的访问。但是`protected`类变量和函数可以在类内部和子类(继承类的类)内部访问。

我们将在接下来的教程中学习如何创建子类以及继承的概念。

让我们举一个简单快速的例子:

```php
<?php
    class Human {
        // protected variable
        protected $genders = array("Male", "Female", "Other");

        // protected function for humans features
        protected function getFeatures($gender) {
            if($gender == "Male") {
                echo "Men will be Men";
            }
            else if($gender == "Female") {
                echo "Women's mind is a maze.";
            }
            else if($gender == "Other") {
                echo "All are born equal.";
            }
        }

    }

    // subclass of the above class
    class Male extends Human {
        protected $gender = "Male";

        // public function to print Male features
        public function getMaleFeatures() {
            // calling the protected getFeatures() method of class Human
            $this->getFeatures($this->gender);
        }
    }

    // object of Human class
    $human = new Human();
    // object of Male class
    $male = new Male();

    /*  
        accessing protected variables and methods
    */
    echo $human->genders;   // INVALID
    $human->getFeatures("Male");    // INVALID
    echo $male->gender;     // INVALID

    /*
        but we can call getMaleFeatures method,
        in which we are calling a protected method 
        of Human class
    */
    $male->getMaleFeatures();

?>
```

在上面的程序中，我们定义了两个类，`Human`和`Male`。`Male`类是`Human`类的子类。

在`Human`类中，所有的类变量和方法都是`protected`，因此它们不能从类外访问，但是它们可以在类的子类`Human`中访问。

不要担心，如果这看起来由于 **[【继承】](php-inheritance)** 的概念而令人困惑，我们将再次重新访问这一点，届时我们将了解继承。

* * *

## `abstract`存取修改子

`abstract`访问修饰符用于 PHP 类及其函数。它不能用于类变量。

如果一个类甚至只有一个`abstract`方法。那么类也必须定义为`abstract`。

此外，PHP 不允许实例化抽象类，即您不能创建`abstract`类的对象，尽管这些类可以被继承。

我们将在讨论抽象类和接口时详细了解这个访问修饰符。

* * *

## `final`存取修改子

当我们使用这个访问修饰符将一个类声明为`final`时，那么这个类就不能被继承。

类似地，当我们将一个类函数定义为`final`时，PHP 会限制该类的子类覆盖声明为`final`的函数。

同样，当我们学习继承时，我们将通过例子来解释这一点。

* * *

* * *