# PHP `$this`关键字

> 原文：<https://www.studytonight.com/php/php-this-keyword>

如果您从头开始学习本教程，或者从 [OOPS 概念](php-object-oriented-programming)开始，您一定注意到了一些代码片段中`$this`的用法。

`this`关键字在类内部使用，通常在成员函数内部，用于访问当前对象的类(变量或函数)的非静态成员。

我们举个例子来了解一下`$this`的用法。

```php
<?php
    class Person {
        // first name of person
        private $name;

        // public function to set value for name (setter method)
        public function setName($name) {
            $this->name = $name;
        }

        // public function to get value of name (getter method)
        public function getName() {
            return $this->name;
        }
    }

    // creating class object
    $john = new Person();

    // calling the public function to set fname
    $john->setName("John Wick");

    // getting the value of the name variable
    echo "My name is " . $john->getName();

?>
```

我叫疾速追杀

在上面的程序中，我们在类中创建了一个名为`$name`的`private`变量，我们有两个`public`方法`setName()`和`getName()`分别给`$name`变量赋值和获取它的值。

每当我们想从成员函数内部调用[类](php-class)的任何变量时，我们使用`$this`指向保存该变量的当前对象。

我们也可以使用`$this`在另一个成员函数内部调用一个类的一个成员函数。

**注:**如果类中有任何`static`成员函数或变量，我们不能用`$this`来引用。

* * *

## 将`self`用于`static`类成员

代替`$this`，对于`static`类成员(变量或函数)，我们使用`self`，以及**范围解析运算符** `::`。让我们举个例子，

```php
<?php
    class Person {
        // first name of person
        public static $name;

        // public function to get value of name (getter method)
        public static function getName() {
            return self::$name;     // using self here
        }
    }

?>
```

* * *

## PHP `self`和`this`的区别

让我们了解一下`self`和`this`的几个区别:

| `self` | `this` |
| `self`关键字前面没有任何符号。 | `this`关键字前面应该有一个`$`符号。 |
| 要使用`self`关键字访问类变量和方法，我们使用**范围解析运算符** `::` | 对于`this`运算符，我们使用`-<`符号。 |
| 用来指代班级的`static`成员。 | 用于访问类的**非静态**成员。 |
| PHP `self`指的是类成员，但不是针对任何特定的对象。这是因为`static`成员(变量或函数)是类的所有对象共享的类成员。 | 而`$this`将引用特定实例的成员变量和函数。 |

让我们举一个代码示例来更好地理解这一点:

```php
<?php
    class Job {
        // opening for position
        public $name;
        // description for the job;
        public $desc;
        // company name - as the company name stays the same
        public static $company;

        // public function to get job name
        public function getName() {
            return $this->name;
        }

        // public function to get job description
        public function getDesc() {
            return $this->desc;
        }

        // static function to get the company name
        public static function getCompany() {
            return self::$company;
        }

        // non-static function to get the company name
        public function getCompany_nonStatic() {
            return self::getCompany();
        }
    }

    $objJob = new Job();
    // setting values to non-static variables
    $objJob->name = "Data Scientist";
    $objJob->desc = "You must know Data Science";

    /* 
        setting value for static variable.
        done using the class name
    */
    Job::$company = "Studytonight";

    // calling the methods
    echo "Job Name: " .$objJob->getName()."<br/>";
    echo "Job Description: " .$objJob->getDesc()."<br/>";
    echo "Company Name: " .Job::getCompany_nonStatic();

?>
```

职位名称:数据科学家职位描述:你一定知道数据科学公司名称:今晚学习

在上面的代码片段中，我们有几个非静态变量和一个`static`变量。

因为`static`成员与类本身相关联，而不是与类的对象相关联，因此我们使用类名来称呼它们。

同样，一个`static`成员函数可以在里面使用一个`static`变量，而如果一个**非静态**方法在里面使用一个`static`变量，那么它也被称为使用类名，就像一个`static`方法一样。

* * *

* * *