# PHP 构造器和析构器

> 原文：<https://www.studytonight.com/php/php-constructor-and-destructor>

当我们创建任何类的[对象](php-class-objects)时，我们需要在使用它之前设置该对象的属性。我们可以这样做:首先初始化对象，然后设置属性的值，如果变量是`public`，则使用`->`操作符，或者对`private`变量使用公共**设置器**方法。

为了一步创建并初始化一个类对象，PHP 提供了一种特殊的方法，称为**构造器**，用于在创建对象时通过分配所需的属性值来构造对象。

而对于破坏对象**使用析构器**方法。

* * *

## 定义构造器和析构器的语法

在 PHP 中，我们有特殊的函数来定义一个类的构造器和析构器，它们是:`__construct()`和`__destruct()`。

```php
<?php
    class <CLASS_NAME> {

        // constructor
        function __construct() {
            // initialize the object properties
        }

        // destructor
        function __destruct() {
            // clearing the object reference
        }
    }
?>
```

构造器可以接受参数，而析构器不会有任何参数，因为析构器的工作是删除当前的对象引用。

* * *

## PHP 构造器

让我们以一个有两个属性`fname`和`lname`的类`Person`为例，对于这个类，我们将定义一个构造器，用于在创建对象时初始化类属性(变量)。

```php
<?php
    class Person {
        // first name of person
        private $fname;
        // last name of person
        private $lname;

        // Constructor
        public function __construct($fname, $lname) {
            echo "Initialising the object...<br/>"; 
            $this->fname = $fname;
            $this->lname = $lname;
        }

        // public method to show name
        public function showName() {
            echo "My name is: " . $this->fname . " " . $this->lname; 
        }
    }

    // creating class object
    $john = new Person("John", "Wick");
    $john->showName();

?>
```

初始化对象...我叫疾速追杀

之前，我们使用`->`操作符来设置变量的值，或者使用**设置器方法**，在构造器方法的情况下，我们可以在对象创建时为变量赋值。

如果一个类有一个构造器，那么无论何时创建该类的对象，都会调用该构造器。

* * *

### PHP 构造器重载

PHP 不支持函数重载，因此我们不能在一个类中有多个构造器实现。

* * *

## PHP 破坏程序

PHP 析构器方法在 PHP 即将从内存中释放任何对象之前被调用。通常，你可以在析构器中关闭文件，清理资源等。让我们举个例子，

```php
<?php
    class Person {
        // first name of person
        private $fname;
        // last name of person
        private $lname;

        // Constructor
        public function __construct($fname, $lname) {
            echo "Initialising the object...<br/>"; 
            $this->fname = $fname;
            $this->lname = $lname;
        }

        // Destructor
        public function __destruct(){
            // clean up resources or do something else
            echo "Destroying Object...";
        }

        // public method to show name
        public function showName() {
            echo "My name is: " . $this->fname . " " . $this->lname . "<br/>"; 
        }
    }

    // creating class object
    $john = new Person("John", "Wick");
    $john->showName();

?>
```

初始化对象...我的名字是:疾速追杀摧毁物体...

正如我们在上面的输出中看到的，当 PHP 程序结束时，就在它之前，PHP 启动了所创建对象的释放，因此调用了**析构器**方法。

析构器方法不能接受任何参数，并且在对象被删除之前被调用，这发生在对象没有引用或者 PHP 脚本完成执行的时候。

**注意:**如果你看到一个 PHP 类的函数与类名同名，那么这个函数将充当构造器。在 PHP 的旧版本中，构造器不是使用`__construct()`名称定义的，但是它曾经和类名同名，就像[核心 Java](/java/overview-of-java.php) 一样。

例如:

```php
<?php
    class Person {
        // first name of person
        private $fname;
        // last name of person
        private $lname;

        // Constructor
        public function Person($fname, $lname) {
            echo "Initialising the object...<br/>"; 
            $this->fname = $fname;
            $this->lname = $lname;
        }

        // public method to show name
        public function showName() {
            echo "My name is: " . $this->fname . " " . $this->lname . "<br/>"; 
        }
    }

    // creating class object
    $john = new Person("John", "Wick");
    $john->showName();

?>
```

* * *

* * *