# PHP 继承

> 原文：<https://www.studytonight.com/php/php-inheritance>

在面向对象编程中，继承使[类](php-class)能够使用现有类的属性和方法。在编码的时候，我们经常会遇到这样的情况:我们必须创建一个新的类，它具有现有类的所有功能和一些附加方法，更像是对现有类的扩展，在这种情况下，我们可以将现有类的所有属性和方法复制到新类中，使它们在新类中可用，或者我们可以简单地继承新类中的旧类。

迷茫？让我们举一个简单的例子来理解它。考虑一个有基本方法的类`Human`，比如`walk()`、`eat()`、`hear()`、`see()`等。现在如果我们要为男性和女性再创建两个名为`Male`和`Female`的类，拥有类`Human`的所有属性和方法，以及一些仅适用于`Male`和`Female`的特定特性，我们可以通过继承`Male`和`Female`类中的`Human`类来实现。

继承的类称为**父**类(或**超**类或**基**类)，而继承其他类的类称为**子**类(或**子**类或**派生**类)。

在上例中，`Human`为父类，`Male`和`Female`为子类。

> 一个类可以被多个类继承。

**继承**如果我们想创建几个类似的类，非常有用。我们可以将公共属性和方法放在一个父类中，然后在子类中继承它。

而对于破坏对象**使用析构器**方法。

* * *

## 继承类的语法

在 PHP 中，`extends`关键字用于指定**父类**的名称，同时定义**子类**。例如，

```php
<?php
    class Human {
        // parent class code
    }

    class Male extends Human {
        // child class code
    }

    class Female extends Human {
        // child class code
    }
?>
```

使用继承时需要记住的一些要点是:

1.  子类只能访问和使用父类上的**非私有**属性和方法。
2.  子类也可以有自己的方法，但父类没有。
3.  子类也可以重写父类中定义的方法，并为其提供自己的实现。

让我们在`Human`类中添加一些方法，看看如何在子类`Male`和`Female`中使用它们。

```php
<?php
    // parent class
    class Human {
        // public property name
        public $name;

        // public function walk
        public function walk() {
            echo $this->name. " is walking...<br/>";
        }

        // public function see
        public function see() {
            echo $this->name. " is seeing...<br/>";
        }
    }

    // child class
    class Male extends Human {
        // No code in child
    }

    // child class
    class Female extends Human {
        // No code in child
    }

    $male = new Male();
    $male->name = "Adam";

    $female = new Female();
    $female->name = "Eve";

    // calling Human class methods
    // check the output (hehe, pun intended)
    $female->walk();
    $male->see();

?>
```

夏娃正在走路...亚当看见了...

从上面的代码中可以看到，两个子类都是空的，我们只继承了两个子类中的类`Human`，这允许它们访问和使用父类上的成员属性和方法。

* * *

## 有自己的方法和属性的子类

当子类继承父类时，它可以访问和使用父类的所有非私有成员。我们知道这一点，但是一个子类可以有自己的成员属性和方法吗？是的，它可以有。让我们举另一个例子来看看我们如何做到这一点:

```php
<?php
    // parent class
    class Vehicle {
        // public property name
        public $name;

        // public function start
        public function start() {
            echo $this->name. " - Engine start...<br/>";
        }

        // public function stop
        public function stop() {
            echo $this->name. " - Engine stop...<br/>";
        }
    }

    // child class
    class Car extends Vehicle {

        public function drive() {
            echo "I am " . $this->name . "<br/>";
            echo "Lets go on a drive...";
        }

    }

    // child class
    class Motorcycle extends Vehicle {

        // motorcycle specific properties
        // and methods

    }

    $car = new Car();
    $car->name = "Mercedes benz";

    // calling parent class method
    $car->start();

    // calling child class method
    $car->drive();

?>
```

奔驰-发动机启动...我是奔驰，我们去兜风吧...

当一个类继承另一个类时，它的优势是能够使用父类中定义的属性和方法，而无需再次定义它们。也可以像其他普通类一样有自己的属性和方法。

* * *

## `protected`访问修饰符

我们了解了各种[访问修饰符](php-access-modifiers)，以及如何使用它们来控制类的各种属性和方法的访问。

当子类继承父类时，它只能访问和重用非私有属性和方法。但是我们不应该对属性使用`public`访问修饰符，因为这样属性也可以从类外访问。

为了只允许子类访问父类的属性和方法，我们可以使用`protected`访问修饰符。

当我们将类的任何**属性**或**方法**定义为`protected`时，这些属性和方法只能在继承该类的子类中访问。

让我们举个例子:

```php
<?php
    // parent class
    class Vehicle {
        // protected property name
        protected $name;

        // public function start
        public function start() {
            echo $this->name. " - Engine start...<br/>";
        }

        // public function stop
        public function stop() {
            echo $this->name. " - Engine stop...<br/>";
        }
    }

    // child class
    class Car extends Vehicle {

        public function drive() {
            // accessing name variable of Car class
            echo "I am " . $this->name . "<br/>";
            echo "Lets go on a drive...";
        }

    }

    $car = new Car();
    $car->name = "Mercedes benz";

    // calling parent class method
    $car->start();

    // calling child class method
    $car->drive();

?>
```

奔驰-发动机启动...我是奔驰，我们去兜风吧...

在上面的例子中，我们已经将`name`变量设为`protected`，尝试运行与`private`同名的代码，您将得到以下错误:

注意:未定义的属性...

* * *

## 重写父类方法

如果一个子类想使用父类方法，但又略有不同，该怎么办？它可以通过重写父类中定义的方法的定义并提供自己的定义来做到这一点。这被称为**方法覆盖**。

让我们举个例子来理解这个概念:

```php
<?php
    // parent class
    class Vehicle {
        // public property name
        public $name;

        // public method
        public function drive() {
            echo "Vehicle class drive method...<br/>";
        }
    }

    // child class
    class Car extends Vehicle {

        public function drive() {
            echo "Car class drive method...<br/>";
        }

    }

    // child class
    class Motorcycle extends Vehicle {

        public function drive() {
            echo "Motorcycle class drive method...<br/>";
        }

    }

    $car = new Car();
    $car->name = "Mercedes benz";

    // calling child class method
    $car->drive();

    $bike = new Motorcycle();
    $bike->name = "Triumph Tiger";

    // calling child class method
    $bike->drive();

?>
```

汽车级驱动方法...摩托车级驱动方法...

在上面的代码中，我们有一个名为`Vehicle`的父类和两个扩展父类的子类，即`Car`和`Motorcycle`。在父类中，我们有一个方法`drive()`，我们已经在子类中覆盖了这个方法，并为它提供了不同的定义。

如果不希望任何子类重写父类方法，该怎么办？

如果我们愿意，我们可以将父类中的方法定义为`final`。

让我们看看如果我们试图覆盖一个`final`方法会发生什么。

```php
<?php
    // parent class
    class Vehicle {
        // public property name
        public $name;

        // public method
        final public function drive() {
            echo "Vehicle class drive method...<br/>";
        }
    }

    // child class
    class Car extends Vehicle {

        public function drive() {
            echo "Car class drive method...<br/>";
        }

    }

    $car = new Car();
    $car->name = "Mercedes benz";

    // calling child class method
    $car->drive();

?>
```

致命错误:无法覆盖最终方法车辆::驱动器()

* * *

* * *