# PHP 抽象类和方法

> 原文：<https://www.studytonight.com/php/php-abstract-class-and-methods>

当可以使用`abstract`关键字定义一个类抽象时。定义为抽象的类不能被实例化。

下面是一些关于抽象类和方法的要点:

1.  抽象类可以像任何其他普通类一样拥有方法和属性。
2.  抽象类不能被实例化，因此我们需要创建一个扩展它的子类，然后我们可以创建子类的对象。
3.  如果一个类只有一个抽象方法，那么这个类也应该是抽象的。
4.  抽象方法只是声明，其中我们提供了方法和参数的名称，而主体部分是空的。

如果你无法理解，不要担心。我们将通过例子一步一步地介绍所有的要点，让我们从理解如何创建一个抽象类开始。

* * *

## 创建`abstract`类

要声明一个类抽象，我们需要在类名前使用`abstract`关键字。

让我们举个例子:

```php
<?php
    // abstract class
    abstract class Vehicle {

        // abstract function mileage
        abstract public function mileage() {

        }
    }

?>
```

在上例中，我们的类`Vehicle`是一个抽象类，它有一个抽象方法。

创建抽象类背后的思想是约束开发人员遵循一套准则，例如，如果您想创建一个扩展我们的类的新类`Vehicle`，那么您必须为抽象方法`mileage()`提供定义，否则子类也应该是抽象的。因此，所有子类都必须为方法`mileage()`提供定义。

* * *

## 抽象类中的非抽象方法

任何甚至只有一个抽象方法的类都必须声明为抽象的。但是抽象类也可以有非抽象方法，子类可以直接访问和使用这些方法，而无需重写它们。

让我们扩展上面的例子，在我们的类`Vehicle`中包含一个非抽象方法:

```php
<?php
    // abstract class
    abstract class Vehicle {

        // protected variable
        protected $name;

        // non-abstract public function start
        public function start() {
            echo $this->name. " - Engine start...<br/>";
        }

        // non-abstract public function stop
        public function stop() {
            echo $this->name. " - Engine stop...<br/>";
        }

        // non-abstract public function setName
        public function setName($name) {
            $this->name = $name;
        }

        // abstract function mileage
        abstract public function mileage() {

        }
    }

?>
```

在上面的代码中，我们在抽象的`Vehicle`类中添加了三个非抽象的方法，即`start()`、`stop()`和`setName()`。

* * *

## 继承抽象类

就像任何其他类一样，我们也可以创建扩展抽象类的类。

这里唯一的区别是子类**必须为抽象父类中声明的抽象方法提供定义**。

如果子类没有为抽象方法提供定义，那么它也应该被定义为抽象类。

让我们创建两个继承类`Vehicle`的子类，它们将有抽象方法`mileage()`的定义:

```php
<?php
    // child class
    class Car extends Vehicle {

        public function mileage() {
            echo "I am " . $this->name . "<br/>";
            echo "My mileage range is - 15 to 22 Km/L";
        }

    }

?>
```

我们可以有任意多的子类，让我们有另一个类:

```php
<?php

    // child class
    class Motorcycle extends Vehicle {

        public function mileage() {
            echo "I am " . $this->name . "<br/>";
            echo "My mileage range is - 35 to 47 Km/L";
        }

    }

?>
```

如上所述，抽象类不能有任何对象，一旦我们定义了合适的子类，我们就可以为它们创建对象。

```php
<?php

    $car = new Car();
    $car->setName("BMW X1");
    $car->mileage();

?>
```

我是宝马 X1 我的里程范围是- 15 到 22 公里/升

如果你想尝试，继续尝试创建类`Vehicle`的对象，你会得到一个错误。

* * *

* * *