# PHP 接口

> 原文：<https://www.studytonight.com/php/php-interfaces>

就像[抽象类](php-abstract-class-and-methods)、**接口**也是为了定义继承接口的类的蓝图而创建的。接口没有抽象的方法，只有`public`没有定义的方法，继承接口的类必须为接口内部声明的方法提供定义。

* * *

## 定义 PHP 接口的语法

就像使用关键字`class`定义类一样，使用关键字`interface`后跟接口名称来定义接口。

```php
<?php
    // interface declaration
    interface NameOfInterface {

    }

?>
```

一个类使用`implements`关键字从接口继承并实现接口中声明的方法。

```php
<?php
    // class declaration
    class SomeClass implements NameOfInterface {

    }

?>
```

* * *

## 举个例子

让我们举一个简单的例子，我们将创建一个接口，其中声明了一些方法，实现它的类将被绑定来为这些方法提供定义。

下面是我们的界面:

```php
<?php
    // interface declaration
    interface WebApp {

        // methods declaration
        public function login($email, $password);

        public function register($email, $password, $username);

        public function logout();

    }

?>
```

我们定义了一个名为`WebApp`的接口，其中声明了三个抽象方法，分别是`login()`、`register()`和`logout()`。正如您在上面的代码中看到的，我们还提供了方法将接受的参数。

现在让我们创建一个实现上述接口的类:

```php
<?php
    // class declaration
    class Studytonight implements WebApp {

        // methods definition
        public function login($email, $password) {
            echo "Login the user with email: " . $email;
        }

        public function register($email, $password, $username) {
            echo "User registered: Email=".$email." and Username=".$username;
        }

        public function logout() {
            echo "User logged out!";
        }

    }

?>
```

在上面的类中，我们已经实现了接口`WebApp`，并为接口中声明的所有方法提供了定义。

* * *

### 实现多接口

一个类也可以实现多个接口。在这种情况下，类必须为类实现的所有接口中声明的方法提供定义。

让我们创建另一个界面:

```php
<?php
    // interface declaration
    interface CMS {

        // methods declaration
        public function publishPost($post);

    }

?>
```

现在我们也把上面的界面添加到我们的类`Studytonight`中:

```php
<?php
    // class declaration
    class Studytonight implements WebApp, CMS {

        // methods definition
        public function login($email, $password) {
            echo "Login the user with email: " . $email;
        }

        public function register($email, $password, $username) {
            echo "User registered: Email=".$email." and Username=".$username;
        }

        public function logout() {
            echo "User logged out!";
        }

        public function publishPost($post) {
            echo $post." published!";
        }

    }

?>
```

现在我们的类`Studytonight`实现了两个接口。

需要注意的一些要点:

*   接口中声明的所有方法都是`public`，不以`abstract`关键字开头。
*   如果我们甚至没有实现接口中声明的单个方法，那么在实现接口的类中，我们将会得到一个错误。
*   接口没有变量。

如果你无法理解，不要担心。我们将通过例子一步一步地介绍所有的要点，让我们从理解如何创建一个抽象类开始。

* * *

## `abstract`类与接口的区别

下面是抽象类和接口之间的一些重要区别:

| 连接 | 抽象类 |
| 接口中不能有具体的方法，即有定义的方法。 | 抽象类中既可以有`abstract`方法，也可以有具体方法。 |
| 界面中声明的所有方法都应该是`public` | 抽象类可以有`public`、`private`和`protected`等方法。 |
| 一个类可以实现多个接口。 | 一个类只能扩展一个抽象类。 |

* * *

* * *