# PHP 错误处理

> 原文：<https://www.studytonight.com/php/php-error-handling>

在学习如何处理 PHP 中的错误之前，我们应该先知道什么是错误。

当一段代码返回意外结果或由于某些不正确的代码而突然停止时，例如**除以零**或**无限循环**等，则称发生了**错误。**

在 PHP 中，我们可以设置 PHP 配置，在浏览器中显示或隐藏错误消息。

PHP 提供了多种处理错误的方法，

1.  使用条件语句或`die()`函数处理代码错误
2.  使用**自定义错误处理程序**
3.  PHP 错误报告

让我们用例子来说明每一个。

* * *

## 使用`die()`功能

PHP 中的`die()`功能用于显示任何消息，**同时退出当前脚本的**。因此，一旦检测到错误情况，就可以使用`die()`函数退出代码执行。

当我们试图用零除一个数时，或者试图打开一个不存在的文件时，可能会发生错误，让我们举个例子，看看如何使用`die()`函数或条件语句来处理错误情况。

```php
<?php

    $fileName = "noerror.txt";
    // opening the file
    fopen($fileName, "r")
    or die("Unable to open file $fileName");

?>
```

在上面的代码片段中，如果给定位置没有名为**的文件，我们将在屏幕上获得消息*无法打开文件 noerror.txt* 。**

`die()`函数是`exit()`函数的别名，也用于退出代码执行。

现在让我们看看如何使用条件语句来处理错误情况。当我们事先知道可能导致错误的情况时，这种类型的错误处理是有用的。

例如，下面的代码将导致错误:

```php
<?php

    function division($numerator, $denominator) {
        // perform division operation
        echo $numerator / $denominator;
    }

    // calling the function
    division(7, 0);

?>
```

警告:除以零...

在这种情况下，当我们知道某个条件会导致错误时，我们可以使用**条件**语句来处理会导致错误的角情况。让我们修复上面的代码:

```php
<?php

    function division($numerator, $denominator) {
        // use if statement to check for zero
        if($denominator != 0) {
            echo $numerator / $denominator;
        }
        else {
            echo "Division by zero(0) no allowed!";
        }
    }

    // calling the function
    division(7, 0);

?>
```

不允许除以零(0)！

正如您在上面的代码中所看到的，错误情况得到了处理。现在我们的代码不会在 scree 上显示任何错误，而是会显示一条消息并优雅地退出。

* * *

## 使用自定义错误处理程序

在 PHP 中，我们可以使用我们的自定义方法来显示任何消息，或者在发生错误时执行任何代码。我们所要做的就是使用函数`set_error_handler()`将我们的方法设置为 PHP 的**默认错误处理程序**

让我们举个例子:

```php
<?php

    // custom function to handle error
    function studytonight_error_handler($error_no, $error_msg) {
        echo "Oops! Something unexpected happen...";
        echo "Possible reason: " . $error_msg;
        echo "We are working on it.";
    }

    // set the above function s default error handler
    set_error_handler("studytonight_error_handler");

    $result = 7 / 0;

?>
```

哎呀！意想不到的事情发生了...可能的原因:除以零我们正在努力。

我们可以用参数`$error_no`和`$error_msg`定义我们自己的函数，并且可以按照我们想要的方式处理它们。我们可以显示自定义消息，记录数据库中的错误，发送电子邮件给开发者报告错误等。

* * *

## PHP 错误报告

PHP 提供了默认的错误报告机制，当错误发生时，可以用来在屏幕上显示消息。

错误处理是为了优雅地处理代码中的错误，并为最终用户提供更好的用户体验。

我们可以使用 PHP 函数`error_reporting()`设置显示哪些错误，隐藏哪些错误。

以下是该函数的语法:

```php
<?php
    // error reporting function
    error_reporting($reporting_level);

?>
```

变量`$reporting_level`的值定义了显示哪个错误和隐藏哪个错误，如果我们没有为其提供任何值，错误报告将被设置为**默认值**。

以下是我们可以为设置各种错误级别提供的值:

| 报告级别 | 描述 |
| 电子警告 | 仅显示警告消息，不停止脚本的执行。 |
| E _ NOTICE | 显示正常代码执行过程中出现的注意事项。 |
| E_USER_ERROR | 显示用户生成的错误，即自定义错误处理程序。 |
| 电子用户警告 | 显示用户生成的警告消息。 |
| 电子用户通知 | 显示用户生成的通知。 |
| E _ RECOVERABLE _ ERROR | 显示非致命错误。 |
| E_ALL | 显示所有错误和警告。 |

这就引出了 PHP 中错误处理的结论。在下一个教程中，我们将学习 **[【异常处理】](php-exception-try-catch)** 。

* * *

* * *