# PHP 异常处理

> 原文：<https://www.studytonight.com/php/php-exception-try-catch>

在[之前的教程](php-error-handling)中，我们介绍了错误处理。现在问题来了，**异常**和一个**错误**有什么区别。

PHP 5 引入了一种新的面向对象的错误处理方式，称为**异常**。

异常处理用于处理错误，并在发生错误时重定向代码执行过程，这与错误不同，在错误中，代码执行停止，屏幕上显示错误消息。

* * *

## 使用`try`和`catch`块

可导致异常或错误的代码包含在`try`块中，如果没有异常发生，则代码正常执行，而在异常情况下，代码执行退出`try`块并进入`catch`块。

以下是使用`try`和`catch`进行异常处理的语法，

```php
<?php

try {
    //code goes here that could lead to an exception
}
catch (Exception $e) {
    //exception handling code goes here
}

?>
```

* * *

## `throw`异常

如果需要，我们可以使用`throw`关键字手动触发**异常**。`Exception`是一个 PHP 类，是 PHP 中所有异常类的父类。

要抛出异常，我们必须创建一个异常类的对象，然后使用`throw`关键字来触发该异常。

让我们举个例子:

```php
<?php
    // funciton declaration
    function triggerException() {
        // using throw keyword
        throw new Exception("Manually triggering exception...");
    }

?>
```

如果我们调用上面的函数`triggerException()`，那么它将抛出异常。

现在我们可以在`try`块内调用这个函数，并处理`catch()`块中的异常，如下所示:

```php
<?php

try {
    // calling the function
    triggerException();
}
catch (Exception $e) {
    echo "Oops! Some unexpected error occured...";
}

?>
```

哎呀！出现了一些意外错误...

在`catch`块内部，我们也可以使用`getMessage()`方法从异常对象获取消息。

* * *

## 自定义异常类

我们可以通过扩展 PHP 提供的`Exception`类来创建自定义异常类。

下面我们有一个自定义异常类的例子:

```php
<?php
    // custom exception class
    class StudytonightException extends Exception {

        // define constructor
        function __construct() {
            // we can even take arguments if we want
        }

        // we can define class methods if required

    }

?>
```

当您需要自定义错误处理时，自定义异常类非常有用，例如记录数据库中的错误等。

* * *

## 处理多个异常

如果一段代码可以抛出不同类型的异常，并且根据异常的类型我们必须执行一些动作，在这种情况下我们可以有多个`catch`块:

```php
<?php

try {
    // calling the function
    triggerException();
}
catch (StudytonightException $e) {
    // do something here...
}
catch (Exception $e) {
    echo "Oops! Some unexpected error occured...";
}

?>
```

使用多个`catch`块处理多个异常时需要记住的几个要点:

1.  `Exception`班的`catch`块搬运子班必须放在`catch`块搬运`Exception`班的上方。或者换句话说，`Exception`类搬运`catch`块应该最后保留。
2.  `catch`块处理`Exception`类也可以处理其他异常，因为所有异常类都是`Exception`类的子类。

* * *

* * *